//
// Copyright (c) 1997, 2013, Oracle and/or its affiliates. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_x86_32.hpp"
#include "adfiles/ad_x86_32.hpp"
#include "memory/allocation.inline.hpp"
#include "asm/assembler.hpp"
#include "code/vmreg.hpp"
#include "gc_interface/collectedHeap.inline.hpp"
#include "oops/compiledICHolderOop.hpp"
#include "oops/markOop.hpp"
#include "oops/methodOop.hpp"
#include "oops/oop.inline.hpp"
#include "oops/oop.inline2.hpp"
#include "opto/cfgnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "assembler_x86.inline.hpp"
#include "nativeInst_x86.hpp"
#include "vmreg_x86.inline.hpp"

//SourceForm

#line 197 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

#define   RELOC_IMM32    Assembler::imm_operand
#define   RELOC_DISP32   Assembler::disp32_operand

#define __ _masm.

// How to find the high register of a Long pair, given the low register
#define   HIGH_FROM_LOW(x) ((x)+2)

// These masks are used to provide 128-bit aligned bitmasks to the XMM
// instructions, to allow sign-masking or sign-bit flipping.  They allow
// fast versions of NegF/NegD and AbsF/AbsD.

// Note: 'double' and 'long long' have 32-bits alignment on x86.
static jlong* double_quadword(jlong *adr, jlong lo, jlong hi) {
  // Use the expression (adr)&(~0xF) to provide 128-bits aligned address
  // of 128-bits operands for SSE instructions.
  jlong *operand = (jlong*)(((uintptr_t)adr)&((uintptr_t)(~0xF)));
  // Store the value to a 128-bits operand.
  operand[0] = lo;
  operand[1] = hi;
  return operand;
}

// Buffer for 128-bits masks used by SSE instructions.
static jlong fp_signmask_pool[(4+1)*2]; // 4*128bits(data) + 128bits(alignment)

// Static initialization during VM startup.
static jlong *float_signmask_pool  = double_quadword(&fp_signmask_pool[1*2], CONST64(0x7FFFFFFF7FFFFFFF), CONST64(0x7FFFFFFF7FFFFFFF));
static jlong *double_signmask_pool = double_quadword(&fp_signmask_pool[2*2], CONST64(0x7FFFFFFFFFFFFFFF), CONST64(0x7FFFFFFFFFFFFFFF));
static jlong *float_signflip_pool  = double_quadword(&fp_signmask_pool[3*2], CONST64(0x8000000080000000), CONST64(0x8000000080000000));
static jlong *double_signflip_pool = double_quadword(&fp_signmask_pool[4*2], CONST64(0x8000000000000000), CONST64(0x8000000000000000));

// Offset hacking within calls.
static int pre_call_resets_size() {
  int size = 0;
  Compile* C = Compile::current();
  if (C->in_24_bit_fp_mode()) {
    size += 6; // fldcw
  }
  if (C->max_vector_size() > 16) {
    size += 3; // vzeroupper
  }
  return size;
}

static int preserve_SP_size() {
  return 2;  // op, rm(reg/reg)
}

// !!!!! Special hack to get all type of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.
int MachCallStaticJavaNode::ret_addr_offset() {
  int offset = 5 + pre_call_resets_size();  // 5 bytes from start of call to where return address points
  if (_method_handle_invoke)
    offset += preserve_SP_size();
  return offset;
}

int MachCallDynamicJavaNode::ret_addr_offset() {
  return 10 + pre_call_resets_size();  // 10 bytes from start of call to where return address points
}

static int sizeof_FFree_Float_Stack_All = -1;

int MachCallRuntimeNode::ret_addr_offset() {
  assert(sizeof_FFree_Float_Stack_All != -1, "must have been emitted already");
  return sizeof_FFree_Float_Stack_All + 5 + pre_call_resets_size();
}

// Indicate if the safepoint node needs the polling page as an input.
// Since x86 does have absolute addressing, it doesn't.
bool SafePointNode::needs_polling_address_input() {
  return false;
}

//
// Compute padding required for nodes which need alignment
//

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallStaticJavaDirectNode::compute_padding(int current_offset) const {
  current_offset += pre_call_resets_size();  // skip fldcw, if any
  current_offset += 1;      // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallStaticJavaHandleNode::compute_padding(int current_offset) const {
  current_offset += pre_call_resets_size();  // skip fldcw, if any
  current_offset += preserve_SP_size();   // skip mov rbp, rsp
  current_offset += 1;      // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallDynamicJavaDirectNode::compute_padding(int current_offset) const {
  current_offset += pre_call_resets_size();  // skip fldcw, if any
  current_offset += 5;      // skip MOV instruction
  current_offset += 1;      // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// EMIT_RM()
void emit_rm(CodeBuffer &cbuf, int f1, int f2, int f3) {
  unsigned char c = (unsigned char)((f1 << 6) | (f2 << 3) | f3);
  cbuf.insts()->emit_int8(c);
}

// EMIT_CC()
void emit_cc(CodeBuffer &cbuf, int f1, int f2) {
  unsigned char c = (unsigned char)( f1 | f2 );
  cbuf.insts()->emit_int8(c);
}

// EMIT_OPCODE()
void emit_opcode(CodeBuffer &cbuf, int code) {
  cbuf.insts()->emit_int8((unsigned char) code);
}

// EMIT_OPCODE() w/ relocation information
void emit_opcode(CodeBuffer &cbuf, int code, relocInfo::relocType reloc, int offset = 0) {
  cbuf.relocate(cbuf.insts_mark() + offset, reloc);
  emit_opcode(cbuf, code);
}

// EMIT_D8()
void emit_d8(CodeBuffer &cbuf, int d8) {
  cbuf.insts()->emit_int8((unsigned char) d8);
}

// EMIT_D16()
void emit_d16(CodeBuffer &cbuf, int d16) {
  cbuf.insts()->emit_int16(d16);
}

// EMIT_D32()
void emit_d32(CodeBuffer &cbuf, int d32) {
  cbuf.insts()->emit_int32(d32);
}

// emit 32 bit value and construct relocation entry from relocInfo::relocType
void emit_d32_reloc(CodeBuffer &cbuf, int d32, relocInfo::relocType reloc,
        int format) {
  cbuf.relocate(cbuf.insts_mark(), reloc, format);
  cbuf.insts()->emit_int32(d32);
}

// emit 32 bit value and construct relocation entry from RelocationHolder
void emit_d32_reloc(CodeBuffer &cbuf, int d32, RelocationHolder const& rspec,
        int format) {
#ifdef ASSERT
  if (rspec.reloc()->type() == relocInfo::oop_type && d32 != 0 && d32 != (int)Universe::non_oop_word()) {
    assert(oop(d32)->is_oop() && (ScavengeRootsInCode || !oop(d32)->is_scavengable()), "cannot embed scavengable oops in code");
  }
#endif
  cbuf.relocate(cbuf.insts_mark(), rspec, format);
  cbuf.insts()->emit_int32(d32);
}

// Access stack slot for load or store
void store_to_stackslot(CodeBuffer &cbuf, int opcode, int rm_field, int disp) {
  emit_opcode( cbuf, opcode );               // (e.g., FILD   [ESP+src])
  if( -128 <= disp && disp <= 127 ) {
    emit_rm( cbuf, 0x01, rm_field, ESP_enc );  // R/M byte
    emit_rm( cbuf, 0x00, ESP_enc, ESP_enc);    // SIB byte
    emit_d8 (cbuf, disp);     // Displacement  // R/M byte
  } else {
    emit_rm( cbuf, 0x02, rm_field, ESP_enc );  // R/M byte
    emit_rm( cbuf, 0x00, ESP_enc, ESP_enc);    // SIB byte
    emit_d32(cbuf, disp);     // Displacement  // R/M byte
  }
}

   // rRegI ereg, memory mem) %{    // emit_reg_mem
void encode_RegMem( CodeBuffer &cbuf, int reg_encoding, int base, int index, int scale, int displace, bool displace_is_oop ) {
  // There is no index & no scale, use form without SIB byte
  if ((index == 0x4) &&
      (scale == 0) && (base != ESP_enc)) {
    // If no displacement, mode is 0x0; unless base is [EBP]
    if ( (displace == 0) && (base != EBP_enc) ) {
      emit_rm(cbuf, 0x0, reg_encoding, base);
    }
    else {                    // If 8-bit displacement, mode 0x1
      if ((displace >= -128) && (displace <= 127)
          && !(displace_is_oop) ) {
        emit_rm(cbuf, 0x1, reg_encoding, base);
        emit_d8(cbuf, displace);
      }
      else {                  // If 32-bit displacement
        if (base == -1) { // Special flag for absolute address
          emit_rm(cbuf, 0x0, reg_encoding, 0x5);
          // (manual lies; no SIB needed here)
          if ( displace_is_oop ) {
            emit_d32_reloc(cbuf, displace, relocInfo::oop_type, 1);
          } else {
            emit_d32      (cbuf, displace);
          }
        }
        else {                // Normal base + offset
          emit_rm(cbuf, 0x2, reg_encoding, base);
          if ( displace_is_oop ) {
            emit_d32_reloc(cbuf, displace, relocInfo::oop_type, 1);
          } else {
            emit_d32      (cbuf, displace);
          }
        }
      }
    }
  }
  else {                      // Else, encode with the SIB byte
    // If no displacement, mode is 0x0; unless base is [EBP]
    if (displace == 0 && (base != EBP_enc)) {  // If no displacement
      emit_rm(cbuf, 0x0, reg_encoding, 0x4);
      emit_rm(cbuf, scale, index, base);
    }
    else {                    // If 8-bit displacement, mode 0x1
      if ((displace >= -128) && (displace <= 127)
          && !(displace_is_oop) ) {
        emit_rm(cbuf, 0x1, reg_encoding, 0x4);
        emit_rm(cbuf, scale, index, base);
        emit_d8(cbuf, displace);
      }
      else {                  // If 32-bit displacement
        if (base == 0x04 ) {
          emit_rm(cbuf, 0x2, reg_encoding, 0x4);
          emit_rm(cbuf, scale, index, 0x04);
        } else {
          emit_rm(cbuf, 0x2, reg_encoding, 0x4);
          emit_rm(cbuf, scale, index, base);
        }
        if ( displace_is_oop ) {
          emit_d32_reloc(cbuf, displace, relocInfo::oop_type, 1);
        } else {
          emit_d32      (cbuf, displace);
        }
      }
    }
  }
}


void encode_Copy( CodeBuffer &cbuf, int dst_encoding, int src_encoding ) {
  if( dst_encoding == src_encoding ) {
    // reg-reg copy, use an empty encoding
  } else {
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, dst_encoding, src_encoding );
  }
}

void emit_cmpfp_fixup(MacroAssembler& _masm) {
  Label exit;
  __ jccb(Assembler::noParity, exit);
  __ pushf();
  //
  // comiss/ucomiss instructions set ZF,PF,CF flags and
  // zero OF,AF,SF for NaN values.
  // Fixup flags by zeroing ZF,PF so that compare of NaN
  // values returns 'less than' result (CF is set).
  // Leave the rest of flags unchanged.
  //
  //    7 6 5 4 3 2 1 0
  //   |S|Z|r|A|r|P|r|C|  (r - reserved bit)
  //    0 0 1 0 1 0 1 1   (0x2B)
  //
  __ andl(Address(rsp, 0), 0xffffff2b);
  __ popf();
  __ bind(exit);
}

void emit_cmpfp3(MacroAssembler& _masm, Register dst) {
  Label done;
  __ movl(dst, -1);
  __ jcc(Assembler::parity, done);
  __ jcc(Assembler::below, done);
  __ setb(Assembler::notEqual, dst);
  __ movzbl(dst, dst);
  __ bind(done);
}


//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int Compile::ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("# MachConstantBaseNode (empty encoding)");
}
#endif


//=============================================================================
#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  Compile* C = ra_->C;

  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove wordSize for return addr which is already pushed.
  framesize -= wordSize;

  if (C->need_stack_bang(framesize)) {
    framesize -= wordSize;
    st->print("# stack bang");
    st->print("\n\t");
    st->print("PUSH   EBP\t# Save EBP");
    if (framesize) {
      st->print("\n\t");
      st->print("SUB    ESP, #%d\t# Create frame",framesize);
    }
  } else {
    st->print("SUB    ESP, #%d\t# Create frame",framesize);
    st->print("\n\t");
    framesize -= wordSize;
    st->print("MOV    [ESP + #%d], EBP\t# Save EBP",framesize);
  }

  if (VerifyStackAtCalls) {
    st->print("\n\t");
    framesize -= wordSize;
    st->print("MOV    [ESP + #%d], 0xBADB100D\t# Majik cookie for stack depth check",framesize);
  }

  if( C->in_24_bit_fp_mode() ) {
    st->print("\n\t");
    st->print("FLDCW  \t# load 24 bit fpu control word");
  }
  if (UseSSE >= 2 && VerifyFPU) {
    st->print("\n\t");
    st->print("# verify FPU stack (must be clean on entry)");
  }

#ifdef ASSERT
  if (VerifyStackAtCalls) {
    st->print("\n\t");
    st->print("# stack alignment check");
  }
#endif
  st->cr();
}
#endif


void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  int framesize = C->frame_slots() << LogBytesPerInt;

  __ verified_entry(framesize, C->need_stack_bang(framesize), C->in_24_bit_fp_mode());

  C->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    Compile::ConstantTable& constant_table = C->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_); // too many variables; just compute it the hard way
}

int MachPrologNode::reloc() const {
  return 0; // a large enough number
}

//=============================================================================
#ifndef PRODUCT
void MachEpilogNode::format( PhaseRegAlloc *ra_, outputStream* st ) const {
  Compile *C = ra_->C;
  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;

  if (C->max_vector_size() > 16) {
    st->print("VZEROUPPER");
    st->cr(); st->print("\t");
  }
  if (C->in_24_bit_fp_mode()) {
    st->print("FLDCW  standard control word");
    st->cr(); st->print("\t");
  }
  if (framesize) {
    st->print("ADD    ESP,%d\t# Destroy frame",framesize);
    st->cr(); st->print("\t");
  }
  st->print_cr("POPL   EBP"); st->print("\t");
  if (do_polling() && C->is_method_compilation()) {
    st->print("TEST   PollPage,EAX\t! Poll Safepoint");
    st->cr(); st->print("\t");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile *C = ra_->C;

  if (C->max_vector_size() > 16) {
    // Clear upper bits of YMM registers when current compiled code uses
    // wide vectors to avoid AVX <-> SSE transition penalty during call.
    MacroAssembler masm(&cbuf);
    masm.vzeroupper();
  }
  // If method set FPU control word, restore to standard control word
  if (C->in_24_bit_fp_mode()) {
    MacroAssembler masm(&cbuf);
    masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
  }

  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;

  // Note that VerifyStackAtCalls' Majik cookie does not change the frame size popped here

  if (framesize >= 128) {
    emit_opcode(cbuf, 0x81); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d32(cbuf, framesize);
  } else if (framesize) {
    emit_opcode(cbuf, 0x83); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, framesize);
  }

  emit_opcode(cbuf, 0x58 | EBP_enc);

  if (do_polling() && C->is_method_compilation()) {
    cbuf.relocate(cbuf.insts_end(), relocInfo::poll_return_type, 0);
    emit_opcode(cbuf,0x85);
    emit_rm(cbuf, 0x0, EAX_enc, 0x5); // EAX
    emit_d32(cbuf, (intptr_t)os::get_polling_page());
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  Compile *C = ra_->C;
  // If method set FPU control word, restore to standard control word
  int size = C->in_24_bit_fp_mode() ? 6 : 0;
  if (C->max_vector_size() > 16) size += 3; // vzeroupper
  if (do_polling() && C->is_method_compilation()) size += 6;

  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;

  size++; // popl rbp,

  if (framesize >= 128) {
    size += 6;
  } else {
    size += framesize ? 3 : 0;
  }
  return size;
}

int MachEpilogNode::reloc() const {
  return 0; // a large enough number
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

int MachEpilogNode::safepoint_offset() const { return 0; }

//=============================================================================

enum RC { rc_bad, rc_int, rc_float, rc_xmm, rc_stack };
static enum RC rc_class( OptoReg::Name reg ) {

  if( !OptoReg::is_valid(reg)  ) return rc_bad;
  if (OptoReg::is_stack(reg)) return rc_stack;

  VMReg r = OptoReg::as_VMReg(reg);
  if (r->is_Register()) return rc_int;
  if (r->is_FloatRegister()) {
    assert(UseSSE < 2, "shouldn't be used in SSE2+ mode");
    return rc_float;
  }
  assert(r->is_XMMRegister(), "must be");
  return rc_xmm;
}

static int impl_helper( CodeBuffer *cbuf, bool do_size, bool is_load, int offset, int reg,
                        int opcode, const char *op_str, int size, outputStream* st ) {
  if( cbuf ) {
    emit_opcode  (*cbuf, opcode );
    encode_RegMem(*cbuf, Matcher::_regEncode[reg], ESP_enc, 0x4, 0, offset, false);
#ifndef PRODUCT
  } else if( !do_size ) {
    if( size != 0 ) st->print("\n\t");
    if( opcode == 0x8B || opcode == 0x89 ) { // MOV
      if( is_load ) st->print("%s   %s,[ESP + #%d]",op_str,Matcher::regName[reg],offset);
      else          st->print("%s   [ESP + #%d],%s",op_str,offset,Matcher::regName[reg]);
    } else { // FLD, FST, PUSH, POP
      st->print("%s [ESP + #%d]",op_str,offset);
    }
#endif
  }
  int offset_size = (offset == 0) ? 0 : ((offset <= 127) ? 1 : 4);
  return size+3+offset_size;
}

// Helper for XMM registers.  Extra opcode bits, limited syntax.
static int impl_x_helper( CodeBuffer *cbuf, bool do_size, bool is_load,
                         int offset, int reg_lo, int reg_hi, int size, outputStream* st ) {
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    if (reg_lo+1 == reg_hi) { // double move?
      if (is_load) {
        __ movdbl(as_XMMRegister(Matcher::_regEncode[reg_lo]), Address(rsp, offset));
      } else {
        __ movdbl(Address(rsp, offset), as_XMMRegister(Matcher::_regEncode[reg_lo]));
      }
    } else {
      if (is_load) {
        __ movflt(as_XMMRegister(Matcher::_regEncode[reg_lo]), Address(rsp, offset));
      } else {
        __ movflt(Address(rsp, offset), as_XMMRegister(Matcher::_regEncode[reg_lo]));
      }
    }
#ifndef PRODUCT
  } else if (!do_size) {
    if (size != 0) st->print("\n\t");
    if (reg_lo+1 == reg_hi) { // double move?
      if (is_load) st->print("%s %s,[ESP + #%d]",
                              UseXmmLoadAndClearUpper ? "MOVSD " : "MOVLPD",
                              Matcher::regName[reg_lo], offset);
      else         st->print("MOVSD  [ESP + #%d],%s",
                              offset, Matcher::regName[reg_lo]);
    } else {
      if (is_load) st->print("MOVSS  %s,[ESP + #%d]",
                              Matcher::regName[reg_lo], offset);
      else         st->print("MOVSS  [ESP + #%d],%s",
                              offset, Matcher::regName[reg_lo]);
    }
#endif
  }
  int offset_size = (offset == 0) ? 0 : ((offset <= 127) ? 1 : 4);
  // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
  return size+5+offset_size;
}


static int impl_movx_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                            int src_hi, int dst_hi, int size, outputStream* st ) {
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    if (src_lo+1 == src_hi && dst_lo+1 == dst_hi) { // double move?
      __ movdbl(as_XMMRegister(Matcher::_regEncode[dst_lo]),
                as_XMMRegister(Matcher::_regEncode[src_lo]));
    } else {
      __ movflt(as_XMMRegister(Matcher::_regEncode[dst_lo]),
                as_XMMRegister(Matcher::_regEncode[src_lo]));
    }
#ifndef PRODUCT
  } else if (!do_size) {
    if (size != 0) st->print("\n\t");
    if (UseXmmRegToRegMoveAll) {//Use movaps,movapd to move between xmm registers
      if (src_lo+1 == src_hi && dst_lo+1 == dst_hi) { // double move?
        st->print("MOVAPD %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      } else {
        st->print("MOVAPS %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      }
    } else {
      if( src_lo+1 == src_hi && dst_lo+1 == dst_hi ) { // double move?
        st->print("MOVSD  %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      } else {
        st->print("MOVSS  %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      }
    }
#endif
  }
  // VEX_2bytes prefix is used if UseAVX > 0, and it takes the same 2 bytes as SIMD prefix.
  // Only MOVAPS SSE prefix uses 1 byte.
  int sz = 4;
  if (!(src_lo+1 == src_hi && dst_lo+1 == dst_hi) &&
      UseXmmRegToRegMoveAll && (UseAVX == 0)) sz = 3;
  return size + sz;
}

static int impl_movgpr2x_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                            int src_hi, int dst_hi, int size, outputStream* st ) {
  // 32-bit
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    __ movdl(as_XMMRegister(Matcher::_regEncode[dst_lo]),
             as_Register(Matcher::_regEncode[src_lo]));
#ifndef PRODUCT
  } else if (!do_size) {
    st->print("movdl   %s, %s\t# spill", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
#endif
  }
  return 4;
}


static int impl_movx2gpr_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                                 int src_hi, int dst_hi, int size, outputStream* st ) {
  // 32-bit
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    __ movdl(as_Register(Matcher::_regEncode[dst_lo]),
             as_XMMRegister(Matcher::_regEncode[src_lo]));
#ifndef PRODUCT
  } else if (!do_size) {
    st->print("movdl   %s, %s\t# spill", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
#endif
  }
  return 4;
}

static int impl_mov_helper( CodeBuffer *cbuf, bool do_size, int src, int dst, int size, outputStream* st ) {
  if( cbuf ) {
    emit_opcode(*cbuf, 0x8B );
    emit_rm    (*cbuf, 0x3, Matcher::_regEncode[dst], Matcher::_regEncode[src] );
#ifndef PRODUCT
  } else if( !do_size ) {
    if( size != 0 ) st->print("\n\t");
    st->print("MOV    %s,%s",Matcher::regName[dst],Matcher::regName[src]);
#endif
  }
  return size+2;
}

static int impl_fp_store_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int src_hi, int dst_lo, int dst_hi,
                                 int offset, int size, outputStream* st ) {
  if( src_lo != FPR1L_num ) {      // Move value to top of FP stack, if not already there
    if( cbuf ) {
      emit_opcode( *cbuf, 0xD9 );  // FLD (i.e., push it)
      emit_d8( *cbuf, 0xC0-1+Matcher::_regEncode[src_lo] );
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("FLD    %s",Matcher::regName[src_lo]);
#endif
    }
    size += 2;
  }

  int st_op = (src_lo != FPR1L_num) ? EBX_num /*store & pop*/ : EDX_num /*store no pop*/;
  const char *op_str;
  int op;
  if( src_lo+1 == src_hi && dst_lo+1 == dst_hi ) { // double store?
    op_str = (src_lo != FPR1L_num) ? "FSTP_D" : "FST_D ";
    op = 0xDD;
  } else {                   // 32-bit store
    op_str = (src_lo != FPR1L_num) ? "FSTP_S" : "FST_S ";
    op = 0xD9;
    assert( !OptoReg::is_valid(src_hi) && !OptoReg::is_valid(dst_hi), "no non-adjacent float-stores" );
  }

  return impl_helper(cbuf,do_size,false,offset,st_op,op,op_str,size, st);
}

// Next two methods are shared by 32- and 64-bit VM. They are defined in x86.ad.
static int vec_mov_helper(CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                          int src_hi, int dst_hi, uint ireg, outputStream* st);

static int vec_spill_helper(CodeBuffer *cbuf, bool do_size, bool is_load,
                            int stack_offset, int reg, uint ireg, outputStream* st);

static int vec_stack_to_stack_helper(CodeBuffer *cbuf, bool do_size, int src_offset,
                                     int dst_offset, uint ireg, outputStream* st) {
  int calc_size = 0;
  int src_offset_size = (src_offset == 0) ? 0 : ((src_offset < 0x80) ? 1 : 4);
  int dst_offset_size = (dst_offset == 0) ? 0 : ((dst_offset < 0x80) ? 1 : 4);
  switch (ireg) {
  case Op_VecS:
    calc_size = 3+src_offset_size + 3+dst_offset_size;
    break;
  case Op_VecD:
    calc_size = 3+src_offset_size + 3+dst_offset_size;
    src_offset += 4;
    dst_offset += 4;
    src_offset_size = (src_offset == 0) ? 0 : ((src_offset < 0x80) ? 1 : 4);
    dst_offset_size = (dst_offset == 0) ? 0 : ((dst_offset < 0x80) ? 1 : 4);
    calc_size += 3+src_offset_size + 3+dst_offset_size;
    break;
  case Op_VecX:
    calc_size = 6 + 6 + 5+src_offset_size + 5+dst_offset_size;
    break;
  case Op_VecY:
    calc_size = 6 + 6 + 5+src_offset_size + 5+dst_offset_size;
    break;
  default:
    ShouldNotReachHere();
  }
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    int offset = __ offset();
    switch (ireg) {
    case Op_VecS:
      __ pushl(Address(rsp, src_offset));
      __ popl (Address(rsp, dst_offset));
      break;
    case Op_VecD:
      __ pushl(Address(rsp, src_offset));
      __ popl (Address(rsp, dst_offset));
      __ pushl(Address(rsp, src_offset+4));
      __ popl (Address(rsp, dst_offset+4));
      break;
    case Op_VecX:
      __ movdqu(Address(rsp, -16), xmm0);
      __ movdqu(xmm0, Address(rsp, src_offset));
      __ movdqu(Address(rsp, dst_offset), xmm0);
      __ movdqu(xmm0, Address(rsp, -16));
      break;
    case Op_VecY:
      __ vmovdqu(Address(rsp, -32), xmm0);
      __ vmovdqu(xmm0, Address(rsp, src_offset));
      __ vmovdqu(Address(rsp, dst_offset), xmm0);
      __ vmovdqu(xmm0, Address(rsp, -32));
      break;
    default:
      ShouldNotReachHere();
    }
    int size = __ offset() - offset;
    assert(size == calc_size, "incorrect size calculattion");
    return size;
#ifndef PRODUCT
  } else if (!do_size) {
    switch (ireg) {
    case Op_VecS:
      st->print("pushl   [rsp + #%d]\t# 32-bit mem-mem spill\n\t"
                "popl    [rsp + #%d]",
                src_offset, dst_offset);
      break;
    case Op_VecD:
      st->print("pushl   [rsp + #%d]\t# 64-bit mem-mem spill\n\t"
                "popq    [rsp + #%d]\n\t"
                "pushl   [rsp + #%d]\n\t"
                "popq    [rsp + #%d]",
                src_offset, dst_offset, src_offset+4, dst_offset+4);
      break;
     case Op_VecX:
      st->print("movdqu  [rsp - #16], xmm0\t# 128-bit mem-mem spill\n\t"
                "movdqu  xmm0, [rsp + #%d]\n\t"
                "movdqu  [rsp + #%d], xmm0\n\t"
                "movdqu  xmm0, [rsp - #16]",
                src_offset, dst_offset);
      break;
    case Op_VecY:
      st->print("vmovdqu [rsp - #32], xmm0\t# 256-bit mem-mem spill\n\t"
                "vmovdqu xmm0, [rsp + #%d]\n\t"
                "vmovdqu [rsp + #%d], xmm0\n\t"
                "vmovdqu xmm0, [rsp - #32]",
                src_offset, dst_offset);
      break;
    default:
      ShouldNotReachHere();
    }
#endif
  }
  return calc_size;
}

uint MachSpillCopyNode::implementation( CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream* st ) const {
  // Get registers to move
  OptoReg::Name src_second = ra_->get_reg_second(in(1));
  OptoReg::Name src_first = ra_->get_reg_first(in(1));
  OptoReg::Name dst_second = ra_->get_reg_second(this );
  OptoReg::Name dst_first = ra_->get_reg_first(this );

  enum RC src_second_rc = rc_class(src_second);
  enum RC src_first_rc = rc_class(src_first);
  enum RC dst_second_rc = rc_class(dst_second);
  enum RC dst_first_rc = rc_class(dst_first);

  assert( OptoReg::is_valid(src_first) && OptoReg::is_valid(dst_first), "must move at least 1 register" );

  // Generate spill code!
  int size = 0;

  if( src_first == dst_first && src_second == dst_second )
    return size;            // Self copy, no move

  if (bottom_type()->isa_vect() != NULL) {
    uint ireg = ideal_reg();
    assert((src_first_rc != rc_int && dst_first_rc != rc_int), "sanity");
    assert((src_first_rc != rc_float && dst_first_rc != rc_float), "sanity");
    assert((ireg == Op_VecS || ireg == Op_VecD || ireg == Op_VecX || ireg == Op_VecY), "sanity");
    if( src_first_rc == rc_stack && dst_first_rc == rc_stack ) {
      // mem -> mem
      int src_offset = ra_->reg2offset(src_first);
      int dst_offset = ra_->reg2offset(dst_first);
      return vec_stack_to_stack_helper(cbuf, do_size, src_offset, dst_offset, ireg, st);
    } else if (src_first_rc == rc_xmm && dst_first_rc == rc_xmm ) {
      return vec_mov_helper(cbuf, do_size, src_first, dst_first, src_second, dst_second, ireg, st);
    } else if (src_first_rc == rc_xmm && dst_first_rc == rc_stack ) {
      int stack_offset = ra_->reg2offset(dst_first);
      return vec_spill_helper(cbuf, do_size, false, stack_offset, src_first, ireg, st);
    } else if (src_first_rc == rc_stack && dst_first_rc == rc_xmm ) {
      int stack_offset = ra_->reg2offset(src_first);
      return vec_spill_helper(cbuf, do_size, true,  stack_offset, dst_first, ireg, st);
    } else {
      ShouldNotReachHere();
    }
  }

  // --------------------------------------
  // Check for mem-mem move.  push/pop to move.
  if( src_first_rc == rc_stack && dst_first_rc == rc_stack ) {
    if( src_second == dst_first ) { // overlapping stack copy ranges
      assert( src_second_rc == rc_stack && dst_second_rc == rc_stack, "we only expect a stk-stk copy here" );
      size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_second),ESI_num,0xFF,"PUSH  ",size, st);
      size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_second),EAX_num,0x8F,"POP   ",size, st);
      src_second_rc = dst_second_rc = rc_bad;  // flag as already moved the second bits
    }
    // move low bits
    size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_first),ESI_num,0xFF,"PUSH  ",size, st);
    size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_first),EAX_num,0x8F,"POP   ",size, st);
    if( src_second_rc == rc_stack && dst_second_rc == rc_stack ) { // mov second bits
      size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_second),ESI_num,0xFF,"PUSH  ",size, st);
      size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_second),EAX_num,0x8F,"POP   ",size, st);
    }
    return size;
  }

  // --------------------------------------
  // Check for integer reg-reg copy
  if( src_first_rc == rc_int && dst_first_rc == rc_int )
    size = impl_mov_helper(cbuf,do_size,src_first,dst_first,size, st);

  // Check for integer store
  if( src_first_rc == rc_int && dst_first_rc == rc_stack )
    size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_first),src_first,0x89,"MOV ",size, st);

  // Check for integer load
  if( dst_first_rc == rc_int && src_first_rc == rc_stack )
    size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_first),dst_first,0x8B,"MOV ",size, st);

  // Check for integer reg-xmm reg copy
  if( src_first_rc == rc_int && dst_first_rc == rc_xmm ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad),
            "no 64 bit integer-float reg moves" );
    return impl_movgpr2x_helper(cbuf,do_size,src_first,dst_first,src_second, dst_second, size, st);
  }
  // --------------------------------------
  // Check for float reg-reg copy
  if( src_first_rc == rc_float && dst_first_rc == rc_float ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad) ||
            (src_first+1 == src_second && dst_first+1 == dst_second), "no non-adjacent float-moves" );
    if( cbuf ) {

      // Note the mucking with the register encode to compensate for the 0/1
      // indexing issue mentioned in a comment in the reg_def sections
      // for FPR registers many lines above here.

      if( src_first != FPR1L_num ) {
        emit_opcode  (*cbuf, 0xD9 );           // FLD    ST(i)
        emit_d8      (*cbuf, 0xC0+Matcher::_regEncode[src_first]-1 );
        emit_opcode  (*cbuf, 0xDD );           // FSTP   ST(i)
        emit_d8      (*cbuf, 0xD8+Matcher::_regEncode[dst_first] );
     } else {
        emit_opcode  (*cbuf, 0xDD );           // FST    ST(i)
        emit_d8      (*cbuf, 0xD0+Matcher::_regEncode[dst_first]-1 );
     }
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      if( src_first != FPR1L_num ) st->print("FLD    %s\n\tFSTP   %s",Matcher::regName[src_first],Matcher::regName[dst_first]);
      else                      st->print(             "FST    %s",                            Matcher::regName[dst_first]);
#endif
    }
    return size + ((src_first != FPR1L_num) ? 2+2 : 2);
  }

  // Check for float store
  if( src_first_rc == rc_float && dst_first_rc == rc_stack ) {
    return impl_fp_store_helper(cbuf,do_size,src_first,src_second,dst_first,dst_second,ra_->reg2offset(dst_first),size, st);
  }

  // Check for float load
  if( dst_first_rc == rc_float && src_first_rc == rc_stack ) {
    int offset = ra_->reg2offset(src_first);
    const char *op_str;
    int op;
    if( src_first+1 == src_second && dst_first+1 == dst_second ) { // double load?
      op_str = "FLD_D";
      op = 0xDD;
    } else {                   // 32-bit load
      op_str = "FLD_S";
      op = 0xD9;
      assert( src_second_rc == rc_bad && dst_second_rc == rc_bad, "no non-adjacent float-loads" );
    }
    if( cbuf ) {
      emit_opcode  (*cbuf, op );
      encode_RegMem(*cbuf, 0x0, ESP_enc, 0x4, 0, offset, false);
      emit_opcode  (*cbuf, 0xDD );           // FSTP   ST(i)
      emit_d8      (*cbuf, 0xD8+Matcher::_regEncode[dst_first] );
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("%s  ST,[ESP + #%d]\n\tFSTP   %s",op_str, offset,Matcher::regName[dst_first]);
#endif
    }
    int offset_size = (offset == 0) ? 0 : ((offset <= 127) ? 1 : 4);
    return size + 3+offset_size+2;
  }

  // Check for xmm reg-reg copy
  if( src_first_rc == rc_xmm && dst_first_rc == rc_xmm ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad) ||
            (src_first+1 == src_second && dst_first+1 == dst_second),
            "no non-adjacent float-moves" );
    return impl_movx_helper(cbuf,do_size,src_first,dst_first,src_second, dst_second, size, st);
  }

  // Check for xmm reg-integer reg copy
  if( src_first_rc == rc_xmm && dst_first_rc == rc_int ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad),
            "no 64 bit float-integer reg moves" );
    return impl_movx2gpr_helper(cbuf,do_size,src_first,dst_first,src_second, dst_second, size, st);
  }

  // Check for xmm store
  if( src_first_rc == rc_xmm && dst_first_rc == rc_stack ) {
    return impl_x_helper(cbuf,do_size,false,ra_->reg2offset(dst_first),src_first, src_second, size, st);
  }

  // Check for float xmm load
  if( dst_first_rc == rc_xmm && src_first_rc == rc_stack ) {
    return impl_x_helper(cbuf,do_size,true ,ra_->reg2offset(src_first),dst_first, dst_second, size, st);
  }

  // Copy from float reg to xmm reg
  if( dst_first_rc == rc_xmm && src_first_rc == rc_float ) {
    // copy to the top of stack from floating point reg
    // and use LEA to preserve flags
    if( cbuf ) {
      emit_opcode(*cbuf,0x8D);  // LEA  ESP,[ESP-8]
      emit_rm(*cbuf, 0x1, ESP_enc, 0x04);
      emit_rm(*cbuf, 0x0, 0x04, ESP_enc);
      emit_d8(*cbuf,0xF8);
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("LEA    ESP,[ESP-8]");
#endif
    }
    size += 4;

    size = impl_fp_store_helper(cbuf,do_size,src_first,src_second,dst_first,dst_second,0,size, st);

    // Copy from the temp memory to the xmm reg.
    size = impl_x_helper(cbuf,do_size,true ,0,dst_first, dst_second, size, st);

    if( cbuf ) {
      emit_opcode(*cbuf,0x8D);  // LEA  ESP,[ESP+8]
      emit_rm(*cbuf, 0x1, ESP_enc, 0x04);
      emit_rm(*cbuf, 0x0, 0x04, ESP_enc);
      emit_d8(*cbuf,0x08);
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("LEA    ESP,[ESP+8]");
#endif
    }
    size += 4;
    return size;
  }

  assert( size > 0, "missed a case" );

  // --------------------------------------------------------------------
  // Check for second bits still needing moving.
  if( src_second == dst_second )
    return size;               // Self copy; no move
  assert( src_second_rc != rc_bad && dst_second_rc != rc_bad, "src_second & dst_second cannot be Bad" );

  // Check for second word int-int move
  if( src_second_rc == rc_int && dst_second_rc == rc_int )
    return impl_mov_helper(cbuf,do_size,src_second,dst_second,size, st);

  // Check for second word integer store
  if( src_second_rc == rc_int && dst_second_rc == rc_stack )
    return impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_second),src_second,0x89,"MOV ",size, st);

  // Check for second word integer load
  if( dst_second_rc == rc_int && src_second_rc == rc_stack )
    return impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_second),dst_second,0x8B,"MOV ",size, st);


  Unimplemented();
}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream* st) const {
  implementation( NULL, ra_, false, st );
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation( &cbuf, ra_, false, NULL );
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return implementation( NULL, ra_, true, NULL );
}


//=============================================================================
#ifndef PRODUCT
void BoxLockNode::format( PhaseRegAlloc *ra_, outputStream* st ) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("LEA    %s,[ESP + #%d]",Matcher::regName[reg],offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_encode(this);
  if( offset >= 128 ) {
    emit_opcode(cbuf, 0x8D);      // LEA  reg,[SP+offset]
    emit_rm(cbuf, 0x2, reg, 0x04);
    emit_rm(cbuf, 0x0, 0x04, ESP_enc);
    emit_d32(cbuf, offset);
  }
  else {
    emit_opcode(cbuf, 0x8D);      // LEA  reg,[SP+offset]
    emit_rm(cbuf, 0x1, reg, 0x04);
    emit_rm(cbuf, 0x0, 0x04, ESP_enc);
    emit_d8(cbuf, offset);
  }
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  if( offset >= 128 ) {
    return 7;
  }
  else {
    return 4;
  }
}

//=============================================================================

// emit call stub, compiled java to interpreter
void emit_java_to_interp(CodeBuffer &cbuf ) {
  // Stub is fixed up when the corresponding call is converted from calling
  // compiled code to calling interpreted code.
  // mov rbx,0
  // jmp -1

  address mark = cbuf.insts_mark();  // get mark within main instrs section

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a stub.
  MacroAssembler _masm(&cbuf);

  address base =
  __ start_a_stub(Compile::MAX_stubs_size);
  if (base == NULL)  return;  // CodeBuffer::expand failed
  // static stub relocation stores the instruction address of the call
  __ relocate(static_stub_Relocation::spec(mark), RELOC_IMM32);
  // static stub relocation also tags the methodOop in the code-stream.
  __ movoop(rbx, (jobject)NULL);  // method is zapped till fixup time
  // This is recognized as unresolved by relocs/nativeInst/ic code
  __ jump(RuntimeAddress(__ pc()));

  __ end_a_stub();
  // Update current stubs pointer and restore insts_end.
}
// size of call stub, compiled java to interpretor
uint size_java_to_interp() {
  return 10;  // movl; jmp
}
// relocation entries for call stub, compiled java to interpretor
uint reloc_java_to_interp() {
  return 4;  // 3 in emit_java_to_interp + 1 in Java_Static_Call
}

//=============================================================================
#ifndef PRODUCT
void MachUEPNode::format( PhaseRegAlloc *ra_, outputStream* st ) const {
  st->print_cr(  "CMP    EAX,[ECX+4]\t# Inline cache check");
  st->print_cr("\tJNE    SharedRuntime::handle_ic_miss_stub");
  st->print_cr("\tNOP");
  st->print_cr("\tNOP");
  if( !OptoBreakpoint )
    st->print_cr("\tNOP");
}
#endif

void MachUEPNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler masm(&cbuf);
#ifdef ASSERT
  uint insts_size = cbuf.insts_size();
#endif
  masm.cmpptr(rax, Address(rcx, oopDesc::klass_offset_in_bytes()));
  masm.jump_cc(Assembler::notEqual,
               RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  /* WARNING these NOPs are critical so that verified entry point is properly
     aligned for patching by NativeJump::patch_verified_entry() */
  int nops_cnt = 2;
  if( !OptoBreakpoint ) // Leave space for int3
     nops_cnt += 1;
  masm.nop(nops_cnt);

  assert(cbuf.insts_size() - insts_size == size(ra_), "checking code size of inline cache node");
}

uint MachUEPNode::size(PhaseRegAlloc *ra_) const {
  return OptoBreakpoint ? 11 : 12;
}


//=============================================================================
uint size_exception_handler() {
  // NativeCall instruction size is the same as NativeJump.
  // exception handler starts out as jump and can be patched to
  // a call be deoptimization.  (4932387)
  // Note that this value is also credited (in output.cpp) to
  // the size of the code section.
  return NativeJump::instruction_size;
}

// Emit exception handler code.  Stuff framesize into a register
// and call a VM stub routine.
int emit_exception_handler(CodeBuffer& cbuf) {

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base =
  __ start_a_stub(size_exception_handler());
  if (base == NULL)  return 0;  // CodeBuffer::expand failed
  int offset = __ offset();
  __ jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

uint size_deopt_handler() {
  // NativeCall instruction size is the same as NativeJump.
  // exception handler starts out as jump and can be patched to
  // a call be deoptimization.  (4932387)
  // Note that this value is also credited (in output.cpp) to
  // the size of the code section.
  return 5 + NativeJump::instruction_size; // pushl(); jmp;
}

// Emit deopt handler code.
int emit_deopt_handler(CodeBuffer& cbuf) {

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base =
  __ start_a_stub(size_exception_handler());
  if (base == NULL)  return 0;  // CodeBuffer::expand failed
  int offset = __ offset();
  InternalAddress here(__ pc());
  __ pushptr(here.addr());

  __ jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));
  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

int Matcher::regnum_to_fpu_offset(int regnum) {
  return regnum - 32; // The FP registers are in the second chunk
}

// This is UltraSparc specific, true just means we have fast l2f conversion
const bool Matcher::convL2FSupported(void) {
  return true;
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.
  // On 86 a branch displacement is calculated relative to address
  // of a next instruction.
  offset -= br_size;

  // the short version of jmpConUCF2 contains multiple branches,
  // making the reach slightly less
  if (rule == jmpConUCF2_rule)
    return (-126 <= offset && offset <= 125);
  return (-128 <= offset && offset <= 127);
}

const bool Matcher::isSimpleConstant64(jlong value) {
  // Will one (StoreL ConL) be cheaper than two (StoreI ConI)?.
  return false;
}

// The ecx parameter to rep stos for the ClearArray node is in dwords.
const bool Matcher::init_array_count_is_in_bytes = false;

// Threshold size for cleararray.
const int Matcher::init_array_short_size = 8 * BytesPerLong;

// Needs 2 CMOV's for longs.
const int Matcher::long_cmove_cost() { return 1; }

// No CMOVF/CMOVD with SSE/SSE2
const int Matcher::float_cmove_cost() { return (UseSSE>=1) ? ConditionalMoveLimit : 0; }

// Should the Matcher clone shifts on addressing modes, expecting them to
// be subsumed into complex addressing expressions or compute them into
// registers?  True for Intel but false for most RISCs
const bool Matcher::clone_shift_expressions = true;

// Do we need to mask the count passed to shift instructions or does
// the cpu only look at the lower 5/6 bits anyway?
const bool Matcher::need_masked_shift_count = false;

bool Matcher::narrow_oop_use_complex_address() {
  ShouldNotCallThis();
  return true;
}


// Is it better to copy float constants, or load them directly from memory?
// Intel can load a float constant from a direct address, requiring no
// extra registers.  Most RISCs will have to materialize an address into a
// register first, so they would do better to copy the constant from stack.
const bool Matcher::rematerialize_float_constants = true;

// If CPU can load and store mis-aligned doubles directly then no fixup is
// needed.  Else we split the double into 2 integer pieces and move it
// piece-by-piece.  Only happens when passing doubles into C code as the
// Java calling convention forces doubles to be aligned.
const bool Matcher::misaligned_doubles_ok = true;


void Matcher::pd_implicit_null_fixup(MachNode *node, uint idx) {
  // Get the memory operand from the node
  uint numopnds = node->num_opnds();        // Virtual call for number of operands
  uint skipped  = node->oper_input_base();  // Sum of leaves skipped so far
  assert( idx >= skipped, "idx too low in pd_implicit_null_fixup" );
  uint opcnt     = 1;                 // First operand
  uint num_edges = node->_opnds[1]->num_edges(); // leaves for first operand
  while( idx >= skipped+num_edges ) {
    skipped += num_edges;
    opcnt++;                          // Bump operand count
    assert( opcnt < numopnds, "Accessing non-existent operand" );
    num_edges = node->_opnds[opcnt]->num_edges(); // leaves for next operand
  }

  MachOper *memory = node->_opnds[opcnt];
  MachOper *new_memory = NULL;
  switch (memory->opcode()) {
  case DIRECT:
  case INDOFFSET32X:
    // No transformation necessary.
    return;
  case INDIRECT:
    new_memory = new (C) indirect_win95_safeOper( );
    break;
  case INDOFFSET8:
    new_memory = new (C) indOffset8_win95_safeOper(memory->disp(NULL, NULL, 0));
    break;
  case INDOFFSET32:
    new_memory = new (C) indOffset32_win95_safeOper(memory->disp(NULL, NULL, 0));
    break;
  case INDINDEXOFFSET:
    new_memory = new (C) indIndexOffset_win95_safeOper(memory->disp(NULL, NULL, 0));
    break;
  case INDINDEXSCALE:
    new_memory = new (C) indIndexScale_win95_safeOper(memory->scale());
    break;
  case INDINDEXSCALEOFFSET:
    new_memory = new (C) indIndexScaleOffset_win95_safeOper(memory->scale(), memory->disp(NULL, NULL, 0));
    break;
  case LOAD_LONG_INDIRECT:
  case LOAD_LONG_INDOFFSET32:
    // Does not use EBP as address register, use { EDX, EBX, EDI, ESI}
    return;
  default:
    assert(false, "unexpected memory operand in pd_implicit_null_fixup()");
    return;
  }
  node->_opnds[opcnt] = new_memory;
}

// Advertise here if the CPU requires explicit rounding operations
// to implement the UseStrictFP mode.
const bool Matcher::strict_fp_requires_explicit_rounding = true;

// Are floats conerted to double when stored to stack during deoptimization?
// On x32 it is stored with convertion only when FPU is used for floats.
bool Matcher::float_in_double() { return (UseSSE == 0); }

// Do ints take an entire long register or just half?
const bool Matcher::int_in_long = false;

// Return whether or not this register is ever used as an argument.  This
// function is used on startup to build the trampoline stubs in generateOptoStub.
// Registers not mentioned will be killed by the VM call in the trampoline, and
// arguments in those registers not be available to the callee.
bool Matcher::can_be_java_arg( int reg ) {
  if(  reg == ECX_num   || reg == EDX_num   ) return true;
  if( (reg == XMM0_num  || reg == XMM1_num ) && UseSSE>=1 ) return true;
  if( (reg == XMM0b_num || reg == XMM1b_num) && UseSSE>=2 ) return true;
  return false;
}

bool Matcher::is_spillable_arg( int reg ) {
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con( jlong divisor ) {
  // Use hardware integer DIV instruction when
  // it is faster than a code which use multiply.
  // Only when constant divisor fits into 32 bit
  // (min_jint is excluded to get only correct
  // positive 32 bit values from negative).
  return VM_Version::has_fast_idiv() &&
         (divisor == (int)divisor && divisor != min_jint);
}

// Register for DIVI projection of divmodI
RegMask Matcher::divI_proj_mask() {
  return EAX_REG_mask();
}

// Register for MODI projection of divmodI
RegMask Matcher::modI_proj_mask() {
  return EDX_REG_mask();
}

// Register for DIVL projection of divmodL
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return EBP_REG_mask();
}

// Returns true if the high 32 bits of the value is known to be zero.
bool is_operand_hi32_zero(Node* n) {
  int opc = n->Opcode();
  if (opc == Op_AndL) {
    Node* o2 = n->in(2);
    if (o2->is_Con() && (o2->get_long() & 0xFFFFFFFF00000000LL) == 0LL) {
      return true;
    }
  }
  if (opc == Op_ConL && (n->get_long() & 0xFFFFFFFF00000000LL) == 0LL) {
    return true;
  }
  return false;
}


#line 1445 "../generated/adfiles/ad_x86_32.cpp"


//SourceForm

#line 477 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

  // Float masks come from different places depending on platform.
#ifdef _LP64
  static address float_signmask()  { return StubRoutines::x86::float_sign_mask(); }
  static address float_signflip()  { return StubRoutines::x86::float_sign_flip(); }
  static address double_signmask() { return StubRoutines::x86::double_sign_mask(); }
  static address double_signflip() { return StubRoutines::x86::double_sign_flip(); }
#else
  static address float_signmask()  { return (address)float_signmask_pool; }
  static address float_signflip()  { return (address)float_signflip_pool; }
  static address double_signmask() { return (address)double_signmask_pool; }
  static address double_signflip() { return (address)double_signflip_pool; }
#endif

// Map Types to machine register types
const int Matcher::base2reg[Type::lastype] = {
  Node::NotAMachineReg,0,0, Op_RegI, Op_RegL, 0, Op_RegN,
  Node::NotAMachineReg, Node::NotAMachineReg, /* tuple, array */
  Op_VecS, Op_VecD, Op_VecX, Op_VecY, /* Vectors */
  Op_RegP, Op_RegP, Op_RegP, Op_RegP, Op_RegP, Op_RegP, /* the pointers */
  0, 0/*abio*/,
  Op_RegP /* Return address */, 0, /* the memories */
  Op_RegF, Op_RegF, Op_RegF, Op_RegD, Op_RegD, Op_RegD,
  0  /*bottom*/
};

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  switch (opcode) {
    case Op_PopCountI:
    case Op_PopCountL:
      if (!UsePopCountInstruction)
        return false;
    break;
    case Op_MulVI:
      if ((UseSSE < 4) && (UseAVX < 1)) // only with SSE4_1 or AVX
        return false;
    break;
    case Op_CompareAndSwapL:
#ifdef _LP64
    case Op_CompareAndSwapP:
#endif
      if (!VM_Version::supports_cx8())
        return false;
    break;
  }

  return true;  // Per default match rules are supported.
}

// Max vector size in bytes. 0 if not supported.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  assert(is_java_primitive(bt), "only primitive type vectors");
  if (UseSSE < 2) return 0;
  // SSE2 supports 128bit vectors for all types.
  // AVX2 supports 256bit vectors for all types.
  int size = (UseAVX > 1) ? 32 : 16;
  // AVX1 supports 256bit vectors only for FLOAT and DOUBLE.
  if (UseAVX > 0 && (bt == T_FLOAT || bt == T_DOUBLE))
    size = 32;
  // Use flag to limit vector size.
  size = MIN2(size,(int)MaxVectorSize);
  // Minimum 2 values in vector (or 4 for bytes).
  switch (bt) {
  case T_DOUBLE:
  case T_LONG:
    if (size < 16) return 0;
  case T_FLOAT:
  case T_INT:
    if (size < 8) return 0;
  case T_BOOLEAN:
  case T_BYTE:
  case T_CHAR:
  case T_SHORT:
    if (size < 4) return 0;
    break;
  default:
    ShouldNotReachHere();
  }
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}
const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  // Min size which can be loaded into vector is 4 bytes.
  int size = (type2aelembytes(bt) == 1) ? 4 : 2;
  return MIN2(size,max_size);
}

// Vector ideal reg corresponding to specidied size in bytes
const int Matcher::vector_ideal_reg(int size) {
  assert(MaxVectorSize >= size, "");
  switch(size) {
    case  4: return Op_VecS;
    case  8: return Op_VecD;
    case 16: return Op_VecX;
    case 32: return Op_VecY;
  }
  ShouldNotReachHere();
  return 0;
}

// Only lowest bits of xmm reg are used for vector shift count.
const int Matcher::vector_shift_count_ideal_reg(int size) {
  return Op_VecS;
}

// x86 supports misaligned vectors store/load.
const bool Matcher::misaligned_vectors_ok() {
  return !AlignVector; // can be changed by flag
}

// Helper methods for MachSpillCopyNode::implementation().
static int vec_mov_helper(CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                          int src_hi, int dst_hi, uint ireg, outputStream* st) {
  // In 64-bit VM size calculation is very complex. Emitting instructions
  // into scratch buffer is used to get size in 64-bit VM.
  LP64_ONLY( assert(!do_size, "this method calculates size only for 32-bit VM"); )
  assert(ireg == Op_VecS || // 32bit vector
         (src_lo & 1) == 0 && (src_lo + 1) == src_hi &&
         (dst_lo & 1) == 0 && (dst_lo + 1) == dst_hi,
         "no non-adjacent vector moves" );
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    int offset = __ offset();
    switch (ireg) {
    case Op_VecS: // copy whole register
    case Op_VecD:
    case Op_VecX:
      __ movdqu(as_XMMRegister(Matcher::_regEncode[dst_lo]), as_XMMRegister(Matcher::_regEncode[src_lo]));
      break;
    case Op_VecY:
      __ vmovdqu(as_XMMRegister(Matcher::_regEncode[dst_lo]), as_XMMRegister(Matcher::_regEncode[src_lo]));
      break;
    default:
      ShouldNotReachHere();
    }
    int size = __ offset() - offset;
#ifdef ASSERT
    // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
    assert(!do_size || size == 4, "incorrect size calculattion");
#endif
    return size;
#ifndef PRODUCT
  } else if (!do_size) {
    switch (ireg) {
    case Op_VecS:
    case Op_VecD:
    case Op_VecX:
      st->print("movdqu  %s,%s\t# spill",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      break;
    case Op_VecY:
      st->print("vmovdqu %s,%s\t# spill",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      break;
    default:
      ShouldNotReachHere();
    }
#endif
  }
  // VEX_2bytes prefix is used if UseAVX > 0, and it takes the same 2 bytes as SIMD prefix.
  return 4;
}

static int vec_spill_helper(CodeBuffer *cbuf, bool do_size, bool is_load,
                            int stack_offset, int reg, uint ireg, outputStream* st) {
  // In 64-bit VM size calculation is very complex. Emitting instructions
  // into scratch buffer is used to get size in 64-bit VM.
  LP64_ONLY( assert(!do_size, "this method calculates size only for 32-bit VM"); )
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    int offset = __ offset();
    if (is_load) {
      switch (ireg) {
      case Op_VecS:
        __ movdl(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      case Op_VecD:
        __ movq(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      case Op_VecX:
        __ movdqu(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      case Op_VecY:
        __ vmovdqu(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      default:
        ShouldNotReachHere();
      }
    } else { // store
      switch (ireg) {
      case Op_VecS:
        __ movdl(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      case Op_VecD:
        __ movq(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      case Op_VecX:
        __ movdqu(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      case Op_VecY:
        __ vmovdqu(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      default:
        ShouldNotReachHere();
      }
    }
    int size = __ offset() - offset;
#ifdef ASSERT
    int offset_size = (stack_offset == 0) ? 0 : ((stack_offset < 0x80) ? 1 : 4);
    // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
    assert(!do_size || size == (5+offset_size), "incorrect size calculattion");
#endif
    return size;
#ifndef PRODUCT
  } else if (!do_size) {
    if (is_load) {
      switch (ireg) {
      case Op_VecS:
        st->print("movd    %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
      case Op_VecD:
        st->print("movq    %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
       case Op_VecX:
        st->print("movdqu  %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
      case Op_VecY:
        st->print("vmovdqu %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
      default:
        ShouldNotReachHere();
      }
    } else { // store
      switch (ireg) {
      case Op_VecS:
        st->print("movd    [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
      case Op_VecD:
        st->print("movq    [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
       case Op_VecX:
        st->print("movdqu  [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
      case Op_VecY:
        st->print("vmovdqu [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
      default:
        ShouldNotReachHere();
      }
    }
#endif
  }
  int offset_size = (stack_offset == 0) ? 0 : ((stack_offset < 0x80) ? 1 : 4);
  // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
  return 5+offset_size;
}

static inline jfloat replicate4_imm(int con, int width) {
  // Load a constant of "width" (in bytes) and replicate it to fill 32bit.
  assert(width == 1 || width == 2, "only byte or short types here");
  int bit_width = width * 8;
  jint val = con;
  val &= (1 << bit_width) - 1;  // mask off sign bits
  while(bit_width < 32) {
    val |= (val << bit_width);
    bit_width <<= 1;
  }
  jfloat fval = *((jfloat*) &val);  // coerce to float type
  return fval;
}

static inline jdouble replicate8_imm(int con, int width) {
  // Load a constant of "width" (in bytes) and replicate it to fill 64bit.
  assert(width == 1 || width == 2 || width == 4, "only byte, short or int types here");
  int bit_width = width * 8;
  jlong val = con;
  val &= (((jlong) 1) << bit_width) - 1;  // mask off sign bits
  while(bit_width < 64) {
    val |= (val << bit_width);
    bit_width <<= 1;
  }
  jdouble dval = *((jdouble*) &val);  // coerce to double type
  return dval;
}

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    MacroAssembler _masm(&cbuf);
    __ nop(_count);
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count;
  }

#ifndef PRODUCT
  void MachBreakpointNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("# breakpoint");
  }
#endif

  void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc* ra_) const {
    MacroAssembler _masm(&cbuf);
    __ int3();
  }

  uint MachBreakpointNode::size(PhaseRegAlloc* ra_) const {
    return MachNode::size(ra_);
  }


#line 1773 "../generated/adfiles/ad_x86_32.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // ECX
  'C', // EBX
  'N', // EBP
  'C', // EDI
  'C', // EAX
  'C', // EDX
  'C', // ESI
  'N', // ESP
  'C', // FPR0L
  'C', // FPR0H
  'C', // FPR1L
  'C', // FPR1H
  'C', // FPR2L
  'C', // FPR2H
  'C', // FPR3L
  'C', // FPR3H
  'C', // FPR4L
  'C', // FPR4H
  'C', // FPR5L
  'C', // FPR5H
  'C', // FPR6L
  'C', // FPR6H
  'C', // FPR7L
  'C', // FPR7H
  'C', // XMM0
  'C', // XMM0b
  'C', // XMM0c
  'C', // XMM0d
  'C', // XMM0e
  'C', // XMM0f
  'C', // XMM0g
  'C', // XMM0h
  'C', // XMM1
  'C', // XMM1b
  'C', // XMM1c
  'C', // XMM1d
  'C', // XMM1e
  'C', // XMM1f
  'C', // XMM1g
  'C', // XMM1h
  'C', // XMM2
  'C', // XMM2b
  'C', // XMM2c
  'C', // XMM2d
  'C', // XMM2e
  'C', // XMM2f
  'C', // XMM2g
  'C', // XMM2h
  'C', // XMM3
  'C', // XMM3b
  'C', // XMM3c
  'C', // XMM3d
  'C', // XMM3e
  'C', // XMM3f
  'C', // XMM3g
  'C', // XMM3h
  'C', // XMM4
  'C', // XMM4b
  'C', // XMM4c
  'C', // XMM4d
  'C', // XMM4e
  'C', // XMM4f
  'C', // XMM4g
  'C', // XMM4h
  'C', // XMM5
  'C', // XMM5b
  'C', // XMM5c
  'C', // XMM5d
  'C', // XMM5e
  'C', // XMM5f
  'C', // XMM5g
  'C', // XMM5h
  'C', // XMM6
  'C', // XMM6b
  'C', // XMM6c
  'C', // XMM6d
  'C', // XMM6e
  'C', // XMM6f
  'C', // XMM6g
  'C', // XMM6h
  'C', // XMM7
  'C', // XMM7b
  'C', // XMM7c
  'C', // XMM7d
  'C', // XMM7e
  'C', // XMM7f
  'C', // XMM7g
  'C', // XMM7h
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // ECX
  'E', // EBX
  'E', // EBP
  'E', // EDI
  'C', // EAX
  'C', // EDX
  'E', // ESI
  'N', // ESP
  'C', // FPR0L
  'C', // FPR0H
  'C', // FPR1L
  'C', // FPR1H
  'C', // FPR2L
  'C', // FPR2H
  'C', // FPR3L
  'C', // FPR3H
  'C', // FPR4L
  'C', // FPR4H
  'C', // FPR5L
  'C', // FPR5H
  'C', // FPR6L
  'C', // FPR6H
  'C', // FPR7L
  'C', // FPR7H
  'C', // XMM0
  'C', // XMM0b
  'C', // XMM0c
  'C', // XMM0d
  'C', // XMM0e
  'C', // XMM0f
  'C', // XMM0g
  'C', // XMM0h
  'C', // XMM1
  'C', // XMM1b
  'C', // XMM1c
  'C', // XMM1d
  'C', // XMM1e
  'C', // XMM1f
  'C', // XMM1g
  'C', // XMM1h
  'C', // XMM2
  'C', // XMM2b
  'C', // XMM2c
  'C', // XMM2d
  'C', // XMM2e
  'C', // XMM2f
  'C', // XMM2g
  'C', // XMM2h
  'C', // XMM3
  'C', // XMM3b
  'C', // XMM3c
  'C', // XMM3d
  'C', // XMM3e
  'C', // XMM3f
  'C', // XMM3g
  'C', // XMM3h
  'C', // XMM4
  'C', // XMM4b
  'C', // XMM4c
  'C', // XMM4d
  'C', // XMM4e
  'C', // XMM4f
  'C', // XMM4g
  'C', // XMM4h
  'C', // XMM5
  'C', // XMM5b
  'C', // XMM5c
  'C', // XMM5d
  'C', // XMM5e
  'C', // XMM5f
  'C', // XMM5g
  'C', // XMM5h
  'C', // XMM6
  'C', // XMM6b
  'C', // XMM6c
  'C', // XMM6d
  'C', // XMM6e
  'C', // XMM6f
  'C', // XMM6g
  'C', // XMM6h
  'C', // XMM7
  'C', // XMM7b
  'C', // XMM7c
  'C', // XMM7d
  'C', // XMM7e
  'C', // XMM7f
  'C', // XMM7g
  'C', // XMM7h
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immI2_rule,
  /*   13 */  immI8_rule,
  /*   14 */  immI16_rule,
  /*   15 */  immI_32_rule,
  /*   16 */  immI_1_31_rule,
  /*   17 */  immI_32_63_rule,
  /*   18 */  immI_1_rule,
  /*   19 */  immI_2_rule,
  /*   20 */  immI_3_rule,
  /*   21 */  immP_rule,
  /*   22 */  immP0_rule,
  /*   23 */  immL_rule,
  /*   24 */  immL0_rule,
  /*   25 */  immL_M1_rule,
  /*   26 */  immL_127_rule,
  /*   27 */  immL_32bits_rule,
  /*   28 */  immL32_rule,
  /*   29 */  immDPR0_rule,
  /*   30 */  immDPR1_rule,
  /*   31 */  immDPR_rule,
  /*   32 */  immD_rule,
  /*   33 */  immD0_rule,
  /*   34 */  immFPR0_rule,
  /*   35 */  immFPR1_rule,
  /*   36 */  immFPR_rule,
  /*   37 */  immF_rule,
  /*   38 */  immF0_rule,
  /*   39 */  immI_16_rule,
  /*   40 */  immI_24_rule,
  /*   41 */  immI_255_rule,
  /*   42 */  immI_65535_rule,
  /*   43 */  rRegI_rule,
  /*   44 */  xRegI_rule,
  /*   45 */  eAXRegI_rule,
  /*   46 */  eBXRegI_rule,
  /*   47 */  eCXRegI_rule,
  /*   48 */  eDXRegI_rule,
  /*   49 */  eDIRegI_rule,
  /*   50 */  naxRegI_rule,
  /*   51 */  nadxRegI_rule,
  /*   52 */  ncxRegI_rule,
  /*   53 */  eSIRegI_rule,
  /*   54 */  anyRegP_rule,
  /*   55 */  eRegP_rule,
  /*   56 */  eRegP_no_EBP_rule,
  /*   57 */  naxRegP_rule,
  /*   58 */  nabxRegP_rule,
  /*   59 */  pRegP_rule,
  /*   60 */  eAXRegP_rule,
  /*   61 */  eBXRegP_rule,
  /*   62 */  eCXRegP_rule,
  /*   63 */  eSIRegP_rule,
  /*   64 */  eDIRegP_rule,
  /*   65 */  eBPRegP_rule,
  /*   66 */  eRegL_rule,
  /*   67 */  eADXRegL_rule,
  /*   68 */  eBCXRegL_rule,
  /*   69 */  eADXRegL_low_only_rule,
  /*   70 */  eFlagsReg_rule,
  /*   71 */  eFlagsRegU_rule,
  /*   72 */  eFlagsRegUCF_rule,
  /*   73 */  flagsReg_long_LTGE_rule,
  /*   74 */  flagsReg_long_EQNE_rule,
  /*   75 */  flagsReg_long_LEGT_rule,
  /*   76 */  regDPR_rule,
  /*   77 */  regDPR1_rule,
  /*   78 */  regDPR2_rule,
  /*   79 */  regnotDPR1_rule,
  /*   80 */  regFPR_rule,
  /*   81 */  regFPR1_rule,
  /*   82 */  regF_rule,
  /*   83 */  regD_rule,
  /*   84 */  direct_rule,
  /*   85 */  indirect_rule,
  /*   86 */  indOffset8_rule,
  /*   87 */  indOffset32_rule,
  /*   88 */  indOffset32X_rule,
  /*   89 */  indIndexOffset_rule,
  /*   90 */  indIndex_rule,
  /*   91 */  indIndexScale_rule,
  /*   92 */  indIndexScaleOffset_rule,
  /*   93 */  load_long_RegP_rule,
  /*   94 */  load_long_indirect_rule,
  /*   95 */  load_long_indOffset32_rule,
  /*   96 */  stackSlotP_rule,
  /*   97 */  stackSlotI_rule,
  /*   98 */  stackSlotF_rule,
  /*   99 */  stackSlotD_rule,
  /*  100 */  stackSlotL_rule,
  /*  101 */  indirect_win95_safe_rule,
  /*  102 */  indOffset8_win95_safe_rule,
  /*  103 */  indOffset32_win95_safe_rule,
  /*  104 */  indIndexOffset_win95_safe_rule,
  /*  105 */  indIndexScale_win95_safe_rule,
  /*  106 */  indIndexScaleOffset_win95_safe_rule,
  /*  107 */  cmpOp_rule,
  /*  108 */  cmpOpU_rule,
  /*  109 */  cmpOpUCF_rule,
  /*  110 */  cmpOpUCF2_rule,
  /*  111 */  cmpOp_fcmov_rule,
  /*  112 */  cmpOp_commute_rule,
  /*  113 */  vecS_rule,
  /*  114 */  vecD_rule,
  /*  115 */  vecX_rule,
  /*  116 */  vecY_rule,
  // last operand
  /*  117 */  load_long_memory_rule,
  /*  118 */  memory_rule,
  /*  119 */  long_memory_rule,
  // last operand class
  /*  120 */  _AddP_eRegP_rRegI_rule,
  /*  121 */  _LShiftI_rRegI_immI2_rule,
  /*  122 */  _AddP_eRegP__LShiftI_rRegI_immI2_rule,
  /*  123 */  _AddP_eRegP_no_EBP_rRegI_rule,
  /*  124 */  _AddP_eRegP_no_EBP__LShiftI_rRegI_immI2_rule,
  /*  125 */  _LoadI_memory__rule,
  /*  126 */  _LoadL_memory__rule,
  /*  127 */  _LoadB_memory__rule,
  /*  128 */  _LoadUB_memory__rule,
  /*  129 */  _AndI__LoadUB_memory__immI8_rule,
  /*  130 */  _LoadS_memory__rule,
  /*  131 */  _LShiftI__LoadS_memory__immI_24_rule,
  /*  132 */  _LoadUS_memory__rule,
  /*  133 */  _LShiftI__LoadUS_memory__immI_24_rule,
  /*  134 */  _AndI__LoadUS_memory__immI_255_rule,
  /*  135 */  _AndI__LoadUS_memory__immI16_rule,
  /*  136 */  _LShiftI__LoadI_memory__immI_24_rule,
  /*  137 */  _LShiftI__LoadI_memory__immI_16_rule,
  /*  138 */  _AndI__LoadI_memory__immI_255_rule,
  /*  139 */  _AndI__LoadI_memory__immI_65535_rule,
  /*  140 */  _AndI__LoadI_memory__immI_rule,
  /*  141 */  _ConvI2L__LoadI_memory___rule,
  /*  142 */  _ConvL2I_eRegL__rule,
  /*  143 */  _RoundDouble_regDPR1__rule,
  /*  144 */  _RoundFloat_regFPR1__rule,
  /*  145 */  _ConvD2F_regDPR1__rule,
  /*  146 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  147 */  _Binary_rRegI_rRegI_rule,
  /*  148 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  149 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  150 */  _Binary_rRegI__LoadI_memory__rule,
  /*  151 */  _Binary_eRegP_eRegP_rule,
  /*  152 */  _Binary_cmpOp_fcmov_eFlagsRegU_rule,
  /*  153 */  _Binary_regDPR1_regDPR_rule,
  /*  154 */  _Binary_regFPR1_regFPR_rule,
  /*  155 */  _Binary_regDPR_regDPR_rule,
  /*  156 */  _Binary_regFPR_regFPR_rule,
  /*  157 */  _Binary_regF_regF_rule,
  /*  158 */  _Binary_regD_regD_rule,
  /*  159 */  _Binary_eRegL_eRegL_rule,
  /*  160 */  _AddI__LoadI_memory__rRegI_rule,
  /*  161 */  _AddI_rRegI__LoadI_memory__rule,
  /*  162 */  _AddI__LoadI_memory__immI_rule,
  /*  163 */  _AddI__LoadI_memory__immI1_rule,
  /*  164 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  165 */  _Binary_eAXRegP_eRegP_rule,
  /*  166 */  _Binary_eAXRegI_rRegI_rule,
  /*  167 */  _Binary_eADXRegL_eBCXRegL_rule,
  /*  168 */  _Binary_eAXRegP_eCXRegP_rule,
  /*  169 */  _Binary_eAXRegI_eCXRegI_rule,
  /*  170 */  _SubI__LoadI_memory__rRegI_rule,
  /*  171 */  _SubI_immI0_rRegI_rule,
  /*  172 */  _ConvI2L_nadxRegI__rule,
  /*  173 */  _MulL__ConvI2L_nadxRegI__eADXRegL_low_only_rule,
  /*  174 */  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_rule,
  /*  175 */  _MulL_eADXRegL_low_only__ConvI2L_nadxRegI__rule,
  /*  176 */  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_rule,
  /*  177 */  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_63_rule,
  /*  178 */  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_63_rule,
  /*  179 */  _ConvI2L_eAXRegI__rule,
  /*  180 */  _AndL__ConvI2L_eAXRegI__immL_32bits_rule,
  /*  181 */  _AndL__ConvI2L_nadxRegI__immL_32bits_rule,
  /*  182 */  _RShiftI__LoadI_memory__immI1_rule,
  /*  183 */  _RShiftI__LoadI_memory__immI8_rule,
  /*  184 */  _LShiftI_xRegI_immI_24_rule,
  /*  185 */  _LShiftI_xRegI_immI_16_rule,
  /*  186 */  _AndI__LoadI_memory__rRegI_rule,
  /*  187 */  _AndI_rRegI__LoadI_memory__rule,
  /*  188 */  _CastP2X_eRegP__rule,
  /*  189 */  _OrI__LoadI_memory__rRegI_rule,
  /*  190 */  _OrI_rRegI__LoadI_memory__rule,
  /*  191 */  _OrI__LoadI_memory__immI_rule,
  /*  192 */  _LShiftI_rRegI_immI1_rule,
  /*  193 */  _URShiftI_rRegI_immI_M1_rule,
  /*  194 */  _LShiftI_rRegI_immI8_rule,
  /*  195 */  _URShiftI_rRegI_immI8_rule,
  /*  196 */  _LShiftI_ncxRegI_eCXRegI_rule,
  /*  197 */  _SubI_immI0_eCXRegI_rule,
  /*  198 */  _URShiftI_ncxRegI__SubI_immI0_eCXRegI_rule,
  /*  199 */  _SubI_immI_32_eCXRegI_rule,
  /*  200 */  _URShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule,
  /*  201 */  _URShiftI_rRegI_immI1_rule,
  /*  202 */  _LShiftI_rRegI_immI_M1_rule,
  /*  203 */  _URShiftI_ncxRegI_eCXRegI_rule,
  /*  204 */  _LShiftI_ncxRegI__SubI_immI0_eCXRegI_rule,
  /*  205 */  _LShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule,
  /*  206 */  _XorI__LoadI_memory__rRegI_rule,
  /*  207 */  _XorI_rRegI__LoadI_memory__rule,
  /*  208 */  _XorI__LoadI_memory__immI_rule,
  /*  209 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  210 */  _AndI__CmpLTMask_rRegI_rRegI_rRegI_rule,
  /*  211 */  _SubI_rRegI_rRegI_rule,
  /*  212 */  _AndI_rRegI__CmpLTMask_rRegI_rRegI_rule,
  /*  213 */  _LoadL_load_long_memory__rule,
  /*  214 */  _LoadD_memory__rule,
  /*  215 */  _SubD_regDPR_regDPR_rule,
  /*  216 */  _AddD_regDPR_regDPR_rule,
  /*  217 */  _AddD__LoadD_memory__regDPR_rule,
  /*  218 */  _RoundDouble__AddD__LoadD_memory__regDPR__rule,
  /*  219 */  _AddD_regDPR__LoadD_memory__rule,
  /*  220 */  _RoundDouble__AddD_regDPR__LoadD_memory___rule,
  /*  221 */  _AddD_regDPR_immDPR_rule,
  /*  222 */  _MulD_regDPR_regDPR_rule,
  /*  223 */  _DivD_regDPR_regDPR_rule,
  /*  224 */  _LoadF_memory__rule,
  /*  225 */  _MulF__LoadF_memory__regFPR_rule,
  /*  226 */  _MulF_regFPR__LoadF_memory__rule,
  /*  227 */  _MulF_regFPR_regFPR_rule,
  /*  228 */  _SubF_regFPR_regFPR_rule,
  /*  229 */  _ConvI2L_rRegI__rule,
  /*  230 */  _Binary_eDIRegP_eCXRegI_rule,
  /*  231 */  _Binary_eSIRegP_eDXRegI_rule,
  /*  232 */  _Binary_eDIRegP_eSIRegP_rule,
  /*  233 */  _Binary_eDIRegP_eDXRegI_rule,
  /*  234 */  _Binary_eSIRegP_immI_rule,
  /*  235 */  _Binary_eSIRegP_eAXRegI_rule,
  /*  236 */  _AndI_rRegI_immI_rule,
  /*  237 */  _AndI_rRegI_memory_rule,
  /*  238 */  _LoadP_memory__rule,
  /*  239 */  _Binary_nadxRegI_eAXRegI_rule,
  /*  240 */  _PartialSubtypeCheck_eSIRegP_eAXRegP_rule,
  /*  241 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  242 */  _Binary_eRegL__LoadL_load_long_memory__rule,
  /*  243 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  244 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  245 */  _ConvF2D_regF__rule,
  /*  246 */  _SqrtD__ConvF2D_regF___rule,
  /*  247 */  _ConvF2D__LoadF_memory___rule,
  /*  248 */  _SqrtD__ConvF2D__LoadF_memory____rule,
  /*  249 */  _ConvF2D_immF__rule,
  /*  250 */  _SqrtD__ConvF2D_immF___rule,
  /*  251 */  _LoadVector_memory__rule,
  // last internally defined operand
  /*  252 */  stackSlotI_rule,
  /*  253 */  stackSlotP_rule,
  /*  254 */  stackSlotL_rule,
  /*  255 */  eRegP_rule,
  /*  256 */  eRegP_rule,
  /*  257 */  eRegP_rule,
  /*  258 */  eRegP_rule,
  /*  259 */  eRegP_rule,
  /*  260 */  rRegI_rule,
  /*  261 */  rRegI_rule,
  /*  262 */  eRegP_rule,
  /*  263 */  eRegL_rule,
  /*  264 */  eRegL_rule,
  /*  265 */  regFPR_rule,
  /*  266 */  regFPR_rule,
  /*  267 */  regFPR_rule,
  /*  268 */  regF_rule,
  /*  269 */  regF_rule,
  /*  270 */  regDPR_rule,
  /*  271 */  regDPR_rule,
  /*  272 */  regDPR_rule,
  /*  273 */  regD_rule,
  /*  274 */  regD_rule,
  /*  275 */  rRegI_rule,
  /*  276 */  eRegL_rule,
  /*  277 */  eRegP_rule,
  /*  278 */  regFPR_rule,
  /*  279 */  regDPR_rule,
  /*  280 */  eADXRegL_low_only_rule,
  /*  281 */  Universe_rule,
  /*  282 */  eAXRegP_rule,
  /*  283 */  rRegI_rule,
  /*  284 */  eRegP_rule,
  /*  285 */  eRegP_rule,
  /*  286 */  rRegI_rule,
  /*  287 */  eFlagsReg_rule,
  /*  288 */  eFlagsReg_rule,
  /*  289 */  eFlagsReg_rule,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  eFlagsRegU_rule,
  /*  293 */  eFlagsRegUCF_rule,
  /*  294 */  eFlagsRegU_rule,
  /*  295 */  eFlagsRegU_rule,
  /*  296 */  eFlagsRegUCF_rule,
  /*  297 */  eFlagsRegU_rule,
  /*  298 */  eFlagsRegUCF_rule,
  /*  299 */  regDPR1_rule,
  /*  300 */  eFlagsRegU_rule,
  /*  301 */  eFlagsRegUCF_rule,
  /*  302 */  eFlagsRegU_rule,
  /*  303 */  eFlagsRegU_rule,
  /*  304 */  eFlagsRegUCF_rule,
  /*  305 */  eFlagsRegU_rule,
  /*  306 */  eFlagsRegUCF_rule,
  /*  307 */  regFPR1_rule,
  /*  308 */  regFPR1_rule,
  /*  309 */  rRegI_rule,
  /*  310 */  rRegI_rule,
  /*  311 */  regFPR_rule,
  /*  312 */  regF_rule,
  /*  313 */  regF_rule,
  /*  314 */  eRegL_rule,
  /*  315 */  regDPR_rule,
  /*  316 */  regD_rule,
  /*  317 */  regD_rule,
  /*  318 */  eFlagsReg_rule,
  /*  319 */  eFlagsReg_rule,
  /*  320 */  eFlagsReg_rule,
  /*  321 */  eFlagsReg_rule,
  /*  322 */  eFlagsReg_rule,
  /*  323 */  eFlagsReg_rule,
  /*  324 */  eFlagsRegU_rule,
  /*  325 */  eFlagsRegU_rule,
  /*  326 */  eFlagsRegU_rule,
  /*  327 */  eFlagsRegU_rule,
  /*  328 */  eFlagsRegU_rule,
  /*  329 */  eFlagsRegU_rule,
  /*  330 */  eFlagsRegU_rule,
  /*  331 */  eFlagsRegU_rule,
  /*  332 */  eFlagsReg_rule,
  /*  333 */  eFlagsReg_rule,
  /*  334 */  eFlagsReg_rule,
  /*  335 */  flagsReg_long_LTGE_rule,
  /*  336 */  flagsReg_long_LTGE_rule,
  /*  337 */  flagsReg_long_EQNE_rule,
  /*  338 */  flagsReg_long_EQNE_rule,
  /*  339 */  flagsReg_long_LEGT_rule,
  /*  340 */  flagsReg_long_LEGT_rule,
  /*  341 */  eFlagsReg_rule,
  /*  342 */  eFlagsReg_rule,
  /*  343 */  Universe_rule,
  /*  344 */  regF_rule,
  /*  345 */  regF_rule,
  /*  346 */  regD_rule,
  /*  347 */  regD_rule,
  /*  348 */  regF_rule,
  /*  349 */  regF_rule,
  /*  350 */  vecS_rule,
  /*  351 */  vecS_rule,
  /*  352 */  rRegI_rule,
  /*  353 */  eRegL_rule,
  /*  354 */  rRegI_rule,
  /*  355 */  rRegI_rule,
  /*  356 */  rRegI_rule,
  /*  357 */  rRegI_rule,
  /*  358 */  rRegI_rule,
  /*  359 */  rRegI_rule,
  /*  360 */  rRegI_rule,
  /*  361 */  rRegI_rule,
  /*  362 */  rRegI_rule,
  /*  363 */  rRegI_rule,
  /*  364 */  rRegI_rule,
  /*  365 */  rRegI_rule,
  /*  366 */  xRegI_rule,
  /*  367 */  eRegL_rule,
  /*  368 */  xRegI_rule,
  /*  369 */  eRegL_rule,
  /*  370 */  eRegL_rule,
  /*  371 */  rRegI_rule,
  /*  372 */  rRegI_rule,
  /*  373 */  eRegL_rule,
  /*  374 */  rRegI_rule,
  /*  375 */  rRegI_rule,
  /*  376 */  eRegL_rule,
  /*  377 */  eRegL_rule,
  /*  378 */  eRegL_rule,
  /*  379 */  rRegI_rule,
  /*  380 */  rRegI_rule,
  /*  381 */  rRegI_rule,
  /*  382 */  rRegI_rule,
  /*  383 */  rRegI_rule,
  /*  384 */  eRegL_rule,
  /*  385 */  eRegL_rule,
  /*  386 */  eRegL_rule,
  /*  387 */  eRegL_rule,
  /*  388 */  eRegL_rule,
  /*  389 */  eRegL_rule,
  /*  390 */  stackSlotL_rule,
  /*  391 */  stackSlotL_rule,
  /*  392 */  eRegL_rule,
  /*  393 */  rRegI_rule,
  /*  394 */  eRegP_rule,
  /*  395 */  eRegP_rule,
  /*  396 */  regDPR_rule,
  /*  397 */  regD_rule,
  /*  398 */  regD_rule,
  /*  399 */  regF_rule,
  /*  400 */  regFPR_rule,
  /*  401 */  Universe_rule,
  /*  402 */  Universe_rule,
  /*  403 */  Universe_rule,
  /*  404 */  Universe_rule,
  /*  405 */  Universe_rule,
  /*  406 */  Universe_rule,
  /*  407 */  Universe_rule,
  /*  408 */  Universe_rule,
  /*  409 */  Universe_rule,
  /*  410 */  Universe_rule,
  /*  411 */  Universe_rule,
  /*  412 */  Universe_rule,
  /*  413 */  Universe_rule,
  /*  414 */  Universe_rule,
  /*  415 */  Universe_rule,
  /*  416 */  Universe_rule,
  /*  417 */  Universe_rule,
  /*  418 */  Universe_rule,
  /*  419 */  Universe_rule,
  /*  420 */  Universe_rule,
  /*  421 */  Universe_rule,
  /*  422 */  Universe_rule,
  /*  423 */  Universe_rule,
  /*  424 */  Universe_rule,
  /*  425 */  Universe_rule,
  /*  426 */  Universe_rule,
  /*  427 */  Universe_rule,
  /*  428 */  Universe_rule,
  /*  429 */  Universe_rule,
  /*  430 */  Universe_rule,
  /*  431 */  Universe_rule,
  /*  432 */  Universe_rule,
  /*  433 */  Universe_rule,
  /*  434 */  Universe_rule,
  /*  435 */  Universe_rule,
  /*  436 */  Universe_rule,
  /*  437 */  Universe_rule,
  /*  438 */  Universe_rule,
  /*  439 */  Universe_rule,
  /*  440 */  Universe_rule,
  /*  441 */  Universe_rule,
  /*  442 */  Universe_rule,
  /*  443 */  rRegI_rule,
  /*  444 */  rRegI_rule,
  /*  445 */  rRegI_rule,
  /*  446 */  rRegI_rule,
  /*  447 */  rRegI_rule,
  /*  448 */  rRegI_rule,
  /*  449 */  rRegI_rule,
  /*  450 */  rRegI_rule,
  /*  451 */  eRegP_rule,
  /*  452 */  eRegP_rule,
  /*  453 */  eRegP_rule,
  /*  454 */  eRegP_rule,
  /*  455 */  regDPR1_rule,
  /*  456 */  regFPR1_rule,
  /*  457 */  regDPR_rule,
  /*  458 */  regFPR_rule,
  /*  459 */  regF_rule,
  /*  460 */  regD_rule,
  /*  461 */  regF_rule,
  /*  462 */  regF_rule,
  /*  463 */  regD_rule,
  /*  464 */  regD_rule,
  /*  465 */  eRegL_rule,
  /*  466 */  eRegL_rule,
  /*  467 */  eRegL_rule,
  /*  468 */  rRegI_rule,
  /*  469 */  rRegI_rule,
  /*  470 */  rRegI_rule,
  /*  471 */  rRegI_rule,
  /*  472 */  eRegP_rule,
  /*  473 */  rRegI_rule,
  /*  474 */  eRegP_rule,
  /*  475 */  eRegP_rule,
  /*  476 */  rRegI_rule,
  /*  477 */  rRegI_rule,
  /*  478 */  Universe_rule,
  /*  479 */  Universe_rule,
  /*  480 */  Universe_rule,
  /*  481 */  Universe_rule,
  /*  482 */  Universe_rule,
  /*  483 */  eRegP_rule,
  /*  484 */  rRegI_rule,
  /*  485 */  rRegI_rule,
  /*  486 */  Universe_rule,
  /*  487 */  rRegI_rule,
  /*  488 */  rRegI_rule,
  /*  489 */  pRegP_rule,
  /*  490 */  rRegI_rule,
  /*  491 */  rRegI_rule,
  /*  492 */  rRegI_rule,
  /*  493 */  rRegI_rule,
  /*  494 */  Universe_rule,
  /*  495 */  eRegP_rule,
  /*  496 */  rRegI_rule,
  /*  497 */  rRegI_rule,
  /*  498 */  rRegI_rule,
  /*  499 */  eDXRegI_rule,
  /*  500 */  eDXRegI_rule,
  /*  501 */  eDXRegI_rule,
  /*  502 */  eDXRegI_rule,
  /*  503 */  rRegI_rule,
  /*  504 */  rRegI_rule,
  /*  505 */  rRegI_rule,
  /*  506 */  eADXRegL_rule,
  /*  507 */  eADXRegL_rule,
  /*  508 */  eADXRegL_rule,
  /*  509 */  eADXRegL_rule,
  /*  510 */  eADXRegL_rule,
  /*  511 */  eADXRegL_rule,
  /*  512 */  eADXRegL_rule,
  /*  513 */  eADXRegL_rule,
  /*  514 */  eADXRegL_rule,
  /*  515 */  eAXRegI_rule,
  /*  516 */  eADXRegL_rule,
  /*  517 */  Universe_rule,
  /*  518 */  eDXRegI_rule,
  /*  519 */  eADXRegL_rule,
  /*  520 */  eADXRegL_rule,
  /*  521 */  eADXRegL_rule,
  /*  522 */  rRegI_rule,
  /*  523 */  rRegI_rule,
  /*  524 */  rRegI_rule,
  /*  525 */  rRegI_rule,
  /*  526 */  Universe_rule,
  /*  527 */  rRegI_rule,
  /*  528 */  Universe_rule,
  /*  529 */  rRegI_rule,
  /*  530 */  rRegI_rule,
  /*  531 */  rRegI_rule,
  /*  532 */  rRegI_rule,
  /*  533 */  rRegI_rule,
  /*  534 */  rRegI_rule,
  /*  535 */  rRegI_rule,
  /*  536 */  rRegI_rule,
  /*  537 */  rRegI_rule,
  /*  538 */  rRegI_rule,
  /*  539 */  Universe_rule,
  /*  540 */  Universe_rule,
  /*  541 */  Universe_rule,
  /*  542 */  rRegI_rule,
  /*  543 */  rRegI_rule,
  /*  544 */  rRegI_rule,
  /*  545 */  rRegI_rule,
  /*  546 */  rRegI_rule,
  /*  547 */  rRegI_rule,
  /*  548 */  Universe_rule,
  /*  549 */  Universe_rule,
  /*  550 */  Universe_rule,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  rRegI_rule,
  /*  555 */  rRegI_rule,
  /*  556 */  rRegI_rule,
  /*  557 */  rRegI_rule,
  /*  558 */  ncxRegI_rule,
  /*  559 */  ncxRegI_rule,
  /*  560 */  ncxRegI_rule,
  /*  561 */  ncxRegI_rule,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  rRegI_rule,
  /*  566 */  rRegI_rule,
  /*  567 */  rRegI_rule,
  /*  568 */  rRegI_rule,
  /*  569 */  ncxRegI_rule,
  /*  570 */  ncxRegI_rule,
  /*  571 */  ncxRegI_rule,
  /*  572 */  ncxRegI_rule,
  /*  573 */  rRegI_rule,
  /*  574 */  rRegI_rule,
  /*  575 */  rRegI_rule,
  /*  576 */  rRegI_rule,
  /*  577 */  rRegI_rule,
  /*  578 */  Universe_rule,
  /*  579 */  Universe_rule,
  /*  580 */  Universe_rule,
  /*  581 */  0,
  /*  582 */  rRegI_rule,
  /*  583 */  0,
  /*  584 */  rRegI_rule,
  /*  585 */  eCXRegI_rule,
  /*  586 */  rRegI_rule,
  /*  587 */  rRegI_rule,
  /*  588 */  rRegI_rule,
  /*  589 */  rRegI_rule,
  /*  590 */  rRegI_rule,
  /*  591 */  rRegI_rule,
  /*  592 */  rRegI_rule,
  /*  593 */  eRegL_rule,
  /*  594 */  eRegL_rule,
  /*  595 */  eRegL_rule,
  /*  596 */  eRegL_rule,
  /*  597 */  eRegL_rule,
  /*  598 */  eRegL_rule,
  /*  599 */  eRegL_rule,
  /*  600 */  eRegL_rule,
  /*  601 */  eRegL_rule,
  /*  602 */  eRegL_rule,
  /*  603 */  eRegL_rule,
  /*  604 */  eRegL_rule,
  /*  605 */  eRegL_rule,
  /*  606 */  eRegL_rule,
  /*  607 */  eRegL_rule,
  /*  608 */  eRegL_rule,
  /*  609 */  eRegL_rule,
  /*  610 */  eRegL_rule,
  /*  611 */  eRegL_rule,
  /*  612 */  eRegL_rule,
  /*  613 */  eRegL_rule,
  /*  614 */  eRegL_rule,
  /*  615 */  eRegL_rule,
  /*  616 */  eRegL_rule,
  /*  617 */  eRegL_rule,
  /*  618 */  eRegL_rule,
  /*  619 */  eRegL_rule,
  /*  620 */  eRegL_rule,
  /*  621 */  eRegL_rule,
  /*  622 */  eRegL_rule,
  /*  623 */  eRegL_rule,
  /*  624 */  eRegL_rule,
  /*  625 */  eRegL_rule,
  /*  626 */  rRegI_rule,
  /*  627 */  rRegI_rule,
  /*  628 */  xRegI_rule,
  /*  629 */  xRegI_rule,
  /*  630 */  regDPR_rule,
  /*  631 */  stackSlotD_rule,
  /*  632 */  regDPR_rule,
  /*  633 */  regDPR1_rule,
  /*  634 */  regDPR_rule,
  /*  635 */  stackSlotD_rule,
  /*  636 */  regDPR_rule,
  /*  637 */  regDPR_rule,
  /*  638 */  Universe_rule,
  /*  639 */  Universe_rule,
  /*  640 */  regDPR_rule,
  /*  641 */  regDPR_rule,
  /*  642 */  stackSlotD_rule,
  /*  643 */  regDPR_rule,
  /*  644 */  regDPR1_rule,
  /*  645 */  regDPR_rule,
  /*  646 */  regDPR_rule,
  /*  647 */  regDPR_rule,
  /*  648 */  regDPR_rule,
  /*  649 */  regDPR_rule,
  /*  650 */  regDPR_rule,
  /*  651 */  regDPR_rule,
  /*  652 */  regDPR_rule,
  /*  653 */  regDPR_rule,
  /*  654 */  regDPR1_rule,
  /*  655 */  stackSlotD_rule,
  /*  656 */  regDPR_rule,
  /*  657 */  regD_rule,
  /*  658 */  regDPR1_rule,
  /*  659 */  regD_rule,
  /*  660 */  regDPR1_rule,
  /*  661 */  regD_rule,
  /*  662 */  regDPR1_rule,
  /*  663 */  regD_rule,
  /*  664 */  regDPR_rule,
  /*  665 */  regD_rule,
  /*  666 */  regDPR_rule,
  /*  667 */  regDPR1_rule,
  /*  668 */  regD_rule,
  /*  669 */  regDPR1_rule,
  /*  670 */  regD_rule,
  /*  671 */  regDPR1_rule,
  /*  672 */  regD_rule,
  /*  673 */  regDPR1_rule,
  /*  674 */  regD_rule,
  /*  675 */  rRegI_rule,
  /*  676 */  rRegI_rule,
  /*  677 */  xRegI_rule,
  /*  678 */  xRegI_rule,
  /*  679 */  stackSlotF_rule,
  /*  680 */  regFPR_rule,
  /*  681 */  stackSlotF_rule,
  /*  682 */  regFPR_rule,
  /*  683 */  stackSlotF_rule,
  /*  684 */  stackSlotF_rule,
  /*  685 */  regFPR_rule,
  /*  686 */  regFPR_rule,
  /*  687 */  stackSlotF_rule,
  /*  688 */  stackSlotF_rule,
  /*  689 */  stackSlotF_rule,
  /*  690 */  stackSlotF_rule,
  /*  691 */  stackSlotF_rule,
  /*  692 */  regFPR_rule,
  /*  693 */  stackSlotF_rule,
  /*  694 */  regFPR_rule,
  /*  695 */  stackSlotF_rule,
  /*  696 */  stackSlotF_rule,
  /*  697 */  regFPR_rule,
  /*  698 */  regFPR_rule,
  /*  699 */  stackSlotF_rule,
  /*  700 */  stackSlotF_rule,
  /*  701 */  regFPR_rule,
  /*  702 */  regFPR_rule,
  /*  703 */  regFPR_rule,
  /*  704 */  regFPR_rule,
  /*  705 */  regFPR_rule,
  /*  706 */  regFPR_rule,
  /*  707 */  regFPR_rule,
  /*  708 */  regFPR_rule,
  /*  709 */  regFPR_rule,
  /*  710 */  regFPR_rule,
  /*  711 */  stackSlotF_rule,
  /*  712 */  regFPR_rule,
  /*  713 */  stackSlotF_rule,
  /*  714 */  regFPR_rule,
  /*  715 */  regF_rule,
  /*  716 */  stackSlotF_rule,
  /*  717 */  stackSlotD_rule,
  /*  718 */  stackSlotF_rule,
  /*  719 */  regF_rule,
  /*  720 */  regF_rule,
  /*  721 */  regDPR_rule,
  /*  722 */  stackSlotD_rule,
  /*  723 */  regDPR_rule,
  /*  724 */  regD_rule,
  /*  725 */  eAXRegI_rule,
  /*  726 */  eAXRegI_rule,
  /*  727 */  eADXRegL_rule,
  /*  728 */  eADXRegL_rule,
  /*  729 */  eAXRegI_rule,
  /*  730 */  eAXRegI_rule,
  /*  731 */  eADXRegL_rule,
  /*  732 */  eADXRegL_rule,
  /*  733 */  regDPR_rule,
  /*  734 */  regD_rule,
  /*  735 */  regD_rule,
  /*  736 */  regD_rule,
  /*  737 */  regDPR_rule,
  /*  738 */  regFPR_rule,
  /*  739 */  stackSlotF_rule,
  /*  740 */  stackSlotF_rule,
  /*  741 */  regFPR_rule,
  /*  742 */  regFPR_rule,
  /*  743 */  regF_rule,
  /*  744 */  regF_rule,
  /*  745 */  eRegL_rule,
  /*  746 */  eRegL_rule,
  /*  747 */  eRegL_rule,
  /*  748 */  stackSlotD_rule,
  /*  749 */  regD_rule,
  /*  750 */  regF_rule,
  /*  751 */  stackSlotF_rule,
  /*  752 */  rRegI_rule,
  /*  753 */  stackSlotI_rule,
  /*  754 */  stackSlotI_rule,
  /*  755 */  stackSlotF_rule,
  /*  756 */  stackSlotL_rule,
  /*  757 */  stackSlotL_rule,
  /*  758 */  eRegL_rule,
  /*  759 */  stackSlotD_rule,
  /*  760 */  regD_rule,
  /*  761 */  Universe_rule,
  /*  762 */  Universe_rule,
  /*  763 */  eAXRegI_rule,
  /*  764 */  eAXRegI_rule,
  /*  765 */  eBXRegI_rule,
  /*  766 */  eBXRegI_rule,
  /*  767 */  eAXRegI_rule,
  /*  768 */  rRegI_rule,
  /*  769 */  rRegI_rule,
  /*  770 */  eAXRegI_rule,
  /*  771 */  Universe_rule,
  /*  772 */  Universe_rule,
  /*  773 */  Universe_rule,
  /*  774 */  Universe_rule,
  /*  775 */  Universe_rule,
  /*  776 */  Universe_rule,
  /*  777 */  Universe_rule,
  /*  778 */  Universe_rule,
  /*  779 */  Universe_rule,
  /*  780 */  eDIRegP_rule,
  /*  781 */  Universe_rule,
  /*  782 */  Universe_rule,
  /*  783 */  Universe_rule,
  /*  784 */  Universe_rule,
  /*  785 */  Universe_rule,
  /*  786 */  Universe_rule,
  /*  787 */  Universe_rule,
  /*  788 */  Universe_rule,
  /*  789 */  eSIRegI_rule,
  /*  790 */  Universe_rule,
  /*  791 */  eRegL_rule,
  /*  792 */  eRegL_rule,
  /*  793 */  rRegI_rule,
  /*  794 */  rRegI_rule,
  /*  795 */  eRegP_rule,
  /*  796 */  regDPR_rule,
  /*  797 */  regD_rule,
  /*  798 */  regFPR_rule,
  /*  799 */  regF_rule,
  /*  800 */  Universe_rule,
  /*  801 */  eRegL_rule,
  /*  802 */  eRegL_rule,
  /*  803 */  rRegI_rule,
  /*  804 */  rRegI_rule,
  /*  805 */  eRegP_rule,
  /*  806 */  regDPR_rule,
  /*  807 */  regD_rule,
  /*  808 */  regFPR_rule,
  /*  809 */  regF_rule,
  /*  810 */  Universe_rule,
  /*  811 */  eRegL_rule,
  /*  812 */  eRegL_rule,
  /*  813 */  rRegI_rule,
  /*  814 */  rRegI_rule,
  /*  815 */  eRegP_rule,
  /*  816 */  regDPR_rule,
  /*  817 */  regD_rule,
  /*  818 */  regFPR_rule,
  /*  819 */  regF_rule,
  /*  820 */  Universe_rule,
  /*  821 */  Universe_rule,
  /*  822 */  Universe_rule,
  /*  823 */  Universe_rule,
  /*  824 */  Universe_rule,
  /*  825 */  Universe_rule,
  /*  826 */  Universe_rule,
  /*  827 */  Universe_rule,
  /*  828 */  Universe_rule,
  /*  829 */  eAXRegP_rule,
  /*  830 */  Universe_rule,
  /*  831 */  eRegP_rule,
  /*  832 */  Universe_rule,
  /*  833 */  regF_rule,
  /*  834 */  regF_rule,
  /*  835 */  regF_rule,
  /*  836 */  regF_rule,
  /*  837 */  regF_rule,
  /*  838 */  regF_rule,
  /*  839 */  regF_rule,
  /*  840 */  regF_rule,
  /*  841 */  regD_rule,
  /*  842 */  regD_rule,
  /*  843 */  regD_rule,
  /*  844 */  regD_rule,
  /*  845 */  regD_rule,
  /*  846 */  regD_rule,
  /*  847 */  regD_rule,
  /*  848 */  regD_rule,
  /*  849 */  regF_rule,
  /*  850 */  regF_rule,
  /*  851 */  regF_rule,
  /*  852 */  regF_rule,
  /*  853 */  regF_rule,
  /*  854 */  regF_rule,
  /*  855 */  regD_rule,
  /*  856 */  regD_rule,
  /*  857 */  regD_rule,
  /*  858 */  regD_rule,
  /*  859 */  regD_rule,
  /*  860 */  regD_rule,
  /*  861 */  regF_rule,
  /*  862 */  regF_rule,
  /*  863 */  regF_rule,
  /*  864 */  regF_rule,
  /*  865 */  regF_rule,
  /*  866 */  regF_rule,
  /*  867 */  regF_rule,
  /*  868 */  regF_rule,
  /*  869 */  regD_rule,
  /*  870 */  regD_rule,
  /*  871 */  regD_rule,
  /*  872 */  regD_rule,
  /*  873 */  regD_rule,
  /*  874 */  regD_rule,
  /*  875 */  regD_rule,
  /*  876 */  regD_rule,
  /*  877 */  regF_rule,
  /*  878 */  regF_rule,
  /*  879 */  regF_rule,
  /*  880 */  regF_rule,
  /*  881 */  regF_rule,
  /*  882 */  regF_rule,
  /*  883 */  regD_rule,
  /*  884 */  regD_rule,
  /*  885 */  regD_rule,
  /*  886 */  regD_rule,
  /*  887 */  regD_rule,
  /*  888 */  regD_rule,
  /*  889 */  regD_rule,
  /*  890 */  regD_rule,
  /*  891 */  regF_rule,
  /*  892 */  regF_rule,
  /*  893 */  regF_rule,
  /*  894 */  regD_rule,
  /*  895 */  regD_rule,
  /*  896 */  regD_rule,
  /*  897 */  vecS_rule,
  /*  898 */  vecD_rule,
  /*  899 */  vecX_rule,
  /*  900 */  vecY_rule,
  /*  901 */  Universe_rule,
  /*  902 */  Universe_rule,
  /*  903 */  Universe_rule,
  /*  904 */  Universe_rule,
  /*  905 */  vecS_rule,
  /*  906 */  vecD_rule,
  /*  907 */  vecX_rule,
  /*  908 */  vecY_rule,
  /*  909 */  vecS_rule,
  /*  910 */  vecD_rule,
  /*  911 */  vecX_rule,
  /*  912 */  vecY_rule,
  /*  913 */  vecS_rule,
  /*  914 */  vecD_rule,
  /*  915 */  vecX_rule,
  /*  916 */  vecY_rule,
  /*  917 */  vecS_rule,
  /*  918 */  vecD_rule,
  /*  919 */  vecX_rule,
  /*  920 */  vecY_rule,
  /*  921 */  vecS_rule,
  /*  922 */  vecD_rule,
  /*  923 */  vecX_rule,
  /*  924 */  vecY_rule,
  /*  925 */  vecS_rule,
  /*  926 */  vecD_rule,
  /*  927 */  vecX_rule,
  /*  928 */  vecY_rule,
  /*  929 */  vecD_rule,
  /*  930 */  vecX_rule,
  /*  931 */  vecY_rule,
  /*  932 */  vecD_rule,
  /*  933 */  vecX_rule,
  /*  934 */  vecY_rule,
  /*  935 */  vecD_rule,
  /*  936 */  vecX_rule,
  /*  937 */  vecY_rule,
  /*  938 */  vecD_rule,
  /*  939 */  vecX_rule,
  /*  940 */  vecY_rule,
  /*  941 */  vecX_rule,
  /*  942 */  vecY_rule,
  /*  943 */  vecX_rule,
  /*  944 */  vecY_rule,
  /*  945 */  vecX_rule,
  /*  946 */  vecY_rule,
  /*  947 */  vecX_rule,
  /*  948 */  vecY_rule,
  /*  949 */  vecD_rule,
  /*  950 */  vecX_rule,
  /*  951 */  vecY_rule,
  /*  952 */  vecD_rule,
  /*  953 */  vecX_rule,
  /*  954 */  vecY_rule,
  /*  955 */  vecX_rule,
  /*  956 */  vecY_rule,
  /*  957 */  vecX_rule,
  /*  958 */  vecY_rule,
  /*  959 */  vecS_rule,
  /*  960 */  vecS_rule,
  /*  961 */  vecD_rule,
  /*  962 */  vecD_rule,
  /*  963 */  vecX_rule,
  /*  964 */  vecX_rule,
  /*  965 */  vecX_rule,
  /*  966 */  vecY_rule,
  /*  967 */  vecY_rule,
  /*  968 */  vecS_rule,
  /*  969 */  vecS_rule,
  /*  970 */  vecD_rule,
  /*  971 */  vecD_rule,
  /*  972 */  vecX_rule,
  /*  973 */  vecX_rule,
  /*  974 */  vecX_rule,
  /*  975 */  vecY_rule,
  /*  976 */  vecY_rule,
  /*  977 */  vecD_rule,
  /*  978 */  vecD_rule,
  /*  979 */  vecX_rule,
  /*  980 */  vecX_rule,
  /*  981 */  vecX_rule,
  /*  982 */  vecY_rule,
  /*  983 */  vecY_rule,
  /*  984 */  vecX_rule,
  /*  985 */  vecX_rule,
  /*  986 */  vecX_rule,
  /*  987 */  vecY_rule,
  /*  988 */  vecY_rule,
  /*  989 */  vecD_rule,
  /*  990 */  vecD_rule,
  /*  991 */  vecX_rule,
  /*  992 */  vecX_rule,
  /*  993 */  vecX_rule,
  /*  994 */  vecY_rule,
  /*  995 */  vecY_rule,
  /*  996 */  vecX_rule,
  /*  997 */  vecX_rule,
  /*  998 */  vecX_rule,
  /*  999 */  vecY_rule,
  /* 1000 */  vecY_rule,
  /* 1001 */  vecS_rule,
  /* 1002 */  vecS_rule,
  /* 1003 */  vecD_rule,
  /* 1004 */  vecD_rule,
  /* 1005 */  vecX_rule,
  /* 1006 */  vecX_rule,
  /* 1007 */  vecX_rule,
  /* 1008 */  vecY_rule,
  /* 1009 */  vecY_rule,
  /* 1010 */  vecS_rule,
  /* 1011 */  vecS_rule,
  /* 1012 */  vecD_rule,
  /* 1013 */  vecD_rule,
  /* 1014 */  vecX_rule,
  /* 1015 */  vecX_rule,
  /* 1016 */  vecX_rule,
  /* 1017 */  vecY_rule,
  /* 1018 */  vecY_rule,
  /* 1019 */  vecD_rule,
  /* 1020 */  vecD_rule,
  /* 1021 */  vecX_rule,
  /* 1022 */  vecX_rule,
  /* 1023 */  vecX_rule,
  /* 1024 */  vecY_rule,
  /* 1025 */  vecY_rule,
  /* 1026 */  vecX_rule,
  /* 1027 */  vecX_rule,
  /* 1028 */  vecX_rule,
  /* 1029 */  vecY_rule,
  /* 1030 */  vecY_rule,
  /* 1031 */  vecD_rule,
  /* 1032 */  vecD_rule,
  /* 1033 */  vecX_rule,
  /* 1034 */  vecX_rule,
  /* 1035 */  vecX_rule,
  /* 1036 */  vecY_rule,
  /* 1037 */  vecY_rule,
  /* 1038 */  vecX_rule,
  /* 1039 */  vecX_rule,
  /* 1040 */  vecX_rule,
  /* 1041 */  vecY_rule,
  /* 1042 */  vecY_rule,
  /* 1043 */  vecS_rule,
  /* 1044 */  vecS_rule,
  /* 1045 */  vecD_rule,
  /* 1046 */  vecD_rule,
  /* 1047 */  vecX_rule,
  /* 1048 */  vecX_rule,
  /* 1049 */  vecX_rule,
  /* 1050 */  vecY_rule,
  /* 1051 */  vecY_rule,
  /* 1052 */  vecD_rule,
  /* 1053 */  vecD_rule,
  /* 1054 */  vecX_rule,
  /* 1055 */  vecX_rule,
  /* 1056 */  vecX_rule,
  /* 1057 */  vecY_rule,
  /* 1058 */  vecY_rule,
  /* 1059 */  vecD_rule,
  /* 1060 */  vecD_rule,
  /* 1061 */  vecX_rule,
  /* 1062 */  vecX_rule,
  /* 1063 */  vecX_rule,
  /* 1064 */  vecY_rule,
  /* 1065 */  vecY_rule,
  /* 1066 */  vecX_rule,
  /* 1067 */  vecX_rule,
  /* 1068 */  vecX_rule,
  /* 1069 */  vecY_rule,
  /* 1070 */  vecY_rule,
  /* 1071 */  vecD_rule,
  /* 1072 */  vecD_rule,
  /* 1073 */  vecX_rule,
  /* 1074 */  vecX_rule,
  /* 1075 */  vecX_rule,
  /* 1076 */  vecY_rule,
  /* 1077 */  vecY_rule,
  /* 1078 */  vecX_rule,
  /* 1079 */  vecX_rule,
  /* 1080 */  vecX_rule,
  /* 1081 */  vecY_rule,
  /* 1082 */  vecY_rule,
  /* 1083 */  vecS_rule,
  /* 1084 */  vecS_rule,
  /* 1085 */  vecS_rule,
  /* 1086 */  vecS_rule,
  /* 1087 */  vecD_rule,
  /* 1088 */  vecD_rule,
  /* 1089 */  vecD_rule,
  /* 1090 */  vecD_rule,
  /* 1091 */  vecX_rule,
  /* 1092 */  vecX_rule,
  /* 1093 */  vecX_rule,
  /* 1094 */  vecX_rule,
  /* 1095 */  vecY_rule,
  /* 1096 */  vecY_rule,
  /* 1097 */  vecD_rule,
  /* 1098 */  vecD_rule,
  /* 1099 */  vecD_rule,
  /* 1100 */  vecD_rule,
  /* 1101 */  vecX_rule,
  /* 1102 */  vecX_rule,
  /* 1103 */  vecX_rule,
  /* 1104 */  vecX_rule,
  /* 1105 */  vecY_rule,
  /* 1106 */  vecY_rule,
  /* 1107 */  vecX_rule,
  /* 1108 */  vecX_rule,
  /* 1109 */  vecX_rule,
  /* 1110 */  vecX_rule,
  /* 1111 */  vecY_rule,
  /* 1112 */  vecY_rule,
  /* 1113 */  vecS_rule,
  /* 1114 */  vecS_rule,
  /* 1115 */  vecS_rule,
  /* 1116 */  vecS_rule,
  /* 1117 */  vecD_rule,
  /* 1118 */  vecD_rule,
  /* 1119 */  vecD_rule,
  /* 1120 */  vecD_rule,
  /* 1121 */  vecX_rule,
  /* 1122 */  vecX_rule,
  /* 1123 */  vecX_rule,
  /* 1124 */  vecX_rule,
  /* 1125 */  vecY_rule,
  /* 1126 */  vecY_rule,
  /* 1127 */  vecD_rule,
  /* 1128 */  vecD_rule,
  /* 1129 */  vecD_rule,
  /* 1130 */  vecD_rule,
  /* 1131 */  vecX_rule,
  /* 1132 */  vecX_rule,
  /* 1133 */  vecX_rule,
  /* 1134 */  vecX_rule,
  /* 1135 */  vecY_rule,
  /* 1136 */  vecY_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecX_rule,
  /* 1139 */  vecX_rule,
  /* 1140 */  vecX_rule,
  /* 1141 */  vecY_rule,
  /* 1142 */  vecY_rule,
  /* 1143 */  vecS_rule,
  /* 1144 */  vecS_rule,
  /* 1145 */  vecS_rule,
  /* 1146 */  vecS_rule,
  /* 1147 */  vecD_rule,
  /* 1148 */  vecD_rule,
  /* 1149 */  vecD_rule,
  /* 1150 */  vecD_rule,
  /* 1151 */  vecX_rule,
  /* 1152 */  vecX_rule,
  /* 1153 */  vecX_rule,
  /* 1154 */  vecX_rule,
  /* 1155 */  vecY_rule,
  /* 1156 */  vecY_rule,
  /* 1157 */  vecD_rule,
  /* 1158 */  vecD_rule,
  /* 1159 */  vecD_rule,
  /* 1160 */  vecD_rule,
  /* 1161 */  vecX_rule,
  /* 1162 */  vecX_rule,
  /* 1163 */  vecX_rule,
  /* 1164 */  vecX_rule,
  /* 1165 */  vecY_rule,
  /* 1166 */  vecY_rule,
  /* 1167 */  vecS_rule,
  /* 1168 */  vecS_rule,
  /* 1169 */  vecD_rule,
  /* 1170 */  vecD_rule,
  /* 1171 */  vecX_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecX_rule,
  /* 1174 */  vecY_rule,
  /* 1175 */  vecY_rule,
  /* 1176 */  vecS_rule,
  /* 1177 */  vecS_rule,
  /* 1178 */  vecD_rule,
  /* 1179 */  vecD_rule,
  /* 1180 */  vecX_rule,
  /* 1181 */  vecX_rule,
  /* 1182 */  vecX_rule,
  /* 1183 */  vecY_rule,
  /* 1184 */  vecY_rule,
  /* 1185 */  vecS_rule,
  /* 1186 */  vecS_rule,
  /* 1187 */  vecD_rule,
  /* 1188 */  vecD_rule,
  /* 1189 */  vecX_rule,
  /* 1190 */  vecX_rule,
  /* 1191 */  vecX_rule,
  /* 1192 */  vecY_rule,
  /* 1193 */  vecY_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  eRegP_rule,
  /*   87 */  eRegP_rule,
  /*   88 */  immP_rule,
  /*   89 */  _AddP_eRegP_rRegI_rule,
  /*   90 */  eRegP_rule,
  /*   91 */  eRegP_rule,
  /*   92 */  _AddP_eRegP__LShiftI_rRegI_immI2_rule,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  load_long_RegP_rule,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  eRegP_no_EBP_rule,
  /*  103 */  eRegP_no_EBP_rule,
  /*  104 */  _AddP_eRegP_no_EBP_rRegI_rule,
  /*  105 */  eRegP_no_EBP_rule,
  /*  106 */  _AddP_eRegP_no_EBP__LShiftI_rRegI_immI2_rule,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  // last operand
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  // last operand class
  /*  120 */  eRegP_rule,
  /*  121 */  rRegI_rule,
  /*  122 */  eRegP_rule,
  /*  123 */  eRegP_no_EBP_rule,
  /*  124 */  eRegP_no_EBP_rule,
  /*  125 */  memory_rule,
  /*  126 */  memory_rule,
  /*  127 */  memory_rule,
  /*  128 */  memory_rule,
  /*  129 */  _LoadUB_memory__rule,
  /*  130 */  memory_rule,
  /*  131 */  _LoadS_memory__rule,
  /*  132 */  memory_rule,
  /*  133 */  _LoadUS_memory__rule,
  /*  134 */  _LoadUS_memory__rule,
  /*  135 */  _LoadUS_memory__rule,
  /*  136 */  _LoadI_memory__rule,
  /*  137 */  _LoadI_memory__rule,
  /*  138 */  _LoadI_memory__rule,
  /*  139 */  _LoadI_memory__rule,
  /*  140 */  _LoadI_memory__rule,
  /*  141 */  _LoadI_memory__rule,
  /*  142 */  eRegL_rule,
  /*  143 */  regDPR1_rule,
  /*  144 */  regFPR1_rule,
  /*  145 */  regDPR1_rule,
  /*  146 */  cmpOp_rule,
  /*  147 */  rRegI_rule,
  /*  148 */  cmpOpU_rule,
  /*  149 */  cmpOpUCF_rule,
  /*  150 */  rRegI_rule,
  /*  151 */  eRegP_rule,
  /*  152 */  cmpOp_fcmov_rule,
  /*  153 */  regDPR1_rule,
  /*  154 */  regFPR1_rule,
  /*  155 */  regDPR_rule,
  /*  156 */  regFPR_rule,
  /*  157 */  regF_rule,
  /*  158 */  regD_rule,
  /*  159 */  eRegL_rule,
  /*  160 */  _LoadI_memory__rule,
  /*  161 */  rRegI_rule,
  /*  162 */  _LoadI_memory__rule,
  /*  163 */  _LoadI_memory__rule,
  /*  164 */  _LoadI_memory__rule,
  /*  165 */  eAXRegP_rule,
  /*  166 */  eAXRegI_rule,
  /*  167 */  eADXRegL_rule,
  /*  168 */  eAXRegP_rule,
  /*  169 */  eAXRegI_rule,
  /*  170 */  _LoadI_memory__rule,
  /*  171 */  immI0_rule,
  /*  172 */  nadxRegI_rule,
  /*  173 */  _ConvI2L_nadxRegI__rule,
  /*  174 */  _MulL__ConvI2L_nadxRegI__eADXRegL_low_only_rule,
  /*  175 */  eADXRegL_low_only_rule,
  /*  176 */  _MulL_eADXRegL_low_only__ConvI2L_nadxRegI__rule,
  /*  177 */  _MulL__ConvI2L_nadxRegI__eADXRegL_low_only_rule,
  /*  178 */  _MulL_eADXRegL_low_only__ConvI2L_nadxRegI__rule,
  /*  179 */  eAXRegI_rule,
  /*  180 */  _ConvI2L_eAXRegI__rule,
  /*  181 */  _ConvI2L_nadxRegI__rule,
  /*  182 */  _LoadI_memory__rule,
  /*  183 */  _LoadI_memory__rule,
  /*  184 */  xRegI_rule,
  /*  185 */  xRegI_rule,
  /*  186 */  _LoadI_memory__rule,
  /*  187 */  rRegI_rule,
  /*  188 */  eRegP_rule,
  /*  189 */  _LoadI_memory__rule,
  /*  190 */  rRegI_rule,
  /*  191 */  _LoadI_memory__rule,
  /*  192 */  rRegI_rule,
  /*  193 */  rRegI_rule,
  /*  194 */  rRegI_rule,
  /*  195 */  rRegI_rule,
  /*  196 */  ncxRegI_rule,
  /*  197 */  immI0_rule,
  /*  198 */  ncxRegI_rule,
  /*  199 */  immI_32_rule,
  /*  200 */  ncxRegI_rule,
  /*  201 */  rRegI_rule,
  /*  202 */  rRegI_rule,
  /*  203 */  ncxRegI_rule,
  /*  204 */  ncxRegI_rule,
  /*  205 */  ncxRegI_rule,
  /*  206 */  _LoadI_memory__rule,
  /*  207 */  rRegI_rule,
  /*  208 */  _LoadI_memory__rule,
  /*  209 */  rRegI_rule,
  /*  210 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  211 */  rRegI_rule,
  /*  212 */  rRegI_rule,
  /*  213 */  load_long_memory_rule,
  /*  214 */  memory_rule,
  /*  215 */  regDPR_rule,
  /*  216 */  regDPR_rule,
  /*  217 */  _LoadD_memory__rule,
  /*  218 */  _AddD__LoadD_memory__regDPR_rule,
  /*  219 */  regDPR_rule,
  /*  220 */  _AddD_regDPR__LoadD_memory__rule,
  /*  221 */  regDPR_rule,
  /*  222 */  regDPR_rule,
  /*  223 */  regDPR_rule,
  /*  224 */  memory_rule,
  /*  225 */  _LoadF_memory__rule,
  /*  226 */  regFPR_rule,
  /*  227 */  regFPR_rule,
  /*  228 */  regFPR_rule,
  /*  229 */  rRegI_rule,
  /*  230 */  eDIRegP_rule,
  /*  231 */  eSIRegP_rule,
  /*  232 */  eDIRegP_rule,
  /*  233 */  eDIRegP_rule,
  /*  234 */  eSIRegP_rule,
  /*  235 */  eSIRegP_rule,
  /*  236 */  rRegI_rule,
  /*  237 */  rRegI_rule,
  /*  238 */  memory_rule,
  /*  239 */  nadxRegI_rule,
  /*  240 */  eSIRegP_rule,
  /*  241 */  cmpOp_rule,
  /*  242 */  eRegL_rule,
  /*  243 */  cmpOp_rule,
  /*  244 */  cmpOp_commute_rule,
  /*  245 */  regF_rule,
  /*  246 */  _ConvF2D_regF__rule,
  /*  247 */  _LoadF_memory__rule,
  /*  248 */  _ConvF2D__LoadF_memory___rule,
  /*  249 */  immF_rule,
  /*  250 */  _ConvF2D_immF__rule,
  /*  251 */  memory_rule,
  // last internally defined operand
  /*  252 */  rRegI_rule,
  /*  253 */  eRegP_rule,
  /*  254 */  eRegL_rule,
  /*  255 */  indOffset8_rule,
  /*  256 */  indOffset32_rule,
  /*  257 */  indIndexOffset_rule,
  /*  258 */  indIndexScale_rule,
  /*  259 */  indIndexScaleOffset_rule,
  /*  260 */  immI_rule,
  /*  261 */  immI0_rule,
  /*  262 */  immP_rule,
  /*  263 */  immL_rule,
  /*  264 */  immL0_rule,
  /*  265 */  immFPR_rule,
  /*  266 */  immFPR0_rule,
  /*  267 */  immFPR1_rule,
  /*  268 */  immF_rule,
  /*  269 */  immF0_rule,
  /*  270 */  immDPR_rule,
  /*  271 */  immDPR0_rule,
  /*  272 */  immDPR1_rule,
  /*  273 */  immD_rule,
  /*  274 */  immD0_rule,
  /*  275 */  stackSlotI_rule,
  /*  276 */  stackSlotL_rule,
  /*  277 */  stackSlotP_rule,
  /*  278 */  stackSlotF_rule,
  /*  279 */  stackSlotD_rule,
  /*  280 */  immL32_rule,
  /*  281 */  0,
  /*  282 */  eAXRegI_rule,
  /*  283 */  eRegP_rule,
  /*  284 */  eRegP_rule,
  /*  285 */  eRegP_rule,
  /*  286 */  rRegI_rule,
  /*  287 */  memory_rule,
  /*  288 */  memory_rule,
  /*  289 */  memory_rule,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  regDPR_rule,
  /*  293 */  regDPR_rule,
  /*  294 */  regDPR_rule,
  /*  295 */  regD_rule,
  /*  296 */  regD_rule,
  /*  297 */  regD_rule,
  /*  298 */  regD_rule,
  /*  299 */  regDPR1_rule,
  /*  300 */  regFPR_rule,
  /*  301 */  regFPR_rule,
  /*  302 */  regFPR_rule,
  /*  303 */  regF_rule,
  /*  304 */  regF_rule,
  /*  305 */  regF_rule,
  /*  306 */  regF_rule,
  /*  307 */  regFPR1_rule,
  /*  308 */  regFPR1_rule,
  /*  309 */  stackSlotF_rule,
  /*  310 */  regF_rule,
  /*  311 */  stackSlotI_rule,
  /*  312 */  stackSlotI_rule,
  /*  313 */  rRegI_rule,
  /*  314 */  stackSlotD_rule,
  /*  315 */  stackSlotL_rule,
  /*  316 */  stackSlotL_rule,
  /*  317 */  stackSlotL_rule,
  /*  318 */  rRegI_rule,
  /*  319 */  rRegI_rule,
  /*  320 */  rRegI_rule,
  /*  321 */  rRegI_rule,
  /*  322 */  _AndI_rRegI_immI_rule,
  /*  323 */  _AndI_rRegI_memory_rule,
  /*  324 */  rRegI_rule,
  /*  325 */  rRegI_rule,
  /*  326 */  rRegI_rule,
  /*  327 */  rRegI_rule,
  /*  328 */  eRegP_rule,
  /*  329 */  eRegP_rule,
  /*  330 */  eRegP_rule,
  /*  331 */  eRegP_rule,
  /*  332 */  eRegP_rule,
  /*  333 */  _LoadP_memory__rule,
  /*  334 */  _PartialSubtypeCheck_eSIRegP_eAXRegP_rule,
  /*  335 */  eRegL_rule,
  /*  336 */  eRegL_rule,
  /*  337 */  eRegL_rule,
  /*  338 */  eRegL_rule,
  /*  339 */  eRegL_rule,
  /*  340 */  eRegL_rule,
  /*  341 */  eRegP_rule,
  /*  342 */  eRegP_rule,
  /*  343 */  0,
  /*  344 */  regF_rule,
  /*  345 */  regF_rule,
  /*  346 */  regD_rule,
  /*  347 */  regD_rule,
  /*  348 */  regF_rule,
  /*  349 */  regF_rule,
  /*  350 */  rRegI_rule,
  /*  351 */  rRegI_rule,
  /*  352 */  rRegI_rule,
  /*  353 */  eRegL_rule,
  /*  354 */  rRegI_rule,
  /*  355 */  rRegI_rule,
  /*  356 */  rRegI_rule,
  /*  357 */  rRegI_rule,
  /*  358 */  eRegL_rule,
  /*  359 */  eRegL_rule,
  /*  360 */  rRegI_rule,
  /*  361 */  eRegL_rule,
  /*  362 */  rRegI_rule,
  /*  363 */  _LoadI_memory__rule,
  /*  364 */  eRegL_rule,
  /*  365 */  _LoadL_memory__rule,
  /*  366 */  memory_rule,
  /*  367 */  _LoadB_memory__rule,
  /*  368 */  memory_rule,
  /*  369 */  _LoadUB_memory__rule,
  /*  370 */  _AndI__LoadUB_memory__immI8_rule,
  /*  371 */  memory_rule,
  /*  372 */  _LShiftI__LoadS_memory__immI_24_rule,
  /*  373 */  _LoadS_memory__rule,
  /*  374 */  memory_rule,
  /*  375 */  _LShiftI__LoadUS_memory__immI_24_rule,
  /*  376 */  _LoadUS_memory__rule,
  /*  377 */  _AndI__LoadUS_memory__immI_255_rule,
  /*  378 */  _AndI__LoadUS_memory__immI16_rule,
  /*  379 */  memory_rule,
  /*  380 */  _LShiftI__LoadI_memory__immI_24_rule,
  /*  381 */  _LoadI_memory__rule,
  /*  382 */  _LShiftI__LoadI_memory__immI_16_rule,
  /*  383 */  _LoadI_memory__rule,
  /*  384 */  _LoadI_memory__rule,
  /*  385 */  _AndI__LoadI_memory__immI_255_rule,
  /*  386 */  _AndI__LoadI_memory__immI_65535_rule,
  /*  387 */  _AndI__LoadI_memory__immI_rule,
  /*  388 */  _ConvI2L__LoadI_memory___rule,
  /*  389 */  load_long_memory_rule,
  /*  390 */  memory_rule,
  /*  391 */  memory_rule,
  /*  392 */  memory_rule,
  /*  393 */  memory_rule,
  /*  394 */  memory_rule,
  /*  395 */  memory_rule,
  /*  396 */  memory_rule,
  /*  397 */  memory_rule,
  /*  398 */  memory_rule,
  /*  399 */  memory_rule,
  /*  400 */  memory_rule,
  /*  401 */  memory_rule,
  /*  402 */  memory_rule,
  /*  403 */  memory_rule,
  /*  404 */  memory_rule,
  /*  405 */  memory_rule,
  /*  406 */  memory_rule,
  /*  407 */  memory_rule,
  /*  408 */  memory_rule,
  /*  409 */  memory_rule,
  /*  410 */  memory_rule,
  /*  411 */  memory_rule,
  /*  412 */  memory_rule,
  /*  413 */  memory_rule,
  /*  414 */  memory_rule,
  /*  415 */  memory_rule,
  /*  416 */  memory_rule,
  /*  417 */  long_memory_rule,
  /*  418 */  memory_rule,
  /*  419 */  memory_rule,
  /*  420 */  memory_rule,
  /*  421 */  memory_rule,
  /*  422 */  memory_rule,
  /*  423 */  memory_rule,
  /*  424 */  memory_rule,
  /*  425 */  memory_rule,
  /*  426 */  memory_rule,
  /*  427 */  memory_rule,
  /*  428 */  memory_rule,
  /*  429 */  memory_rule,
  /*  430 */  memory_rule,
  /*  431 */  memory_rule,
  /*  432 */  memory_rule,
  /*  433 */  memory_rule,
  /*  434 */  memory_rule,
  /*  435 */  memory_rule,
  /*  436 */  memory_rule,
  /*  437 */  0,
  /*  438 */  0,
  /*  439 */  0,
  /*  440 */  0,
  /*  441 */  0,
  /*  442 */  0,
  /*  443 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  444 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  445 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  446 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  447 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  448 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  449 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  450 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  451 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  452 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  453 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  454 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  455 */  _Binary_cmpOp_fcmov_eFlagsRegU_rule,
  /*  456 */  _Binary_cmpOp_fcmov_eFlagsRegU_rule,
  /*  457 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  458 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  459 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  460 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  461 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  462 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  463 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  464 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  465 */  _Binary_cmpOp_eFlagsReg_rule,
  /*  466 */  _Binary_cmpOpU_eFlagsRegU_rule,
  /*  467 */  _Binary_cmpOpUCF_eFlagsRegUCF_rule,
  /*  468 */  rRegI_rule,
  /*  469 */  rRegI_rule,
  /*  470 */  rRegI_rule,
  /*  471 */  rRegI_rule,
  /*  472 */  eRegP_rule,
  /*  473 */  rRegI_rule,
  /*  474 */  eRegP_rule,
  /*  475 */  eRegP_rule,
  /*  476 */  rRegI_rule,
  /*  477 */  _LoadI_memory__rule,
  /*  478 */  memory_rule,
  /*  479 */  memory_rule,
  /*  480 */  memory_rule,
  /*  481 */  memory_rule,
  /*  482 */  memory_rule,
  /*  483 */  memory_rule,
  /*  484 */  eSIRegP_rule,
  /*  485 */  pRegP_rule,
  /*  486 */  memory_rule,
  /*  487 */  memory_rule,
  /*  488 */  memory_rule,
  /*  489 */  memory_rule,
  /*  490 */  pRegP_rule,
  /*  491 */  rRegI_rule,
  /*  492 */  rRegI_rule,
  /*  493 */  rRegI_rule,
  /*  494 */  memory_rule,
  /*  495 */  eRegP_rule,
  /*  496 */  immI0_rule,
  /*  497 */  rRegI_rule,
  /*  498 */  rRegI_rule,
  /*  499 */  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_rule,
  /*  500 */  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_rule,
  /*  501 */  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_63_rule,
  /*  502 */  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_63_rule,
  /*  503 */  _LoadI_memory__rule,
  /*  504 */  rRegI_rule,
  /*  505 */  _LoadI_memory__rule,
  /*  506 */  _ConvI2L_eAXRegI__rule,
  /*  507 */  _ConvI2L_nadxRegI__rule,
  /*  508 */  _AndL__ConvI2L_eAXRegI__immL_32bits_rule,
  /*  509 */  _AndL__ConvI2L_nadxRegI__immL_32bits_rule,
  /*  510 */  eADXRegL_rule,
  /*  511 */  eADXRegL_rule,
  /*  512 */  eADXRegL_rule,
  /*  513 */  eADXRegL_rule,
  /*  514 */  eADXRegL_rule,
  /*  515 */  eAXRegI_rule,
  /*  516 */  eRegL_rule,
  /*  517 */  eAXRegI_rule,
  /*  518 */  eAXRegI_rule,
  /*  519 */  eRegL_rule,
  /*  520 */  eADXRegL_rule,
  /*  521 */  eADXRegL_rule,
  /*  522 */  rRegI_rule,
  /*  523 */  rRegI_rule,
  /*  524 */  rRegI_rule,
  /*  525 */  rRegI_rule,
  /*  526 */  memory_rule,
  /*  527 */  rRegI_rule,
  /*  528 */  memory_rule,
  /*  529 */  rRegI_rule,
  /*  530 */  rRegI_rule,
  /*  531 */  rRegI_rule,
  /*  532 */  _LShiftI_xRegI_immI_24_rule,
  /*  533 */  _LShiftI_xRegI_immI_16_rule,
  /*  534 */  rRegI_rule,
  /*  535 */  rRegI_rule,
  /*  536 */  rRegI_rule,
  /*  537 */  rRegI_rule,
  /*  538 */  _LoadI_memory__rule,
  /*  539 */  memory_rule,
  /*  540 */  memory_rule,
  /*  541 */  memory_rule,
  /*  542 */  rRegI_rule,
  /*  543 */  rRegI_rule,
  /*  544 */  _CastP2X_eRegP__rule,
  /*  545 */  rRegI_rule,
  /*  546 */  rRegI_rule,
  /*  547 */  _LoadI_memory__rule,
  /*  548 */  memory_rule,
  /*  549 */  memory_rule,
  /*  550 */  memory_rule,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  _LShiftI_rRegI_immI1_rule,
  /*  555 */  _URShiftI_rRegI_immI_M1_rule,
  /*  556 */  _LShiftI_rRegI_immI8_rule,
  /*  557 */  _URShiftI_rRegI_immI8_rule,
  /*  558 */  _LShiftI_ncxRegI_eCXRegI_rule,
  /*  559 */  _URShiftI_ncxRegI__SubI_immI0_eCXRegI_rule,
  /*  560 */  _LShiftI_ncxRegI_eCXRegI_rule,
  /*  561 */  _URShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  _URShiftI_rRegI_immI1_rule,
  /*  566 */  _LShiftI_rRegI_immI_M1_rule,
  /*  567 */  _URShiftI_rRegI_immI8_rule,
  /*  568 */  _LShiftI_rRegI_immI8_rule,
  /*  569 */  _URShiftI_ncxRegI_eCXRegI_rule,
  /*  570 */  _LShiftI_ncxRegI__SubI_immI0_eCXRegI_rule,
  /*  571 */  _URShiftI_ncxRegI_eCXRegI_rule,
  /*  572 */  _LShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule,
  /*  573 */  rRegI_rule,
  /*  574 */  rRegI_rule,
  /*  575 */  rRegI_rule,
  /*  576 */  rRegI_rule,
  /*  577 */  _LoadI_memory__rule,
  /*  578 */  memory_rule,
  /*  579 */  memory_rule,
  /*  580 */  memory_rule,
  /*  581 */  0,
  /*  582 */  rRegI_rule,
  /*  583 */  0,
  /*  584 */  eRegP_rule,
  /*  585 */  ncxRegI_rule,
  /*  586 */  rRegI_rule,
  /*  587 */  _AndI__CmpLTMask_rRegI_rRegI_rRegI_rule,
  /*  588 */  _SubI_rRegI_rRegI_rule,
  /*  589 */  _AndI_rRegI__CmpLTMask_rRegI_rRegI_rule,
  /*  590 */  _SubI_rRegI_rRegI_rule,
  /*  591 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  592 */  rRegI_rule,
  /*  593 */  eRegL_rule,
  /*  594 */  eRegL_rule,
  /*  595 */  eRegL_rule,
  /*  596 */  _LoadL_load_long_memory__rule,
  /*  597 */  eRegL_rule,
  /*  598 */  eRegL_rule,
  /*  599 */  eRegL_rule,
  /*  600 */  immL0_rule,
  /*  601 */  eRegL_rule,
  /*  602 */  eRegL_rule,
  /*  603 */  eRegL_rule,
  /*  604 */  _LoadL_load_long_memory__rule,
  /*  605 */  eRegL_rule,
  /*  606 */  eRegL_rule,
  /*  607 */  eRegL_rule,
  /*  608 */  _LoadL_load_long_memory__rule,
  /*  609 */  eRegL_rule,
  /*  610 */  eRegL_rule,
  /*  611 */  eRegL_rule,
  /*  612 */  eRegL_rule,
  /*  613 */  _LoadL_load_long_memory__rule,
  /*  614 */  eRegL_rule,
  /*  615 */  eRegL_rule,
  /*  616 */  eRegL_rule,
  /*  617 */  eRegL_rule,
  /*  618 */  eRegL_rule,
  /*  619 */  eRegL_rule,
  /*  620 */  eRegL_rule,
  /*  621 */  eRegL_rule,
  /*  622 */  eRegL_rule,
  /*  623 */  eRegL_rule,
  /*  624 */  eRegL_rule,
  /*  625 */  eRegL_rule,
  /*  626 */  regDPR_rule,
  /*  627 */  regDPR_rule,
  /*  628 */  regD_rule,
  /*  629 */  regD_rule,
  /*  630 */  regDPR_rule,
  /*  631 */  _SubD_regDPR_regDPR_rule,
  /*  632 */  regDPR_rule,
  /*  633 */  regDPR1_rule,
  /*  634 */  regDPR_rule,
  /*  635 */  _AddD_regDPR_regDPR_rule,
  /*  636 */  regDPR_rule,
  /*  637 */  _LoadD_memory__rule,
  /*  638 */  memory_rule,
  /*  639 */  memory_rule,
  /*  640 */  regDPR_rule,
  /*  641 */  regDPR_rule,
  /*  642 */  _AddD_regDPR_immDPR_rule,
  /*  643 */  regDPR_rule,
  /*  644 */  regDPR1_rule,
  /*  645 */  regDPR_rule,
  /*  646 */  regDPR_rule,
  /*  647 */  _LoadD_memory__rule,
  /*  648 */  regDPR_rule,
  /*  649 */  _LoadD_memory__rule,
  /*  650 */  _MulD_regDPR_regDPR_rule,
  /*  651 */  regDPR_rule,
  /*  652 */  _MulD_regDPR_regDPR_rule,
  /*  653 */  regDPR_rule,
  /*  654 */  regDPR1_rule,
  /*  655 */  _DivD_regDPR_regDPR_rule,
  /*  656 */  regDPR_rule,
  /*  657 */  regD_rule,
  /*  658 */  regDPR1_rule,
  /*  659 */  regD_rule,
  /*  660 */  regDPR1_rule,
  /*  661 */  regD_rule,
  /*  662 */  regDPR1_rule,
  /*  663 */  regD_rule,
  /*  664 */  regDPR_rule,
  /*  665 */  regD_rule,
  /*  666 */  regDPR_rule,
  /*  667 */  regDPR_rule,
  /*  668 */  regD_rule,
  /*  669 */  regDPR1_rule,
  /*  670 */  regD_rule,
  /*  671 */  regDPR1_rule,
  /*  672 */  regD_rule,
  /*  673 */  regDPR1_rule,
  /*  674 */  regD_rule,
  /*  675 */  regFPR_rule,
  /*  676 */  regFPR_rule,
  /*  677 */  regF_rule,
  /*  678 */  regF_rule,
  /*  679 */  regFPR_rule,
  /*  680 */  regFPR_rule,
  /*  681 */  regFPR_rule,
  /*  682 */  regFPR_rule,
  /*  683 */  regFPR_rule,
  /*  684 */  _LoadF_memory__rule,
  /*  685 */  regFPR_rule,
  /*  686 */  _LoadF_memory__rule,
  /*  687 */  memory_rule,
  /*  688 */  memory_rule,
  /*  689 */  _LoadF_memory__rule,
  /*  690 */  memory_rule,
  /*  691 */  regFPR_rule,
  /*  692 */  regFPR_rule,
  /*  693 */  regFPR_rule,
  /*  694 */  regFPR_rule,
  /*  695 */  regFPR_rule,
  /*  696 */  _LoadF_memory__rule,
  /*  697 */  regFPR_rule,
  /*  698 */  _LoadF_memory__rule,
  /*  699 */  memory_rule,
  /*  700 */  regFPR_rule,
  /*  701 */  regFPR_rule,
  /*  702 */  _LoadF_memory__rule,
  /*  703 */  regFPR_rule,
  /*  704 */  _MulF__LoadF_memory__regFPR_rule,
  /*  705 */  regFPR_rule,
  /*  706 */  _MulF_regFPR__LoadF_memory__rule,
  /*  707 */  regFPR_rule,
  /*  708 */  _MulF_regFPR_regFPR_rule,
  /*  709 */  regFPR_rule,
  /*  710 */  _SubF_regFPR_regFPR_rule,
  /*  711 */  regFPR_rule,
  /*  712 */  regFPR_rule,
  /*  713 */  regFPR_rule,
  /*  714 */  regFPR_rule,
  /*  715 */  regF_rule,
  /*  716 */  regFPR_rule,
  /*  717 */  regDPR_rule,
  /*  718 */  regDPR_rule,
  /*  719 */  regDPR_rule,
  /*  720 */  regD_rule,
  /*  721 */  regFPR_rule,
  /*  722 */  regFPR_rule,
  /*  723 */  regF_rule,
  /*  724 */  regF_rule,
  /*  725 */  regDPR_rule,
  /*  726 */  regD_rule,
  /*  727 */  regDPR_rule,
  /*  728 */  regD_rule,
  /*  729 */  regFPR_rule,
  /*  730 */  regF_rule,
  /*  731 */  regFPR_rule,
  /*  732 */  regF_rule,
  /*  733 */  stackSlotI_rule,
  /*  734 */  rRegI_rule,
  /*  735 */  _LoadI_memory__rule,
  /*  736 */  rRegI_rule,
  /*  737 */  _LoadI_memory__rule,
  /*  738 */  stackSlotI_rule,
  /*  739 */  stackSlotI_rule,
  /*  740 */  _LoadI_memory__rule,
  /*  741 */  stackSlotI_rule,
  /*  742 */  _LoadI_memory__rule,
  /*  743 */  rRegI_rule,
  /*  744 */  rRegI_rule,
  /*  745 */  rRegI_rule,
  /*  746 */  _ConvI2L_rRegI__rule,
  /*  747 */  eRegL_rule,
  /*  748 */  eRegL_rule,
  /*  749 */  eRegL_rule,
  /*  750 */  eRegL_rule,
  /*  751 */  eRegL_rule,
  /*  752 */  eRegL_rule,
  /*  753 */  regFPR_rule,
  /*  754 */  regF_rule,
  /*  755 */  rRegI_rule,
  /*  756 */  regDPR_rule,
  /*  757 */  regD_rule,
  /*  758 */  regD_rule,
  /*  759 */  eRegL_rule,
  /*  760 */  eRegL_rule,
  /*  761 */  eCXRegI_rule,
  /*  762 */  eCXRegI_rule,
  /*  763 */  _Binary_eDIRegP_eCXRegI_rule,
  /*  764 */  _Binary_eDIRegP_eSIRegP_rule,
  /*  765 */  _Binary_eDIRegP_eDXRegI_rule,
  /*  766 */  _Binary_eDIRegP_eDXRegI_rule,
  /*  767 */  eDIRegP_rule,
  /*  768 */  rRegI_rule,
  /*  769 */  rRegI_rule,
  /*  770 */  _Binary_nadxRegI_eAXRegI_rule,
  /*  771 */  rRegI_rule,
  /*  772 */  0,
  /*  773 */  cmpOp_rule,
  /*  774 */  cmpOp_rule,
  /*  775 */  cmpOpU_rule,
  /*  776 */  cmpOpUCF_rule,
  /*  777 */  cmpOpU_rule,
  /*  778 */  cmpOpUCF_rule,
  /*  779 */  cmpOpUCF2_rule,
  /*  780 */  eSIRegP_rule,
  /*  781 */  0,
  /*  782 */  cmpOp_rule,
  /*  783 */  cmpOp_rule,
  /*  784 */  cmpOpU_rule,
  /*  785 */  cmpOpUCF_rule,
  /*  786 */  cmpOpU_rule,
  /*  787 */  cmpOpUCF_rule,
  /*  788 */  cmpOpUCF2_rule,
  /*  789 */  eRegL_rule,
  /*  790 */  cmpOp_rule,
  /*  791 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  792 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  793 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  794 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  795 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  796 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  797 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  798 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  799 */  _Binary_cmpOp_flagsReg_long_LTGE_rule,
  /*  800 */  cmpOp_rule,
  /*  801 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  802 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  803 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  804 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  805 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  806 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  807 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  808 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  809 */  _Binary_cmpOp_flagsReg_long_EQNE_rule,
  /*  810 */  cmpOp_commute_rule,
  /*  811 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  812 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  813 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  814 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  815 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  816 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  817 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  818 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  819 */  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule,
  /*  820 */  0,
  /*  821 */  0,
  /*  822 */  0,
  /*  823 */  0,
  /*  824 */  0,
  /*  825 */  0,
  /*  826 */  0,
  /*  827 */  eRegP_no_EBP_rule,
  /*  828 */  eRegP_no_EBP_rule,
  /*  829 */  0,
  /*  830 */  0,
  /*  831 */  0,
  /*  832 */  0,
  /*  833 */  regF_rule,
  /*  834 */  regF_rule,
  /*  835 */  _LoadF_memory__rule,
  /*  836 */  regF_rule,
  /*  837 */  regF_rule,
  /*  838 */  regF_rule,
  /*  839 */  _LoadF_memory__rule,
  /*  840 */  regF_rule,
  /*  841 */  regD_rule,
  /*  842 */  regD_rule,
  /*  843 */  _LoadD_memory__rule,
  /*  844 */  regD_rule,
  /*  845 */  regD_rule,
  /*  846 */  regD_rule,
  /*  847 */  _LoadD_memory__rule,
  /*  848 */  regD_rule,
  /*  849 */  regF_rule,
  /*  850 */  regF_rule,
  /*  851 */  regF_rule,
  /*  852 */  regF_rule,
  /*  853 */  regF_rule,
  /*  854 */  regF_rule,
  /*  855 */  regD_rule,
  /*  856 */  regD_rule,
  /*  857 */  regD_rule,
  /*  858 */  regD_rule,
  /*  859 */  regD_rule,
  /*  860 */  regD_rule,
  /*  861 */  regF_rule,
  /*  862 */  regF_rule,
  /*  863 */  _LoadF_memory__rule,
  /*  864 */  regF_rule,
  /*  865 */  regF_rule,
  /*  866 */  regF_rule,
  /*  867 */  _LoadF_memory__rule,
  /*  868 */  regF_rule,
  /*  869 */  regD_rule,
  /*  870 */  regD_rule,
  /*  871 */  _LoadD_memory__rule,
  /*  872 */  regD_rule,
  /*  873 */  regD_rule,
  /*  874 */  regD_rule,
  /*  875 */  _LoadD_memory__rule,
  /*  876 */  regD_rule,
  /*  877 */  regF_rule,
  /*  878 */  regF_rule,
  /*  879 */  regF_rule,
  /*  880 */  regF_rule,
  /*  881 */  regF_rule,
  /*  882 */  regF_rule,
  /*  883 */  regD_rule,
  /*  884 */  regD_rule,
  /*  885 */  regD_rule,
  /*  886 */  regD_rule,
  /*  887 */  regD_rule,
  /*  888 */  regD_rule,
  /*  889 */  regD_rule,
  /*  890 */  regD_rule,
  /*  891 */  _SqrtD__ConvF2D_regF___rule,
  /*  892 */  _SqrtD__ConvF2D__LoadF_memory____rule,
  /*  893 */  _SqrtD__ConvF2D_immF___rule,
  /*  894 */  regD_rule,
  /*  895 */  _LoadD_memory__rule,
  /*  896 */  immD_rule,
  /*  897 */  memory_rule,
  /*  898 */  memory_rule,
  /*  899 */  memory_rule,
  /*  900 */  memory_rule,
  /*  901 */  memory_rule,
  /*  902 */  memory_rule,
  /*  903 */  memory_rule,
  /*  904 */  memory_rule,
  /*  905 */  rRegI_rule,
  /*  906 */  rRegI_rule,
  /*  907 */  rRegI_rule,
  /*  908 */  rRegI_rule,
  /*  909 */  immI_rule,
  /*  910 */  immI_rule,
  /*  911 */  immI_rule,
  /*  912 */  immI_rule,
  /*  913 */  immI0_rule,
  /*  914 */  immI0_rule,
  /*  915 */  immI0_rule,
  /*  916 */  immI0_rule,
  /*  917 */  rRegI_rule,
  /*  918 */  rRegI_rule,
  /*  919 */  rRegI_rule,
  /*  920 */  rRegI_rule,
  /*  921 */  immI_rule,
  /*  922 */  immI_rule,
  /*  923 */  immI_rule,
  /*  924 */  immI_rule,
  /*  925 */  immI0_rule,
  /*  926 */  immI0_rule,
  /*  927 */  immI0_rule,
  /*  928 */  immI0_rule,
  /*  929 */  rRegI_rule,
  /*  930 */  rRegI_rule,
  /*  931 */  rRegI_rule,
  /*  932 */  immI_rule,
  /*  933 */  immI_rule,
  /*  934 */  immI_rule,
  /*  935 */  _LoadI_memory__rule,
  /*  936 */  _LoadI_memory__rule,
  /*  937 */  _LoadI_memory__rule,
  /*  938 */  immI0_rule,
  /*  939 */  immI0_rule,
  /*  940 */  immI0_rule,
  /*  941 */  eRegL_rule,
  /*  942 */  eRegL_rule,
  /*  943 */  immL_rule,
  /*  944 */  immL_rule,
  /*  945 */  _LoadL_memory__rule,
  /*  946 */  _LoadL_memory__rule,
  /*  947 */  immL0_rule,
  /*  948 */  immL0_rule,
  /*  949 */  regF_rule,
  /*  950 */  regF_rule,
  /*  951 */  regF_rule,
  /*  952 */  immF0_rule,
  /*  953 */  immF0_rule,
  /*  954 */  immF0_rule,
  /*  955 */  regD_rule,
  /*  956 */  regD_rule,
  /*  957 */  immD0_rule,
  /*  958 */  immD0_rule,
  /*  959 */  vecS_rule,
  /*  960 */  vecS_rule,
  /*  961 */  vecD_rule,
  /*  962 */  vecD_rule,
  /*  963 */  vecX_rule,
  /*  964 */  vecX_rule,
  /*  965 */  vecX_rule,
  /*  966 */  vecY_rule,
  /*  967 */  vecY_rule,
  /*  968 */  vecS_rule,
  /*  969 */  vecS_rule,
  /*  970 */  vecD_rule,
  /*  971 */  vecD_rule,
  /*  972 */  vecX_rule,
  /*  973 */  vecX_rule,
  /*  974 */  vecX_rule,
  /*  975 */  vecY_rule,
  /*  976 */  vecY_rule,
  /*  977 */  vecD_rule,
  /*  978 */  vecD_rule,
  /*  979 */  vecX_rule,
  /*  980 */  vecX_rule,
  /*  981 */  vecX_rule,
  /*  982 */  vecY_rule,
  /*  983 */  vecY_rule,
  /*  984 */  vecX_rule,
  /*  985 */  vecX_rule,
  /*  986 */  vecX_rule,
  /*  987 */  vecY_rule,
  /*  988 */  vecY_rule,
  /*  989 */  vecD_rule,
  /*  990 */  vecD_rule,
  /*  991 */  vecX_rule,
  /*  992 */  vecX_rule,
  /*  993 */  vecX_rule,
  /*  994 */  vecY_rule,
  /*  995 */  vecY_rule,
  /*  996 */  vecX_rule,
  /*  997 */  vecX_rule,
  /*  998 */  vecX_rule,
  /*  999 */  vecY_rule,
  /* 1000 */  vecY_rule,
  /* 1001 */  vecS_rule,
  /* 1002 */  vecS_rule,
  /* 1003 */  vecD_rule,
  /* 1004 */  vecD_rule,
  /* 1005 */  vecX_rule,
  /* 1006 */  vecX_rule,
  /* 1007 */  vecX_rule,
  /* 1008 */  vecY_rule,
  /* 1009 */  vecY_rule,
  /* 1010 */  vecS_rule,
  /* 1011 */  vecS_rule,
  /* 1012 */  vecD_rule,
  /* 1013 */  vecD_rule,
  /* 1014 */  vecX_rule,
  /* 1015 */  vecX_rule,
  /* 1016 */  vecX_rule,
  /* 1017 */  vecY_rule,
  /* 1018 */  vecY_rule,
  /* 1019 */  vecD_rule,
  /* 1020 */  vecD_rule,
  /* 1021 */  vecX_rule,
  /* 1022 */  vecX_rule,
  /* 1023 */  vecX_rule,
  /* 1024 */  vecY_rule,
  /* 1025 */  vecY_rule,
  /* 1026 */  vecX_rule,
  /* 1027 */  vecX_rule,
  /* 1028 */  vecX_rule,
  /* 1029 */  vecY_rule,
  /* 1030 */  vecY_rule,
  /* 1031 */  vecD_rule,
  /* 1032 */  vecD_rule,
  /* 1033 */  vecX_rule,
  /* 1034 */  vecX_rule,
  /* 1035 */  vecX_rule,
  /* 1036 */  vecY_rule,
  /* 1037 */  vecY_rule,
  /* 1038 */  vecX_rule,
  /* 1039 */  vecX_rule,
  /* 1040 */  vecX_rule,
  /* 1041 */  vecY_rule,
  /* 1042 */  vecY_rule,
  /* 1043 */  vecS_rule,
  /* 1044 */  vecS_rule,
  /* 1045 */  vecD_rule,
  /* 1046 */  vecD_rule,
  /* 1047 */  vecX_rule,
  /* 1048 */  vecX_rule,
  /* 1049 */  vecX_rule,
  /* 1050 */  vecY_rule,
  /* 1051 */  vecY_rule,
  /* 1052 */  vecD_rule,
  /* 1053 */  vecD_rule,
  /* 1054 */  vecX_rule,
  /* 1055 */  vecX_rule,
  /* 1056 */  vecX_rule,
  /* 1057 */  vecY_rule,
  /* 1058 */  vecY_rule,
  /* 1059 */  vecD_rule,
  /* 1060 */  vecD_rule,
  /* 1061 */  vecX_rule,
  /* 1062 */  vecX_rule,
  /* 1063 */  vecX_rule,
  /* 1064 */  vecY_rule,
  /* 1065 */  vecY_rule,
  /* 1066 */  vecX_rule,
  /* 1067 */  vecX_rule,
  /* 1068 */  vecX_rule,
  /* 1069 */  vecY_rule,
  /* 1070 */  vecY_rule,
  /* 1071 */  vecD_rule,
  /* 1072 */  vecD_rule,
  /* 1073 */  vecX_rule,
  /* 1074 */  vecX_rule,
  /* 1075 */  vecX_rule,
  /* 1076 */  vecY_rule,
  /* 1077 */  vecY_rule,
  /* 1078 */  vecX_rule,
  /* 1079 */  vecX_rule,
  /* 1080 */  vecX_rule,
  /* 1081 */  vecY_rule,
  /* 1082 */  vecY_rule,
  /* 1083 */  vecS_rule,
  /* 1084 */  vecS_rule,
  /* 1085 */  vecS_rule,
  /* 1086 */  vecS_rule,
  /* 1087 */  vecD_rule,
  /* 1088 */  vecD_rule,
  /* 1089 */  vecD_rule,
  /* 1090 */  vecD_rule,
  /* 1091 */  vecX_rule,
  /* 1092 */  vecX_rule,
  /* 1093 */  vecX_rule,
  /* 1094 */  vecX_rule,
  /* 1095 */  vecY_rule,
  /* 1096 */  vecY_rule,
  /* 1097 */  vecD_rule,
  /* 1098 */  vecD_rule,
  /* 1099 */  vecD_rule,
  /* 1100 */  vecD_rule,
  /* 1101 */  vecX_rule,
  /* 1102 */  vecX_rule,
  /* 1103 */  vecX_rule,
  /* 1104 */  vecX_rule,
  /* 1105 */  vecY_rule,
  /* 1106 */  vecY_rule,
  /* 1107 */  vecX_rule,
  /* 1108 */  vecX_rule,
  /* 1109 */  vecX_rule,
  /* 1110 */  vecX_rule,
  /* 1111 */  vecY_rule,
  /* 1112 */  vecY_rule,
  /* 1113 */  vecS_rule,
  /* 1114 */  vecS_rule,
  /* 1115 */  vecS_rule,
  /* 1116 */  vecS_rule,
  /* 1117 */  vecD_rule,
  /* 1118 */  vecD_rule,
  /* 1119 */  vecD_rule,
  /* 1120 */  vecD_rule,
  /* 1121 */  vecX_rule,
  /* 1122 */  vecX_rule,
  /* 1123 */  vecX_rule,
  /* 1124 */  vecX_rule,
  /* 1125 */  vecY_rule,
  /* 1126 */  vecY_rule,
  /* 1127 */  vecD_rule,
  /* 1128 */  vecD_rule,
  /* 1129 */  vecD_rule,
  /* 1130 */  vecD_rule,
  /* 1131 */  vecX_rule,
  /* 1132 */  vecX_rule,
  /* 1133 */  vecX_rule,
  /* 1134 */  vecX_rule,
  /* 1135 */  vecY_rule,
  /* 1136 */  vecY_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecX_rule,
  /* 1139 */  vecX_rule,
  /* 1140 */  vecX_rule,
  /* 1141 */  vecY_rule,
  /* 1142 */  vecY_rule,
  /* 1143 */  vecS_rule,
  /* 1144 */  vecS_rule,
  /* 1145 */  vecS_rule,
  /* 1146 */  vecS_rule,
  /* 1147 */  vecD_rule,
  /* 1148 */  vecD_rule,
  /* 1149 */  vecD_rule,
  /* 1150 */  vecD_rule,
  /* 1151 */  vecX_rule,
  /* 1152 */  vecX_rule,
  /* 1153 */  vecX_rule,
  /* 1154 */  vecX_rule,
  /* 1155 */  vecY_rule,
  /* 1156 */  vecY_rule,
  /* 1157 */  vecD_rule,
  /* 1158 */  vecD_rule,
  /* 1159 */  vecD_rule,
  /* 1160 */  vecD_rule,
  /* 1161 */  vecX_rule,
  /* 1162 */  vecX_rule,
  /* 1163 */  vecX_rule,
  /* 1164 */  vecX_rule,
  /* 1165 */  vecY_rule,
  /* 1166 */  vecY_rule,
  /* 1167 */  vecS_rule,
  /* 1168 */  vecS_rule,
  /* 1169 */  vecD_rule,
  /* 1170 */  vecD_rule,
  /* 1171 */  vecX_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecX_rule,
  /* 1174 */  vecY_rule,
  /* 1175 */  vecY_rule,
  /* 1176 */  vecS_rule,
  /* 1177 */  vecS_rule,
  /* 1178 */  vecD_rule,
  /* 1179 */  vecD_rule,
  /* 1180 */  vecX_rule,
  /* 1181 */  vecX_rule,
  /* 1182 */  vecX_rule,
  /* 1183 */  vecY_rule,
  /* 1184 */  vecY_rule,
  /* 1185 */  vecS_rule,
  /* 1186 */  vecS_rule,
  /* 1187 */  vecD_rule,
  /* 1188 */  vecD_rule,
  /* 1189 */  vecX_rule,
  /* 1190 */  vecX_rule,
  /* 1191 */  vecX_rule,
  /* 1192 */  vecY_rule,
  /* 1193 */  vecY_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  immI8_rule,
  /*   87 */  immI_rule,
  /*   88 */  rRegI_rule,
  /*   89 */  immI_rule,
  /*   90 */  rRegI_rule,
  /*   91 */  _LShiftI_rRegI_immI2_rule,
  /*   92 */  immI_rule,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  immI_rule,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  immI8_rule,
  /*  103 */  immI_rule,
  /*  104 */  immI_rule,
  /*  105 */  _LShiftI_rRegI_immI2_rule,
  /*  106 */  immI_rule,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  // last operand
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  // last operand class
  /*  120 */  rRegI_rule,
  /*  121 */  immI2_rule,
  /*  122 */  _LShiftI_rRegI_immI2_rule,
  /*  123 */  rRegI_rule,
  /*  124 */  _LShiftI_rRegI_immI2_rule,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  immI8_rule,
  /*  130 */  0,
  /*  131 */  immI_24_rule,
  /*  132 */  0,
  /*  133 */  immI_24_rule,
  /*  134 */  immI_255_rule,
  /*  135 */  immI16_rule,
  /*  136 */  immI_24_rule,
  /*  137 */  immI_16_rule,
  /*  138 */  immI_255_rule,
  /*  139 */  immI_65535_rule,
  /*  140 */  immI_rule,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  eFlagsReg_rule,
  /*  147 */  rRegI_rule,
  /*  148 */  eFlagsRegU_rule,
  /*  149 */  eFlagsRegUCF_rule,
  /*  150 */  _LoadI_memory__rule,
  /*  151 */  eRegP_rule,
  /*  152 */  eFlagsRegU_rule,
  /*  153 */  regDPR_rule,
  /*  154 */  regFPR_rule,
  /*  155 */  regDPR_rule,
  /*  156 */  regFPR_rule,
  /*  157 */  regF_rule,
  /*  158 */  regD_rule,
  /*  159 */  eRegL_rule,
  /*  160 */  rRegI_rule,
  /*  161 */  _LoadI_memory__rule,
  /*  162 */  immI_rule,
  /*  163 */  immI1_rule,
  /*  164 */  immI_M1_rule,
  /*  165 */  eRegP_rule,
  /*  166 */  rRegI_rule,
  /*  167 */  eBCXRegL_rule,
  /*  168 */  eCXRegP_rule,
  /*  169 */  eCXRegI_rule,
  /*  170 */  rRegI_rule,
  /*  171 */  rRegI_rule,
  /*  172 */  0,
  /*  173 */  eADXRegL_low_only_rule,
  /*  174 */  immI_32_rule,
  /*  175 */  _ConvI2L_nadxRegI__rule,
  /*  176 */  immI_32_rule,
  /*  177 */  immI_32_63_rule,
  /*  178 */  immI_32_63_rule,
  /*  179 */  0,
  /*  180 */  immL_32bits_rule,
  /*  181 */  immL_32bits_rule,
  /*  182 */  immI1_rule,
  /*  183 */  immI8_rule,
  /*  184 */  immI_24_rule,
  /*  185 */  immI_16_rule,
  /*  186 */  rRegI_rule,
  /*  187 */  _LoadI_memory__rule,
  /*  188 */  0,
  /*  189 */  rRegI_rule,
  /*  190 */  _LoadI_memory__rule,
  /*  191 */  immI_rule,
  /*  192 */  immI1_rule,
  /*  193 */  immI_M1_rule,
  /*  194 */  immI8_rule,
  /*  195 */  immI8_rule,
  /*  196 */  eCXRegI_rule,
  /*  197 */  eCXRegI_rule,
  /*  198 */  _SubI_immI0_eCXRegI_rule,
  /*  199 */  eCXRegI_rule,
  /*  200 */  _SubI_immI_32_eCXRegI_rule,
  /*  201 */  immI1_rule,
  /*  202 */  immI_M1_rule,
  /*  203 */  eCXRegI_rule,
  /*  204 */  _SubI_immI0_eCXRegI_rule,
  /*  205 */  _SubI_immI_32_eCXRegI_rule,
  /*  206 */  rRegI_rule,
  /*  207 */  _LoadI_memory__rule,
  /*  208 */  immI_rule,
  /*  209 */  rRegI_rule,
  /*  210 */  rRegI_rule,
  /*  211 */  rRegI_rule,
  /*  212 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  regDPR_rule,
  /*  216 */  regDPR_rule,
  /*  217 */  regDPR_rule,
  /*  218 */  0,
  /*  219 */  _LoadD_memory__rule,
  /*  220 */  0,
  /*  221 */  immDPR_rule,
  /*  222 */  regDPR_rule,
  /*  223 */  regDPR_rule,
  /*  224 */  0,
  /*  225 */  regFPR_rule,
  /*  226 */  _LoadF_memory__rule,
  /*  227 */  regFPR_rule,
  /*  228 */  regFPR_rule,
  /*  229 */  0,
  /*  230 */  eCXRegI_rule,
  /*  231 */  eDXRegI_rule,
  /*  232 */  eSIRegP_rule,
  /*  233 */  eDXRegI_rule,
  /*  234 */  immI_rule,
  /*  235 */  eAXRegI_rule,
  /*  236 */  immI_rule,
  /*  237 */  memory_rule,
  /*  238 */  0,
  /*  239 */  eAXRegI_rule,
  /*  240 */  eAXRegP_rule,
  /*  241 */  flagsReg_long_LTGE_rule,
  /*  242 */  _LoadL_load_long_memory__rule,
  /*  243 */  flagsReg_long_EQNE_rule,
  /*  244 */  flagsReg_long_LEGT_rule,
  /*  245 */  0,
  /*  246 */  0,
  /*  247 */  0,
  /*  248 */  0,
  /*  249 */  0,
  /*  250 */  0,
  /*  251 */  0,
  // last internally defined operand
  /*  252 */  0,
  /*  253 */  0,
  /*  254 */  0,
  /*  255 */  0,
  /*  256 */  0,
  /*  257 */  0,
  /*  258 */  0,
  /*  259 */  0,
  /*  260 */  0,
  /*  261 */  0,
  /*  262 */  0,
  /*  263 */  0,
  /*  264 */  0,
  /*  265 */  0,
  /*  266 */  0,
  /*  267 */  0,
  /*  268 */  0,
  /*  269 */  0,
  /*  270 */  0,
  /*  271 */  0,
  /*  272 */  0,
  /*  273 */  0,
  /*  274 */  0,
  /*  275 */  0,
  /*  276 */  0,
  /*  277 */  0,
  /*  278 */  0,
  /*  279 */  0,
  /*  280 */  0,
  /*  281 */  0,
  /*  282 */  0,
  /*  283 */  0,
  /*  284 */  0,
  /*  285 */  0,
  /*  286 */  0,
  /*  287 */  _Binary_eAXRegP_eRegP_rule,
  /*  288 */  _Binary_eAXRegI_rRegI_rule,
  /*  289 */  _Binary_eADXRegL_eBCXRegL_rule,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  regDPR_rule,
  /*  293 */  regDPR_rule,
  /*  294 */  regDPR_rule,
  /*  295 */  regD_rule,
  /*  296 */  regD_rule,
  /*  297 */  _LoadD_memory__rule,
  /*  298 */  _LoadD_memory__rule,
  /*  299 */  0,
  /*  300 */  regFPR_rule,
  /*  301 */  regFPR_rule,
  /*  302 */  regFPR_rule,
  /*  303 */  regF_rule,
  /*  304 */  regF_rule,
  /*  305 */  _LoadF_memory__rule,
  /*  306 */  _LoadF_memory__rule,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  0,
  /*  312 */  0,
  /*  313 */  0,
  /*  314 */  0,
  /*  315 */  0,
  /*  316 */  0,
  /*  317 */  0,
  /*  318 */  rRegI_rule,
  /*  319 */  immI_rule,
  /*  320 */  _LoadI_memory__rule,
  /*  321 */  immI0_rule,
  /*  322 */  immI0_rule,
  /*  323 */  immI0_rule,
  /*  324 */  rRegI_rule,
  /*  325 */  immI_rule,
  /*  326 */  _LoadI_memory__rule,
  /*  327 */  immI0_rule,
  /*  328 */  eRegP_rule,
  /*  329 */  immP_rule,
  /*  330 */  _LoadP_memory__rule,
  /*  331 */  _LoadP_memory__rule,
  /*  332 */  immP0_rule,
  /*  333 */  immI0_rule,
  /*  334 */  immP0_rule,
  /*  335 */  immL0_rule,
  /*  336 */  eRegL_rule,
  /*  337 */  immL0_rule,
  /*  338 */  eRegL_rule,
  /*  339 */  immL0_rule,
  /*  340 */  eRegL_rule,
  /*  341 */  eBXRegP_rule,
  /*  342 */  eAXRegP_rule,
  /*  343 */  0,
  /*  344 */  0,
  /*  345 */  0,
  /*  346 */  0,
  /*  347 */  0,
  /*  348 */  0,
  /*  349 */  0,
  /*  350 */  0,
  /*  351 */  0,
  /*  352 */  0,
  /*  353 */  0,
  /*  354 */  0,
  /*  355 */  0,
  /*  356 */  0,
  /*  357 */  0,
  /*  358 */  0,
  /*  359 */  0,
  /*  360 */  0,
  /*  361 */  0,
  /*  362 */  0,
  /*  363 */  0,
  /*  364 */  0,
  /*  365 */  0,
  /*  366 */  0,
  /*  367 */  0,
  /*  368 */  0,
  /*  369 */  0,
  /*  370 */  0,
  /*  371 */  0,
  /*  372 */  immI_24_rule,
  /*  373 */  0,
  /*  374 */  0,
  /*  375 */  immI_24_rule,
  /*  376 */  0,
  /*  377 */  0,
  /*  378 */  0,
  /*  379 */  0,
  /*  380 */  immI_24_rule,
  /*  381 */  immI_255_rule,
  /*  382 */  immI_16_rule,
  /*  383 */  immI_65535_rule,
  /*  384 */  0,
  /*  385 */  0,
  /*  386 */  0,
  /*  387 */  0,
  /*  388 */  immL_32bits_rule,
  /*  389 */  0,
  /*  390 */  0,
  /*  391 */  0,
  /*  392 */  0,
  /*  393 */  0,
  /*  394 */  0,
  /*  395 */  0,
  /*  396 */  0,
  /*  397 */  0,
  /*  398 */  0,
  /*  399 */  0,
  /*  400 */  0,
  /*  401 */  0,
  /*  402 */  0,
  /*  403 */  0,
  /*  404 */  0,
  /*  405 */  0,
  /*  406 */  0,
  /*  407 */  0,
  /*  408 */  0,
  /*  409 */  0,
  /*  410 */  0,
  /*  411 */  0,
  /*  412 */  0,
  /*  413 */  0,
  /*  414 */  xRegI_rule,
  /*  415 */  rRegI_rule,
  /*  416 */  rRegI_rule,
  /*  417 */  eRegL_rule,
  /*  418 */  _ConvL2I_eRegL__rule,
  /*  419 */  stackSlotL_rule,
  /*  420 */  stackSlotL_rule,
  /*  421 */  eRegL_rule,
  /*  422 */  anyRegP_rule,
  /*  423 */  immI_rule,
  /*  424 */  immI16_rule,
  /*  425 */  immP_rule,
  /*  426 */  immI8_rule,
  /*  427 */  immI8_rule,
  /*  428 */  regDPR1_rule,
  /*  429 */  _RoundDouble_regDPR1__rule,
  /*  430 */  regD_rule,
  /*  431 */  regF_rule,
  /*  432 */  regFPR1_rule,
  /*  433 */  _RoundFloat_regFPR1__rule,
  /*  434 */  _ConvD2F_regDPR1__rule,
  /*  435 */  immFPR_rule,
  /*  436 */  immF_rule,
  /*  437 */  0,
  /*  438 */  0,
  /*  439 */  0,
  /*  440 */  0,
  /*  441 */  0,
  /*  442 */  0,
  /*  443 */  _Binary_rRegI_rRegI_rule,
  /*  444 */  _Binary_rRegI_rRegI_rule,
  /*  445 */  _Binary_rRegI_rRegI_rule,
  /*  446 */  _Binary_rRegI_rRegI_rule,
  /*  447 */  _Binary_rRegI_rRegI_rule,
  /*  448 */  _Binary_rRegI__LoadI_memory__rule,
  /*  449 */  _Binary_rRegI__LoadI_memory__rule,
  /*  450 */  _Binary_rRegI__LoadI_memory__rule,
  /*  451 */  _Binary_eRegP_eRegP_rule,
  /*  452 */  _Binary_eRegP_eRegP_rule,
  /*  453 */  _Binary_eRegP_eRegP_rule,
  /*  454 */  _Binary_eRegP_eRegP_rule,
  /*  455 */  _Binary_regDPR1_regDPR_rule,
  /*  456 */  _Binary_regFPR1_regFPR_rule,
  /*  457 */  _Binary_regDPR_regDPR_rule,
  /*  458 */  _Binary_regFPR_regFPR_rule,
  /*  459 */  _Binary_regF_regF_rule,
  /*  460 */  _Binary_regD_regD_rule,
  /*  461 */  _Binary_regF_regF_rule,
  /*  462 */  _Binary_regF_regF_rule,
  /*  463 */  _Binary_regD_regD_rule,
  /*  464 */  _Binary_regD_regD_rule,
  /*  465 */  _Binary_eRegL_eRegL_rule,
  /*  466 */  _Binary_eRegL_eRegL_rule,
  /*  467 */  _Binary_eRegL_eRegL_rule,
  /*  468 */  rRegI_rule,
  /*  469 */  immI_rule,
  /*  470 */  immI1_rule,
  /*  471 */  immI_rule,
  /*  472 */  immI_rule,
  /*  473 */  immI_M1_rule,
  /*  474 */  rRegI_rule,
  /*  475 */  immI_rule,
  /*  476 */  _LoadI_memory__rule,
  /*  477 */  rRegI_rule,
  /*  478 */  _AddI__LoadI_memory__rRegI_rule,
  /*  479 */  _AddI_rRegI__LoadI_memory__rule,
  /*  480 */  _AddI__LoadI_memory__immI_rule,
  /*  481 */  _AddI__LoadI_memory__immI1_rule,
  /*  482 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  483 */  0,
  /*  484 */  _Binary_eADXRegL_eBCXRegL_rule,
  /*  485 */  _Binary_eAXRegP_eCXRegP_rule,
  /*  486 */  immI_rule,
  /*  487 */  rRegI_rule,
  /*  488 */  rRegI_rule,
  /*  489 */  pRegP_rule,
  /*  490 */  _Binary_eAXRegI_eCXRegI_rule,
  /*  491 */  rRegI_rule,
  /*  492 */  immI_rule,
  /*  493 */  _LoadI_memory__rule,
  /*  494 */  _SubI__LoadI_memory__rRegI_rule,
  /*  495 */  _SubI_immI0_rRegI_rule,
  /*  496 */  rRegI_rule,
  /*  497 */  rRegI_rule,
  /*  498 */  immI_rule,
  /*  499 */  0,
  /*  500 */  0,
  /*  501 */  0,
  /*  502 */  0,
  /*  503 */  immI_rule,
  /*  504 */  _LoadI_memory__rule,
  /*  505 */  rRegI_rule,
  /*  506 */  _ConvI2L_nadxRegI__rule,
  /*  507 */  _ConvI2L_eAXRegI__rule,
  /*  508 */  _AndL__ConvI2L_nadxRegI__immL_32bits_rule,
  /*  509 */  _AndL__ConvI2L_eAXRegI__immL_32bits_rule,
  /*  510 */  eRegL_rule,
  /*  511 */  eRegL_rule,
  /*  512 */  eRegL_rule,
  /*  513 */  eRegL_rule,
  /*  514 */  immL_127_rule,
  /*  515 */  eCXRegI_rule,
  /*  516 */  eRegL_rule,
  /*  517 */  eCXRegI_rule,
  /*  518 */  eCXRegI_rule,
  /*  519 */  eRegL_rule,
  /*  520 */  immL32_rule,
  /*  521 */  immL32_rule,
  /*  522 */  immI1_rule,
  /*  523 */  immI8_rule,
  /*  524 */  eCXRegI_rule,
  /*  525 */  immI1_rule,
  /*  526 */  _RShiftI__LoadI_memory__immI1_rule,
  /*  527 */  immI8_rule,
  /*  528 */  _RShiftI__LoadI_memory__immI8_rule,
  /*  529 */  eCXRegI_rule,
  /*  530 */  immI1_rule,
  /*  531 */  immI8_rule,
  /*  532 */  immI_24_rule,
  /*  533 */  immI_16_rule,
  /*  534 */  eCXRegI_rule,
  /*  535 */  rRegI_rule,
  /*  536 */  immI_rule,
  /*  537 */  _LoadI_memory__rule,
  /*  538 */  rRegI_rule,
  /*  539 */  _AndI__LoadI_memory__rRegI_rule,
  /*  540 */  _AndI_rRegI__LoadI_memory__rule,
  /*  541 */  _AndI__LoadI_memory__immI_rule,
  /*  542 */  rRegI_rule,
  /*  543 */  _CastP2X_eRegP__rule,
  /*  544 */  rRegI_rule,
  /*  545 */  immI_rule,
  /*  546 */  _LoadI_memory__rule,
  /*  547 */  rRegI_rule,
  /*  548 */  _OrI__LoadI_memory__rRegI_rule,
  /*  549 */  _OrI_rRegI__LoadI_memory__rule,
  /*  550 */  _OrI__LoadI_memory__immI_rule,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  _URShiftI_rRegI_immI_M1_rule,
  /*  555 */  _LShiftI_rRegI_immI1_rule,
  /*  556 */  _URShiftI_rRegI_immI8_rule,
  /*  557 */  _LShiftI_rRegI_immI8_rule,
  /*  558 */  _URShiftI_ncxRegI__SubI_immI0_eCXRegI_rule,
  /*  559 */  _LShiftI_ncxRegI_eCXRegI_rule,
  /*  560 */  _URShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule,
  /*  561 */  _LShiftI_ncxRegI_eCXRegI_rule,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  _LShiftI_rRegI_immI_M1_rule,
  /*  566 */  _URShiftI_rRegI_immI1_rule,
  /*  567 */  _LShiftI_rRegI_immI8_rule,
  /*  568 */  _URShiftI_rRegI_immI8_rule,
  /*  569 */  _LShiftI_ncxRegI__SubI_immI0_eCXRegI_rule,
  /*  570 */  _URShiftI_ncxRegI_eCXRegI_rule,
  /*  571 */  _LShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule,
  /*  572 */  _URShiftI_ncxRegI_eCXRegI_rule,
  /*  573 */  rRegI_rule,
  /*  574 */  immI_M1_rule,
  /*  575 */  immI_rule,
  /*  576 */  _LoadI_memory__rule,
  /*  577 */  rRegI_rule,
  /*  578 */  _XorI__LoadI_memory__rRegI_rule,
  /*  579 */  _XorI_rRegI__LoadI_memory__rule,
  /*  580 */  _XorI__LoadI_memory__immI_rule,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  ncxRegI_rule,
  /*  586 */  immI0_rule,
  /*  587 */  _SubI_rRegI_rRegI_rule,
  /*  588 */  _AndI__CmpLTMask_rRegI_rRegI_rRegI_rule,
  /*  589 */  _SubI_rRegI_rRegI_rule,
  /*  590 */  _AndI_rRegI__CmpLTMask_rRegI_rRegI_rule,
  /*  591 */  rRegI_rule,
  /*  592 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  593 */  eRegL_rule,
  /*  594 */  immL_rule,
  /*  595 */  _LoadL_load_long_memory__rule,
  /*  596 */  eRegL_rule,
  /*  597 */  eRegL_rule,
  /*  598 */  immL_rule,
  /*  599 */  _LoadL_load_long_memory__rule,
  /*  600 */  eRegL_rule,
  /*  601 */  eRegL_rule,
  /*  602 */  immL_rule,
  /*  603 */  _LoadL_load_long_memory__rule,
  /*  604 */  eRegL_rule,
  /*  605 */  eRegL_rule,
  /*  606 */  immL_rule,
  /*  607 */  _LoadL_load_long_memory__rule,
  /*  608 */  eRegL_rule,
  /*  609 */  eRegL_rule,
  /*  610 */  immL_M1_rule,
  /*  611 */  immL_rule,
  /*  612 */  _LoadL_load_long_memory__rule,
  /*  613 */  eRegL_rule,
  /*  614 */  immI_1_rule,
  /*  615 */  immI_2_rule,
  /*  616 */  immI_3_rule,
  /*  617 */  immI_1_31_rule,
  /*  618 */  immI_32_63_rule,
  /*  619 */  eCXRegI_rule,
  /*  620 */  immI_1_31_rule,
  /*  621 */  immI_32_63_rule,
  /*  622 */  eCXRegI_rule,
  /*  623 */  immI_1_31_rule,
  /*  624 */  immI_32_63_rule,
  /*  625 */  eCXRegI_rule,
  /*  626 */  immDPR0_rule,
  /*  627 */  regDPR_rule,
  /*  628 */  regD_rule,
  /*  629 */  _LoadD_memory__rule,
  /*  630 */  regDPR_rule,
  /*  631 */  0,
  /*  632 */  _LoadD_memory__rule,
  /*  633 */  0,
  /*  634 */  regDPR_rule,
  /*  635 */  0,
  /*  636 */  _LoadD_memory__rule,
  /*  637 */  regDPR_rule,
  /*  638 */  _RoundDouble__AddD__LoadD_memory__regDPR__rule,
  /*  639 */  _RoundDouble__AddD_regDPR__LoadD_memory___rule,
  /*  640 */  immDPR1_rule,
  /*  641 */  immDPR_rule,
  /*  642 */  0,
  /*  643 */  regDPR_rule,
  /*  644 */  regnotDPR1_rule,
  /*  645 */  immDPR_rule,
  /*  646 */  _LoadD_memory__rule,
  /*  647 */  regDPR_rule,
  /*  648 */  _LoadD_memory__rule,
  /*  649 */  regDPR_rule,
  /*  650 */  regDPR_rule,
  /*  651 */  _MulD_regDPR_regDPR_rule,
  /*  652 */  regDPR_rule,
  /*  653 */  regDPR_rule,
  /*  654 */  regnotDPR1_rule,
  /*  655 */  0,
  /*  656 */  regDPR_rule,
  /*  657 */  regD_rule,
  /*  658 */  0,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  0,
  /*  664 */  regDPR_rule,
  /*  665 */  regD_rule,
  /*  666 */  0,
  /*  667 */  regDPR1_rule,
  /*  668 */  regD_rule,
  /*  669 */  0,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  immFPR0_rule,
  /*  676 */  regFPR_rule,
  /*  677 */  regF_rule,
  /*  678 */  _LoadF_memory__rule,
  /*  679 */  regFPR_rule,
  /*  680 */  regFPR_rule,
  /*  681 */  regFPR_rule,
  /*  682 */  regFPR_rule,
  /*  683 */  _LoadF_memory__rule,
  /*  684 */  regFPR_rule,
  /*  685 */  _LoadF_memory__rule,
  /*  686 */  regFPR_rule,
  /*  687 */  regFPR_rule,
  /*  688 */  _LoadF_memory__rule,
  /*  689 */  memory_rule,
  /*  690 */  memory_rule,
  /*  691 */  immFPR_rule,
  /*  692 */  immFPR_rule,
  /*  693 */  regFPR_rule,
  /*  694 */  regFPR_rule,
  /*  695 */  _LoadF_memory__rule,
  /*  696 */  regFPR_rule,
  /*  697 */  _LoadF_memory__rule,
  /*  698 */  regFPR_rule,
  /*  699 */  memory_rule,
  /*  700 */  immFPR_rule,
  /*  701 */  immFPR_rule,
  /*  702 */  regFPR_rule,
  /*  703 */  _LoadF_memory__rule,
  /*  704 */  regFPR_rule,
  /*  705 */  _MulF__LoadF_memory__regFPR_rule,
  /*  706 */  regFPR_rule,
  /*  707 */  _MulF_regFPR__LoadF_memory__rule,
  /*  708 */  regFPR_rule,
  /*  709 */  _MulF_regFPR_regFPR_rule,
  /*  710 */  regFPR_rule,
  /*  711 */  regFPR_rule,
  /*  712 */  regFPR_rule,
  /*  713 */  regFPR_rule,
  /*  714 */  regFPR_rule,
  /*  715 */  regF_rule,
  /*  716 */  0,
  /*  717 */  0,
  /*  718 */  0,
  /*  719 */  0,
  /*  720 */  0,
  /*  721 */  0,
  /*  722 */  0,
  /*  723 */  0,
  /*  724 */  0,
  /*  725 */  0,
  /*  726 */  0,
  /*  727 */  0,
  /*  728 */  0,
  /*  729 */  0,
  /*  730 */  0,
  /*  731 */  0,
  /*  732 */  0,
  /*  733 */  0,
  /*  734 */  0,
  /*  735 */  0,
  /*  736 */  0,
  /*  737 */  0,
  /*  738 */  0,
  /*  739 */  0,
  /*  740 */  0,
  /*  741 */  0,
  /*  742 */  0,
  /*  743 */  0,
  /*  744 */  0,
  /*  745 */  0,
  /*  746 */  immL_32bits_rule,
  /*  747 */  immL_32bits_rule,
  /*  748 */  0,
  /*  749 */  0,
  /*  750 */  0,
  /*  751 */  0,
  /*  752 */  0,
  /*  753 */  0,
  /*  754 */  0,
  /*  755 */  0,
  /*  756 */  0,
  /*  757 */  0,
  /*  758 */  0,
  /*  759 */  0,
  /*  760 */  0,
  /*  761 */  eDIRegP_rule,
  /*  762 */  eDIRegP_rule,
  /*  763 */  _Binary_eSIRegP_eDXRegI_rule,
  /*  764 */  eCXRegI_rule,
  /*  765 */  _Binary_eSIRegP_immI_rule,
  /*  766 */  _Binary_eSIRegP_eAXRegI_rule,
  /*  767 */  eSIRegP_rule,
  /*  768 */  rRegI_rule,
  /*  769 */  rRegI_rule,
  /*  770 */  immI_rule,
  /*  771 */  0,
  /*  772 */  0,
  /*  773 */  eFlagsReg_rule,
  /*  774 */  eFlagsReg_rule,
  /*  775 */  eFlagsRegU_rule,
  /*  776 */  eFlagsRegUCF_rule,
  /*  777 */  eFlagsRegU_rule,
  /*  778 */  eFlagsRegUCF_rule,
  /*  779 */  eFlagsRegUCF_rule,
  /*  780 */  eAXRegP_rule,
  /*  781 */  0,
  /*  782 */  eFlagsReg_rule,
  /*  783 */  eFlagsReg_rule,
  /*  784 */  eFlagsRegU_rule,
  /*  785 */  eFlagsRegUCF_rule,
  /*  786 */  eFlagsRegU_rule,
  /*  787 */  eFlagsRegUCF_rule,
  /*  788 */  eFlagsRegUCF_rule,
  /*  789 */  eRegL_rule,
  /*  790 */  flagsReg_long_LTGE_rule,
  /*  791 */  _Binary_eRegL_eRegL_rule,
  /*  792 */  _Binary_eRegL__LoadL_load_long_memory__rule,
  /*  793 */  _Binary_rRegI_rRegI_rule,
  /*  794 */  _Binary_rRegI__LoadI_memory__rule,
  /*  795 */  _Binary_eRegP_eRegP_rule,
  /*  796 */  _Binary_regDPR_regDPR_rule,
  /*  797 */  _Binary_regD_regD_rule,
  /*  798 */  _Binary_regFPR_regFPR_rule,
  /*  799 */  _Binary_regF_regF_rule,
  /*  800 */  flagsReg_long_EQNE_rule,
  /*  801 */  _Binary_eRegL_eRegL_rule,
  /*  802 */  _Binary_eRegL__LoadL_load_long_memory__rule,
  /*  803 */  _Binary_rRegI_rRegI_rule,
  /*  804 */  _Binary_rRegI__LoadI_memory__rule,
  /*  805 */  _Binary_eRegP_eRegP_rule,
  /*  806 */  _Binary_regDPR_regDPR_rule,
  /*  807 */  _Binary_regD_regD_rule,
  /*  808 */  _Binary_regFPR_regFPR_rule,
  /*  809 */  _Binary_regF_regF_rule,
  /*  810 */  flagsReg_long_LEGT_rule,
  /*  811 */  _Binary_eRegL_eRegL_rule,
  /*  812 */  _Binary_eRegL__LoadL_load_long_memory__rule,
  /*  813 */  _Binary_rRegI_rRegI_rule,
  /*  814 */  _Binary_rRegI__LoadI_memory__rule,
  /*  815 */  _Binary_eRegP_eRegP_rule,
  /*  816 */  _Binary_regDPR_regDPR_rule,
  /*  817 */  _Binary_regD_regD_rule,
  /*  818 */  _Binary_regFPR_regFPR_rule,
  /*  819 */  _Binary_regF_regF_rule,
  /*  820 */  0,
  /*  821 */  0,
  /*  822 */  0,
  /*  823 */  0,
  /*  824 */  0,
  /*  825 */  0,
  /*  826 */  0,
  /*  827 */  eBXRegP_rule,
  /*  828 */  eAXRegP_rule,
  /*  829 */  0,
  /*  830 */  0,
  /*  831 */  0,
  /*  832 */  0,
  /*  833 */  regF_rule,
  /*  834 */  _LoadF_memory__rule,
  /*  835 */  regF_rule,
  /*  836 */  immF_rule,
  /*  837 */  regF_rule,
  /*  838 */  _LoadF_memory__rule,
  /*  839 */  regF_rule,
  /*  840 */  immF_rule,
  /*  841 */  regD_rule,
  /*  842 */  _LoadD_memory__rule,
  /*  843 */  regD_rule,
  /*  844 */  immD_rule,
  /*  845 */  regD_rule,
  /*  846 */  _LoadD_memory__rule,
  /*  847 */  regD_rule,
  /*  848 */  immD_rule,
  /*  849 */  regF_rule,
  /*  850 */  _LoadF_memory__rule,
  /*  851 */  immF_rule,
  /*  852 */  regF_rule,
  /*  853 */  _LoadF_memory__rule,
  /*  854 */  immF_rule,
  /*  855 */  regD_rule,
  /*  856 */  _LoadD_memory__rule,
  /*  857 */  immD_rule,
  /*  858 */  regD_rule,
  /*  859 */  _LoadD_memory__rule,
  /*  860 */  immD_rule,
  /*  861 */  regF_rule,
  /*  862 */  _LoadF_memory__rule,
  /*  863 */  regF_rule,
  /*  864 */  immF_rule,
  /*  865 */  regF_rule,
  /*  866 */  _LoadF_memory__rule,
  /*  867 */  regF_rule,
  /*  868 */  immF_rule,
  /*  869 */  regD_rule,
  /*  870 */  _LoadD_memory__rule,
  /*  871 */  regD_rule,
  /*  872 */  immD_rule,
  /*  873 */  regD_rule,
  /*  874 */  _LoadD_memory__rule,
  /*  875 */  regD_rule,
  /*  876 */  immD_rule,
  /*  877 */  regF_rule,
  /*  878 */  _LoadF_memory__rule,
  /*  879 */  immF_rule,
  /*  880 */  regF_rule,
  /*  881 */  _LoadF_memory__rule,
  /*  882 */  immF_rule,
  /*  883 */  regD_rule,
  /*  884 */  _LoadD_memory__rule,
  /*  885 */  immD_rule,
  /*  886 */  regD_rule,
  /*  887 */  _LoadD_memory__rule,
  /*  888 */  immD_rule,
  /*  889 */  0,
  /*  890 */  0,
  /*  891 */  0,
  /*  892 */  0,
  /*  893 */  0,
  /*  894 */  0,
  /*  895 */  0,
  /*  896 */  0,
  /*  897 */  0,
  /*  898 */  0,
  /*  899 */  0,
  /*  900 */  0,
  /*  901 */  vecS_rule,
  /*  902 */  vecD_rule,
  /*  903 */  vecX_rule,
  /*  904 */  vecY_rule,
  /*  905 */  0,
  /*  906 */  0,
  /*  907 */  0,
  /*  908 */  0,
  /*  909 */  0,
  /*  910 */  0,
  /*  911 */  0,
  /*  912 */  0,
  /*  913 */  0,
  /*  914 */  0,
  /*  915 */  0,
  /*  916 */  0,
  /*  917 */  0,
  /*  918 */  0,
  /*  919 */  0,
  /*  920 */  0,
  /*  921 */  0,
  /*  922 */  0,
  /*  923 */  0,
  /*  924 */  0,
  /*  925 */  0,
  /*  926 */  0,
  /*  927 */  0,
  /*  928 */  0,
  /*  929 */  0,
  /*  930 */  0,
  /*  931 */  0,
  /*  932 */  0,
  /*  933 */  0,
  /*  934 */  0,
  /*  935 */  0,
  /*  936 */  0,
  /*  937 */  0,
  /*  938 */  0,
  /*  939 */  0,
  /*  940 */  0,
  /*  941 */  0,
  /*  942 */  0,
  /*  943 */  0,
  /*  944 */  0,
  /*  945 */  0,
  /*  946 */  0,
  /*  947 */  0,
  /*  948 */  0,
  /*  949 */  0,
  /*  950 */  0,
  /*  951 */  0,
  /*  952 */  0,
  /*  953 */  0,
  /*  954 */  0,
  /*  955 */  0,
  /*  956 */  0,
  /*  957 */  0,
  /*  958 */  0,
  /*  959 */  vecS_rule,
  /*  960 */  vecS_rule,
  /*  961 */  vecD_rule,
  /*  962 */  vecD_rule,
  /*  963 */  vecX_rule,
  /*  964 */  vecX_rule,
  /*  965 */  _LoadVector_memory__rule,
  /*  966 */  vecY_rule,
  /*  967 */  _LoadVector_memory__rule,
  /*  968 */  vecS_rule,
  /*  969 */  vecS_rule,
  /*  970 */  vecD_rule,
  /*  971 */  vecD_rule,
  /*  972 */  vecX_rule,
  /*  973 */  vecX_rule,
  /*  974 */  _LoadVector_memory__rule,
  /*  975 */  vecY_rule,
  /*  976 */  _LoadVector_memory__rule,
  /*  977 */  vecD_rule,
  /*  978 */  vecD_rule,
  /*  979 */  vecX_rule,
  /*  980 */  vecX_rule,
  /*  981 */  _LoadVector_memory__rule,
  /*  982 */  vecY_rule,
  /*  983 */  _LoadVector_memory__rule,
  /*  984 */  vecX_rule,
  /*  985 */  vecX_rule,
  /*  986 */  _LoadVector_memory__rule,
  /*  987 */  vecY_rule,
  /*  988 */  _LoadVector_memory__rule,
  /*  989 */  vecD_rule,
  /*  990 */  vecD_rule,
  /*  991 */  vecX_rule,
  /*  992 */  vecX_rule,
  /*  993 */  _LoadVector_memory__rule,
  /*  994 */  vecY_rule,
  /*  995 */  _LoadVector_memory__rule,
  /*  996 */  vecX_rule,
  /*  997 */  vecX_rule,
  /*  998 */  _LoadVector_memory__rule,
  /*  999 */  vecY_rule,
  /* 1000 */  _LoadVector_memory__rule,
  /* 1001 */  vecS_rule,
  /* 1002 */  vecS_rule,
  /* 1003 */  vecD_rule,
  /* 1004 */  vecD_rule,
  /* 1005 */  vecX_rule,
  /* 1006 */  vecX_rule,
  /* 1007 */  _LoadVector_memory__rule,
  /* 1008 */  vecY_rule,
  /* 1009 */  _LoadVector_memory__rule,
  /* 1010 */  vecS_rule,
  /* 1011 */  vecS_rule,
  /* 1012 */  vecD_rule,
  /* 1013 */  vecD_rule,
  /* 1014 */  vecX_rule,
  /* 1015 */  vecX_rule,
  /* 1016 */  _LoadVector_memory__rule,
  /* 1017 */  vecY_rule,
  /* 1018 */  _LoadVector_memory__rule,
  /* 1019 */  vecD_rule,
  /* 1020 */  vecD_rule,
  /* 1021 */  vecX_rule,
  /* 1022 */  vecX_rule,
  /* 1023 */  _LoadVector_memory__rule,
  /* 1024 */  vecY_rule,
  /* 1025 */  _LoadVector_memory__rule,
  /* 1026 */  vecX_rule,
  /* 1027 */  vecX_rule,
  /* 1028 */  _LoadVector_memory__rule,
  /* 1029 */  vecY_rule,
  /* 1030 */  _LoadVector_memory__rule,
  /* 1031 */  vecD_rule,
  /* 1032 */  vecD_rule,
  /* 1033 */  vecX_rule,
  /* 1034 */  vecX_rule,
  /* 1035 */  _LoadVector_memory__rule,
  /* 1036 */  vecY_rule,
  /* 1037 */  _LoadVector_memory__rule,
  /* 1038 */  vecX_rule,
  /* 1039 */  vecX_rule,
  /* 1040 */  _LoadVector_memory__rule,
  /* 1041 */  vecY_rule,
  /* 1042 */  _LoadVector_memory__rule,
  /* 1043 */  vecS_rule,
  /* 1044 */  vecS_rule,
  /* 1045 */  vecD_rule,
  /* 1046 */  vecD_rule,
  /* 1047 */  vecX_rule,
  /* 1048 */  vecX_rule,
  /* 1049 */  _LoadVector_memory__rule,
  /* 1050 */  vecY_rule,
  /* 1051 */  _LoadVector_memory__rule,
  /* 1052 */  vecD_rule,
  /* 1053 */  vecD_rule,
  /* 1054 */  vecX_rule,
  /* 1055 */  vecX_rule,
  /* 1056 */  _LoadVector_memory__rule,
  /* 1057 */  vecY_rule,
  /* 1058 */  _LoadVector_memory__rule,
  /* 1059 */  vecD_rule,
  /* 1060 */  vecD_rule,
  /* 1061 */  vecX_rule,
  /* 1062 */  vecX_rule,
  /* 1063 */  _LoadVector_memory__rule,
  /* 1064 */  vecY_rule,
  /* 1065 */  _LoadVector_memory__rule,
  /* 1066 */  vecX_rule,
  /* 1067 */  vecX_rule,
  /* 1068 */  _LoadVector_memory__rule,
  /* 1069 */  vecY_rule,
  /* 1070 */  _LoadVector_memory__rule,
  /* 1071 */  vecD_rule,
  /* 1072 */  vecD_rule,
  /* 1073 */  vecX_rule,
  /* 1074 */  vecX_rule,
  /* 1075 */  _LoadVector_memory__rule,
  /* 1076 */  vecY_rule,
  /* 1077 */  _LoadVector_memory__rule,
  /* 1078 */  vecX_rule,
  /* 1079 */  vecX_rule,
  /* 1080 */  _LoadVector_memory__rule,
  /* 1081 */  vecY_rule,
  /* 1082 */  _LoadVector_memory__rule,
  /* 1083 */  vecS_rule,
  /* 1084 */  immI8_rule,
  /* 1085 */  vecS_rule,
  /* 1086 */  immI8_rule,
  /* 1087 */  vecS_rule,
  /* 1088 */  immI8_rule,
  /* 1089 */  vecS_rule,
  /* 1090 */  immI8_rule,
  /* 1091 */  vecS_rule,
  /* 1092 */  immI8_rule,
  /* 1093 */  vecS_rule,
  /* 1094 */  immI8_rule,
  /* 1095 */  vecS_rule,
  /* 1096 */  immI8_rule,
  /* 1097 */  vecS_rule,
  /* 1098 */  immI8_rule,
  /* 1099 */  vecS_rule,
  /* 1100 */  immI8_rule,
  /* 1101 */  vecS_rule,
  /* 1102 */  immI8_rule,
  /* 1103 */  vecS_rule,
  /* 1104 */  immI8_rule,
  /* 1105 */  vecS_rule,
  /* 1106 */  immI8_rule,
  /* 1107 */  vecS_rule,
  /* 1108 */  immI8_rule,
  /* 1109 */  vecS_rule,
  /* 1110 */  immI8_rule,
  /* 1111 */  vecS_rule,
  /* 1112 */  immI8_rule,
  /* 1113 */  vecS_rule,
  /* 1114 */  immI8_rule,
  /* 1115 */  vecS_rule,
  /* 1116 */  immI8_rule,
  /* 1117 */  vecS_rule,
  /* 1118 */  immI8_rule,
  /* 1119 */  vecS_rule,
  /* 1120 */  immI8_rule,
  /* 1121 */  vecS_rule,
  /* 1122 */  immI8_rule,
  /* 1123 */  vecS_rule,
  /* 1124 */  immI8_rule,
  /* 1125 */  vecS_rule,
  /* 1126 */  immI8_rule,
  /* 1127 */  vecS_rule,
  /* 1128 */  immI8_rule,
  /* 1129 */  vecS_rule,
  /* 1130 */  immI8_rule,
  /* 1131 */  vecS_rule,
  /* 1132 */  immI8_rule,
  /* 1133 */  vecS_rule,
  /* 1134 */  immI8_rule,
  /* 1135 */  vecS_rule,
  /* 1136 */  immI8_rule,
  /* 1137 */  vecS_rule,
  /* 1138 */  immI8_rule,
  /* 1139 */  vecS_rule,
  /* 1140 */  immI8_rule,
  /* 1141 */  vecS_rule,
  /* 1142 */  immI8_rule,
  /* 1143 */  vecS_rule,
  /* 1144 */  immI8_rule,
  /* 1145 */  vecS_rule,
  /* 1146 */  immI8_rule,
  /* 1147 */  vecS_rule,
  /* 1148 */  immI8_rule,
  /* 1149 */  vecS_rule,
  /* 1150 */  immI8_rule,
  /* 1151 */  vecS_rule,
  /* 1152 */  immI8_rule,
  /* 1153 */  vecS_rule,
  /* 1154 */  immI8_rule,
  /* 1155 */  vecS_rule,
  /* 1156 */  immI8_rule,
  /* 1157 */  vecS_rule,
  /* 1158 */  immI8_rule,
  /* 1159 */  vecS_rule,
  /* 1160 */  immI8_rule,
  /* 1161 */  vecS_rule,
  /* 1162 */  immI8_rule,
  /* 1163 */  vecS_rule,
  /* 1164 */  immI8_rule,
  /* 1165 */  vecS_rule,
  /* 1166 */  immI8_rule,
  /* 1167 */  vecS_rule,
  /* 1168 */  vecS_rule,
  /* 1169 */  vecD_rule,
  /* 1170 */  vecD_rule,
  /* 1171 */  vecX_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  _LoadVector_memory__rule,
  /* 1174 */  vecY_rule,
  /* 1175 */  _LoadVector_memory__rule,
  /* 1176 */  vecS_rule,
  /* 1177 */  vecS_rule,
  /* 1178 */  vecD_rule,
  /* 1179 */  vecD_rule,
  /* 1180 */  vecX_rule,
  /* 1181 */  vecX_rule,
  /* 1182 */  _LoadVector_memory__rule,
  /* 1183 */  vecY_rule,
  /* 1184 */  _LoadVector_memory__rule,
  /* 1185 */  vecS_rule,
  /* 1186 */  vecS_rule,
  /* 1187 */  vecD_rule,
  /* 1188 */  vecD_rule,
  /* 1189 */  vecX_rule,
  /* 1190 */  vecX_rule,
  /* 1191 */  _LoadVector_memory__rule,
  /* 1192 */  vecY_rule,
  /* 1193 */  _LoadVector_memory__rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMI2",
  /*   13 */  "IMMI8",
  /*   14 */  "IMMI16",
  /*   15 */  "IMMI_32",
  /*   16 */  "IMMI_1_31",
  /*   17 */  "IMMI_32_63",
  /*   18 */  "IMMI_1",
  /*   19 */  "IMMI_2",
  /*   20 */  "IMMI_3",
  /*   21 */  "IMMP",
  /*   22 */  "IMMP0",
  /*   23 */  "IMML",
  /*   24 */  "IMML0",
  /*   25 */  "IMML_M1",
  /*   26 */  "IMML_127",
  /*   27 */  "IMML_32BITS",
  /*   28 */  "IMML32",
  /*   29 */  "IMMDPR0",
  /*   30 */  "IMMDPR1",
  /*   31 */  "IMMDPR",
  /*   32 */  "IMMD",
  /*   33 */  "IMMD0",
  /*   34 */  "IMMFPR0",
  /*   35 */  "IMMFPR1",
  /*   36 */  "IMMFPR",
  /*   37 */  "IMMF",
  /*   38 */  "IMMF0",
  /*   39 */  "IMMI_16",
  /*   40 */  "IMMI_24",
  /*   41 */  "IMMI_255",
  /*   42 */  "IMMI_65535",
  /*   43 */  "RREGI",
  /*   44 */  "XREGI",
  /*   45 */  "EAXREGI",
  /*   46 */  "EBXREGI",
  /*   47 */  "ECXREGI",
  /*   48 */  "EDXREGI",
  /*   49 */  "EDIREGI",
  /*   50 */  "NAXREGI",
  /*   51 */  "NADXREGI",
  /*   52 */  "NCXREGI",
  /*   53 */  "ESIREGI",
  /*   54 */  "ANYREGP",
  /*   55 */  "EREGP",
  /*   56 */  "EREGP_NO_EBP",
  /*   57 */  "NAXREGP",
  /*   58 */  "NABXREGP",
  /*   59 */  "PREGP",
  /*   60 */  "EAXREGP",
  /*   61 */  "EBXREGP",
  /*   62 */  "ECXREGP",
  /*   63 */  "ESIREGP",
  /*   64 */  "EDIREGP",
  /*   65 */  "EBPREGP",
  /*   66 */  "EREGL",
  /*   67 */  "EADXREGL",
  /*   68 */  "EBCXREGL",
  /*   69 */  "EADXREGL_LOW_ONLY",
  /*   70 */  "EFLAGSREG",
  /*   71 */  "EFLAGSREGU",
  /*   72 */  "EFLAGSREGUCF",
  /*   73 */  "FLAGSREG_LONG_LTGE",
  /*   74 */  "FLAGSREG_LONG_EQNE",
  /*   75 */  "FLAGSREG_LONG_LEGT",
  /*   76 */  "REGDPR",
  /*   77 */  "REGDPR1",
  /*   78 */  "REGDPR2",
  /*   79 */  "REGNOTDPR1",
  /*   80 */  "REGFPR",
  /*   81 */  "REGFPR1",
  /*   82 */  "REGF",
  /*   83 */  "REGD",
  /*   84 */  "DIRECT",
  /*   85 */  "INDIRECT",
  /*   86 */  "INDOFFSET8",
  /*   87 */  "INDOFFSET32",
  /*   88 */  "INDOFFSET32X",
  /*   89 */  "INDINDEXOFFSET",
  /*   90 */  "INDINDEX",
  /*   91 */  "INDINDEXSCALE",
  /*   92 */  "INDINDEXSCALEOFFSET",
  /*   93 */  "LOAD_LONG_REGP",
  /*   94 */  "LOAD_LONG_INDIRECT",
  /*   95 */  "LOAD_LONG_INDOFFSET32",
  /*   96 */  "STACKSLOTP",
  /*   97 */  "STACKSLOTI",
  /*   98 */  "STACKSLOTF",
  /*   99 */  "STACKSLOTD",
  /*  100 */  "STACKSLOTL",
  /*  101 */  "INDIRECT_WIN95_SAFE",
  /*  102 */  "INDOFFSET8_WIN95_SAFE",
  /*  103 */  "INDOFFSET32_WIN95_SAFE",
  /*  104 */  "INDINDEXOFFSET_WIN95_SAFE",
  /*  105 */  "INDINDEXSCALE_WIN95_SAFE",
  /*  106 */  "INDINDEXSCALEOFFSET_WIN95_SAFE",
  /*  107 */  "CMPOP",
  /*  108 */  "CMPOPU",
  /*  109 */  "CMPOPUCF",
  /*  110 */  "CMPOPUCF2",
  /*  111 */  "CMPOP_FCMOV",
  /*  112 */  "CMPOP_COMMUTE",
  /*  113 */  "VECS",
  /*  114 */  "VECD",
  /*  115 */  "VECX",
  /*  116 */  "VECY",
  // last operand
  /*  117 */  "LOAD_LONG_MEMORY",
  /*  118 */  "MEMORY",
  /*  119 */  "LONG_MEMORY",
  // last operand class
  /*  120 */  "_AddP_eRegP_rRegI",
  /*  121 */  "_LShiftI_rRegI_immI2",
  /*  122 */  "_AddP_eRegP__LShiftI_rRegI_immI2",
  /*  123 */  "_AddP_eRegP_no_EBP_rRegI",
  /*  124 */  "_AddP_eRegP_no_EBP__LShiftI_rRegI_immI2",
  /*  125 */  "_LoadI_memory_",
  /*  126 */  "_LoadL_memory_",
  /*  127 */  "_LoadB_memory_",
  /*  128 */  "_LoadUB_memory_",
  /*  129 */  "_AndI__LoadUB_memory__immI8",
  /*  130 */  "_LoadS_memory_",
  /*  131 */  "_LShiftI__LoadS_memory__immI_24",
  /*  132 */  "_LoadUS_memory_",
  /*  133 */  "_LShiftI__LoadUS_memory__immI_24",
  /*  134 */  "_AndI__LoadUS_memory__immI_255",
  /*  135 */  "_AndI__LoadUS_memory__immI16",
  /*  136 */  "_LShiftI__LoadI_memory__immI_24",
  /*  137 */  "_LShiftI__LoadI_memory__immI_16",
  /*  138 */  "_AndI__LoadI_memory__immI_255",
  /*  139 */  "_AndI__LoadI_memory__immI_65535",
  /*  140 */  "_AndI__LoadI_memory__immI",
  /*  141 */  "_ConvI2L__LoadI_memory__",
  /*  142 */  "_ConvL2I_eRegL_",
  /*  143 */  "_RoundDouble_regDPR1_",
  /*  144 */  "_RoundFloat_regFPR1_",
  /*  145 */  "_ConvD2F_regDPR1_",
  /*  146 */  "_Binary_cmpOp_eFlagsReg",
  /*  147 */  "_Binary_rRegI_rRegI",
  /*  148 */  "_Binary_cmpOpU_eFlagsRegU",
  /*  149 */  "_Binary_cmpOpUCF_eFlagsRegUCF",
  /*  150 */  "_Binary_rRegI__LoadI_memory_",
  /*  151 */  "_Binary_eRegP_eRegP",
  /*  152 */  "_Binary_cmpOp_fcmov_eFlagsRegU",
  /*  153 */  "_Binary_regDPR1_regDPR",
  /*  154 */  "_Binary_regFPR1_regFPR",
  /*  155 */  "_Binary_regDPR_regDPR",
  /*  156 */  "_Binary_regFPR_regFPR",
  /*  157 */  "_Binary_regF_regF",
  /*  158 */  "_Binary_regD_regD",
  /*  159 */  "_Binary_eRegL_eRegL",
  /*  160 */  "_AddI__LoadI_memory__rRegI",
  /*  161 */  "_AddI_rRegI__LoadI_memory_",
  /*  162 */  "_AddI__LoadI_memory__immI",
  /*  163 */  "_AddI__LoadI_memory__immI1",
  /*  164 */  "_AddI__LoadI_memory__immI_M1",
  /*  165 */  "_Binary_eAXRegP_eRegP",
  /*  166 */  "_Binary_eAXRegI_rRegI",
  /*  167 */  "_Binary_eADXRegL_eBCXRegL",
  /*  168 */  "_Binary_eAXRegP_eCXRegP",
  /*  169 */  "_Binary_eAXRegI_eCXRegI",
  /*  170 */  "_SubI__LoadI_memory__rRegI",
  /*  171 */  "_SubI_immI0_rRegI",
  /*  172 */  "_ConvI2L_nadxRegI_",
  /*  173 */  "_MulL__ConvI2L_nadxRegI__eADXRegL_low_only",
  /*  174 */  "_RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32",
  /*  175 */  "_MulL_eADXRegL_low_only__ConvI2L_nadxRegI_",
  /*  176 */  "_RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32",
  /*  177 */  "_RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_63",
  /*  178 */  "_RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_63",
  /*  179 */  "_ConvI2L_eAXRegI_",
  /*  180 */  "_AndL__ConvI2L_eAXRegI__immL_32bits",
  /*  181 */  "_AndL__ConvI2L_nadxRegI__immL_32bits",
  /*  182 */  "_RShiftI__LoadI_memory__immI1",
  /*  183 */  "_RShiftI__LoadI_memory__immI8",
  /*  184 */  "_LShiftI_xRegI_immI_24",
  /*  185 */  "_LShiftI_xRegI_immI_16",
  /*  186 */  "_AndI__LoadI_memory__rRegI",
  /*  187 */  "_AndI_rRegI__LoadI_memory_",
  /*  188 */  "_CastP2X_eRegP_",
  /*  189 */  "_OrI__LoadI_memory__rRegI",
  /*  190 */  "_OrI_rRegI__LoadI_memory_",
  /*  191 */  "_OrI__LoadI_memory__immI",
  /*  192 */  "_LShiftI_rRegI_immI1",
  /*  193 */  "_URShiftI_rRegI_immI_M1",
  /*  194 */  "_LShiftI_rRegI_immI8",
  /*  195 */  "_URShiftI_rRegI_immI8",
  /*  196 */  "_LShiftI_ncxRegI_eCXRegI",
  /*  197 */  "_SubI_immI0_eCXRegI",
  /*  198 */  "_URShiftI_ncxRegI__SubI_immI0_eCXRegI",
  /*  199 */  "_SubI_immI_32_eCXRegI",
  /*  200 */  "_URShiftI_ncxRegI__SubI_immI_32_eCXRegI",
  /*  201 */  "_URShiftI_rRegI_immI1",
  /*  202 */  "_LShiftI_rRegI_immI_M1",
  /*  203 */  "_URShiftI_ncxRegI_eCXRegI",
  /*  204 */  "_LShiftI_ncxRegI__SubI_immI0_eCXRegI",
  /*  205 */  "_LShiftI_ncxRegI__SubI_immI_32_eCXRegI",
  /*  206 */  "_XorI__LoadI_memory__rRegI",
  /*  207 */  "_XorI_rRegI__LoadI_memory_",
  /*  208 */  "_XorI__LoadI_memory__immI",
  /*  209 */  "_CmpLTMask_rRegI_rRegI",
  /*  210 */  "_AndI__CmpLTMask_rRegI_rRegI_rRegI",
  /*  211 */  "_SubI_rRegI_rRegI",
  /*  212 */  "_AndI_rRegI__CmpLTMask_rRegI_rRegI",
  /*  213 */  "_LoadL_load_long_memory_",
  /*  214 */  "_LoadD_memory_",
  /*  215 */  "_SubD_regDPR_regDPR",
  /*  216 */  "_AddD_regDPR_regDPR",
  /*  217 */  "_AddD__LoadD_memory__regDPR",
  /*  218 */  "_RoundDouble__AddD__LoadD_memory__regDPR_",
  /*  219 */  "_AddD_regDPR__LoadD_memory_",
  /*  220 */  "_RoundDouble__AddD_regDPR__LoadD_memory__",
  /*  221 */  "_AddD_regDPR_immDPR",
  /*  222 */  "_MulD_regDPR_regDPR",
  /*  223 */  "_DivD_regDPR_regDPR",
  /*  224 */  "_LoadF_memory_",
  /*  225 */  "_MulF__LoadF_memory__regFPR",
  /*  226 */  "_MulF_regFPR__LoadF_memory_",
  /*  227 */  "_MulF_regFPR_regFPR",
  /*  228 */  "_SubF_regFPR_regFPR",
  /*  229 */  "_ConvI2L_rRegI_",
  /*  230 */  "_Binary_eDIRegP_eCXRegI",
  /*  231 */  "_Binary_eSIRegP_eDXRegI",
  /*  232 */  "_Binary_eDIRegP_eSIRegP",
  /*  233 */  "_Binary_eDIRegP_eDXRegI",
  /*  234 */  "_Binary_eSIRegP_immI",
  /*  235 */  "_Binary_eSIRegP_eAXRegI",
  /*  236 */  "_AndI_rRegI_immI",
  /*  237 */  "_AndI_rRegI_memory",
  /*  238 */  "_LoadP_memory_",
  /*  239 */  "_Binary_nadxRegI_eAXRegI",
  /*  240 */  "_PartialSubtypeCheck_eSIRegP_eAXRegP",
  /*  241 */  "_Binary_cmpOp_flagsReg_long_LTGE",
  /*  242 */  "_Binary_eRegL__LoadL_load_long_memory_",
  /*  243 */  "_Binary_cmpOp_flagsReg_long_EQNE",
  /*  244 */  "_Binary_cmpOp_commute_flagsReg_long_LEGT",
  /*  245 */  "_ConvF2D_regF_",
  /*  246 */  "_SqrtD__ConvF2D_regF__",
  /*  247 */  "_ConvF2D__LoadF_memory__",
  /*  248 */  "_SqrtD__ConvF2D__LoadF_memory___",
  /*  249 */  "_ConvF2D_immF_",
  /*  250 */  "_SqrtD__ConvF2D_immF__",
  /*  251 */  "_LoadVector_memory_",
  // last internally defined operand
  /*  252 */  "storeSSI",
  /*  253 */  "storeSSP",
  /*  254 */  "storeSSL",
  /*  255 */  "leaP8",
  /*  256 */  "leaP32",
  /*  257 */  "leaPIdxOff",
  /*  258 */  "leaPIdxScale",
  /*  259 */  "leaPIdxScaleOff",
  /*  260 */  "loadConI",
  /*  261 */  "loadConI0",
  /*  262 */  "loadConP",
  /*  263 */  "loadConL",
  /*  264 */  "loadConL0",
  /*  265 */  "loadConFPR",
  /*  266 */  "loadConFPR0",
  /*  267 */  "loadConFPR1",
  /*  268 */  "loadConF",
  /*  269 */  "loadConF0",
  /*  270 */  "loadConDPR",
  /*  271 */  "loadConDPR0",
  /*  272 */  "loadConDPR1",
  /*  273 */  "loadConD",
  /*  274 */  "loadConD0",
  /*  275 */  "loadSSI",
  /*  276 */  "loadSSL",
  /*  277 */  "loadSSP",
  /*  278 */  "loadSSF",
  /*  279 */  "loadSSD",
  /*  280 */  "loadConL_low_only",
  /*  281 */  "membar_volatile",
  /*  282 */  "castX2P",
  /*  283 */  "castP2X",
  /*  284 */  "checkCastPP",
  /*  285 */  "castPP",
  /*  286 */  "castII",
  /*  287 */  "storePConditional",
  /*  288 */  "storeIConditional",
  /*  289 */  "storeLConditional",
  /*  290 */  "movI_nocopy",
  /*  291 */  "movP_nocopy",
  /*  292 */  "cmpDPR_cc_P6",
  /*  293 */  "cmpDPR_cc_P6CF",
  /*  294 */  "cmpDPR_cc",
  /*  295 */  "cmpD_cc",
  /*  296 */  "cmpD_ccCF",
  /*  297 */  "cmpD_ccmem",
  /*  298 */  "cmpD_ccmemCF",
  /*  299 */  "absDPR_reg",
  /*  300 */  "cmpFPR_cc_P6",
  /*  301 */  "cmpFPR_cc_P6CF",
  /*  302 */  "cmpFPR_cc",
  /*  303 */  "cmpF_cc",
  /*  304 */  "cmpF_ccCF",
  /*  305 */  "cmpF_ccmem",
  /*  306 */  "cmpF_ccmemCF",
  /*  307 */  "absFPR_reg",
  /*  308 */  "negFPR_reg",
  /*  309 */  "MoveF2I_stack_reg",
  /*  310 */  "MoveF2I_reg_reg_sse",
  /*  311 */  "MoveI2FPR_stack_reg",
  /*  312 */  "MoveI2F_stack_reg_sse",
  /*  313 */  "MoveI2F_reg_reg_sse",
  /*  314 */  "MoveD2L_stack_reg",
  /*  315 */  "MoveL2DPR_stack_reg",
  /*  316 */  "MoveL2D_stack_reg_sse",
  /*  317 */  "MoveL2D_stack_reg_sse_partial",
  /*  318 */  "compI_eReg",
  /*  319 */  "compI_eReg_imm",
  /*  320 */  "compI_eReg_mem",
  /*  321 */  "testI_reg",
  /*  322 */  "testI_reg_imm",
  /*  323 */  "testI_reg_mem",
  /*  324 */  "compU_eReg",
  /*  325 */  "compU_eReg_imm",
  /*  326 */  "compU_eReg_mem",
  /*  327 */  "testU_reg",
  /*  328 */  "compP_eReg",
  /*  329 */  "compP_eReg_imm",
  /*  330 */  "compP_eReg_mem",
  /*  331 */  "compP_mem_eReg",
  /*  332 */  "testP_reg",
  /*  333 */  "testP_Reg_mem",
  /*  334 */  "partialSubtypeCheck_vs_Zero",
  /*  335 */  "cmpL_zero_flags_LTGE",
  /*  336 */  "cmpL_reg_flags_LTGE",
  /*  337 */  "cmpL_zero_flags_EQNE",
  /*  338 */  "cmpL_reg_flags_EQNE",
  /*  339 */  "cmpL_zero_flags_LEGT",
  /*  340 */  "cmpL_reg_flags_LEGT",
  /*  341 */  "cmpFastLock",
  /*  342 */  "cmpFastUnlock",
  /*  343 */  "safePoint_poll",
  /*  344 */  "absF_reg",
  /*  345 */  "absF_reg_reg",
  /*  346 */  "absD_reg",
  /*  347 */  "absD_reg_reg",
  /*  348 */  "negF_reg",
  /*  349 */  "negF_reg_reg",
  /*  350 */  "vshiftcnt",
  /*  351 */  "vshiftcnt_0",
  /*  352 */  "bytes_reverse_int",
  /*  353 */  "bytes_reverse_long",
  /*  354 */  "bytes_reverse_unsigned_short",
  /*  355 */  "bytes_reverse_short",
  /*  356 */  "countLeadingZerosI",
  /*  357 */  "countLeadingZerosI_bsr",
  /*  358 */  "countLeadingZerosL",
  /*  359 */  "countLeadingZerosL_bsr",
  /*  360 */  "countTrailingZerosI",
  /*  361 */  "countTrailingZerosL",
  /*  362 */  "popCountI",
  /*  363 */  "popCountI_mem",
  /*  364 */  "popCountL",
  /*  365 */  "popCountL_mem",
  /*  366 */  "loadB",
  /*  367 */  "loadB2L",
  /*  368 */  "loadUB",
  /*  369 */  "loadUB2L",
  /*  370 */  "loadUB2L_immI8",
  /*  371 */  "loadS",
  /*  372 */  "loadS2B",
  /*  373 */  "loadS2L",
  /*  374 */  "loadUS",
  /*  375 */  "loadUS2B",
  /*  376 */  "loadUS2L",
  /*  377 */  "loadUS2L_immI_255",
  /*  378 */  "loadUS2L_immI16",
  /*  379 */  "loadI",
  /*  380 */  "loadI2B",
  /*  381 */  "loadI2UB",
  /*  382 */  "loadI2S",
  /*  383 */  "loadI2US",
  /*  384 */  "loadI2L",
  /*  385 */  "loadI2L_immI_255",
  /*  386 */  "loadI2L_immI_65535",
  /*  387 */  "loadI2L_immI",
  /*  388 */  "loadUI2L",
  /*  389 */  "loadL",
  /*  390 */  "loadL_volatile",
  /*  391 */  "loadLX_volatile",
  /*  392 */  "loadLX_reg_volatile",
  /*  393 */  "loadRange",
  /*  394 */  "loadP",
  /*  395 */  "loadKlass",
  /*  396 */  "loadDPR",
  /*  397 */  "loadD",
  /*  398 */  "loadD_partial",
  /*  399 */  "loadF",
  /*  400 */  "loadFPR",
  /*  401 */  "prefetchr0",
  /*  402 */  "prefetchr",
  /*  403 */  "prefetchrNTA",
  /*  404 */  "prefetchrT0",
  /*  405 */  "prefetchrT2",
  /*  406 */  "prefetchw0",
  /*  407 */  "prefetchw",
  /*  408 */  "prefetchwNTA",
  /*  409 */  "prefetchAlloc0",
  /*  410 */  "prefetchAlloc",
  /*  411 */  "prefetchAllocNTA",
  /*  412 */  "prefetchAllocT0",
  /*  413 */  "prefetchAllocT2",
  /*  414 */  "storeB",
  /*  415 */  "storeC",
  /*  416 */  "storeI",
  /*  417 */  "storeL",
  /*  418 */  "storeL2I",
  /*  419 */  "storeL_volatile",
  /*  420 */  "storeLX_volatile",
  /*  421 */  "storeLX_reg_volatile",
  /*  422 */  "storeP",
  /*  423 */  "storeImmI",
  /*  424 */  "storeImmI16",
  /*  425 */  "storeImmP",
  /*  426 */  "storeImmB",
  /*  427 */  "storeImmCM",
  /*  428 */  "storeDPR",
  /*  429 */  "storeDPR_rounded",
  /*  430 */  "storeD",
  /*  431 */  "storeF",
  /*  432 */  "storeFPR",
  /*  433 */  "storeFPR_rounded",
  /*  434 */  "storeFPR_Drounded",
  /*  435 */  "storeFPR_imm",
  /*  436 */  "storeF_imm",
  /*  437 */  "membar_acquire",
  /*  438 */  "membar_acquire_lock",
  /*  439 */  "membar_release",
  /*  440 */  "membar_release_lock",
  /*  441 */  "unnecessary_membar_volatile",
  /*  442 */  "membar_storestore",
  /*  443 */  "jmovI_reg",
  /*  444 */  "jmovI_regU",
  /*  445 */  "cmovI_reg",
  /*  446 */  "cmovI_regU",
  /*  447 */  "cmovI_regUCF",
  /*  448 */  "cmovI_mem",
  /*  449 */  "cmovI_memU",
  /*  450 */  "cmovI_memUCF",
  /*  451 */  "cmovP_reg",
  /*  452 */  "cmovP_reg_nonP6",
  /*  453 */  "cmovP_regU",
  /*  454 */  "cmovP_regUCF",
  /*  455 */  "fcmovDPR_regU",
  /*  456 */  "fcmovFPR_regU",
  /*  457 */  "fcmovDPR_regS",
  /*  458 */  "fcmovFPR_regS",
  /*  459 */  "fcmovF_regS",
  /*  460 */  "fcmovD_regS",
  /*  461 */  "fcmovF_regU",
  /*  462 */  "fcmovF_regUCF",
  /*  463 */  "fcmovD_regU",
  /*  464 */  "fcmovD_regUCF",
  /*  465 */  "cmovL_reg",
  /*  466 */  "cmovL_regU",
  /*  467 */  "cmovL_regUCF",
  /*  468 */  "addI_eReg",
  /*  469 */  "addI_eReg_imm",
  /*  470 */  "incI_eReg",
  /*  471 */  "leaI_eReg_immI",
  /*  472 */  "leaP_eReg_immI",
  /*  473 */  "decI_eReg",
  /*  474 */  "addP_eReg",
  /*  475 */  "addP_eReg_imm",
  /*  476 */  "addI_eReg_mem",
  /*  477 */  "addI_eReg_mem_0",
  /*  478 */  "addI_mem_eReg",
  /*  479 */  "addI_mem_eReg_0",
  /*  480 */  "addI_mem_imm",
  /*  481 */  "incI_mem",
  /*  482 */  "decI_mem",
  /*  483 */  "loadPLocked",
  /*  484 */  "compareAndSwapL",
  /*  485 */  "compareAndSwapP",
  /*  486 */  "xaddI_no_res",
  /*  487 */  "xaddI",
  /*  488 */  "xchgI",
  /*  489 */  "xchgP",
  /*  490 */  "compareAndSwapI",
  /*  491 */  "subI_eReg",
  /*  492 */  "subI_eReg_imm",
  /*  493 */  "subI_eReg_mem",
  /*  494 */  "subI_mem_eReg",
  /*  495 */  "subP_eReg",
  /*  496 */  "negI_eReg",
  /*  497 */  "mulI_eReg",
  /*  498 */  "mulI_eReg_imm",
  /*  499 */  "mulI_imm_high",
  /*  500 */  "mulI_imm_high_0",
  /*  501 */  "mulI_imm_RShift_high",
  /*  502 */  "mulI_imm_RShift_high_0",
  /*  503 */  "mulI_mem_imm",
  /*  504 */  "mulI",
  /*  505 */  "mulI_0",
  /*  506 */  "mulI2L",
  /*  507 */  "mulI2L_0",
  /*  508 */  "mulIS_eReg",
  /*  509 */  "mulIS_eReg_0",
  /*  510 */  "mulL_eReg",
  /*  511 */  "mulL_eReg_lhi0",
  /*  512 */  "mulL_eReg_rhi0",
  /*  513 */  "mulL_eReg_hi0",
  /*  514 */  "mulL_eReg_con",
  /*  515 */  "divI_eReg",
  /*  516 */  "divL_eReg",
  /*  517 */  "divModI_eReg_divmod",
  /*  518 */  "modI_eReg",
  /*  519 */  "modL_eReg",
  /*  520 */  "divL_eReg_imm32",
  /*  521 */  "modL_eReg_imm32",
  /*  522 */  "shlI_eReg_1",
  /*  523 */  "salI_eReg_imm",
  /*  524 */  "salI_eReg_CL",
  /*  525 */  "sarI_eReg_1",
  /*  526 */  "sarI_mem_1",
  /*  527 */  "sarI_eReg_imm",
  /*  528 */  "sarI_mem_imm",
  /*  529 */  "sarI_eReg_CL",
  /*  530 */  "shrI_eReg_1",
  /*  531 */  "shrI_eReg_imm",
  /*  532 */  "i2b",
  /*  533 */  "i2s",
  /*  534 */  "shrI_eReg_CL",
  /*  535 */  "andI_eReg",
  /*  536 */  "andI_eReg_imm",
  /*  537 */  "andI_eReg_mem",
  /*  538 */  "andI_eReg_mem_0",
  /*  539 */  "andI_mem_eReg",
  /*  540 */  "andI_mem_eReg_0",
  /*  541 */  "andI_mem_imm",
  /*  542 */  "orI_eReg",
  /*  543 */  "orI_eReg_castP2X",
  /*  544 */  "orI_eReg_castP2X_0",
  /*  545 */  "orI_eReg_imm",
  /*  546 */  "orI_eReg_mem",
  /*  547 */  "orI_eReg_mem_0",
  /*  548 */  "orI_mem_eReg",
  /*  549 */  "orI_mem_eReg_0",
  /*  550 */  "orI_mem_imm",
  /*  551 */  "rolI_eReg_imm1",
  /*  552 */  "rolI_eReg_imm8",
  /*  553 */  "rolI_eReg_CL",
  /*  554 */  "rolI_eReg_i1",
  /*  555 */  "rolI_eReg_i1_0",
  /*  556 */  "rolI_eReg_i8",
  /*  557 */  "rolI_eReg_i8_0",
  /*  558 */  "rolI_eReg_Var_C0",
  /*  559 */  "rolI_eReg_Var_C0_0",
  /*  560 */  "rolI_eReg_Var_C32",
  /*  561 */  "rolI_eReg_Var_C32_0",
  /*  562 */  "rorI_eReg_imm1",
  /*  563 */  "rorI_eReg_imm8",
  /*  564 */  "rorI_eReg_CL",
  /*  565 */  "rorI_eReg_i1",
  /*  566 */  "rorI_eReg_i1_0",
  /*  567 */  "rorI_eReg_i8",
  /*  568 */  "rorI_eReg_i8_0",
  /*  569 */  "rorI_eReg_Var_C0",
  /*  570 */  "rorI_eReg_Var_C0_0",
  /*  571 */  "rorI_eReg_Var_C32",
  /*  572 */  "rorI_eReg_Var_C32_0",
  /*  573 */  "xorI_eReg",
  /*  574 */  "xorI_eReg_im1",
  /*  575 */  "xorI_eReg_imm",
  /*  576 */  "xorI_eReg_mem",
  /*  577 */  "xorI_eReg_mem_0",
  /*  578 */  "xorI_mem_eReg",
  /*  579 */  "xorI_mem_eReg_0",
  /*  580 */  "xorI_mem_imm",
  /*  581 */  "ci2b",
  /*  582 */  "convI2B",
  /*  583 */  "cp2b",
  /*  584 */  "convP2B",
  /*  585 */  "cmpLTMask",
  /*  586 */  "cmpLTMask0",
  /*  587 */  "cadd_cmpLTMask",
  /*  588 */  "cadd_cmpLTMask_1",
  /*  589 */  "cadd_cmpLTMask_0",
  /*  590 */  "cadd_cmpLTMask_2",
  /*  591 */  "and_cmpLTMask",
  /*  592 */  "and_cmpLTMask_0",
  /*  593 */  "addL_eReg",
  /*  594 */  "addL_eReg_imm",
  /*  595 */  "addL_eReg_mem",
  /*  596 */  "addL_eReg_mem_0",
  /*  597 */  "subL_eReg",
  /*  598 */  "subL_eReg_imm",
  /*  599 */  "subL_eReg_mem",
  /*  600 */  "negL_eReg",
  /*  601 */  "andL_eReg",
  /*  602 */  "andL_eReg_imm",
  /*  603 */  "andL_eReg_mem",
  /*  604 */  "andL_eReg_mem_0",
  /*  605 */  "orl_eReg",
  /*  606 */  "orl_eReg_imm",
  /*  607 */  "orl_eReg_mem",
  /*  608 */  "orl_eReg_mem_0",
  /*  609 */  "xorl_eReg",
  /*  610 */  "xorl_eReg_im1",
  /*  611 */  "xorl_eReg_imm",
  /*  612 */  "xorl_eReg_mem",
  /*  613 */  "xorl_eReg_mem_0",
  /*  614 */  "shlL_eReg_1",
  /*  615 */  "shlL_eReg_2",
  /*  616 */  "shlL_eReg_3",
  /*  617 */  "shlL_eReg_1_31",
  /*  618 */  "shlL_eReg_32_63",
  /*  619 */  "salL_eReg_CL",
  /*  620 */  "shrL_eReg_1_31",
  /*  621 */  "shrL_eReg_32_63",
  /*  622 */  "shrL_eReg_CL",
  /*  623 */  "sarL_eReg_1_31",
  /*  624 */  "sarL_eReg_32_63",
  /*  625 */  "sarL_eReg_CL",
  /*  626 */  "cmpDPR_0",
  /*  627 */  "cmpDPR_reg",
  /*  628 */  "cmpD_reg",
  /*  629 */  "cmpD_regmem",
  /*  630 */  "subDPR_reg",
  /*  631 */  "subDPR_reg_round",
  /*  632 */  "subDPR_reg_mem",
  /*  633 */  "negDPR_reg",
  /*  634 */  "addDPR_reg",
  /*  635 */  "addDPR_reg_round",
  /*  636 */  "addDPR_reg_mem",
  /*  637 */  "addDPR_reg_mem_0",
  /*  638 */  "addDPR_mem_reg",
  /*  639 */  "addDPR_mem_reg_0",
  /*  640 */  "addDPR_reg_imm1",
  /*  641 */  "addDPR_reg_imm",
  /*  642 */  "addDPR_reg_imm_round",
  /*  643 */  "mulDPR_reg",
  /*  644 */  "strictfp_mulDPR_reg",
  /*  645 */  "mulDPR_reg_imm",
  /*  646 */  "mulDPR_reg_mem",
  /*  647 */  "mulDPR_reg_mem_0",
  /*  648 */  "mulDPR_reg_mem_cisc",
  /*  649 */  "mulDPR_reg_mem_cisc_0",
  /*  650 */  "addDPR_mulDPR_reg",
  /*  651 */  "addDPR_mulDPR_reg_0",
  /*  652 */  "subDPR_mulDPR_reg",
  /*  653 */  "divDPR_reg",
  /*  654 */  "strictfp_divDPR_reg",
  /*  655 */  "divDPR_reg_round",
  /*  656 */  "modDPR_reg",
  /*  657 */  "modD_reg",
  /*  658 */  "sinDPR_reg",
  /*  659 */  "sinD_reg",
  /*  660 */  "cosDPR_reg",
  /*  661 */  "cosD_reg",
  /*  662 */  "tanDPR_reg",
  /*  663 */  "tanD_reg",
  /*  664 */  "atanDPR_reg",
  /*  665 */  "atanD_reg",
  /*  666 */  "sqrtDPR_reg",
  /*  667 */  "powDPR_reg",
  /*  668 */  "powD_reg",
  /*  669 */  "expDPR_reg",
  /*  670 */  "expD_reg",
  /*  671 */  "log10DPR_reg",
  /*  672 */  "log10D_reg",
  /*  673 */  "logDPR_reg",
  /*  674 */  "logD_reg",
  /*  675 */  "cmpFPR_0",
  /*  676 */  "cmpFPR_reg",
  /*  677 */  "cmpF_reg",
  /*  678 */  "cmpF_regmem",
  /*  679 */  "subFPR24_reg",
  /*  680 */  "subFPR_reg",
  /*  681 */  "addFPR24_reg",
  /*  682 */  "addFPR_reg",
  /*  683 */  "addFPR24_reg_mem",
  /*  684 */  "addFPR24_reg_mem_0",
  /*  685 */  "addFPR_reg_mem",
  /*  686 */  "addFPR_reg_mem_0",
  /*  687 */  "addFPR24_mem_reg",
  /*  688 */  "addFPR24_mem_cisc",
  /*  689 */  "addFPR24_mem_cisc_0",
  /*  690 */  "addFPR24_mem_mem",
  /*  691 */  "addFPR24_reg_imm",
  /*  692 */  "addFPR_reg_imm",
  /*  693 */  "mulFPR24_reg",
  /*  694 */  "mulFPR_reg",
  /*  695 */  "mulFPR24_reg_mem",
  /*  696 */  "mulFPR24_reg_mem_0",
  /*  697 */  "mulFPR_reg_mem",
  /*  698 */  "mulFPR_reg_mem_0",
  /*  699 */  "mulFPR24_mem_mem",
  /*  700 */  "mulFPR24_reg_imm",
  /*  701 */  "mulFPR_reg_imm",
  /*  702 */  "mulFPR_reg_load1",
  /*  703 */  "mulFPR_reg_load1_0",
  /*  704 */  "addFPR_mulFPR_reg_load1",
  /*  705 */  "addFPR_mulFPR_reg_load1_1",
  /*  706 */  "addFPR_mulFPR_reg_load1_0",
  /*  707 */  "addFPR_mulFPR_reg_load1_2",
  /*  708 */  "addFPR_mulFPR_reg",
  /*  709 */  "addFPR_mulFPR_reg_0",
  /*  710 */  "subFPR_divFPR_reg",
  /*  711 */  "divFPR24_reg",
  /*  712 */  "divFPR_reg",
  /*  713 */  "modFPR24_reg",
  /*  714 */  "modFPR_reg",
  /*  715 */  "modF_reg",
  /*  716 */  "roundFloat_mem_reg",
  /*  717 */  "roundDouble_mem_reg",
  /*  718 */  "convDPR2FPR_reg",
  /*  719 */  "convDPR2F_reg",
  /*  720 */  "convD2F_reg",
  /*  721 */  "convFPR2DPR_reg_reg",
  /*  722 */  "convFPR2D_reg",
  /*  723 */  "convF2DPR_reg",
  /*  724 */  "convF2D_reg",
  /*  725 */  "convDPR2I_reg_reg",
  /*  726 */  "convD2I_reg_reg",
  /*  727 */  "convDPR2L_reg_reg",
  /*  728 */  "convD2L_reg_reg",
  /*  729 */  "convFPR2I_reg_reg",
  /*  730 */  "convF2I_reg",
  /*  731 */  "convFPR2L_reg_reg",
  /*  732 */  "convF2L_reg_reg",
  /*  733 */  "convI2DPR_reg",
  /*  734 */  "convI2D_reg",
  /*  735 */  "convI2D_mem",
  /*  736 */  "convXI2D_reg",
  /*  737 */  "convI2DPR_mem",
  /*  738 */  "conv24I2FPR_reg",
  /*  739 */  "convI2FPR_SSF",
  /*  740 */  "convI2FPR_SSF_mem",
  /*  741 */  "convI2FPR_reg",
  /*  742 */  "convI2FPR_mem",
  /*  743 */  "convI2F_reg",
  /*  744 */  "convXI2F_reg",
  /*  745 */  "convI2L_reg",
  /*  746 */  "convI2L_reg_zex",
  /*  747 */  "zerox_long",
  /*  748 */  "convL2DPR_reg",
  /*  749 */  "convL2D_reg",
  /*  750 */  "convL2F_reg",
  /*  751 */  "convL2FPR_reg",
  /*  752 */  "convL2I_reg",
  /*  753 */  "MoveFPR2I_reg_stack",
  /*  754 */  "MoveF2I_reg_stack_sse",
  /*  755 */  "MoveI2F_reg_stack",
  /*  756 */  "MoveDPR2L_reg_stack",
  /*  757 */  "MoveD2L_reg_stack_sse",
  /*  758 */  "MoveD2L_reg_reg_sse",
  /*  759 */  "MoveL2D_reg_stack",
  /*  760 */  "MoveL2D_reg_reg_sse",
  /*  761 */  "rep_stos",
  /*  762 */  "rep_fast_stosb",
  /*  763 */  "string_compare",
  /*  764 */  "string_equals",
  /*  765 */  "string_indexof_con",
  /*  766 */  "string_indexof",
  /*  767 */  "array_equals",
  /*  768 */  "minI_eReg",
  /*  769 */  "maxI_eReg",
  /*  770 */  "loopLimit_eReg",
  /*  771 */  "jumpXtnd",
  /*  772 */  "jmpDir",
  /*  773 */  "jmpCon",
  /*  774 */  "jmpLoopEnd",
  /*  775 */  "jmpLoopEndU",
  /*  776 */  "jmpLoopEndUCF",
  /*  777 */  "jmpConU",
  /*  778 */  "jmpConUCF",
  /*  779 */  "jmpConUCF2",
  /*  780 */  "partialSubtypeCheck",
  /*  781 */  "jmpDir_short",
  /*  782 */  "jmpCon_short",
  /*  783 */  "jmpLoopEnd_short",
  /*  784 */  "jmpLoopEndU_short",
  /*  785 */  "jmpLoopEndUCF_short",
  /*  786 */  "jmpConU_short",
  /*  787 */  "jmpConUCF_short",
  /*  788 */  "jmpConUCF2_short",
  /*  789 */  "cmpL3_reg_reg",
  /*  790 */  "cmpL_LTGE",
  /*  791 */  "cmovLL_reg_LTGE",
  /*  792 */  "cmovLL_mem_LTGE",
  /*  793 */  "cmovII_reg_LTGE",
  /*  794 */  "cmovII_mem_LTGE",
  /*  795 */  "cmovPP_reg_LTGE",
  /*  796 */  "cmovDDPR_reg_LTGE",
  /*  797 */  "cmovDD_reg_LTGE",
  /*  798 */  "cmovFFPR_reg_LTGE",
  /*  799 */  "cmovFF_reg_LTGE",
  /*  800 */  "cmpL_EQNE",
  /*  801 */  "cmovLL_reg_EQNE",
  /*  802 */  "cmovLL_mem_EQNE",
  /*  803 */  "cmovII_reg_EQNE",
  /*  804 */  "cmovII_mem_EQNE",
  /*  805 */  "cmovPP_reg_EQNE",
  /*  806 */  "cmovDDPR_reg_EQNE",
  /*  807 */  "cmovDD_reg_EQNE",
  /*  808 */  "cmovFFPR_reg_EQNE",
  /*  809 */  "cmovFF_reg_EQNE",
  /*  810 */  "cmpL_LEGT",
  /*  811 */  "cmovLL_reg_LEGT",
  /*  812 */  "cmovLL_mem_LEGT",
  /*  813 */  "cmovII_reg_LEGT",
  /*  814 */  "cmovII_mem_LEGT",
  /*  815 */  "cmovPP_reg_LEGT",
  /*  816 */  "cmovDDPR_reg_LEGT",
  /*  817 */  "cmovDD_reg_LEGT",
  /*  818 */  "cmovFFPR_reg_LEGT",
  /*  819 */  "cmovFF_reg_LEGT",
  /*  820 */  "CallStaticJavaDirect",
  /*  821 */  "CallStaticJavaHandle",
  /*  822 */  "CallDynamicJavaDirect",
  /*  823 */  "CallRuntimeDirect",
  /*  824 */  "CallLeafDirect",
  /*  825 */  "CallLeafNoFPDirect",
  /*  826 */  "Ret",
  /*  827 */  "TailCalljmpInd",
  /*  828 */  "tailjmpInd",
  /*  829 */  "CreateException",
  /*  830 */  "RethrowException",
  /*  831 */  "tlsLoadP",
  /*  832 */  "ShouldNotReachHere",
  /*  833 */  "addF_reg",
  /*  834 */  "addF_mem",
  /*  835 */  "addF_mem_0",
  /*  836 */  "addF_imm",
  /*  837 */  "addF_reg_reg",
  /*  838 */  "addF_reg_mem",
  /*  839 */  "addF_reg_mem_0",
  /*  840 */  "addF_reg_imm",
  /*  841 */  "addD_reg",
  /*  842 */  "addD_mem",
  /*  843 */  "addD_mem_0",
  /*  844 */  "addD_imm",
  /*  845 */  "addD_reg_reg",
  /*  846 */  "addD_reg_mem",
  /*  847 */  "addD_reg_mem_0",
  /*  848 */  "addD_reg_imm",
  /*  849 */  "subF_reg",
  /*  850 */  "subF_mem",
  /*  851 */  "subF_imm",
  /*  852 */  "subF_reg_reg",
  /*  853 */  "subF_reg_mem",
  /*  854 */  "subF_reg_imm",
  /*  855 */  "subD_reg",
  /*  856 */  "subD_mem",
  /*  857 */  "subD_imm",
  /*  858 */  "subD_reg_reg",
  /*  859 */  "subD_reg_mem",
  /*  860 */  "subD_reg_imm",
  /*  861 */  "mulF_reg",
  /*  862 */  "mulF_mem",
  /*  863 */  "mulF_mem_0",
  /*  864 */  "mulF_imm",
  /*  865 */  "mulF_reg_reg",
  /*  866 */  "mulF_reg_mem",
  /*  867 */  "mulF_reg_mem_0",
  /*  868 */  "mulF_reg_imm",
  /*  869 */  "mulD_reg",
  /*  870 */  "mulD_mem",
  /*  871 */  "mulD_mem_0",
  /*  872 */  "mulD_imm",
  /*  873 */  "mulD_reg_reg",
  /*  874 */  "mulD_reg_mem",
  /*  875 */  "mulD_reg_mem_0",
  /*  876 */  "mulD_reg_imm",
  /*  877 */  "divF_reg",
  /*  878 */  "divF_mem",
  /*  879 */  "divF_imm",
  /*  880 */  "divF_reg_reg",
  /*  881 */  "divF_reg_mem",
  /*  882 */  "divF_reg_imm",
  /*  883 */  "divD_reg",
  /*  884 */  "divD_mem",
  /*  885 */  "divD_imm",
  /*  886 */  "divD_reg_reg",
  /*  887 */  "divD_reg_mem",
  /*  888 */  "divD_reg_imm",
  /*  889 */  "negD_reg",
  /*  890 */  "negD_reg_reg",
  /*  891 */  "sqrtF_reg",
  /*  892 */  "sqrtF_mem",
  /*  893 */  "sqrtF_imm",
  /*  894 */  "sqrtD_reg",
  /*  895 */  "sqrtD_mem",
  /*  896 */  "sqrtD_imm",
  /*  897 */  "loadV4",
  /*  898 */  "loadV8",
  /*  899 */  "loadV16",
  /*  900 */  "loadV32",
  /*  901 */  "storeV4",
  /*  902 */  "storeV8",
  /*  903 */  "storeV16",
  /*  904 */  "storeV32",
  /*  905 */  "Repl4B",
  /*  906 */  "Repl8B",
  /*  907 */  "Repl16B",
  /*  908 */  "Repl32B",
  /*  909 */  "Repl4B_imm",
  /*  910 */  "Repl8B_imm",
  /*  911 */  "Repl16B_imm",
  /*  912 */  "Repl32B_imm",
  /*  913 */  "Repl4B_zero",
  /*  914 */  "Repl8B_zero",
  /*  915 */  "Repl16B_zero",
  /*  916 */  "Repl32B_zero",
  /*  917 */  "Repl2S",
  /*  918 */  "Repl4S",
  /*  919 */  "Repl8S",
  /*  920 */  "Repl16S",
  /*  921 */  "Repl2S_imm",
  /*  922 */  "Repl4S_imm",
  /*  923 */  "Repl8S_imm",
  /*  924 */  "Repl16S_imm",
  /*  925 */  "Repl2S_zero",
  /*  926 */  "Repl4S_zero",
  /*  927 */  "Repl8S_zero",
  /*  928 */  "Repl16S_zero",
  /*  929 */  "Repl2I",
  /*  930 */  "Repl4I",
  /*  931 */  "Repl8I",
  /*  932 */  "Repl2I_imm",
  /*  933 */  "Repl4I_imm",
  /*  934 */  "Repl8I_imm",
  /*  935 */  "Repl2I_mem",
  /*  936 */  "Repl4I_mem",
  /*  937 */  "Repl8I_mem",
  /*  938 */  "Repl2I_zero",
  /*  939 */  "Repl4I_zero",
  /*  940 */  "Repl8I_zero",
  /*  941 */  "Repl2L",
  /*  942 */  "Repl4L",
  /*  943 */  "Repl2L_imm",
  /*  944 */  "Repl4L_imm",
  /*  945 */  "Repl2L_mem",
  /*  946 */  "Repl4L_mem",
  /*  947 */  "Repl2L_zero",
  /*  948 */  "Repl4L_zero",
  /*  949 */  "Repl2F",
  /*  950 */  "Repl4F",
  /*  951 */  "Repl8F",
  /*  952 */  "Repl2F_zero",
  /*  953 */  "Repl4F_zero",
  /*  954 */  "Repl8F_zero",
  /*  955 */  "Repl2D",
  /*  956 */  "Repl4D",
  /*  957 */  "Repl2D_zero",
  /*  958 */  "Repl4D_zero",
  /*  959 */  "vadd4B",
  /*  960 */  "vadd4B_reg",
  /*  961 */  "vadd8B",
  /*  962 */  "vadd8B_reg",
  /*  963 */  "vadd16B",
  /*  964 */  "vadd16B_reg",
  /*  965 */  "vadd16B_mem",
  /*  966 */  "vadd32B_reg",
  /*  967 */  "vadd32B_mem",
  /*  968 */  "vadd2S",
  /*  969 */  "vadd2S_reg",
  /*  970 */  "vadd4S",
  /*  971 */  "vadd4S_reg",
  /*  972 */  "vadd8S",
  /*  973 */  "vadd8S_reg",
  /*  974 */  "vadd8S_mem",
  /*  975 */  "vadd16S_reg",
  /*  976 */  "vadd16S_mem",
  /*  977 */  "vadd2I",
  /*  978 */  "vadd2I_reg",
  /*  979 */  "vadd4I",
  /*  980 */  "vadd4I_reg",
  /*  981 */  "vadd4I_mem",
  /*  982 */  "vadd8I_reg",
  /*  983 */  "vadd8I_mem",
  /*  984 */  "vadd2L",
  /*  985 */  "vadd2L_reg",
  /*  986 */  "vadd2L_mem",
  /*  987 */  "vadd4L_reg",
  /*  988 */  "vadd4L_mem",
  /*  989 */  "vadd2F",
  /*  990 */  "vadd2F_reg",
  /*  991 */  "vadd4F",
  /*  992 */  "vadd4F_reg",
  /*  993 */  "vadd4F_mem",
  /*  994 */  "vadd8F_reg",
  /*  995 */  "vadd8F_mem",
  /*  996 */  "vadd2D",
  /*  997 */  "vadd2D_reg",
  /*  998 */  "vadd2D_mem",
  /*  999 */  "vadd4D_reg",
  /* 1000 */  "vadd4D_mem",
  /* 1001 */  "vsub4B",
  /* 1002 */  "vsub4B_reg",
  /* 1003 */  "vsub8B",
  /* 1004 */  "vsub8B_reg",
  /* 1005 */  "vsub16B",
  /* 1006 */  "vsub16B_reg",
  /* 1007 */  "vsub16B_mem",
  /* 1008 */  "vsub32B_reg",
  /* 1009 */  "vsub32B_mem",
  /* 1010 */  "vsub2S",
  /* 1011 */  "vsub2S_reg",
  /* 1012 */  "vsub4S",
  /* 1013 */  "vsub4S_reg",
  /* 1014 */  "vsub8S",
  /* 1015 */  "vsub8S_reg",
  /* 1016 */  "vsub8S_mem",
  /* 1017 */  "vsub16S_reg",
  /* 1018 */  "vsub16S_mem",
  /* 1019 */  "vsub2I",
  /* 1020 */  "vsub2I_reg",
  /* 1021 */  "vsub4I",
  /* 1022 */  "vsub4I_reg",
  /* 1023 */  "vsub4I_mem",
  /* 1024 */  "vsub8I_reg",
  /* 1025 */  "vsub8I_mem",
  /* 1026 */  "vsub2L",
  /* 1027 */  "vsub2L_reg",
  /* 1028 */  "vsub2L_mem",
  /* 1029 */  "vsub4L_reg",
  /* 1030 */  "vsub4L_mem",
  /* 1031 */  "vsub2F",
  /* 1032 */  "vsub2F_reg",
  /* 1033 */  "vsub4F",
  /* 1034 */  "vsub4F_reg",
  /* 1035 */  "vsub4F_mem",
  /* 1036 */  "vsub8F_reg",
  /* 1037 */  "vsub8F_mem",
  /* 1038 */  "vsub2D",
  /* 1039 */  "vsub2D_reg",
  /* 1040 */  "vsub2D_mem",
  /* 1041 */  "vsub4D_reg",
  /* 1042 */  "vsub4D_mem",
  /* 1043 */  "vmul2S",
  /* 1044 */  "vmul2S_reg",
  /* 1045 */  "vmul4S",
  /* 1046 */  "vmul4S_reg",
  /* 1047 */  "vmul8S",
  /* 1048 */  "vmul8S_reg",
  /* 1049 */  "vmul8S_mem",
  /* 1050 */  "vmul16S_reg",
  /* 1051 */  "vmul16S_mem",
  /* 1052 */  "vmul2I",
  /* 1053 */  "vmul2I_reg",
  /* 1054 */  "vmul4I",
  /* 1055 */  "vmul4I_reg",
  /* 1056 */  "vmul4I_mem",
  /* 1057 */  "vmul8I_reg",
  /* 1058 */  "vmul8I_mem",
  /* 1059 */  "vmul2F",
  /* 1060 */  "vmul2F_reg",
  /* 1061 */  "vmul4F",
  /* 1062 */  "vmul4F_reg",
  /* 1063 */  "vmul4F_mem",
  /* 1064 */  "vmul8F_reg",
  /* 1065 */  "vmul8F_mem",
  /* 1066 */  "vmul2D",
  /* 1067 */  "vmul2D_reg",
  /* 1068 */  "vmul2D_mem",
  /* 1069 */  "vmul4D_reg",
  /* 1070 */  "vmul4D_mem",
  /* 1071 */  "vdiv2F",
  /* 1072 */  "vdiv2F_reg",
  /* 1073 */  "vdiv4F",
  /* 1074 */  "vdiv4F_reg",
  /* 1075 */  "vdiv4F_mem",
  /* 1076 */  "vdiv8F_reg",
  /* 1077 */  "vdiv8F_mem",
  /* 1078 */  "vdiv2D",
  /* 1079 */  "vdiv2D_reg",
  /* 1080 */  "vdiv2D_mem",
  /* 1081 */  "vdiv4D_reg",
  /* 1082 */  "vdiv4D_mem",
  /* 1083 */  "vsll2S",
  /* 1084 */  "vsll2S_imm",
  /* 1085 */  "vsll2S_reg",
  /* 1086 */  "vsll2S_reg_imm",
  /* 1087 */  "vsll4S",
  /* 1088 */  "vsll4S_imm",
  /* 1089 */  "vsll4S_reg",
  /* 1090 */  "vsll4S_reg_imm",
  /* 1091 */  "vsll8S",
  /* 1092 */  "vsll8S_imm",
  /* 1093 */  "vsll8S_reg",
  /* 1094 */  "vsll8S_reg_imm",
  /* 1095 */  "vsll16S_reg",
  /* 1096 */  "vsll16S_reg_imm",
  /* 1097 */  "vsll2I",
  /* 1098 */  "vsll2I_imm",
  /* 1099 */  "vsll2I_reg",
  /* 1100 */  "vsll2I_reg_imm",
  /* 1101 */  "vsll4I",
  /* 1102 */  "vsll4I_imm",
  /* 1103 */  "vsll4I_reg",
  /* 1104 */  "vsll4I_reg_imm",
  /* 1105 */  "vsll8I_reg",
  /* 1106 */  "vsll8I_reg_imm",
  /* 1107 */  "vsll2L",
  /* 1108 */  "vsll2L_imm",
  /* 1109 */  "vsll2L_reg",
  /* 1110 */  "vsll2L_reg_imm",
  /* 1111 */  "vsll4L_reg",
  /* 1112 */  "vsll4L_reg_imm",
  /* 1113 */  "vsrl2S",
  /* 1114 */  "vsrl2S_imm",
  /* 1115 */  "vsrl2S_reg",
  /* 1116 */  "vsrl2S_reg_imm",
  /* 1117 */  "vsrl4S",
  /* 1118 */  "vsrl4S_imm",
  /* 1119 */  "vsrl4S_reg",
  /* 1120 */  "vsrl4S_reg_imm",
  /* 1121 */  "vsrl8S",
  /* 1122 */  "vsrl8S_imm",
  /* 1123 */  "vsrl8S_reg",
  /* 1124 */  "vsrl8S_reg_imm",
  /* 1125 */  "vsrl16S_reg",
  /* 1126 */  "vsrl16S_reg_imm",
  /* 1127 */  "vsrl2I",
  /* 1128 */  "vsrl2I_imm",
  /* 1129 */  "vsrl2I_reg",
  /* 1130 */  "vsrl2I_reg_imm",
  /* 1131 */  "vsrl4I",
  /* 1132 */  "vsrl4I_imm",
  /* 1133 */  "vsrl4I_reg",
  /* 1134 */  "vsrl4I_reg_imm",
  /* 1135 */  "vsrl8I_reg",
  /* 1136 */  "vsrl8I_reg_imm",
  /* 1137 */  "vsrl2L",
  /* 1138 */  "vsrl2L_imm",
  /* 1139 */  "vsrl2L_reg",
  /* 1140 */  "vsrl2L_reg_imm",
  /* 1141 */  "vsrl4L_reg",
  /* 1142 */  "vsrl4L_reg_imm",
  /* 1143 */  "vsra2S",
  /* 1144 */  "vsra2S_imm",
  /* 1145 */  "vsra2S_reg",
  /* 1146 */  "vsra2S_reg_imm",
  /* 1147 */  "vsra4S",
  /* 1148 */  "vsra4S_imm",
  /* 1149 */  "vsra4S_reg",
  /* 1150 */  "vsra4S_reg_imm",
  /* 1151 */  "vsra8S",
  /* 1152 */  "vsra8S_imm",
  /* 1153 */  "vsra8S_reg",
  /* 1154 */  "vsra8S_reg_imm",
  /* 1155 */  "vsra16S_reg",
  /* 1156 */  "vsra16S_reg_imm",
  /* 1157 */  "vsra2I",
  /* 1158 */  "vsra2I_imm",
  /* 1159 */  "vsra2I_reg",
  /* 1160 */  "vsra2I_reg_imm",
  /* 1161 */  "vsra4I",
  /* 1162 */  "vsra4I_imm",
  /* 1163 */  "vsra4I_reg",
  /* 1164 */  "vsra4I_reg_imm",
  /* 1165 */  "vsra8I_reg",
  /* 1166 */  "vsra8I_reg_imm",
  /* 1167 */  "vand4B",
  /* 1168 */  "vand4B_reg",
  /* 1169 */  "vand8B",
  /* 1170 */  "vand8B_reg",
  /* 1171 */  "vand16B",
  /* 1172 */  "vand16B_reg",
  /* 1173 */  "vand16B_mem",
  /* 1174 */  "vand32B_reg",
  /* 1175 */  "vand32B_mem",
  /* 1176 */  "vor4B",
  /* 1177 */  "vor4B_reg",
  /* 1178 */  "vor8B",
  /* 1179 */  "vor8B_reg",
  /* 1180 */  "vor16B",
  /* 1181 */  "vor16B_reg",
  /* 1182 */  "vor16B_mem",
  /* 1183 */  "vor32B_reg",
  /* 1184 */  "vor32B_mem",
  /* 1185 */  "vxor4B",
  /* 1186 */  "vxor4B_reg",
  /* 1187 */  "vxor8B",
  /* 1188 */  "vxor8B_reg",
  /* 1189 */  "vxor16B",
  /* 1190 */  "vxor16B_reg",
  /* 1191 */  "vxor16B_mem",
  /* 1192 */  "vxor32B_reg",
  /* 1193 */  "vxor32B_mem",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  false,
  /*   44 */  false,
  /*   45 */  false,
  /*   46 */  false,
  /*   47 */  false,
  /*   48 */  false,
  /*   49 */  false,
  /*   50 */  false,
  /*   51 */  false,
  /*   52 */  false,
  /*   53 */  false,
  /*   54 */  false,
  /*   55 */  false,
  /*   56 */  false,
  /*   57 */  false,
  /*   58 */  false,
  /*   59 */  false,
  /*   60 */  false,
  /*   61 */  false,
  /*   62 */  false,
  /*   63 */  false,
  /*   64 */  false,
  /*   65 */  false,
  /*   66 */  false,
  /*   67 */  false,
  /*   68 */  false,
  /*   69 */  false,
  /*   70 */  false,
  /*   71 */  false,
  /*   72 */  false,
  /*   73 */  false,
  /*   74 */  false,
  /*   75 */  false,
  /*   76 */  false,
  /*   77 */  false,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  true,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  true,
  /*  108 */  true,
  /*  109 */  true,
  /*  110 */  true,
  /*  111 */  true,
  /*  112 */  true,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  // last operand
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  // last operand class
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  /*  188 */  false,
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  // last internally defined operand
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // RegFlags: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // _last_machine_leaf: 13
  0, // AbsD: 14
  0, // AbsF: 15
  0, // AbsI: 16
  0, // AddD: 17
  0, // AddF: 18
  0, // AddI: 19
  0, // AddL: 20
  0, // AddP: 21
  0, // Allocate: 22
  0, // AllocateArray: 23
  0, // AndI: 24
  0, // AndL: 25
  0, // AryEq: 26
  0, // AtanD: 27
  1, // Binary: 28
  1, // Bool: 29
  0, // BoxLock: 30
  0, // ReverseBytesI: 31
  0, // ReverseBytesL: 32
  0, // ReverseBytesUS: 33
  0, // ReverseBytesS: 34
  0, // CProj: 35
  0, // CallDynamicJava: 36
  0, // CallJava: 37
  0, // CallLeaf: 38
  0, // CallLeafNoFP: 39
  0, // CallRuntime: 40
  0, // CallStaticJava: 41
  0, // CastII: 42
  0, // CastX2P: 43
  0, // CastP2X: 44
  0, // CastPP: 45
  0, // Catch: 46
  0, // CatchProj: 47
  0, // CheckCastPP: 48
  0, // ClearArray: 49
  0, // ConstraintCast: 50
  0, // CMoveD: 51
  0, // CMoveF: 52
  0, // CMoveI: 53
  0, // CMoveL: 54
  0, // CMoveP: 55
  0, // CMoveN: 56
  1, // CmpN: 57
  1, // CmpD: 58
  0, // CmpD3: 59
  1, // CmpF: 60
  0, // CmpF3: 61
  1, // CmpI: 62
  1, // CmpL: 63
  0, // CmpL3: 64
  0, // CmpLTMask: 65
  1, // CmpP: 66
  1, // CmpU: 67
  0, // CompareAndSwapI: 68
  0, // CompareAndSwapL: 69
  0, // CompareAndSwapP: 70
  0, // CompareAndSwapN: 71
  0, // GetAndAddI: 72
  0, // GetAndAddL: 73
  0, // GetAndSetI: 74
  0, // GetAndSetL: 75
  0, // GetAndSetP: 76
  0, // GetAndSetN: 77
  0, // Con: 78
  0, // ConN: 79
  0, // ConD: 80
  0, // ConF: 81
  0, // ConI: 82
  0, // ConL: 83
  0, // ConP: 84
  0, // Conv2B: 85
  0, // ConvD2F: 86
  0, // ConvD2I: 87
  0, // ConvD2L: 88
  0, // ConvF2D: 89
  0, // ConvF2I: 90
  0, // ConvF2L: 91
  0, // ConvI2D: 92
  0, // ConvI2F: 93
  0, // ConvI2L: 94
  0, // ConvL2D: 95
  0, // ConvL2F: 96
  0, // ConvL2I: 97
  0, // CosD: 98
  0, // CountedLoop: 99
  0, // CountedLoopEnd: 100
  0, // CountLeadingZerosI: 101
  0, // CountLeadingZerosL: 102
  0, // CountTrailingZerosI: 103
  0, // CountTrailingZerosL: 104
  0, // CreateEx: 105
  0, // DecodeN: 106
  0, // DivD: 107
  0, // DivF: 108
  0, // DivI: 109
  0, // DivL: 110
  0, // DivMod: 111
  0, // DivModI: 112
  0, // DivModL: 113
  0, // EncodeP: 114
  0, // ExpD: 115
  1, // FastLock: 116
  1, // FastUnlock: 117
  0, // Goto: 118
  0, // Halt: 119
  0, // If: 120
  0, // IfFalse: 121
  0, // IfTrue: 122
  0, // Initialize: 123
  0, // JProj: 124
  0, // Jump: 125
  0, // JumpProj: 126
  0, // LShiftI: 127
  0, // LShiftL: 128
  0, // LoadB: 129
  0, // LoadUB: 130
  0, // LoadUS: 131
  0, // LoadD: 132
  0, // LoadD_unaligned: 133
  0, // LoadF: 134
  0, // LoadI: 135
  0, // LoadKlass: 136
  0, // LoadNKlass: 137
  0, // LoadL: 138
  0, // LoadL_unaligned: 139
  0, // LoadPLocked: 140
  0, // LoadP: 141
  0, // LoadN: 142
  0, // LoadRange: 143
  0, // LoadS: 144
  0, // Lock: 145
  0, // LogD: 146
  0, // Log10D: 147
  0, // Loop: 148
  0, // LoopLimit: 149
  0, // Mach: 150
  0, // MachProj: 151
  0, // MaxI: 152
  0, // MemBarAcquire: 153
  0, // MemBarAcquireLock: 154
  0, // MemBarCPUOrder: 155
  0, // MemBarRelease: 156
  0, // MemBarReleaseLock: 157
  0, // MemBarVolatile: 158
  0, // MemBarStoreStore: 159
  0, // MergeMem: 160
  0, // MinI: 161
  0, // ModD: 162
  0, // ModF: 163
  0, // ModI: 164
  0, // ModL: 165
  0, // MoveI2F: 166
  0, // MoveF2I: 167
  0, // MoveL2D: 168
  0, // MoveD2L: 169
  0, // MulD: 170
  0, // MulF: 171
  0, // MulHiL: 172
  0, // MulI: 173
  0, // MulL: 174
  0, // Multi: 175
  0, // NegD: 176
  0, // NegF: 177
  0, // NeverBranch: 178
  0, // Opaque1: 179
  0, // Opaque2: 180
  0, // OrI: 181
  0, // OrL: 182
  0, // PCTable: 183
  0, // Parm: 184
  0, // PartialSubtypeCheck: 185
  0, // Phi: 186
  0, // PopCountI: 187
  0, // PopCountL: 188
  0, // PowD: 189
  0, // PrefetchAllocation: 190
  0, // PrefetchRead: 191
  0, // PrefetchWrite: 192
  0, // Proj: 193
  0, // RShiftI: 194
  0, // RShiftL: 195
  0, // Region: 196
  0, // Rethrow: 197
  0, // Return: 198
  0, // Root: 199
  0, // RoundDouble: 200
  0, // RoundFloat: 201
  0, // SafePoint: 202
  0, // SafePointScalarObject: 203
  0, // SCMemProj: 204
  0, // SinD: 205
  0, // SqrtD: 206
  0, // Start: 207
  0, // StartOSR: 208
  0, // StoreB: 209
  0, // StoreC: 210
  0, // StoreCM: 211
  0, // StorePConditional: 212
  0, // StoreIConditional: 213
  0, // StoreLConditional: 214
  0, // StoreD: 215
  0, // StoreF: 216
  0, // StoreI: 217
  0, // StoreL: 218
  0, // StoreP: 219
  0, // StoreN: 220
  0, // StrComp: 221
  0, // StrEquals: 222
  0, // StrIndexOf: 223
  0, // SubD: 224
  0, // SubF: 225
  0, // SubI: 226
  0, // SubL: 227
  0, // TailCall: 228
  0, // TailJump: 229
  0, // TanD: 230
  0, // ThreadLocal: 231
  0, // Unlock: 232
  0, // URShiftI: 233
  0, // URShiftL: 234
  0, // XorI: 235
  0, // XorL: 236
  0, // Vector: 237
  0, // AddVB: 238
  0, // AddVS: 239
  0, // AddVI: 240
  0, // AddVL: 241
  0, // AddVF: 242
  0, // AddVD: 243
  0, // SubVB: 244
  0, // SubVS: 245
  0, // SubVI: 246
  0, // SubVL: 247
  0, // SubVF: 248
  0, // SubVD: 249
  0, // MulVS: 250
  0, // MulVI: 251
  0, // MulVF: 252
  0, // MulVD: 253
  0, // DivVF: 254
  0, // DivVD: 255
  0, // LShiftCntV: 256
  0, // RShiftCntV: 257
  0, // LShiftVB: 258
  0, // LShiftVS: 259
  0, // LShiftVI: 260
  0, // LShiftVL: 261
  0, // RShiftVB: 262
  0, // RShiftVS: 263
  0, // RShiftVI: 264
  0, // RShiftVL: 265
  0, // URShiftVB: 266
  0, // URShiftVS: 267
  0, // URShiftVI: 268
  0, // URShiftVL: 269
  0, // AndV: 270
  0, // OrV: 271
  0, // XorV: 272
  0, // LoadVector: 273
  0, // StoreVector: 274
  0, // Pack: 275
  0, // PackB: 276
  0, // PackS: 277
  0, // PackI: 278
  0, // PackL: 279
  0, // PackF: 280
  0, // PackD: 281
  0, // Pack2L: 282
  0, // Pack2D: 283
  0, // ReplicateB: 284
  0, // ReplicateS: 285
  0, // ReplicateI: 286
  0, // ReplicateL: 287
  0, // ReplicateF: 288
  0, // ReplicateD: 289
  0, // Extract: 290
  0, // ExtractB: 291
  0, // ExtractUB: 292
  0, // ExtractC: 293
  0, // ExtractS: 294
  0, // ExtractI: 295
  0, // ExtractL: 296
  0, // ExtractF: 297
  0 // no trailing comma // ExtractD: 298
};
//  The following instructions can cisc-spill
//  popCountI can cisc-spill operand 1 to popCountI_mem
//  popCountL can cisc-spill operand 1 to popCountL_mem
//  cmovI_reg can cisc-spill operand 4 to cmovI_mem
//  cmovI_regU can cisc-spill operand 4 to cmovI_memU
//  cmovI_regUCF can cisc-spill operand 4 to cmovI_memUCF
//  addI_eReg can cisc-spill operand 2 to addI_eReg_mem
//  subI_eReg can cisc-spill operand 2 to subI_eReg_mem
//  mulI_eReg can cisc-spill operand 2 to mulI
//  mulI_eReg_imm can cisc-spill operand 1 to mulI_mem_imm
//  i2b can cisc-spill operand 1 to loadI2B
//  i2s can cisc-spill operand 1 to loadI2S
//  andI_eReg can cisc-spill operand 2 to andI_eReg_mem
//  orI_eReg can cisc-spill operand 2 to orI_eReg_mem
//  xorI_eReg can cisc-spill operand 2 to xorI_eReg_mem
//  addL_eReg can cisc-spill operand 2 to addL_eReg_mem
//  subL_eReg can cisc-spill operand 2 to subL_eReg_mem
//  andL_eReg can cisc-spill operand 2 to andL_eReg_mem
//  orl_eReg can cisc-spill operand 2 to orl_eReg_mem
//  xorl_eReg can cisc-spill operand 2 to xorl_eReg_mem
//  cmpD_cc can cisc-spill operand 2 to cmpD_ccmem
//  cmpD_ccCF can cisc-spill operand 2 to cmpD_ccmemCF
//  cmpD_reg can cisc-spill operand 2 to cmpD_regmem
//  subDPR_reg can cisc-spill operand 2 to subDPR_reg_mem
//  addDPR_reg can cisc-spill operand 2 to addDPR_reg_mem
//  mulDPR_reg can cisc-spill operand 2 to mulDPR_reg_mem
//  cmpF_cc can cisc-spill operand 2 to cmpF_ccmem
//  cmpF_ccCF can cisc-spill operand 2 to cmpF_ccmemCF
//  cmpF_reg can cisc-spill operand 2 to cmpF_regmem
//  addFPR24_reg can cisc-spill operand 2 to addFPR24_reg_mem
//  addFPR_reg can cisc-spill operand 2 to addFPR_reg_mem
//  addFPR24_reg_mem can cisc-spill operand 1 to addFPR24_mem_cisc
//  addFPR24_reg_mem_0 can cisc-spill operand 2 to addFPR24_mem_cisc_0
//  addFPR24_mem_reg can cisc-spill operand 2 to addFPR24_mem_cisc
//  mulFPR24_reg can cisc-spill operand 2 to mulFPR24_reg_mem
//  mulFPR_reg can cisc-spill operand 2 to mulFPR_reg_mem
//  addFPR_mulFPR_reg can cisc-spill operand 1 to addFPR_mulFPR_reg_load1
//  addFPR_mulFPR_reg_0 can cisc-spill operand 2 to addFPR_mulFPR_reg_load1_1
//  convI2L_reg can cisc-spill operand 1 to loadI2L
//  convI2L_reg_zex can cisc-spill operand 1 to loadUI2L
//  compI_eReg can cisc-spill operand 2 to compI_eReg_mem
//  compU_eReg can cisc-spill operand 2 to compU_eReg_mem
//  compP_eReg can cisc-spill operand 2 to compP_eReg_mem
//  cmovLL_reg_LTGE can cisc-spill operand 4 to cmovLL_mem_LTGE
//  cmovII_reg_LTGE can cisc-spill operand 4 to cmovII_mem_LTGE
//  cmovLL_reg_EQNE can cisc-spill operand 4 to cmovLL_mem_EQNE
//  cmovII_reg_EQNE can cisc-spill operand 4 to cmovII_mem_EQNE
//  cmovLL_reg_LEGT can cisc-spill operand 4 to cmovLL_mem_LEGT
//  cmovII_reg_LEGT can cisc-spill operand 4 to cmovII_mem_LEGT
//  addF_reg can cisc-spill operand 2 to addF_mem
//  addF_reg_reg can cisc-spill operand 2 to addF_reg_mem
//  addD_reg can cisc-spill operand 2 to addD_mem
//  addD_reg_reg can cisc-spill operand 2 to addD_reg_mem
//  subF_reg can cisc-spill operand 2 to subF_mem
//  subF_reg_reg can cisc-spill operand 2 to subF_reg_mem
//  subD_reg can cisc-spill operand 2 to subD_mem
//  subD_reg_reg can cisc-spill operand 2 to subD_reg_mem
//  mulF_reg can cisc-spill operand 2 to mulF_mem
//  mulF_reg_reg can cisc-spill operand 2 to mulF_reg_mem
//  mulD_reg can cisc-spill operand 2 to mulD_mem
//  mulD_reg_reg can cisc-spill operand 2 to mulD_reg_mem
//  divF_reg can cisc-spill operand 2 to divF_mem
//  divF_reg_reg can cisc-spill operand 2 to divF_reg_mem
//  divD_reg can cisc-spill operand 2 to divD_mem
//  divD_reg_reg can cisc-spill operand 2 to divD_reg_mem
//  sqrtF_reg can cisc-spill operand 1 to sqrtF_mem
//  sqrtD_reg can cisc-spill operand 1 to sqrtD_mem
//  Repl2I can cisc-spill operand 1 to Repl2I_mem
//  Repl4I can cisc-spill operand 1 to Repl4I_mem
//  Repl8I can cisc-spill operand 1 to Repl8I_mem



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "ECX",
  "EBX",
  "EBP",
  "EDI",
  "EAX",
  "EDX",
  "ESI",
  "ESP",
  "FPR0L",
  "FPR0H",
  "FPR1L",
  "FPR1H",
  "FPR2L",
  "FPR2H",
  "FPR3L",
  "FPR3H",
  "FPR4L",
  "FPR4H",
  "FPR5L",
  "FPR5H",
  "FPR6L",
  "FPR6H",
  "FPR7L",
  "FPR7H",
  "XMM0",
  "XMM0b",
  "XMM0c",
  "XMM0d",
  "XMM0e",
  "XMM0f",
  "XMM0g",
  "XMM0h",
  "XMM1",
  "XMM1b",
  "XMM1c",
  "XMM1d",
  "XMM1e",
  "XMM1f",
  "XMM1g",
  "XMM1h",
  "XMM2",
  "XMM2b",
  "XMM2c",
  "XMM2d",
  "XMM2e",
  "XMM2f",
  "XMM2g",
  "XMM2h",
  "XMM3",
  "XMM3b",
  "XMM3c",
  "XMM3d",
  "XMM3e",
  "XMM3f",
  "XMM3g",
  "XMM3h",
  "XMM4",
  "XMM4b",
  "XMM4c",
  "XMM4d",
  "XMM4e",
  "XMM4f",
  "XMM4g",
  "XMM4h",
  "XMM5",
  "XMM5b",
  "XMM5c",
  "XMM5d",
  "XMM5e",
  "XMM5f",
  "XMM5g",
  "XMM5h",
  "XMM6",
  "XMM6b",
  "XMM6c",
  "XMM6d",
  "XMM6e",
  "XMM6f",
  "XMM6g",
  "XMM6h",
  "XMM7",
  "XMM7b",
  "XMM7c",
  "XMM7d",
  "XMM7e",
  "XMM7f",
  "XMM7g",
  "XMM7h",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	rcx->as_VMReg(),
	rbx->as_VMReg(),
	rbp->as_VMReg(),
	rdi->as_VMReg(),
	rax->as_VMReg(),
	rdx->as_VMReg(),
	rsi->as_VMReg(),
	rsp->as_VMReg(),
	VMRegImpl::Bad(),
	VMRegImpl::Bad(),
	as_FloatRegister(0)->as_VMReg(),
	as_FloatRegister(0)->as_VMReg()->next(),
	as_FloatRegister(1)->as_VMReg(),
	as_FloatRegister(1)->as_VMReg()->next(),
	as_FloatRegister(2)->as_VMReg(),
	as_FloatRegister(2)->as_VMReg()->next(),
	as_FloatRegister(3)->as_VMReg(),
	as_FloatRegister(3)->as_VMReg()->next(),
	as_FloatRegister(4)->as_VMReg(),
	as_FloatRegister(4)->as_VMReg()->next(),
	as_FloatRegister(5)->as_VMReg(),
	as_FloatRegister(5)->as_VMReg()->next(),
	as_FloatRegister(6)->as_VMReg(),
	as_FloatRegister(6)->as_VMReg()->next(),
	xmm0->as_VMReg(),
	xmm0->as_VMReg()->next(1),
	xmm0->as_VMReg()->next(2),
	xmm0->as_VMReg()->next(3),
	xmm0->as_VMReg()->next(4),
	xmm0->as_VMReg()->next(5),
	xmm0->as_VMReg()->next(6),
	xmm0->as_VMReg()->next(7),
	xmm1->as_VMReg(),
	xmm1->as_VMReg()->next(1),
	xmm1->as_VMReg()->next(2),
	xmm1->as_VMReg()->next(3),
	xmm1->as_VMReg()->next(4),
	xmm1->as_VMReg()->next(5),
	xmm1->as_VMReg()->next(6),
	xmm1->as_VMReg()->next(7),
	xmm2->as_VMReg(),
	xmm2->as_VMReg()->next(1),
	xmm2->as_VMReg()->next(2),
	xmm2->as_VMReg()->next(3),
	xmm2->as_VMReg()->next(4),
	xmm2->as_VMReg()->next(5),
	xmm2->as_VMReg()->next(6),
	xmm2->as_VMReg()->next(7),
	xmm3->as_VMReg(),
	xmm3->as_VMReg()->next(1),
	xmm3->as_VMReg()->next(2),
	xmm3->as_VMReg()->next(3),
	xmm3->as_VMReg()->next(4),
	xmm3->as_VMReg()->next(5),
	xmm3->as_VMReg()->next(6),
	xmm3->as_VMReg()->next(7),
	xmm4->as_VMReg(),
	xmm4->as_VMReg()->next(1),
	xmm4->as_VMReg()->next(2),
	xmm4->as_VMReg()->next(3),
	xmm4->as_VMReg()->next(4),
	xmm4->as_VMReg()->next(5),
	xmm4->as_VMReg()->next(6),
	xmm4->as_VMReg()->next(7),
	xmm5->as_VMReg(),
	xmm5->as_VMReg()->next(1),
	xmm5->as_VMReg()->next(2),
	xmm5->as_VMReg()->next(3),
	xmm5->as_VMReg()->next(4),
	xmm5->as_VMReg()->next(5),
	xmm5->as_VMReg()->next(6),
	xmm5->as_VMReg()->next(7),
	xmm6->as_VMReg(),
	xmm6->as_VMReg()->next(1),
	xmm6->as_VMReg()->next(2),
	xmm6->as_VMReg()->next(3),
	xmm6->as_VMReg()->next(4),
	xmm6->as_VMReg()->next(5),
	xmm6->as_VMReg()->next(6),
	xmm6->as_VMReg()->next(7),
	xmm7->as_VMReg(),
	xmm7->as_VMReg()->next(1),
	xmm7->as_VMReg()->next(2),
	xmm7->as_VMReg()->next(3),
	xmm7->as_VMReg()->next(4),
	xmm7->as_VMReg()->next(5),
	xmm7->as_VMReg()->next(6),
	xmm7->as_VMReg()->next(7),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\x1',  // ECX
  (unsigned char)'\x3',  // EBX
  (unsigned char)'\x5',  // EBP
  (unsigned char)'\x7',  // EDI
  (unsigned char)'\x0',  // EAX
  (unsigned char)'\x2',  // EDX
  (unsigned char)'\x6',  // ESI
  (unsigned char)'\x4',  // ESP
  (unsigned char)'\x0',  // FPR0L
  (unsigned char)'\x0',  // FPR0H
  (unsigned char)'\x1',  // FPR1L
  (unsigned char)'\x1',  // FPR1H
  (unsigned char)'\x2',  // FPR2L
  (unsigned char)'\x2',  // FPR2H
  (unsigned char)'\x3',  // FPR3L
  (unsigned char)'\x3',  // FPR3H
  (unsigned char)'\x4',  // FPR4L
  (unsigned char)'\x4',  // FPR4H
  (unsigned char)'\x5',  // FPR5L
  (unsigned char)'\x5',  // FPR5H
  (unsigned char)'\x6',  // FPR6L
  (unsigned char)'\x6',  // FPR6H
  (unsigned char)'\x7',  // FPR7L
  (unsigned char)'\x7',  // FPR7H
  (unsigned char)'\x0',  // XMM0
  (unsigned char)'\x0',  // XMM0b
  (unsigned char)'\x0',  // XMM0c
  (unsigned char)'\x0',  // XMM0d
  (unsigned char)'\x0',  // XMM0e
  (unsigned char)'\x0',  // XMM0f
  (unsigned char)'\x0',  // XMM0g
  (unsigned char)'\x0',  // XMM0h
  (unsigned char)'\x1',  // XMM1
  (unsigned char)'\x1',  // XMM1b
  (unsigned char)'\x1',  // XMM1c
  (unsigned char)'\x1',  // XMM1d
  (unsigned char)'\x1',  // XMM1e
  (unsigned char)'\x1',  // XMM1f
  (unsigned char)'\x1',  // XMM1g
  (unsigned char)'\x1',  // XMM1h
  (unsigned char)'\x2',  // XMM2
  (unsigned char)'\x2',  // XMM2b
  (unsigned char)'\x2',  // XMM2c
  (unsigned char)'\x2',  // XMM2d
  (unsigned char)'\x2',  // XMM2e
  (unsigned char)'\x2',  // XMM2f
  (unsigned char)'\x2',  // XMM2g
  (unsigned char)'\x2',  // XMM2h
  (unsigned char)'\x3',  // XMM3
  (unsigned char)'\x3',  // XMM3b
  (unsigned char)'\x3',  // XMM3c
  (unsigned char)'\x3',  // XMM3d
  (unsigned char)'\x3',  // XMM3e
  (unsigned char)'\x3',  // XMM3f
  (unsigned char)'\x3',  // XMM3g
  (unsigned char)'\x3',  // XMM3h
  (unsigned char)'\x4',  // XMM4
  (unsigned char)'\x4',  // XMM4b
  (unsigned char)'\x4',  // XMM4c
  (unsigned char)'\x4',  // XMM4d
  (unsigned char)'\x4',  // XMM4e
  (unsigned char)'\x4',  // XMM4f
  (unsigned char)'\x4',  // XMM4g
  (unsigned char)'\x4',  // XMM4h
  (unsigned char)'\x5',  // XMM5
  (unsigned char)'\x5',  // XMM5b
  (unsigned char)'\x5',  // XMM5c
  (unsigned char)'\x5',  // XMM5d
  (unsigned char)'\x5',  // XMM5e
  (unsigned char)'\x5',  // XMM5f
  (unsigned char)'\x5',  // XMM5g
  (unsigned char)'\x5',  // XMM5h
  (unsigned char)'\x6',  // XMM6
  (unsigned char)'\x6',  // XMM6b
  (unsigned char)'\x6',  // XMM6c
  (unsigned char)'\x6',  // XMM6d
  (unsigned char)'\x6',  // XMM6e
  (unsigned char)'\x6',  // XMM6f
  (unsigned char)'\x6',  // XMM6g
  (unsigned char)'\x6',  // XMM6h
  (unsigned char)'\x7',  // XMM7
  (unsigned char)'\x7',  // XMM7b
  (unsigned char)'\x7',  // XMM7c
  (unsigned char)'\x7',  // XMM7d
  (unsigned char)'\x7',  // XMM7e
  (unsigned char)'\x7',  // XMM7f
  (unsigned char)'\x7',  // XMM7g
  (unsigned char)'\x7',  // XMM7h
  (unsigned char)'\x8' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone(Compile* C) const {
  return  new (C) labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone(Compile* C) const {
  return  new (C) methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *rRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *xRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_X_REG_mask();
}

const RegMask *eAXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EAX_REG_mask();
}

const RegMask *eBXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBX_REG_mask();
}

const RegMask *eCXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ECX_REG_mask();
}

const RegMask *eDXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EDX_REG_mask();
}

const RegMask *eDIRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EDI_REG_mask();
}

const RegMask *naxRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NAX_REG_mask();
}

const RegMask *nadxRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NADX_REG_mask();
}

const RegMask *ncxRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NCX_REG_mask();
}

const RegMask *eSIRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *anyRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *eRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *eRegP_no_EBPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_NO_RBP_mask();
}

const RegMask *naxRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NAX_REG_mask();
}

const RegMask *nabxRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NABX_REG_mask();
}

const RegMask *pRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &P_REG_mask();
}

const RegMask *eAXRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EAX_REG_mask();
}

const RegMask *eBXRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBX_REG_mask();
}

const RegMask *eCXRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ECX_REG_mask();
}

const RegMask *eSIRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *eDIRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EDI_REG_mask();
}

const RegMask *eBPRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBP_REG_mask();
}

const RegMask *eRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_REG_mask();
}

const RegMask *eADXRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EADX_REG_mask();
}

const RegMask *eBCXRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBCX_REG_mask();
}

const RegMask *eADXRegL_low_onlyOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EADX_REG_mask();
}

const RegMask *eFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *eFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *eFlagsRegUCFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_long_LTGEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_long_EQNEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_long_LEGTOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *regDPROper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_DBL_REG_mask();
}

const RegMask *regDPR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_DBL_REG0_mask();
}

const RegMask *regDPR2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_DBL_REG1_mask();
}

const RegMask *regnotDPR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_DBL_NOTREG0_mask();
}

const RegMask *regFPROper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_FLT_REG_mask();
}

const RegMask *regFPR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_FLT_REG0_mask();
}

const RegMask *regFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *regDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indOffset8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indOffset32Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indOffset32XOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indIndexOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indIndexScaleOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indIndexScaleOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &INT_REG_mask();
}

const RegMask *load_long_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *load_long_indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *load_long_indOffset32Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *indirect_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indOffset8_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_NO_RBP_mask();
}

const RegMask *indOffset32_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_NO_RBP_mask();
}

const RegMask *indIndexOffset_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_NO_RBP_mask();
  case 1: return &INT_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScale_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_NO_RBP_mask();
  case 1: return &INT_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaleOffset_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_NO_RBP_mask();
  case 1: return &INT_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *vecSOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORS_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vecYOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORY_REG_mask();
}

//------------------Define members for classes derived from MachNode----------

void popCountINode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *popCountINode::cisc_version( int offset, Compile* C ) {
  popCountI_memNode *node = new (C) popCountI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void popCountLNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *popCountLNode::cisc_version( int offset, Compile* C ) {
  popCountL_memNode *node = new (C) popCountL_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regNode::cisc_version( int offset, Compile* C ) {
  cmovI_memNode *node = new (C) cmovI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regUNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regUNode::cisc_version( int offset, Compile* C ) {
  cmovI_memUNode *node = new (C) cmovI_memUNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regUCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regUCFNode::cisc_version( int offset, Compile* C ) {
  cmovI_memUCFNode *node = new (C) cmovI_memUCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addI_eRegNode::cisc_version( int offset, Compile* C ) {
  addI_eReg_memNode *node = new (C) addI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *subI_eRegNode::cisc_version( int offset, Compile* C ) {
  subI_eReg_memNode *node = new (C) subI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulI_eRegNode::cisc_version( int offset, Compile* C ) {
  mulINode *node = new (C) mulINode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulI_eReg_immNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulI_eReg_immNode::cisc_version( int offset, Compile* C ) {
  mulI_mem_immNode *node = new (C) mulI_mem_immNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void i2bNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_X_REG_mask();
}

// Build CISC version of this instruction
MachNode *i2bNode::cisc_version( int offset, Compile* C ) {
  loadI2BNode *node = new (C) loadI2BNode();
  node->_num_opnds = 3;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void i2sNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_X_REG_mask();
}

// Build CISC version of this instruction
MachNode *i2sNode::cisc_version( int offset, Compile* C ) {
  loadI2SNode *node = new (C) loadI2SNode();
  node->_num_opnds = 3;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *andI_eRegNode::cisc_version( int offset, Compile* C ) {
  andI_eReg_memNode *node = new (C) andI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void orI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *orI_eRegNode::cisc_version( int offset, Compile* C ) {
  orI_eReg_memNode *node = new (C) orI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void xorI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *xorI_eRegNode::cisc_version( int offset, Compile* C ) {
  xorI_eReg_memNode *node = new (C) xorI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addL_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *addL_eRegNode::cisc_version( int offset, Compile* C ) {
  addL_eReg_memNode *node = new (C) addL_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subL_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *subL_eRegNode::cisc_version( int offset, Compile* C ) {
  subL_eReg_memNode *node = new (C) subL_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andL_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *andL_eRegNode::cisc_version( int offset, Compile* C ) {
  andL_eReg_memNode *node = new (C) andL_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void orl_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *orl_eRegNode::cisc_version( int offset, Compile* C ) {
  orl_eReg_memNode *node = new (C) orl_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void xorl_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *xorl_eRegNode::cisc_version( int offset, Compile* C ) {
  xorl_eReg_memNode *node = new (C) xorl_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_ccNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_ccNode::cisc_version( int offset, Compile* C ) {
  cmpD_ccmemNode *node = new (C) cmpD_ccmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_ccCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_ccCFNode::cisc_version( int offset, Compile* C ) {
  cmpD_ccmemCFNode *node = new (C) cmpD_ccmemCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_regNode::cisc_version( int offset, Compile* C ) {
  cmpD_regmemNode *node = new (C) cmpD_regmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subDPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_DBL_REG_mask();
}

// Build CISC version of this instruction
MachNode *subDPR_regNode::cisc_version( int offset, Compile* C ) {
  subDPR_reg_memNode *node = new (C) subDPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addDPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_DBL_REG_mask();
}

// Build CISC version of this instruction
MachNode *addDPR_regNode::cisc_version( int offset, Compile* C ) {
  addDPR_reg_memNode *node = new (C) addDPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulDPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_DBL_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulDPR_regNode::cisc_version( int offset, Compile* C ) {
  mulDPR_reg_memNode *node = new (C) mulDPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_ccNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_ccNode::cisc_version( int offset, Compile* C ) {
  cmpF_ccmemNode *node = new (C) cmpF_ccmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_ccCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_ccCFNode::cisc_version( int offset, Compile* C ) {
  cmpF_ccmemCFNode *node = new (C) cmpF_ccmemCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_regNode::cisc_version( int offset, Compile* C ) {
  cmpF_regmemNode *node = new (C) cmpF_regmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_regNode::cisc_version( int offset, Compile* C ) {
  addFPR24_reg_memNode *node = new (C) addFPR24_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR_regNode::cisc_version( int offset, Compile* C ) {
  addFPR_reg_memNode *node = new (C) addFPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_reg_memNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_reg_memNode::cisc_version( int offset, Compile* C ) {
  addFPR24_mem_ciscNode *node = new (C) addFPR24_mem_ciscNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_reg_mem_0Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_reg_mem_0Node::cisc_version( int offset, Compile* C ) {
  addFPR24_mem_cisc_0Node *node = new (C) addFPR24_mem_cisc_0Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_mem_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_mem_regNode::cisc_version( int offset, Compile* C ) {
  addFPR24_mem_ciscNode *node = new (C) addFPR24_mem_ciscNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulFPR24_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulFPR24_regNode::cisc_version( int offset, Compile* C ) {
  mulFPR24_reg_memNode *node = new (C) mulFPR24_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulFPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulFPR_regNode::cisc_version( int offset, Compile* C ) {
  mulFPR_reg_memNode *node = new (C) mulFPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR_mulFPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR_mulFPR_regNode::cisc_version( int offset, Compile* C ) {
  addFPR_mulFPR_reg_load1Node *node = new (C) addFPR_mulFPR_reg_load1Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR_mulFPR_reg_0Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FP_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR_mulFPR_reg_0Node::cisc_version( int offset, Compile* C ) {
  addFPR_mulFPR_reg_load1_1Node *node = new (C) addFPR_mulFPR_reg_load1_1Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convI2L_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *convI2L_regNode::cisc_version( int offset, Compile* C ) {
  loadI2LNode *node = new (C) loadI2LNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convI2L_reg_zexNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *convI2L_reg_zexNode::cisc_version( int offset, Compile* C ) {
  loadUI2LNode *node = new (C) loadUI2LNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *compI_eRegNode::cisc_version( int offset, Compile* C ) {
  compI_eReg_memNode *node = new (C) compI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compU_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *compU_eRegNode::cisc_version( int offset, Compile* C ) {
  compU_eReg_memNode *node = new (C) compU_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compP_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *compP_eRegNode::cisc_version( int offset, Compile* C ) {
  compP_eReg_memNode *node = new (C) compP_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}

// Build short branch version of this instruction
MachNode *jmpDirNode::short_branch_version(Compile* C) {
  jmpDir_shortNode *node = new (C) jmpDir_shortNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConNode::short_branch_version(Compile* C) {
  jmpCon_shortNode *node = new (C) jmpCon_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndNode::short_branch_version(Compile* C) {
  jmpLoopEnd_shortNode *node = new (C) jmpLoopEnd_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndUNode::short_branch_version(Compile* C) {
  jmpLoopEndU_shortNode *node = new (C) jmpLoopEndU_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndUCFNode::short_branch_version(Compile* C) {
  jmpLoopEndUCF_shortNode *node = new (C) jmpLoopEndUCF_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUNode::short_branch_version(Compile* C) {
  jmpConU_shortNode *node = new (C) jmpConU_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUCFNode::short_branch_version(Compile* C) {
  jmpConUCF_shortNode *node = new (C) jmpConUCF_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUCF2Node::short_branch_version(Compile* C) {
  jmpConUCF2_shortNode *node = new (C) jmpConUCF2_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}


void cmovLL_reg_LTGENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovLL_reg_LTGENode::cisc_version( int offset, Compile* C ) {
  cmovLL_mem_LTGENode *node = new (C) cmovLL_mem_LTGENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovII_reg_LTGENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovII_reg_LTGENode::cisc_version( int offset, Compile* C ) {
  cmovII_mem_LTGENode *node = new (C) cmovII_mem_LTGENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovLL_reg_EQNENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovLL_reg_EQNENode::cisc_version( int offset, Compile* C ) {
  cmovLL_mem_EQNENode *node = new (C) cmovLL_mem_EQNENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovII_reg_EQNENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovII_reg_EQNENode::cisc_version( int offset, Compile* C ) {
  cmovII_mem_EQNENode *node = new (C) cmovII_mem_EQNENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovLL_reg_LEGTNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovLL_reg_LEGTNode::cisc_version( int offset, Compile* C ) {
  cmovLL_mem_LEGTNode *node = new (C) cmovLL_mem_LEGTNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovII_reg_LEGTNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovII_reg_LEGTNode::cisc_version( int offset, Compile* C ) {
  cmovII_mem_LEGTNode *node = new (C) cmovII_mem_LEGTNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addF_regNode::cisc_version( int offset, Compile* C ) {
  addF_memNode *node = new (C) addF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addF_reg_regNode::cisc_version( int offset, Compile* C ) {
  addF_reg_memNode *node = new (C) addF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *addD_regNode::cisc_version( int offset, Compile* C ) {
  addD_memNode *node = new (C) addD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *addD_reg_regNode::cisc_version( int offset, Compile* C ) {
  addD_reg_memNode *node = new (C) addD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *subF_regNode::cisc_version( int offset, Compile* C ) {
  subF_memNode *node = new (C) subF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *subF_reg_regNode::cisc_version( int offset, Compile* C ) {
  subF_reg_memNode *node = new (C) subF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *subD_regNode::cisc_version( int offset, Compile* C ) {
  subD_memNode *node = new (C) subD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *subD_reg_regNode::cisc_version( int offset, Compile* C ) {
  subD_reg_memNode *node = new (C) subD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulF_regNode::cisc_version( int offset, Compile* C ) {
  mulF_memNode *node = new (C) mulF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulF_reg_regNode::cisc_version( int offset, Compile* C ) {
  mulF_reg_memNode *node = new (C) mulF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulD_regNode::cisc_version( int offset, Compile* C ) {
  mulD_memNode *node = new (C) mulD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulD_reg_regNode::cisc_version( int offset, Compile* C ) {
  mulD_reg_memNode *node = new (C) mulD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *divF_regNode::cisc_version( int offset, Compile* C ) {
  divF_memNode *node = new (C) divF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *divF_reg_regNode::cisc_version( int offset, Compile* C ) {
  divF_reg_memNode *node = new (C) divF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *divD_regNode::cisc_version( int offset, Compile* C ) {
  divD_memNode *node = new (C) divD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *divD_reg_regNode::cisc_version( int offset, Compile* C ) {
  divD_reg_memNode *node = new (C) divD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void sqrtF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *sqrtF_regNode::cisc_version( int offset, Compile* C ) {
  sqrtF_memNode *node = new (C) sqrtF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void sqrtD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *sqrtD_regNode::cisc_version( int offset, Compile* C ) {
  sqrtD_memNode *node = new (C) sqrtD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl2INode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl2INode::cisc_version( int offset, Compile* C ) {
  Repl2I_memNode *node = new (C) Repl2I_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl4INode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl4INode::cisc_version( int offset, Compile* C ) {
  Repl4I_memNode *node = new (C) Repl4I_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl8INode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl8INode::cisc_version( int offset, Compile* C ) {
  Repl8I_memNode *node = new (C) Repl8I_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode( MachNode* node, Compile* C) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone(C);
  }
}

void jmpDirNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpDirNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUCFNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUCFNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCFNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCFNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF2Node::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF2Node::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpDir_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpDir_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpCon_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpCon_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEnd_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEnd_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndU_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndU_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUCF_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUCF_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConU_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConU_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF2_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF2_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_LTGENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_LTGENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_EQNENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_EQNENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_LEGTNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_LEGTNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallStaticJavaHandleNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadUB2L_immI8Node::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2BNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2BNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadUS2L_immI_255Node::reloc() const {
  return 1;
}

int loadUS2L_immI16Node::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2BNode::reloc() const {
  return 1;
}

int loadI2UBNode::reloc() const {
  return 1;
}

int loadI2SNode::reloc() const {
  return 1;
}

int loadI2USNode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadI2L_immI_255Node::reloc() const {
  return 1;
}

int loadI2L_immI_65535Node::reloc() const {
  return 1;
}

int loadI2L_immINode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadL_volatileNode::reloc() const {
  return 1;
}

int loadLX_volatileNode::reloc() const {
  return 1;
}

int loadLX_reg_volatileNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadDPRNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadD_partialNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadFPRNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConFPRNode::reloc() const {
  return 2;
}

int loadConFPR0Node::reloc() const {
  return 2;
}

int loadConFPR1Node::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConF0Node::reloc() const {
  return 2;
}

int loadConDPRNode::reloc() const {
  return 2;
}

int loadConDPR0Node::reloc() const {
  return 2;
}

int loadConDPR1Node::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int loadConD0Node::reloc() const {
  return 2;
}

int prefetchr0Node::reloc() const {
  return 1;
}

int prefetchrNode::reloc() const {
  return 1;
}

int prefetchrNTANode::reloc() const {
  return 1;
}

int prefetchrT0Node::reloc() const {
  return 1;
}

int prefetchrT2Node::reloc() const {
  return 1;
}

int prefetchw0Node::reloc() const {
  return 1;
}

int prefetchwNode::reloc() const {
  return 1;
}

int prefetchwNTANode::reloc() const {
  return 1;
}

int prefetchAlloc0Node::reloc() const {
  return 1;
}

int prefetchAllocNode::reloc() const {
  return 1;
}

int prefetchAllocNTANode::reloc() const {
  return 1;
}

int prefetchAllocT0Node::reloc() const {
  return 1;
}

int prefetchAllocT2Node::reloc() const {
  return 1;
}

int storeBNode::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeL2INode::reloc() const {
  return 2;
}

int storeL_volatileNode::reloc() const {
  return 2;
}

int storeLX_volatileNode::reloc() const {
  return 2;
}

int storeLX_reg_volatileNode::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeImmINode::reloc() const {
  return 2;
}

int storeImmI16Node::reloc() const {
  return 2;
}

int storeImmPNode::reloc() const {
  return 3;
}

int storeImmBNode::reloc() const {
  return 2;
}

int storeImmCMNode::reloc() const {
  return 2;
}

int storeDPRNode::reloc() const {
  return 2;
}

int storeDPR_roundedNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeFPRNode::reloc() const {
  return 2;
}

int storeFPR_roundedNode::reloc() const {
  return 2;
}

int storeFPR_DroundedNode::reloc() const {
  return 2;
}

int storeFPR_immNode::reloc() const {
  return 3;
}

int storeF_immNode::reloc() const {
  return 3;
}

int cmovI_memNode::reloc() const {
  return 1;
}

int cmovI_memUNode::reloc() const {
  return 1;
}

int cmovI_memUCFNode::reloc() const {
  return 1;
}

int addI_eReg_memNode::reloc() const {
  return 1;
}

int addI_eReg_mem_0Node::reloc() const {
  return 1;
}

int addI_mem_eRegNode::reloc() const {
  return 3;
}

int addI_mem_eReg_0Node::reloc() const {
  return 3;
}

int addI_mem_immNode::reloc() const {
  return 3;
}

int incI_memNode::reloc() const {
  return 3;
}

int decI_memNode::reloc() const {
  return 3;
}

int loadPLockedNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int storeIConditionalNode::reloc() const {
  return 1;
}

int storeLConditionalNode::reloc() const {
  return 1;
}

int xaddI_no_resNode::reloc() const {
  return 1;
}

int xaddINode::reloc() const {
  return 1;
}

int xchgINode::reloc() const {
  return 1;
}

int xchgPNode::reloc() const {
  return 1;
}

int subI_eReg_memNode::reloc() const {
  return 1;
}

int subI_mem_eRegNode::reloc() const {
  return 3;
}

int mulI_mem_immNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 1;
}

int mulI_0Node::reloc() const {
  return 1;
}

int sarI_mem_1Node::reloc() const {
  return 3;
}

int sarI_mem_immNode::reloc() const {
  return 3;
}

int andI_eReg_memNode::reloc() const {
  return 1;
}

int andI_eReg_mem_0Node::reloc() const {
  return 1;
}

int andI_mem_eRegNode::reloc() const {
  return 3;
}

int andI_mem_eReg_0Node::reloc() const {
  return 3;
}

int andI_mem_immNode::reloc() const {
  return 3;
}

int orI_eReg_memNode::reloc() const {
  return 1;
}

int orI_eReg_mem_0Node::reloc() const {
  return 1;
}

int orI_mem_eRegNode::reloc() const {
  return 3;
}

int orI_mem_eReg_0Node::reloc() const {
  return 3;
}

int orI_mem_immNode::reloc() const {
  return 3;
}

int xorI_eReg_memNode::reloc() const {
  return 1;
}

int xorI_eReg_mem_0Node::reloc() const {
  return 1;
}

int xorI_mem_eRegNode::reloc() const {
  return 3;
}

int xorI_mem_eReg_0Node::reloc() const {
  return 3;
}

int xorI_mem_immNode::reloc() const {
  return 3;
}

int addL_eReg_memNode::reloc() const {
  return 1;
}

int addL_eReg_mem_0Node::reloc() const {
  return 1;
}

int subL_eReg_memNode::reloc() const {
  return 1;
}

int andL_eReg_memNode::reloc() const {
  return 1;
}

int andL_eReg_mem_0Node::reloc() const {
  return 1;
}

int orl_eReg_memNode::reloc() const {
  return 1;
}

int orl_eReg_mem_0Node::reloc() const {
  return 1;
}

int xorl_eReg_memNode::reloc() const {
  return 1;
}

int xorl_eReg_mem_0Node::reloc() const {
  return 1;
}

int cmpDPR_0Node::reloc() const {
  return 1;
}

int cmpD_ccmemNode::reloc() const {
  return 1;
}

int cmpD_ccmemCFNode::reloc() const {
  return 1;
}

int cmpD_regmemNode::reloc() const {
  return 1;
}

int subDPR_reg_memNode::reloc() const {
  return 1;
}

int addDPR_reg_memNode::reloc() const {
  return 1;
}

int addDPR_reg_mem_0Node::reloc() const {
  return 1;
}

int addDPR_mem_regNode::reloc() const {
  return 3;
}

int addDPR_mem_reg_0Node::reloc() const {
  return 3;
}

int addDPR_reg_imm1Node::reloc() const {
  return 1;
}

int addDPR_reg_immNode::reloc() const {
  return 1;
}

int addDPR_reg_imm_roundNode::reloc() const {
  return 1;
}

int mulDPR_reg_immNode::reloc() const {
  return 1;
}

int mulDPR_reg_memNode::reloc() const {
  return 1;
}

int mulDPR_reg_mem_0Node::reloc() const {
  return 1;
}

int mulDPR_reg_mem_ciscNode::reloc() const {
  return 1;
}

int mulDPR_reg_mem_cisc_0Node::reloc() const {
  return 1;
}

int cmpFPR_0Node::reloc() const {
  return 1;
}

int cmpF_ccmemNode::reloc() const {
  return 1;
}

int cmpF_ccmemCFNode::reloc() const {
  return 1;
}

int cmpF_regmemNode::reloc() const {
  return 1;
}

int addFPR24_reg_memNode::reloc() const {
  return 1;
}

int addFPR24_reg_mem_0Node::reloc() const {
  return 1;
}

int addFPR_reg_memNode::reloc() const {
  return 1;
}

int addFPR_reg_mem_0Node::reloc() const {
  return 1;
}

int addFPR24_mem_regNode::reloc() const {
  return 1;
}

int addFPR24_mem_ciscNode::reloc() const {
  return 2;
}

int addFPR24_mem_cisc_0Node::reloc() const {
  return 2;
}

int addFPR24_mem_memNode::reloc() const {
  return 2;
}

int addFPR24_reg_immNode::reloc() const {
  return 1;
}

int addFPR_reg_immNode::reloc() const {
  return 1;
}

int mulFPR24_reg_memNode::reloc() const {
  return 1;
}

int mulFPR24_reg_mem_0Node::reloc() const {
  return 1;
}

int mulFPR_reg_memNode::reloc() const {
  return 1;
}

int mulFPR_reg_mem_0Node::reloc() const {
  return 1;
}

int mulFPR24_mem_memNode::reloc() const {
  return 2;
}

int mulFPR24_reg_immNode::reloc() const {
  return 1;
}

int mulFPR_reg_immNode::reloc() const {
  return 1;
}

int mulFPR_reg_load1Node::reloc() const {
  return 1;
}

int mulFPR_reg_load1_0Node::reloc() const {
  return 1;
}

int addFPR_mulFPR_reg_load1Node::reloc() const {
  return 1;
}

int addFPR_mulFPR_reg_load1_1Node::reloc() const {
  return 1;
}

int addFPR_mulFPR_reg_load1_0Node::reloc() const {
  return 1;
}

int addFPR_mulFPR_reg_load1_2Node::reloc() const {
  return 1;
}

int convI2D_memNode::reloc() const {
  return 1;
}

int convI2DPR_memNode::reloc() const {
  return 1;
}

int convI2FPR_SSF_memNode::reloc() const {
  return 1;
}

int convI2FPR_memNode::reloc() const {
  return 1;
}

int compI_eReg_memNode::reloc() const {
  return 1;
}

int testI_reg_memNode::reloc() const {
  return 1;
}

int compU_eReg_memNode::reloc() const {
  return 1;
}

int compP_eReg_immNode::reloc() const {
  return 1;
}

int compP_eReg_memNode::reloc() const {
  return 1;
}

int compP_mem_eRegNode::reloc() const {
  return 1;
}

int testP_regNode::reloc() const {
  return 1;
}

int testP_Reg_memNode::reloc() const {
  return 1;
}

int partialSubtypeCheck_vs_ZeroNode::reloc() const {
  return 1;
}

int cmovLL_mem_LTGENode::reloc() const {
  return 1;
}

int cmovII_mem_LTGENode::reloc() const {
  return 1;
}

int cmovLL_mem_EQNENode::reloc() const {
  return 1;
}

int cmovII_mem_EQNENode::reloc() const {
  return 1;
}

int cmovLL_mem_LEGTNode::reloc() const {
  return 1;
}

int cmovII_mem_LEGTNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallStaticJavaHandleNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int tailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int safePoint_pollNode::reloc() const {
  return 1;
}

int addF_memNode::reloc() const {
  return 1;
}

int addF_mem_0Node::reloc() const {
  return 1;
}

int addF_immNode::reloc() const {
  return 1;
}

int addF_reg_memNode::reloc() const {
  return 1;
}

int addF_reg_mem_0Node::reloc() const {
  return 1;
}

int addF_reg_immNode::reloc() const {
  return 1;
}

int addD_memNode::reloc() const {
  return 1;
}

int addD_mem_0Node::reloc() const {
  return 1;
}

int addD_immNode::reloc() const {
  return 1;
}

int addD_reg_memNode::reloc() const {
  return 1;
}

int addD_reg_mem_0Node::reloc() const {
  return 1;
}

int addD_reg_immNode::reloc() const {
  return 1;
}

int subF_memNode::reloc() const {
  return 1;
}

int subF_immNode::reloc() const {
  return 1;
}

int subF_reg_memNode::reloc() const {
  return 1;
}

int subF_reg_immNode::reloc() const {
  return 1;
}

int subD_memNode::reloc() const {
  return 1;
}

int subD_immNode::reloc() const {
  return 1;
}

int subD_reg_memNode::reloc() const {
  return 1;
}

int subD_reg_immNode::reloc() const {
  return 1;
}

int mulF_memNode::reloc() const {
  return 1;
}

int mulF_mem_0Node::reloc() const {
  return 1;
}

int mulF_immNode::reloc() const {
  return 1;
}

int mulF_reg_memNode::reloc() const {
  return 1;
}

int mulF_reg_mem_0Node::reloc() const {
  return 1;
}

int mulF_reg_immNode::reloc() const {
  return 1;
}

int mulD_memNode::reloc() const {
  return 1;
}

int mulD_mem_0Node::reloc() const {
  return 1;
}

int mulD_immNode::reloc() const {
  return 1;
}

int mulD_reg_memNode::reloc() const {
  return 1;
}

int mulD_reg_mem_0Node::reloc() const {
  return 1;
}

int mulD_reg_immNode::reloc() const {
  return 1;
}

int divF_memNode::reloc() const {
  return 1;
}

int divF_immNode::reloc() const {
  return 1;
}

int divF_reg_memNode::reloc() const {
  return 1;
}

int divF_reg_immNode::reloc() const {
  return 1;
}

int divD_memNode::reloc() const {
  return 1;
}

int divD_immNode::reloc() const {
  return 1;
}

int divD_reg_memNode::reloc() const {
  return 1;
}

int divD_reg_immNode::reloc() const {
  return 1;
}

int sqrtF_memNode::reloc() const {
  return 1;
}

int sqrtF_immNode::reloc() const {
  return 1;
}

int sqrtD_memNode::reloc() const {
  return 1;
}

int sqrtD_immNode::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int loadV32Node::reloc() const {
  return 1;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int storeV32Node::reloc() const {
  return 2;
}

int Repl2I_memNode::reloc() const {
  return 1;
}

int Repl4I_memNode::reloc() const {
  return 1;
}

int Repl8I_memNode::reloc() const {
  return 1;
}

int Repl2L_memNode::reloc() const {
  return 1;
}

int Repl4L_memNode::reloc() const {
  return 1;
}

int Repl2F_zeroNode::reloc() const {
  return 1;
}

int Repl4F_zeroNode::reloc() const {
  return 1;
}

int Repl8F_zeroNode::reloc() const {
  return 1;
}

int Repl2D_zeroNode::reloc() const {
  return 1;
}

int Repl4D_zeroNode::reloc() const {
  return 1;
}

int vadd16B_memNode::reloc() const {
  return 1;
}

int vadd32B_memNode::reloc() const {
  return 1;
}

int vadd8S_memNode::reloc() const {
  return 1;
}

int vadd16S_memNode::reloc() const {
  return 1;
}

int vadd4I_memNode::reloc() const {
  return 1;
}

int vadd8I_memNode::reloc() const {
  return 1;
}

int vadd2L_memNode::reloc() const {
  return 1;
}

int vadd4L_memNode::reloc() const {
  return 1;
}

int vadd4F_memNode::reloc() const {
  return 1;
}

int vadd8F_memNode::reloc() const {
  return 1;
}

int vadd2D_memNode::reloc() const {
  return 1;
}

int vadd4D_memNode::reloc() const {
  return 1;
}

int vsub16B_memNode::reloc() const {
  return 1;
}

int vsub32B_memNode::reloc() const {
  return 1;
}

int vsub8S_memNode::reloc() const {
  return 1;
}

int vsub16S_memNode::reloc() const {
  return 1;
}

int vsub4I_memNode::reloc() const {
  return 1;
}

int vsub8I_memNode::reloc() const {
  return 1;
}

int vsub2L_memNode::reloc() const {
  return 1;
}

int vsub4L_memNode::reloc() const {
  return 1;
}

int vsub4F_memNode::reloc() const {
  return 1;
}

int vsub8F_memNode::reloc() const {
  return 1;
}

int vsub2D_memNode::reloc() const {
  return 1;
}

int vsub4D_memNode::reloc() const {
  return 1;
}

int vmul8S_memNode::reloc() const {
  return 1;
}

int vmul16S_memNode::reloc() const {
  return 1;
}

int vmul4I_memNode::reloc() const {
  return 1;
}

int vmul8I_memNode::reloc() const {
  return 1;
}

int vmul4F_memNode::reloc() const {
  return 1;
}

int vmul8F_memNode::reloc() const {
  return 1;
}

int vmul2D_memNode::reloc() const {
  return 1;
}

int vmul4D_memNode::reloc() const {
  return 1;
}

int vdiv4F_memNode::reloc() const {
  return 1;
}

int vdiv8F_memNode::reloc() const {
  return 1;
}

int vdiv2D_memNode::reloc() const {
  return 1;
}

int vdiv4D_memNode::reloc() const {
  return 1;
}

int vand16B_memNode::reloc() const {
  return 1;
}

int vand32B_memNode::reloc() const {
  return 1;
}

int vor16B_memNode::reloc() const {
  return 1;
}

int vor32B_memNode::reloc() const {
  return 1;
}

int vxor16B_memNode::reloc() const {
  return 1;
}

int vxor32B_memNode::reloc() const {
  return 1;
}


void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 11870 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1751 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_cc(cbuf, (0xC8 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 11878 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 1755 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int destlo = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int desthi = HIGH_FROM_LOW(destlo);
    // bswap lo
    emit_opcode(cbuf, 0x0F);
    emit_cc(cbuf, 0xC8, destlo);
    // bswap hi
    emit_opcode(cbuf, 0x0F);
    emit_cc(cbuf, 0xC8, desthi);
    // xchg lo and hi
    emit_opcode(cbuf, 0x87);
    emit_rm(cbuf, 0x3, destlo, desthi);
  
#line 11903 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 5592 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ bswapl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ shrl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 16); 
  
#line 11920 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 5605 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ bswapl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ sarl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 16); 
  
#line 11937 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ lzcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 11953 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void countLeadingZerosI_bsrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5638 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Label skip;
    __ bsrl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, skip);
    __ movl(Rdst, -1);
    __ bind(skip);
    __ negl(Rdst);
    __ addl(Rdst, BitsPerInt - 1);
  
#line 11977 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 5662 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(2)->as_Register(ra_,this,idx2)/* dst */;
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Label done;
    __ lzcntl(Rdst, HIGH_FROM_LOW(Rsrc));
    __ jccb(Assembler::carryClear, done);
    __ lzcntl(Rdst, Rsrc);
    __ addl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 12001 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void countLeadingZerosL_bsrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 5691 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(2)->as_Register(ra_,this,idx2)/* dst */;
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Label msw_is_zero;
    Label not_zero;
    __ bsrl(Rdst, HIGH_FROM_LOW(Rsrc));
    __ jccb(Assembler::zero, msw_is_zero);
    __ addl(Rdst, BitsPerInt);
    __ jmpb(not_zero);
    __ bind(msw_is_zero);
    __ bsrl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, not_zero);
    __ movl(Rdst, -1);
    __ bind(not_zero);
    __ negl(Rdst);
    __ addl(Rdst, BitsPerLong - 1);
  
#line 12032 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5719 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Label done;
    __ bsfl(Rdst, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ jccb(Assembler::notZero, done);
    __ movl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 12053 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 5742 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(2)->as_Register(ra_,this,idx2)/* dst */;
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Label msw_not_zero;
    Label done;
    __ bsfl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, done);
    __ bsfl(Rdst, HIGH_FROM_LOW(Rsrc));
    __ jccb(Assembler::notZero, msw_not_zero);
    __ movl(Rdst, BitsPerInt);
    __ bind(msw_not_zero);
    __ addl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 12081 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5768 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ popcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 12097 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5780 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ popcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12113 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 5795 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ popcntl(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ popcntl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* src */));
    __ addl(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
  
#line 12133 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 5812 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    //__ popcntl($dst$$Register, $mem$$Address$$first);
    //__ popcntl($tmp$$Register, $mem$$Address$$second);
    __ popcntl(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), false));
    __ popcntl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, false));
    __ addl(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
  
#line 12155 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5832 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12171 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5849 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), opnd_array(0)->as_Register(ra_,this)/* dst */); // This is always a different register.
    __ sarl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), 7); // 24+1 MSB are already signed extended.
  
#line 12189 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5865 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12205 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5881 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 12223 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUB2L_immI8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 5898 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 12243 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5914 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12259 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 5927 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12276 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5943 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), opnd_array(0)->as_Register(ra_,this)/* dst */); // This is always a different register.
    __ sarl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), 15); // 16+1 MSB are already signed extended.
  
#line 12294 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5959 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12310 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 5972 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12327 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5987 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */));
  
#line 12344 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUS2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6002 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 12363 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUS2L_immI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzwl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 12383 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6034 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12399 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 6047 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12416 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2UBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12433 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// sixteen
  {
    MacroAssembler _masm(&cbuf);

#line 6071 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12450 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2USNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6083 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12467 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6099 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), opnd_array(0)->as_Register(ra_,this)/* dst */); // This is always a different register.
    __ sarl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), 31);
  
#line 12485 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6115 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 12504 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2L_immI_65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6130 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzwl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 12523 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadI2L_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6146 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 12543 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 6164 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */));
  
#line 12561 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6182 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Address Amemlo = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), false);
    Address Amemhi = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, false);
    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Amemlo);
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), Amemhi);
  
#line 12580 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3636 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xDF);
    int rm_byte_opcode = 0x05;
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
    store_to_stackslot( cbuf, 0x0DF, 0x07, opnd_array(0)->disp(ra_,this,0) );
  
#line 12603 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadLX_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 6213 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */);
  
#line 12621 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadLX_reg_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 6229 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */);
    __ psrlq(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */, 32);
    __ movdl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */);
  
#line 12641 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 12656 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12670 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 12685 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12699 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 12714 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12728 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadDPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*primary()*/));
  
#line 12743 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 12757 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 12766 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6292 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12782 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6303 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12798 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6316 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 12814 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadFPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 12829 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 12843 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 12852 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void leaP8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 12867 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12881 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void leaP32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 12896 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12910 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void leaPIdxOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 12925 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12939 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void leaPIdxScaleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 12954 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12968 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void leaPIdxScaleOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 12983 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12997 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1972 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    emit_opcode(cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32(cbuf, opnd_array(1)->constant());
  
#line 13015 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 13030 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13038 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1979 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    emit_opcode(cbuf, (0xB8 /*primary()*/) + opnd_array(0)->reg(ra_,this)/* dst */);
    
if ( opnd_array(1)->constant_is_oop() ) {
  emit_d32_reloc(cbuf, opnd_array(1)->constant(), relocInfo::oop_type, 0);
} else {
  emit_d32(cbuf, opnd_array(1)->constant());
};
  
#line 13061 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1986 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    int dst_enc = opnd_array(0)->reg(ra_,this)/* dst */;
    int src_con = opnd_array(1)->constantL() & 0x0FFFFFFFFL;
    if (src_con == 0) {
      // xor dst, dst
      emit_opcode(cbuf, 0x33);
      emit_rm(cbuf, 0x3, dst_enc, dst_enc);
    } else {
      emit_opcode(cbuf, (0xB8 /*primary()*/) + dst_enc);
      emit_d32(cbuf, src_con);
    }
  
#line 13087 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2001 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    int dst_enc = opnd_array(0)->reg(ra_,this)/* dst */ + 2;
    int src_con = ((julong)(opnd_array(1)->constantL())) >> 32;
    if (src_con == 0) {
      // xor dst, dst
      emit_opcode(cbuf, 0x33);
      emit_rm(cbuf, 0x3, dst_enc, dst_enc);
    } else {
      emit_opcode(cbuf, (0xB8 /*primary()*/) + dst_enc);
      emit_d32(cbuf, src_con);
    }
  
#line 13106 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2030 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13122 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2035 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */), HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 13131 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConFPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6445 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13148 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConFPRNode::eval_constant(Compile* C) {
  {

#line 6446 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 13157 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFPR0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fldz();
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13173 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConFPR1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6471 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld1();
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13190 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6483 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 13206 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 6484 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 13215 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 13230 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConDPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6507 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13247 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConDPRNode::eval_constant(Compile* C) {
  {

#line 6508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 13256 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDPR0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6521 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fldz();
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13272 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConDPR1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6535 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld1();
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 13289 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 13305 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 6548 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 13314 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6558 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ xorpd (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 13329 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadSSINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 13344 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13358 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadSSLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 13373 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13387 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*secondary()*/));
  
#line 13395 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 13409 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadSSPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 13424 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13438 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadSSFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 13453 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2223 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 13467 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 13476 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadSSDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*primary()*/));
  
#line 13491 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2223 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 13505 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 13514 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchr0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  // User did not define which encode class to use.
}

uint prefetchr0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void prefetchrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6642 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchr(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13542 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchrNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6654 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13558 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchrT0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6666 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht0(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13574 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchrT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6678 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht2(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13590 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchw0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  // User did not define which encode class to use.
}

uint prefetchw0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void prefetchwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6700 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13618 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchwNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6712 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13634 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchAlloc0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  // User did not define which encode class to use.
}

uint prefetchAlloc0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void prefetchAllocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6736 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13662 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchAllocNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6748 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13678 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchAllocT0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht0(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13694 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void prefetchAllocT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6772 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht2(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 13710 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x88 /*primary()*/));
  
#line 13726 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13740 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x66 /*secondary()*/));
  
#line 13756 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 13764 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13778 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 13794 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13808 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 13824 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13838 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*secondary()*/));
  
#line 13846 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 13860 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6831 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 13877 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 13893 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = (EAX_enc);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13907 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3652 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0x0DF, 0x05, opnd_array(2)->disp(ra_,this,idx2) );
    cbuf.set_insts_mark();            // Mark start of FIST in case $mem has an oop
    emit_opcode(cbuf,0xDF);
    int rm_byte_opcode = 0x07;
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 13924 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeLX_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 6862 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cmpl(rax, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */, Address(rsp, opnd_array(2)->disp(ra_,this,idx2)));
    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */);
  
#line 13944 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeLX_reg_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 6880 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cmpl(rax, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdl(opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
    __ movdl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp2 */, HIGH_FROM_LOW(opnd_array(2)->as_Register(ra_,this,idx2)/* src */));
    __ punpckldq(opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp */, opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp2 */);
    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp */);
  
#line 13967 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 13983 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13997 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 14013 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14027 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2052 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constant());
  
#line 14036 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeImmI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1630 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0x66);
  
#line 14052 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 14060 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14074 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2071 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    emit_d16(cbuf, opnd_array(2)->constant());
  
#line 14083 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeImmPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 14099 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14113 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2052 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    
if ( opnd_array(2)->constant_is_oop() ) {
  emit_d32_reloc(cbuf, opnd_array(2)->constant(), relocInfo::oop_type, 0);
} else {
  emit_d32(cbuf, opnd_array(2)->constant());
};
  
#line 14127 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC6 /*primary()*/));
  
#line 14143 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14157 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 14172 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeImmCMNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC6 /*primary()*/));
  
#line 14188 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14202 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 14217 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeDPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2277 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xDD /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14248 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeDPR_roundedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2277 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xDD /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14279 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6989 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 14296 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7002 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 14313 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeFPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2277 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xD9 /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14344 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeFPR_roundedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2277 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xD9 /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14375 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeFPR_DroundedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2277 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xD9 /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14406 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeFPR_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 14422 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14436 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2057 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output Float immediate bits
    jfloat jf = opnd_array(2)->constantF();
    int    jf_as_bits = jint_cast( jf );
    emit_d32(cbuf, jf_as_bits);
  
#line 14447 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 14463 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14477 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2064 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output Float immediate bits
    jfloat jf = opnd_array(2)->constantF();
    int    jf_as_bits = jint_cast( jf );
    emit_d32(cbuf, jf_as_bits);
  
#line 14488 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeSSINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2441 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0x89 /*primary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */, opnd_array(0)->disp(ra_,this,0) );
  
#line 14503 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeSSPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2441 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0x89 /*primary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */, opnd_array(0)->disp(ra_,this,0) );
  
#line 14518 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeSSLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 14533 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0);
    bool disp_is_oop = opnd_array(0)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14547 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*secondary()*/));
  
#line 14555 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */);  // Hi register of pair, computed from lo
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(0)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 14569 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquireNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquire_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_releaseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_release_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7158 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ membar(Assembler::StoreLoad);
  
#line 14633 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint unnecessary_membar_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_storestoreNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // User did not define which encode class to use.
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 14680 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void jmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7211 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movl(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
    __ bind(Lskip);
  
#line 14703 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void jmovI_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7228 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movl(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
    __ bind(Lskip);
  
#line 14726 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 14745 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 14753 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovI_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 14772 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 14780 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 14799 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14813 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovI_memUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 14832 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14846 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 14865 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 14873 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovP_reg_nonP6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1785 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Invert sense of branch from sense of CMOV
    emit_cc( cbuf, 0x70, (opnd_array(1)->ccode()^1) );
    emit_d8( cbuf, (0x2) );
  
#line 14893 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8b /*primary()*/));
  
#line 14901 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 14909 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovP_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 14928 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 14936 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovDPR_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1778 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int op = 0xDA00 + opnd_array(1)->ccode() + (opnd_array(4)->reg(ra_,this,idx4)/* src */-1);
    emit_d8(cbuf, op >> 8 );
    emit_d8(cbuf, op & 255);
  
#line 14956 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovFPR_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1778 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int op = 0xDA00 + opnd_array(1)->ccode() + (opnd_array(4)->reg(ra_,this,idx4)/* src */-1);
    emit_d8(cbuf, op >> 8 );
    emit_d8(cbuf, op & 255);
  
#line 14976 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovDPR_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1785 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Invert sense of branch from sense of CMOV
    emit_cc( cbuf, 0x70, (opnd_array(1)->ccode()^1) );
    emit_d8( cbuf, (0x4) );
  
#line 14996 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(4)->reg(ra_,this,idx4)/* src */ );   // FLD ST(i-1)
  
#line 15005 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xdd /*primary()*/));
  
#line 15013 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(3)->reg(ra_,this,idx3)/* dst */ );
  
#line 15021 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovFPR_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1785 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Invert sense of branch from sense of CMOV
    emit_cc( cbuf, 0x70, (opnd_array(1)->ccode()^1) );
    emit_d8( cbuf, (0x4) );
  
#line 15041 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(4)->reg(ra_,this,idx4)/* src */ );
  
#line 15050 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xdd /*primary()*/));
  
#line 15058 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(3)->reg(ra_,this,idx3)/* dst */ );
  
#line 15066 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovF_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7427 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movflt(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(skip);
  
#line 15089 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovD_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7445 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(skip);
  
#line 15112 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovF_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7463 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movflt(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(skip);
  
#line 15135 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void fcmovD_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7490 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(skip);
  
#line 15158 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 15177 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2040 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 15185 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 15194 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)/* src */));
  
#line 15202 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovL_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 15221 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2040 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 15229 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 15238 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)/* src */));
  
#line 15246 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 15262 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 15270 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint addI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void addI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 15298 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15313 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void incI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1690 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x40 /*primary()*/) + opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 15329 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint incI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 1);
}
void leaI_eReg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 15349 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2243 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base         = opnd_array(1)->reg(ra_,this,idx1)/* src0 */;      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constant(); // 0x00 indicates no displacement
    bool disp_is_oop = false;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15363 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void leaP_eReg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 15379 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2243 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base         = opnd_array(1)->reg(ra_,this,idx1)/* src0 */;      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constant(); // 0x00 indicates no displacement
    bool disp_is_oop = false;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15393 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void decI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1690 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x48 /*primary()*/) + opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 15409 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint decI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 1);
}
void addP_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 15429 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 15437 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint addP_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void addP_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 15465 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15480 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 15496 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15510 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 15526 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15540 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 15556 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15570 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 15586 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15600 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1696 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 15622 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 15636 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15651 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void incI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 15667 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 15681 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void decI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 15697 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x01);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 15711 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 15754 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15768 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2086 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);         // [Lock]
  
#line 15786 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 15794 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xB1));
  
#line 15802 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15816 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2086 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);         // [Lock]
  
#line 15834 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 15842 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xB1));
  
#line 15850 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15864 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7754 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Note: we need to swap rbx, and rcx before and after the
    //       cmpxchg8 instruction because the instruction uses
    //       rcx as the high order word of the new value to store but
    //       our register encoding uses rbx.
    __ xchgl(as_Register(EBX_enc), as_Register(ECX_enc));
    if( os::is_MP() )
      __ lock();
    __ cmpxchg8(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xchgl(as_Register(EBX_enc), as_Register(ECX_enc));
  
#line 15890 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2096 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"


    // XCHG  rbx,ecx
    emit_opcode(cbuf,0x87);
    emit_opcode(cbuf,0xD9);
    // [Lock]
    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);
    // CMPXCHG8 [Eptr]
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xC7);
    emit_rm( cbuf, 0x0, 1, opnd_array(1)->reg(ra_,this,idx1)/* mem_ptr */ );
    // XCHG  rbx,ecx
    emit_opcode(cbuf,0x87);
    emit_opcode(cbuf,0xD9);
  
#line 15920 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2124 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int res_encoding = opnd_array(0)->reg(ra_,this)/* res */;

    // MOV  res,0
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 0 );
    // JNE,s  fail
    emit_opcode(cbuf,0x75);
    emit_d8(cbuf, 5 );
    // MOV  res,1
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 1 );
    // fail:
  
#line 15939 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2113 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // [Lock]
    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);

    // CMPXCHG [Eptr]
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xB1);
    emit_rm( cbuf, 0x0, 1, opnd_array(1)->reg(ra_,this,idx1)/* mem_ptr */ );
  
#line 15963 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2124 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int res_encoding = opnd_array(0)->reg(ra_,this)/* res */;

    // MOV  res,0
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 0 );
    // JNE,s  fail
    emit_opcode(cbuf,0x75);
    emit_d8(cbuf, 5 );
    // MOV  res,1
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 1 );
    // fail:
  
#line 15982 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xaddI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  {
    MacroAssembler _masm(&cbuf);

#line 7801 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (os::is_MP()) { __ lock(); }
    __ addl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->constant());
  
#line 16000 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7812 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (os::is_MP()) { __ lock(); }
    __ xaddl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_Register(ra_,this,idx2)/* newval */);
  
#line 16018 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xchgINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7822 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ xchgl(opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 16035 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xchgPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7831 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ xchgl(opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 16052 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2113 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // [Lock]
    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);

    // CMPXCHG [Eptr]
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xB1);
    emit_rm( cbuf, 0x0, 1, opnd_array(1)->reg(ra_,this,idx1)/* mem_ptr */ );
  
#line 16076 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2124 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int res_encoding = opnd_array(0)->reg(ra_,this)/* res */;

    // MOV  res,0
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 0 );
    // JNE,s  fail
    emit_opcode(cbuf,0x75);
    emit_d8(cbuf, 5 );
    // MOV  res,1
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 1 );
    // fail:
  
#line 16095 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 16111 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 16119 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint subI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void subI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 16147 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 16162 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 16178 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16192 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x29 /*primary()*/));
  
#line 16208 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16222 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subP_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 16239 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(3)->reg(ra_,this,idx3)/* src */);
  
#line 16247 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint subP_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void negI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 16267 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x03 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* dst */ );
  
#line 16275 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint negI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void mulI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*secondary()*/));
  
#line 16295 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAF /*primary()*/));
  
#line 16303 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 16311 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint mulI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3);
}
void mulI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {

#line 1696 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 16337 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */);
  
#line 16345 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 16360 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadConL_low_onlyNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1986 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    int dst_enc = opnd_array(0)->reg(ra_,this)/* dst */;
    int src_con = opnd_array(1)->constantL() & 0x0FFFFFFFFL;
    if (src_con == 0) {
      // xor dst, dst
      emit_opcode(cbuf, 0x33);
      emit_rm(cbuf, 0x3, dst_enc, dst_enc);
    } else {
      emit_opcode(cbuf, (0xB8 /*primary()*/) + dst_enc);
      emit_d32(cbuf, src_con);
    }
  
#line 16386 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI_imm_highNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {

#line 2765 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this)/* dst */ );
      emit_d8(cbuf, shift_count);
    }
  
#line 16412 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI_imm_high_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {

#line 2765 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(2)->reg(ra_,this,idx2)/* src1 */ );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this)/* dst */ );
      emit_d8(cbuf, shift_count);
    }
  
#line 16438 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI_imm_RShift_highNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {

#line 2765 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this)/* dst */ );
      emit_d8(cbuf, shift_count);
    }
  
#line 16464 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI_imm_RShift_high_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {

#line 2765 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(2)->reg(ra_,this,idx2)/* src1 */ );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this)/* dst */ );
      emit_d8(cbuf, shift_count);
    }
  
#line 16490 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {

#line 1696 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 16512 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16526 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 16541 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*secondary()*/));
  
#line 16557 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAF /*primary()*/));
  
#line 16565 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16579 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*secondary()*/));
  
#line 16595 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAF /*primary()*/));
  
#line 16603 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16617 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 2791 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: long = (long)int * (long)int
    // IMUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(2)->reg(ra_,this,idx2)/* src1 */);
  
#line 16636 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulI2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2791 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: long = (long)int * (long)int
    // IMUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
  
#line 16655 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulIS_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {

#line 2798 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic Idea:  long = (int & 0xffffffffL) * (int & 0xffffffffL)
    // MUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, opnd_array(3)->reg(ra_,this,idx3)/* src1 */);
  
#line 16675 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulIS_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  {

#line 2798 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic Idea:  long = (int & 0xffffffffL) * (int & 0xffffffffL)
    // MUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
  
#line 16695 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 2805 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: lo(result) = lo(x_lo * y_lo)
    //             hi(result) = hi(x_lo * y_lo) + lo(x_hi * y_lo) + lo(x_lo * y_hi)
    // MOV    $tmp,$src.lo
    encode_Copy( cbuf, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    // IMUL   $tmp,EDX
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0xAF );
    emit_rm( cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
    // MOV    EDX,$src.hi
    encode_Copy( cbuf, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */) );
    // IMUL   EDX,EAX
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0xAF );
    emit_rm( cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
    // ADD    $tmp,EDX
    emit_opcode( cbuf, 0x03 );
    emit_rm( cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
    // MUL   EDX:EAX,$src.lo
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, opnd_array(2)->reg(ra_,this,idx2)/* src */ );
    // ADD    EDX,ESI
    emit_opcode( cbuf, 0x03 );
    emit_rm( cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), opnd_array(3)->reg(ra_,this,idx3)/* tmp */ );
  
#line 16734 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulL_eReg_lhi0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8069 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(2)->as_Register(ra_,this,idx2)/* src */));
    __ imull(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, rax);
    __ mull(opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
    __ addl(rdx, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
  
#line 16755 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulL_eReg_rhi0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8090 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
    __ imull(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, rdx);
    __ mull(opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
    __ addl(rdx, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
  
#line 16776 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulL_eReg_hi0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8108 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ mull(opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 16793 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulL_eReg_conNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 2831 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: lo(result) = lo(src * y_lo)
    //             hi(result) = hi(src * y_lo) + lo(src * y_hi)
    // IMUL   $tmp,EDX,$src
    emit_opcode( cbuf, 0x6B );
    emit_rm( cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
    emit_d8( cbuf, (int)opnd_array(2)->constantL() );
    // MOV    EDX,$src
    emit_opcode(cbuf, 0xB8 + EDX_enc);
    emit_d32( cbuf, (int)opnd_array(2)->constantL() );
    // MUL   EDX:EAX,EDX
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, EDX_enc );
    // ADD    EDX,ESI
    emit_opcode( cbuf, 0x03 );
    emit_rm( cbuf, 0x3, EDX_enc, opnd_array(3)->reg(ra_,this,idx3)/* tmp */ );
  
#line 16824 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint mulL_eReg_conNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}
void divI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// rax
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div
  {

#line 1648 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax,: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax,: quotient  (= rax, idiv reg)       min_int
    //         rdx: remainder (= rax, irem reg)       0
    //
    //  Code sequnce:
    //
    //  81 F8 00 00 00 80    cmp         rax,80000000h
    //  0F 85 0B 00 00 00    jne         normal_case
    //  33 D2                xor         rdx,edx
    //  83 F9 FF             cmp         rcx,0FFh
    //  0F 84 03 00 00 00    je          done
    //                  normal_case:
    //  99                   cdq
    //  F7 F9                idiv        rax,ecx
    //                  done:
    //
    emit_opcode(cbuf,0x81); emit_d8(cbuf,0xF8);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x80);                     // cmp rax,80000000h
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x85);
    emit_opcode(cbuf,0x0B); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // jne normal_case
    emit_opcode(cbuf,0x33); emit_d8(cbuf,0xD2);                     // xor rdx,edx
    emit_opcode(cbuf,0x83); emit_d8(cbuf,0xF9); emit_d8(cbuf,0xFF); // cmp rcx,0FFh
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x84);
    emit_opcode(cbuf,0x03); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // je done
    // normal_case:
    emit_opcode(cbuf,0x99);                                         // cdq
    // idiv (note: must be emitted by the user of this rule)
    // normal:
  
#line 16881 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 16889 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ );
  
#line 16897 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint divI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 26, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 26);
}
void divL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2849 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // PUSH src1.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(1)->reg(ra_,this,idx1)/* src1 */) );
    // PUSH src1.lo
    emit_opcode(cbuf,               0x50+opnd_array(1)->reg(ra_,this,idx1)/* src1 */  );
    // PUSH src2.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(2)->reg(ra_,this,idx2)/* src2 */) );
    // PUSH src2.lo
    emit_opcode(cbuf,               0x50+opnd_array(2)->reg(ra_,this,idx2)/* src2 */  );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (CAST_FROM_FN_PTR(address, SharedRuntime::ldiv) - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Restore stack
    emit_opcode(cbuf, 0x83); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 4*4);
  
#line 16932 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divModI_eReg_divmodNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// div
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rdx
  {

#line 1648 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax,: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax,: quotient  (= rax, idiv reg)       min_int
    //         rdx: remainder (= rax, irem reg)       0
    //
    //  Code sequnce:
    //
    //  81 F8 00 00 00 80    cmp         rax,80000000h
    //  0F 85 0B 00 00 00    jne         normal_case
    //  33 D2                xor         rdx,edx
    //  83 F9 FF             cmp         rcx,0FFh
    //  0F 84 03 00 00 00    je          done
    //                  normal_case:
    //  99                   cdq
    //  F7 F9                idiv        rax,ecx
    //                  done:
    //
    emit_opcode(cbuf,0x81); emit_d8(cbuf,0xF8);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x80);                     // cmp rax,80000000h
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x85);
    emit_opcode(cbuf,0x0B); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // jne normal_case
    emit_opcode(cbuf,0x33); emit_d8(cbuf,0xD2);                     // xor rdx,edx
    emit_opcode(cbuf,0x83); emit_d8(cbuf,0xF9); emit_d8(cbuf,0xFF); // cmp rcx,0FFh
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x84);
    emit_opcode(cbuf,0x03); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // je done
    // normal_case:
    emit_opcode(cbuf,0x99);                                         // cdq
    // idiv (note: must be emitted by the user of this rule)
    // normal:
  
#line 16985 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 16993 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ );
  
#line 17001 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint divModI_eReg_divmodNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 26, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 26);
}
void modI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// rax
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div
  {

#line 1648 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax,: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax,: quotient  (= rax, idiv reg)       min_int
    //         rdx: remainder (= rax, irem reg)       0
    //
    //  Code sequnce:
    //
    //  81 F8 00 00 00 80    cmp         rax,80000000h
    //  0F 85 0B 00 00 00    jne         normal_case
    //  33 D2                xor         rdx,edx
    //  83 F9 FF             cmp         rcx,0FFh
    //  0F 84 03 00 00 00    je          done
    //                  normal_case:
    //  99                   cdq
    //  F7 F9                idiv        rax,ecx
    //                  done:
    //
    emit_opcode(cbuf,0x81); emit_d8(cbuf,0xF8);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x80);                     // cmp rax,80000000h
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x85);
    emit_opcode(cbuf,0x0B); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // jne normal_case
    emit_opcode(cbuf,0x33); emit_d8(cbuf,0xD2);                     // xor rdx,edx
    emit_opcode(cbuf,0x83); emit_d8(cbuf,0xF9); emit_d8(cbuf,0xFF); // cmp rcx,0FFh
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x84);
    emit_opcode(cbuf,0x03); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // je done
    // normal_case:
    emit_opcode(cbuf,0x99);                                         // cdq
    // idiv (note: must be emitted by the user of this rule)
    // normal:
  
#line 17058 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 17066 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ );
  
#line 17074 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint modI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 26, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 26);
}
void modL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2868 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // PUSH src1.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(1)->reg(ra_,this,idx1)/* src1 */) );
    // PUSH src1.lo
    emit_opcode(cbuf,               0x50+opnd_array(1)->reg(ra_,this,idx1)/* src1 */  );
    // PUSH src2.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(2)->reg(ra_,this,idx2)/* src2 */) );
    // PUSH src2.lo
    emit_opcode(cbuf,               0x50+opnd_array(2)->reg(ra_,this,idx2)/* src2 */  );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (CAST_FROM_FN_PTR(address, SharedRuntime::lrem ) - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Restore stack
    emit_opcode(cbuf, 0x83); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 4*4);
  
#line 17109 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divL_eReg_imm32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 8239 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int con = (int)opnd_array(2)->constantL();
    assert(con != 0 && con != -1 && con != min_jint, "wrong divisor");
    int pcon = (con > 0) ? con : -con;
    Label Lfast, Lpos, Ldone;

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, pcon);
    __ xorl(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */,opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ cmpl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ jccb(Assembler::above, Lfast); // result fits into 32 bit

    __ movl(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */); // save
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ movl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),0); // preserve flags
    __ jccb(Assembler::lessEqual, Lpos); // result is positive

    // Negative dividend.
    // convert value to positive to use unsigned division
    __ lneg(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    __ xchgl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    // revert result back to negative
    __ lneg(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ jmpb(Ldone);

    __ bind(Lpos);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */); // Use unsigned division
    __ xchgl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    // Fallthrow for final divide, tmp2 has 32 bit hi result

    __ bind(Lfast);
    // fast path: src is positive
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */); // Use unsigned division

    __ bind(Ldone);
    __ movl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    if (con < 0) {
      __ lneg(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    }
  
#line 17166 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void modL_eReg_imm32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 8309 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int con = (int)opnd_array(2)->constantL();
    assert(con != 0 && con != -1 && con != min_jint, "wrong divisor");
    int pcon = (con > 0) ? con : -con;
    Label  Lfast, Lpos, Ldone;

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, pcon);
    __ cmpl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ jccb(Assembler::above, Lfast); // src is positive and result fits into 32 bit

    __ movl(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */); // save
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ movl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),0); // preserve flags
    __ jccb(Assembler::lessEqual, Lpos); // result is positive

    // Negative dividend.
    // convert value to positive to use unsigned division
    __ lneg(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    // revert remainder back to negative
    __ negl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ jmpb(Ldone);

    __ bind(Lpos);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);

    __ bind(Lfast);
    // fast path: src is positive
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);

    __ bind(Ldone);
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ sarl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */), 31); // result sign

  
#line 17220 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shlI_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 17236 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 17244 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint shlI_eReg_1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void salI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1966 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 17266 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint salI_eReg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3);
}
void salI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 17286 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 17294 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint salI_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void sarI_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 17314 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 17322 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint sarI_eReg_1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void sarI_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 17342 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 17356 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sarI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1966 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 17374 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint sarI_eReg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3);
}
void sarI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 17394 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 17408 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 17423 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sarI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 17439 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 17447 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint sarI_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void shrI_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 17467 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 17475 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint shrI_eReg_1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void shrI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1966 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 17497 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint shrI_eReg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3);
}
void i2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 8476 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 17518 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint i2bNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3);
}
void i2sNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// sixteen
  {
    MacroAssembler _masm(&cbuf);

#line 8489 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 17539 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint i2sNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3);
}
void shrI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 17559 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 17567 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint shrI_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void andI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 17587 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 17595 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint andI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void andI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 17623 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 17638 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 17654 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17668 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 17684 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17698 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 17714 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17728 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 17744 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17758 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1696 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 17780 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 17794 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 17809 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 17825 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 17833 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint orI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void orI_eReg_castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 17853 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 17861 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint orI_eReg_castP2XNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void orI_eReg_castP2X_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 17881 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */);
  
#line 17889 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint orI_eReg_castP2X_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void orI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 17917 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 17932 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 17948 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17962 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 17978 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17992 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 18008 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18022 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 18038 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18052 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1696 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 18074 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x1 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18088 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 18103 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rolI_eReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 18119 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 18127 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rolI_eReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 1966 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 18145 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rolI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 18161 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 18169 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rorI_eReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 18185 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 18193 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rorI_eReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 1966 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 18211 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rorI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 18227 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 18235 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 18251 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 18259 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint xorI_eRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void xorI_eReg_im1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {
    MacroAssembler _masm(&cbuf);

#line 8799 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

     __ notl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
  
#line 18280 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint xorI_eReg_im1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void xorI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 18308 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 18323 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 18339 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18353 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 18369 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18383 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 18399 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18413 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 18429 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18443 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1696 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 18465 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x6 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18479 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 18494 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void movI_nocopyNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 18509 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void ci2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2296 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // NEG $dst
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0x03, opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 18527 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1638 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x13));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 18536 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint ci2bNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}
void movP_nocopyNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 18555 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cp2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2296 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // NEG $dst
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0x03, opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 18573 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1638 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x13));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 18582 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 8917 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Rd = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Label done;
    __ xorl(Rd, Rd);
    __ cmpl(Rp, Rq);
    __ setb(Assembler::less, Rd);
    __ negl(Rd);
  
#line 18606 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpLTMask0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8937 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

  __ sarl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 31);
  
#line 18623 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cadd_cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 8952 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 18648 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cadd_cmpLTMask_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 8952 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 18673 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cadd_cmpLTMask_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 8952 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(2)->as_Register(ra_,this,idx2)/* p */;
    Register Rq = opnd_array(3)->as_Register(ra_,this,idx3)/* q */;
    Register Ry = opnd_array(1)->as_Register(ra_,this,idx1)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 18698 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cadd_cmpLTMask_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 8952 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 18723 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void and_cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 8977 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ cmpl(Rp, Rq);
    __ jccb(Assembler::less, done);
    __ xorl(Ry, Ry);
    __ bind(done);
  
#line 18748 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void and_cmpLTMask_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 8977 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rp = opnd_array(2)->as_Register(ra_,this,idx2)/* p */;
    Register Rq = opnd_array(3)->as_Register(ra_,this,idx3)/* q */;
    Register Ry = opnd_array(1)->as_Register(ra_,this,idx1)/* y */;
    Label done;
    __ cmpl(Rp, Rq);
    __ jccb(Assembler::less, done);
    __ xorl(Ry, Ry);
    __ bind(done);
  
#line 18773 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2030 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x03 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 18790 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2035 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x13 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 18799 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addL_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 18822 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1740 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x02 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 18837 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addL_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 18853 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18867 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x13 /*secondary()*/));
  
#line 18875 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 18889 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addL_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 18905 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 18919 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x13 /*secondary()*/));
  
#line 18927 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 18941 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2030 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x2B /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 18958 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2035 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x1B /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 18967 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subL_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 18990 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1740 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x03 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19005 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subL_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 19021 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19035 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x1B /*secondary()*/));
  
#line 19043 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19057 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2933 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xF7);    // NEG hi
    emit_rm    (cbuf,0x3, 0x3, HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* dst */));
    emit_opcode(cbuf,0xF7);    // NEG lo
    emit_rm    (cbuf,0x3, 0x3,               opnd_array(2)->reg(ra_,this,idx2)/* dst */ );
    emit_opcode(cbuf,0x83);    // SBB hi,0
    emit_rm    (cbuf,0x3, 0x3, HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* dst */));
    emit_d8    (cbuf,0 );
  
#line 19079 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2030 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x23 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 19096 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2035 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x23 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 19105 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andL_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19128 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1740 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19143 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andL_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 19159 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19173 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*secondary()*/));
  
#line 19181 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19195 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void andL_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 19211 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19225 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*secondary()*/));
  
#line 19233 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19247 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orl_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2030 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0B /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 19264 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2035 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0B /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 19273 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orl_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19296 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1740 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19311 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orl_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 19327 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19341 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*secondary()*/));
  
#line 19349 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19363 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void orl_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 19379 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19393 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*secondary()*/));
  
#line 19401 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19415 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorl_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2030 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 19432 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2035 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 19441 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorl_eReg_im1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {
    MacroAssembler _masm(&cbuf);

#line 9160 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

     __ notl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
     __ notl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
  
#line 19459 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorl_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19482 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1740 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 19497 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorl_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 19513 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19527 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*secondary()*/));
  
#line 19535 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19549 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void xorl_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 19565 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 19579 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*secondary()*/));
  
#line 19587 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 19601 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shlL_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 9198 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */,opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
  
#line 19619 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shlL_eReg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 9215 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */,opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */,opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
  
#line 19639 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shlL_eReg_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 9236 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */,opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */,opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */,opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */));
  
#line 19661 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shlL_eReg_1_31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {

#line 2163 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0xA4 /*tertiary()*/) == 0xA4 ) { r1 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,(0xA4 /*tertiary()*/));
    emit_rm(cbuf, 0x3, r1, r2);
    emit_d8(cbuf,opnd_array(2)->constant());
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), r1);
    emit_d8(cbuf,opnd_array(2)->constant());
  
#line 19686 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shlL_eReg_32_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {

#line 2189 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0x4 /*secondary()*/) == 0x5 ) { r1 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }

    emit_opcode( cbuf, 0x8B ); // Move r1,r2
    emit_rm(cbuf, 0x3, r1, r2);
    if( opnd_array(2)->constant() > 32 ) { // Shift, if not by zero
      emit_opcode(cbuf,(0xC1 /*primary()*/));
      emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), r1);
      emit_d8(cbuf,opnd_array(2)->constant()-32);
    }
    emit_opcode(cbuf,0x33);  // XOR r2,r2
    emit_rm(cbuf, 0x3, r2, r2);
  
#line 19714 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void salL_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2326 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // TEST shift,32
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0, ECX_enc);
    emit_d32(cbuf,0x20);
    // JEQ,s small
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x04);
    // MOV    $dst.hi,$dst.lo
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
    // CLR    $dst.lo
    emit_opcode(cbuf, 0x33);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* dst */);
// small:
    // SHLD   $dst.hi,$dst.lo,$shift
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xA5);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    // SHL    $dst.lo,$shift"
    emit_opcode(cbuf,0xD3);
    emit_rm(cbuf, 0x3, 0x4, opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 19750 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint salL_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 17, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 17);
}
void shrL_eReg_1_31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {

#line 2163 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0xAC /*tertiary()*/) == 0xA4 ) { r1 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,(0xAC /*tertiary()*/));
    emit_rm(cbuf, 0x3, r1, r2);
    emit_d8(cbuf,opnd_array(2)->constant());
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), r1);
    emit_d8(cbuf,opnd_array(2)->constant());
  
#line 19779 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shrL_eReg_32_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {

#line 2189 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0x5 /*secondary()*/) == 0x5 ) { r1 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }

    emit_opcode( cbuf, 0x8B ); // Move r1,r2
    emit_rm(cbuf, 0x3, r1, r2);
    if( opnd_array(2)->constant() > 32 ) { // Shift, if not by zero
      emit_opcode(cbuf,(0xC1 /*primary()*/));
      emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), r1);
      emit_d8(cbuf,opnd_array(2)->constant()-32);
    }
    emit_opcode(cbuf,0x33);  // XOR r2,r2
    emit_rm(cbuf, 0x3, r2, r2);
  
#line 19807 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void shrL_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2350 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // TEST shift,32
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0, ECX_enc);
    emit_d32(cbuf,0x20);
    // JEQ,s small
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x04);
    // MOV    $dst.lo,$dst.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
    // CLR    $dst.hi
    emit_opcode(cbuf, 0x33);
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
// small:
    // SHRD   $dst.lo,$dst.hi,$shift
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xAD);
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    // SHR    $dst.hi,$shift"
    emit_opcode(cbuf,0xD3);
    emit_rm(cbuf, 0x3, 0x5, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
  
#line 19843 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint shrL_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 17, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 17);
}
void sarL_eReg_1_31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {

#line 2163 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0xAC /*tertiary()*/) == 0xA4 ) { r1 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1)/* dst */;  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */); }
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,(0xAC /*tertiary()*/));
    emit_rm(cbuf, 0x3, r1, r2);
    emit_d8(cbuf,opnd_array(2)->constant());
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), r1);
    emit_d8(cbuf,opnd_array(2)->constant());
  
#line 19872 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sarL_eReg_32_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {

#line 2176 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0x8B ); // Move
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    if( opnd_array(2)->constant() > 32 ) { // Shift, if not by zero
      emit_d8(cbuf,(0xC1 /*primary()*/));
      emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
      emit_d8(cbuf,opnd_array(2)->constant()-32);
    }
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */));
    emit_d8(cbuf,31);
  
#line 19897 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sarL_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2374 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // TEST shift,32
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0, ECX_enc);
    emit_d32(cbuf,0x20);
    // JEQ,s small
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x05);
    // MOV    $dst.lo,$dst.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
    // SAR    $dst.hi,31
    emit_opcode(cbuf, 0xC1);
    emit_rm(cbuf, 0x3, 7, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
    emit_d8(cbuf, 0x1F );
// small:
    // SHRD   $dst.lo,$dst.hi,$shift
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xAD);
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
    // SAR    $dst.hi,$shift"
    emit_opcode(cbuf,0xD3);
    emit_rm(cbuf, 0x3, 0x7, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* dst */) );
  
#line 19934 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint sarL_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 18, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 18);
}
void cmpDPR_cc_P6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 19955 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 19963 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 19971 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2661 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Fixup the integer flags in case comparison involved a NaN
    //
    // JNP exit (no unordered comparison, P-flag is set by NaN)
    emit_opcode( cbuf, 0x7B );
    emit_d8    ( cbuf, 0x03 );
    // MOV AH,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // SAHF
    emit_opcode( cbuf, 0x9E);
    // NOP     // target for branch to avoid branch to branch
    emit_opcode( cbuf, 0x90);
  
#line 19990 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpDPR_cc_P6CFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 20007 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 20015 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 20023 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpDPR_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 20040 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20048 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 20056 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2638 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // test ax,0x0400
    emit_opcode( cbuf, 0x66 );   // operand-size prefix for 16-bit immediate
    emit_opcode( cbuf, 0xA9 );
    emit_d16   ( cbuf, 0x0400 );
    // // // This sequence works, but stalls for 12-16 cycles on PPro
    // // test rax,0x0400
    // emit_opcode( cbuf, 0xA9 );
    // emit_d32   ( cbuf, 0x00000400 );
    //
    // jz exit (no unordered comparison)
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x02 );
    // mov ah,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // sahf
    emit_opcode( cbuf, 0x9E);
  
#line 20083 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpDPR_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 20100 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 20108 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE4 /*primary()*/));
  
#line 20116 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2408 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 20125 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2691 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 1 );
  
#line 20158 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 20175 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20183 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 20191 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2691 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 1 );
  
#line 20224 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpD_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9466 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp_fixup(_masm);
  
#line 20242 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpD_ccCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9478 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 20259 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpD_ccmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9495 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp_fixup(_masm);
  
#line 20277 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpD_ccmemCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9507 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 20294 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9526 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 20312 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpD_regmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9546 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 20330 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 20347 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20355 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20363 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subDPR_reg_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );   // FLD ST(i-1)
  
#line 20380 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20388 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 20396 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2465 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20404 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subDPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 20420 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20434 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20442 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20450 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void absDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 20465 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE1 /*primary()*/));
  
#line 20473 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 20488 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE0 /*primary()*/));
  
#line 20496 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 20513 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20521 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20529 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint addDPR_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}
void addDPR_reg_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );   // FLD ST(i-1)
  
#line 20550 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20558 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 20566 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2465 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20574 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 20590 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20604 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20612 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20620 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 20636 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20650 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20658 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* dst */ );
  
#line 20666 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 20682 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20696 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 20704 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 20712 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 20720 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 20728 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x03);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20742 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_mem_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 20758 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20772 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 20780 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 20788 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 20796 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 20804 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x03);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20818 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_reg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9680 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld1();
    __ faddp(opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 20836 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9693 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ faddp(opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 20854 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 9694 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 20863 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_imm_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9707 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fadd(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    __ fstp_d(Address(rsp, opnd_array(0)->disp(ra_,this,0)));
  
#line 20881 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_reg_imm_roundNode::eval_constant(Compile* C) {
  {

#line 9708 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 20890 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 20906 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20914 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20922 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void strictfp_mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2424 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias1() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20942 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 20951 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20959 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20967 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2432 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias2() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 20979 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulDPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fmulp(opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 20997 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulDPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 9761 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 21006 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 21021 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21035 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 21043 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21051 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulDPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 21067 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21081 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 21089 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* dst */ );
  
#line 21097 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulDPR_reg_mem_ciscNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21113 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21127 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 21136 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 21145 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulDPR_reg_mem_cisc_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21161 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21175 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 21184 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 21193 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src0 */ );
  
#line 21211 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2)/* src1 */);
  
#line 21222 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3595 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3)/* src2 */);
  
#line 21232 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addDPR_mulDPR_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src0
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src0 */ );
  
#line 21250 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(3)->reg(ra_,this,idx3)/* src1 */);
  
#line 21261 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3595 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1)/* src2 */);
  
#line 21271 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subDPR_mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src0 */ );
  
#line 21289 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2)/* src1 */);
  
#line 21300 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE));
  
#line 21308 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1690 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE0) + opnd_array(3)->reg(ra_,this,idx3)/* src2 */);
  
#line 21316 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 21333 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 21341 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21349 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void strictfp_divDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2424 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias1() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21369 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 21378 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 21386 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21394 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2432 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias2() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21406 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divDPR_reg_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 21423 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 21431 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x6 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 21439 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2465 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 21447 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void modDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2514 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // load dst in FPR0
    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // swap src with FPR1:
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
  
#line 21477 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 21503 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2587 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
    // // following asm replaced with Pop_Reg_F or Pop_Mem_F
    // // FSTP   FPR$dst$$reg
    // emit_opcode( cbuf, 0xDD );
    // emit_d8( cbuf, 0xD8+$dst$$reg );
  
#line 21525 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21534 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void modD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 2532 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */);
    __ fld_d(Address(rsp, 0));
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src0 */);
    __ fld_d(Address(rsp, 0));
  
#line 21555 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 21581 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 21592 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2408 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 21601 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sinDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21616 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFE /*secondary()*/));
  
#line 21624 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sinD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 21642 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21650 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFE /*secondary()*/));
  
#line 21658 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 21669 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cosDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21684 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*secondary()*/));
  
#line 21692 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cosD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 21710 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21718 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*secondary()*/));
  
#line 21726 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 21737 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void tanDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 21752 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF2));
  
#line 21760 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 21768 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 21776 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void tanD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 21794 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 21802 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF2));
  
#line 21810 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 21818 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 21826 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 21837 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void atanDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );   // FLD ST(i-1)
  
#line 21854 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21862 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF3 /*secondary()*/));
  
#line 21870 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0xF3 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 21878 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void atanD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
    __ fld_d(Address(rsp, 0));
  
#line 21897 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21905 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF3 /*secondary()*/));
  
#line 21913 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 21924 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );   // FLD ST(i-1)
  
#line 21940 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 21948 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFA /*primary()*/));
  
#line 21956 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 21965 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void powDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// X
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// Y
  {
    MacroAssembler _masm(&cbuf);

#line 10024 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 8);
    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)/* X */- 1);
    __ fast_pow();
    __ addptr(rsp, 8);
  
#line 21985 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void powD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10038 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */);
    __ fld_d(Address(rsp, 0));
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src0 */);
    __ fld_d(Address(rsp, 0));
    __ fast_pow();
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 22010 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void expDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dpr1
  {
    MacroAssembler _masm(&cbuf);

#line 10058 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fast_exp();
  
#line 22026 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void expD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10069 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
    __ fast_exp();
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 22048 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void log10DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22063 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xEC));
  
#line 22071 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22079 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC9));
  
#line 22087 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22095 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 22103 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void log10D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22118 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xEC));
  
#line 22126 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
  
#line 22137 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22145 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 22153 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 22164 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void logDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22179 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xED));
  
#line 22187 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22195 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC9));
  
#line 22203 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22211 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 22219 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void logD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22234 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xED));
  
#line 22242 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
  
#line 22253 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 22261 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 22269 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 22280 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFPR_cc_P6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 22297 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 22305 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 22313 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2661 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Fixup the integer flags in case comparison involved a NaN
    //
    // JNP exit (no unordered comparison, P-flag is set by NaN)
    emit_opcode( cbuf, 0x7B );
    emit_d8    ( cbuf, 0x03 );
    // MOV AH,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // SAHF
    emit_opcode( cbuf, 0x9E);
    // NOP     // target for branch to avoid branch to branch
    emit_opcode( cbuf, 0x90);
  
#line 22332 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFPR_cc_P6CFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 22349 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 22357 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 22365 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFPR_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 22382 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 22390 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 22398 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2638 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // test ax,0x0400
    emit_opcode( cbuf, 0x66 );   // operand-size prefix for 16-bit immediate
    emit_opcode( cbuf, 0xA9 );
    emit_d16   ( cbuf, 0x0400 );
    // // // This sequence works, but stalls for 12-16 cycles on PPro
    // // test rax,0x0400
    // emit_opcode( cbuf, 0xA9 );
    // emit_d32   ( cbuf, 0x00000400 );
    //
    // jz exit (no unordered comparison)
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x02 );
    // mov ah,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // sahf
    emit_opcode( cbuf, 0x9E);
  
#line 22425 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFPR_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 22442 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 22450 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE4 /*primary()*/));
  
#line 22458 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2408 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 22467 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2691 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 1 );
  
#line 22500 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );   // FLD ST(i-1)
  
#line 22517 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 22525 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 22533 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2691 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this)/* dst */);
    emit_d32( cbuf, 1 );
  
#line 22566 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpF_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10258 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp_fixup(_masm);
  
#line 22584 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpF_ccCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10270 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 22601 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpF_ccmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10287 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp_fixup(_masm);
  
#line 22619 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpF_ccmemCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10299 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 22636 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10318 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 22654 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpF_regmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10338 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 22672 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 22689 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 22698 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22706 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 22723 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 22731 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 22739 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 22756 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 22765 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22773 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 22790 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 22798 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 22806 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void absFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 22821 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE1 /*primary()*/));
  
#line 22829 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 22844 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE0 /*primary()*/));
  
#line 22852 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 22868 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 22882 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 22891 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22899 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 22915 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 22929 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src1 */ );
  
#line 22938 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22946 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 22962 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 22976 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 22984 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 22992 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23008 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23022 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 23030 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* dst */ );
  
#line 23038 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23054 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23068 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 23077 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23085 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_mem_ciscNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23101 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23115 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 23123 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 23131 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x0 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23145 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23153 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_mem_cisc_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23169 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23183 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 23191 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 23199 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x0 /*secondary()*/);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23213 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23221 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_mem_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23237 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23251 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 23259 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 23267 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x0 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23281 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23289 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 10496 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)/* src */- 1);  // FLD ST(i-1)
    __ fadd_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_s(Address(rsp, opnd_array(0)->disp(ra_,this,0)));
  
#line 23308 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR24_reg_immNode::eval_constant(Compile* C) {
  {

#line 10498 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 23317 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 10511 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)/* src */- 1);  // FLD ST(i-1)
    __ fadd_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 23335 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 10513 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 23344 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 23360 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 23369 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23377 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 23394 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 23403 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23412 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR24_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23428 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23442 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 23451 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23459 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR24_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23475 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23489 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src1 */ );
  
#line 23498 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23506 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23522 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23536 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 23545 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23554 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23570 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23584 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src1 */ );
  
#line 23593 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23602 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR24_mem_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23618 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23632 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 23640 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 23648 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x1 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23662 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23670 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR24_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 10602 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)/* src */- 1);  // FLD ST(i-1)
    __ fmul_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_s(Address(rsp, opnd_array(0)->disp(ra_,this,0)));
  
#line 23689 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR24_reg_immNode::eval_constant(Compile* C) {
  {

#line 10604 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 23698 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 10618 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)/* src */- 1);  // FLD ST(i-1)
    __ fmul_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 23716 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 10620 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 23725 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_load1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23740 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23754 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 23763 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23772 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulFPR_reg_load1_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem1
  {

#line 1626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 23788 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23802 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 23811 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23820 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_mulFPR_reg_load1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 23837 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23851 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2)/* src1 */);
  
#line 23862 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3588 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3)/* src2 */);
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 23873 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23882 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_mulFPR_reg_load1_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 23899 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23913 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(3)->reg(ra_,this,idx3)/* src1 */);
  
#line 23924 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3588 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1)/* src2 */);
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 23935 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 23944 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_mulFPR_reg_load1_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 23961 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 23975 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
  
#line 23986 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3588 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3)/* src2 */);
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 23997 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 24006 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_mulFPR_reg_load1_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mem1
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 24023 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(3)->base(ra_,this,idx3);
    int index    = opnd_array(3)->index(ra_,this,idx3);
    int scale    = opnd_array(3)->scale();
    int displace = opnd_array(3)->disp(ra_,this,idx3);
    bool disp_is_oop = opnd_array(3)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 24037 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2)/* src1 */);
  
#line 24048 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3588 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1)/* src2 */);
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 24059 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 24068 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_mulFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src0 */ );
  
#line 24086 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2)/* src1 */);
  
#line 24097 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3595 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3)/* src2 */);
  
#line 24107 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addFPR_mulFPR_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src0
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src0 */ );
  
#line 24125 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3581 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(3)->reg(ra_,this,idx3)/* src1 */);
  
#line 24136 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3595 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1)/* src2 */);
  
#line 24146 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subFPR_divFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src2 */ );
  
#line 24164 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3601 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand has been loaded into fp ST (stack top)
      // FSUB   ST,$src1
      emit_opcode(cbuf, 0xD8);
      emit_opcode(cbuf, 0xE0 + opnd_array(2)->reg(ra_,this,idx2)/* src1 */);

      // FDIV
      emit_opcode(cbuf, 0xD8);
      emit_opcode(cbuf, 0xF0 + opnd_array(3)->reg(ra_,this,idx3)/* src3 */);
  
#line 24179 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 24188 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
  
#line 24205 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2402 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x6 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
  
#line 24214 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 24222 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
  
#line 24239 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 24247 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 24255 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void modFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2514 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // load dst in FPR0
    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
    if (opnd_array(2)->reg(ra_,this,idx2)/* src2 */ != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // swap src with FPR1:
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
  
#line 24285 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 24311 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2587 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src2 */ != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
    // // following asm replaced with Pop_Reg_F or Pop_Mem_F
    // // FSTP   FPR$dst$$reg
    // emit_opcode( cbuf, 0xDD );
    // emit_d8( cbuf, 0xD8+$dst$$reg );
  
#line 24333 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 24341 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void modFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2514 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // load dst in FPR0
    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // swap src with FPR1:
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
  
#line 24371 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 24397 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2587 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2)/* src */ );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
    // // following asm replaced with Pop_Reg_F or Pop_Mem_F
    // // FSTP   FPR$dst$$reg
    // emit_opcode( cbuf, 0xDD );
    // emit_d8( cbuf, 0xD8+$dst$$reg );
  
#line 24419 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(1)->reg(ra_,this,idx1)/* dst */ );
  
#line 24428 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void modF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 2541 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */);
    __ fld_s(Address(rsp, 0));
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src0 */);
    __ fld_s(Address(rsp, 0));
  
#line 24449 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 24475 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2557 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_s(Address(rsp, 0));
    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, (0x4));
  
#line 24486 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2408 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 24495 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void roundFloat_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2480 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xD9, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_S  [ESP+dst]
  
#line 24516 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void roundDouble_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2491 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xDD, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_D  [ESP+dst]
  
#line 24537 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convDPR2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10818 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 4);
    if (opnd_array(1)->reg(ra_,this,idx1)/* src */!= FPR1L_enc) {
      __ fld_s(opnd_array(1)->reg(ra_,this,idx1)/* src */-1);
      __ fstp_s(Address(rsp, 0));
    } else {
      __ fst_s(Address(rsp, 0));
    }
    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 4);
  
#line 24561 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10837 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsd2ss (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 24577 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convFPR2DPR_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2502 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0xD0 - 1; // -1 since we skip FLD
    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(src-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
      pop = 0xD8;
    }
    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, pop+opnd_array(0)->reg(ra_,this)/* dst */ );      // FST<P> ST(i)
  
#line 24599 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convF2DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10869 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_s(Address(rsp, 0));
    __ addptr(rsp, 4);
    __ fstp_d(opnd_array(0)->reg(ra_,this)/* dst */);
  
#line 24619 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10883 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtss2sd (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 24635 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convDPR2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );   // FLD ST(i-1)
  
#line 24651 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3496 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Flip to round-to-zero mode.  We attempted to allow invalid-op
    // exceptions here, so that a NAN or other corner-case value will
    // thrown an exception (but normal values get converted at full speed).
    // However, I2C adapters and other float-stack manglers leave pending
    // invalid-op exceptions hanging.  We would have to clear them before
    // enabling them and that is more expensive than just testing for the
    // invalid value Intel stores down in the corner cases.
    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,4
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x04);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as an int, popping the FPU stack
    emit_opcode(cbuf,0xDB);            // FISTP [ESP]
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x3D);       // CMP EAX,imm
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2i_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 24698 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10923 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ cvttsd2sil(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ cmpl(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
    __ addptr(rsp, 8);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2i_wrapper())));
    __ bind(fast);
  
#line 24723 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convDPR2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );   // FLD ST(i-1)
  
#line 24739 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3539 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,8
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x08);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as a long, popping the FPU stack
    emit_opcode(cbuf,0xDF);            // FISTP [ESP]
    emit_opcode(cbuf,0x3C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x5A);       // POP EDX
    emit_opcode(cbuf,0x81);       // CMP EDX,imm
    emit_d8    (cbuf,0xFA);       // rdx
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07+4);     // Size of slow_call
    emit_opcode(cbuf,0x85);       // TEST EAX,EAX
    emit_opcode(cbuf,0xC0);       // 2/rax,/rax,
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2l_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 24785 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10983 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
    __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_trunc()));
    __ fistp_d(Address(rsp, 0));
    // Restore the rounding mode, mask the exception
    if (Compile::current()->in_24_bit_fp_mode()) {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    } else {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    // Load the converted long, adjust CPU stack
    __ pop(rax);
    __ pop(rdx);
    __ cmpl(rdx, 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ testl(rax, rax);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
    __ addptr(rsp, 8);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2l_wrapper())));
    __ bind(fast);
  
#line 24825 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convFPR2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 24841 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3496 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Flip to round-to-zero mode.  We attempted to allow invalid-op
    // exceptions here, so that a NAN or other corner-case value will
    // thrown an exception (but normal values get converted at full speed).
    // However, I2C adapters and other float-stack manglers leave pending
    // invalid-op exceptions hanging.  We would have to clear them before
    // enabling them and that is more expensive than just testing for the
    // invalid value Intel stores down in the corner cases.
    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,4
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x04);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as an int, popping the FPU stack
    emit_opcode(cbuf,0xDB);            // FISTP [ESP]
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x3D);       // CMP EAX,imm
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2i_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 24888 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convF2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11053 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ cvttss2sil(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ cmpl(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_s(Address(rsp, 0));
    __ addptr(rsp, 4);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2i_wrapper())));
    __ bind(fast);
  
#line 24913 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convFPR2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2474 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 24929 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3539 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,8
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x08);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as a long, popping the FPU stack
    emit_opcode(cbuf,0xDF);            // FISTP [ESP]
    emit_opcode(cbuf,0x3C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x5A);       // POP EDX
    emit_opcode(cbuf,0x81);       // CMP EDX,imm
    emit_d8    (cbuf,0xFA);       // rdx
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07+4);     // Size of slow_call
    emit_opcode(cbuf,0x85);       // TEST EAX,EAX
    emit_opcode(cbuf,0xC0);       // 2/rax,/rax,
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2l_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 24975 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11114 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ subptr(rsp, 8);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_s(Address(rsp, 0));
    __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_trunc()));
    __ fistp_d(Address(rsp, 0));
    // Restore the rounding mode, mask the exception
    if (Compile::current()->in_24_bit_fp_mode()) {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    } else {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    // Load the converted long, adjust CPU stack
    __ pop(rax);
    __ pop(rdx);
    __ cmpl(rdx, 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ testl(rax, rax);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_s(Address(rsp, 0));
    __ addptr(rsp, 4);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2l_wrapper())));
    __ bind(fast);
  
#line 25015 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2454 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 25030 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25039 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11158 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsi2sdl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25055 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 11168 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsi2sdl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 25071 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convXI2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11181 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cvtdq2pd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 25088 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2DPR_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDB /*primary()*/));
  
#line 25103 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 25117 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25126 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void conv24I2FPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2454 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 25141 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25150 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2FPR_SSFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2454 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 25165 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 25173 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2FPR_SSF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDB /*primary()*/));
  
#line 25188 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 25202 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 25210 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2FPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2454 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 25225 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25234 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2FPR_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDB /*primary()*/));
  
#line 25249 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 25263 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25272 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11266 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsi2ssl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25288 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convXI2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11279 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cvtdq2ps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 25305 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2736 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // mov $dst.lo,$src
    int dst_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int src_encoding = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    encode_Copy( cbuf, dst_encoding  , src_encoding );
    // mov $dst.hi,$src
    encode_Copy( cbuf, HIGH_FROM_LOW(dst_encoding), src_encoding );
    // sar $dst.hi,31
    emit_opcode( cbuf, 0xC1 );
    emit_rm(cbuf, 0x3, 7, HIGH_FROM_LOW(dst_encoding) );
    emit_d8(cbuf, 0x1F );
  
#line 25329 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convI2L_reg_zexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 25345 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 25353 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */), HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 25361 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void zerox_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 25377 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 25385 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */), HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 25393 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convL2DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2749 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)/* src */  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
    // pop stack
    emit_opcode(cbuf, 0x83); // add  SP, #8
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 0x8);
  
#line 25420 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2465 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 25428 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convL2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2779 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)/* src */  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
  
#line 25451 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2550 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 25462 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convL2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2779 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)/* src */  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
  
#line 25485 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2557 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_s(Address(rsp, 0));
    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, (0x8));
  
#line 25496 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convL2FPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2749 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)/* src */  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
    // pop stack
    emit_opcode(cbuf, 0x83); // add  SP, #8
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 0x8);
  
#line 25523 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2459 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 25531 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2022 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this)/* dst */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 25546 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11392 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 25562 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveFPR2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2480 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xD9, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_S  [ESP+dst]
  
#line 25583 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveF2I_reg_stack_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11416 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 25599 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveF2I_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11428 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 25615 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11440 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25631 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveI2FPR_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 25646 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2223 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 25660 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2469 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25669 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveI2F_stack_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11468 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 25685 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveI2F_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11481 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25701 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 25716 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25730 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*secondary()*/));
  
#line 25738 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 25752 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveDPR2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2491 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1)/* src */ );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xDD, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_D  [ESP+dst]
  
#line 25773 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveD2L_reg_stack_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11516 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 25789 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveD2L_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 11530 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x4e);
    __ movdl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)/* dst */), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* tmp */);
  
#line 25808 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 25823 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0);
    bool disp_is_oop = opnd_array(0)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25837 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*secondary()*/));
  
#line 25845 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */);  // Hi register of pair, computed from lo
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(0)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 25859 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveL2DPR_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*primary()*/));
  
#line 25874 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2223 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 25888 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this)/* dst */ );
  
#line 25897 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveL2D_stack_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11573 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 25913 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveL2D_stack_reg_sse_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11586 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 25929 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void MoveL2D_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 11600 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ movdl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* src */));
    __ punpckldq(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */);
  
#line 25949 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rep_stosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 11618 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ clear_mem(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */, as_Register(EAX_enc));
  
#line 25966 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void rep_fast_stosbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 11631 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ clear_mem(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */, as_Register(EAX_enc));
  
#line 25983 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void string_compareNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    MacroAssembler _masm(&cbuf);

#line 11643 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* tmp1 */);
  
#line 26005 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void string_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 11658 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ char_arrays_equals(false, opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                          opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(EBX_enc),
                          opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* tmp2 */);
  
#line 26027 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void string_indexof_conNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vec
  {
    MacroAssembler _masm(&cbuf);

#line 11674 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    if (icnt2 >= 8) {
      // IndexOf for constant substrings with size >= 8 elements
      // which don't need to be loaded through stack.
      __ string_indexofC8(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                          opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, as_Register(EAX_enc),
                          icnt2, opnd_array(0)->as_Register(ra_,this)/* result */,
                          opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* vec */, as_Register(ECX_enc));
    } else {
      // Small strings are loaded through stack if they cross page boundary.
      __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                        opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, as_Register(EAX_enc),
                        icnt2, opnd_array(0)->as_Register(ra_,this)/* result */,
                        opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* vec */, as_Register(ECX_enc));
    }
  
#line 26061 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void string_indexofNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vec
  {
    MacroAssembler _masm(&cbuf);

#line 11701 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      (-1), opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* vec */, as_Register(ECX_enc));
  
#line 26084 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void array_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 11719 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ char_arrays_equals(true, opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                          as_Register(ECX_enc), opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(EBX_enc),
                          opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp2 */);
  
#line 26105 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26121 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */, opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
  
#line 26129 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
  
#line 26153 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 26168 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26184 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 26198 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void testI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 26214 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */, opnd_array(1)->reg(ra_,this,idx1)/* src */);
  
#line 26222 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void testI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 26239 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ );
  
#line 26247 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2052 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constant());
  
#line 26256 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void testI_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 26273 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 26287 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compU_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26303 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */, opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
  
#line 26311 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compU_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
  
#line 26335 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 26350 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compU_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26366 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 26380 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void testU_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 26396 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */, opnd_array(1)->reg(ra_,this,idx1)/* src */);
  
#line 26404 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compP_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26420 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */, opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
  
#line 26428 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compP_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1706 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
  
#line 26452 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      
if ( opnd_array(2)->constant_is_oop() ) {
  emit_d32_reloc(cbuf, opnd_array(2)->constant(), relocInfo::oop_type, 0);
} else {
  emit_d32(cbuf, opnd_array(2)->constant());
};
    }
  
#line 26472 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compP_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26488 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 26502 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void compP_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 26518 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 26532 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 26548 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */, opnd_array(1)->reg(ra_,this,idx1)/* src */);
  
#line 26556 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void testP_Reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 26572 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 26586 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2076 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d32(cbuf,(0xFFFFFFFF));
  
#line 26594 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void minI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2253 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Compare dst,src
    emit_opcode(cbuf,0x3B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // jmp dst < src around move
    emit_opcode(cbuf,0x7C);
    emit_d8(cbuf,2);
    // move dst,src
    emit_opcode(cbuf,0x8B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 26618 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void maxI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2265 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Compare dst,src
    emit_opcode(cbuf,0x3B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // jmp dst > src around move
    emit_opcode(cbuf,0x7F);
    emit_d8(cbuf,2);
    // move dst,src
    emit_opcode(cbuf,0x8B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */, opnd_array(2)->reg(ra_,this,idx2)/* src */);
  
#line 26642 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loopLimit_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// init
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// limit
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// stride
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// limit_hi
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 12002 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int strd = (int)opnd_array(3)->constant();
    assert(strd != 1 && strd != -1, "sanity");
    int m1 = (strd > 0) ? 1 : -1;
    // Convert limit to long (EAX:EDX)
    __ cdql();
    // Convert init to long (init:tmp)
    __ movl(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* init */);
    __ sarl(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */, 31);
    // $limit - $init
    __ subl(opnd_array(2)->as_Register(ra_,this,idx2)/* limit */, opnd_array(1)->as_Register(ra_,this,idx1)/* init */);
    __ sbbl(opnd_array(4)->as_Register(ra_,this,idx4)/* limit_hi */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */);
    // + ($stride - 1)
    if (strd > 0) {
      __ addl(opnd_array(2)->as_Register(ra_,this,idx2)/* limit */, (strd - 1));
      __ adcl(opnd_array(4)->as_Register(ra_,this,idx4)/* limit_hi */, 0);
      __ movl(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */, strd);
    } else {
      __ addl(opnd_array(2)->as_Register(ra_,this,idx2)/* limit */, (strd + 1));
      __ adcl(opnd_array(4)->as_Register(ra_,this,idx4)/* limit_hi */, -1);
      __ lneg(opnd_array(4)->as_Register(ra_,this,idx4)/* limit_hi */, opnd_array(2)->as_Register(ra_,this,idx2)/* limit */);
      __ movl(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */, -strd);
    }
    // signed devision: (EAX:EDX) / pos_stride
    __ idivl(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */);
    if (strd < 0) {
      // restore sign
      __ negl(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */);
    }
    // (EAX) * stride
    __ mull(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */);
    // + init (ignore upper bits)
    __ addl(opnd_array(2)->as_Register(ra_,this,idx2)/* limit */, opnd_array(1)->as_Register(ra_,this,idx1)/* init */);
  
#line 26693 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void jumpXtndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  ra_->C->constant_table().fill_jump_table(cbuf, (MachConstantNode*) this, _index2label);
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12046 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Jump to Address(table_base + switch_reg)
    Address index(noreg, opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */, Address::times_1);
    __ jump(ArrayAddress(InternalAddress(__ code()->consts()->start() + constant_offset()), index));
  
#line 26712 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void jumpXtndNode::eval_constant(Compile* C) {
  _constant = C->constant_table().add_jump_table(this);
  // User did not define an encode section.
}
void jmpDirNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12062 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(1)->label();
    __ jmp(*L, false); // Always long jump
  
#line 26733 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpDirNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 5, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 5);
}
void jmpConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12077 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 26756 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpConNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12092 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 26779 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpLoopEndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12107 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 26802 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpLoopEndUNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpLoopEndUCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12121 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 26825 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpLoopEndUCFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12136 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 26848 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpConUNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpConUCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12150 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 26871 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpConUCFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpConUCF2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12172 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* l = opnd_array(3)->label();
    if (opnd_array(1)->ccode()== Assembler::notEqual) {
      __ jcc(Assembler::parity, *l, false);
      __ jcc(Assembler::notEqual, *l, false);
    } else if (opnd_array(1)->ccode()== Assembler::equal) {
      Label done;
      __ jccb(Assembler::parity, done);
      __ jcc(Assembler::equal, *l, false);
      __ bind(done);
    } else {
       ShouldNotReachHere();
    }
  
#line 26904 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 1791 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Redi = as_Register(EDI_enc); // result register
    Register Reax = as_Register(EAX_enc); // super class
    Register Recx = as_Register(ECX_enc); // killed
    Register Resi = as_Register(ESI_enc); // sub class
    Label miss;

    MacroAssembler _masm(&cbuf);
    __ check_klass_subtype_slow_path(Resi, Reax, Recx, Redi,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
    if ((0x1 /*primary()*/)) {
      __ xorptr(Redi, Redi);
    }
    __ bind(miss);
  
#line 26933 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void partialSubtypeCheck_vs_ZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 1791 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Redi = as_Register(EDI_enc); // result register
    Register Reax = as_Register(EAX_enc); // super class
    Register Recx = as_Register(ECX_enc); // killed
    Register Resi = as_Register(ESI_enc); // sub class
    Label miss;

    MacroAssembler _masm(&cbuf);
    __ check_klass_subtype_slow_path(Resi, Reax, Recx, Redi,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
    if ((0x0 /*primary()*/)) {
      __ xorptr(Redi, Redi);
    }
    __ bind(miss);
  
#line 26963 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void jmpDir_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12251 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(1)->label();
    __ jmpb(*L);
  
#line 26980 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpDir_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpCon_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12267 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 27003 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpCon_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpLoopEnd_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12283 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 27026 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpLoopEnd_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpLoopEndU_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12299 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 27049 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpLoopEndU_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpLoopEndUCF_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12314 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 27072 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpLoopEndUCF_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpConU_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12330 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 27095 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpConU_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpConUCF_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12345 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 27118 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpConUCF_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpConUCF2_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12369 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* l = opnd_array(3)->label();
    if (opnd_array(1)->ccode()== Assembler::notEqual) {
      __ jccb(Assembler::parity, *l);
      __ jccb(Assembler::notEqual, *l);
    } else if (opnd_array(1)->ccode()== Assembler::equal) {
      Label done;
      __ jccb(Assembler::parity, done);
      __ jccb(Assembler::equal, *l);
      __ bind(done);
    } else {
       ShouldNotReachHere();
    }
  
#line 27151 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint jmpConUCF2_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}
void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12425 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label p_one, m_one, done;
    __ xorptr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ cmpl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */), HIGH_FROM_LOW(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
    __ jccb(Assembler::less,    m_one);
    __ jccb(Assembler::greater, p_one);
    __ cmpl(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ jccb(Assembler::below,   m_one);
    __ jccb(Assembler::equal,   done);
    __ bind(p_one);
    __ incrementl(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ jmpb(done);
    __ bind(m_one);
    __ decrementl(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ bind(done);
  
#line 27185 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpL_zero_flags_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 27201 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27209 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpL_reg_flags_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 2908 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CMP    $src1.lo,$src2.lo\t! Long compare; set flags for low bits
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src1 */, opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
    // MOV    $tmp,$src1.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src1 */) );
    // SBB   $tmp,$src2.hi\t! Compute flags for long compare
    emit_opcode( cbuf, 0x1B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src2 */) );
  
#line 27234 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovLL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27253 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2040 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27261 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27270 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)/* src */));
  
#line 27278 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovLL_mem_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27297 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 27311 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27320 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(4)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 27334 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovII_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27353 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27361 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovII_mem_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27380 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 27394 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovPP_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27413 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27421 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpL_zero_flags_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 2887 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // MOV   $tmp,$src.lo
    emit_opcode(cbuf, 0x8B);
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, opnd_array(1)->reg(ra_,this,idx1)/* src */);
    // OR    $tmp,$src.hi
    emit_opcode(cbuf, 0x0B);
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27443 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpL_reg_flags_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2896 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CMP    $src1.lo,$src2.lo
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src1 */, opnd_array(2)->reg(ra_,this,idx2)/* src2 */ );
    // JNE,s  skip
    emit_cc(cbuf, 0x70, 0x5);
    emit_d8(cbuf,2);
    // CMP    $src1.hi,$src2.hi
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src2 */) );
  
#line 27467 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovLL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27486 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2040 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27494 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27503 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)/* src */));
  
#line 27511 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovLL_mem_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27530 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 27544 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27553 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(4)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 27567 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovII_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27586 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27594 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovII_mem_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27613 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 27627 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovPP_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27646 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27654 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpL_zero_flags_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 2920 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // XOR    $tmp,$tmp
    emit_opcode(cbuf,0x33);  // XOR
    emit_rm(cbuf,0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    // CMP    $tmp,$src.lo
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, opnd_array(1)->reg(ra_,this,idx1)/* src */ );
    // SBB    $tmp,$src.hi
    emit_opcode( cbuf, 0x1B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src */) );
  
#line 27679 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpL_reg_flags_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 2908 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CMP    $src1.lo,$src2.lo\t! Long compare; set flags for low bits
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2)/* src2 */, opnd_array(1)->reg(ra_,this,idx1)/* src1 */ );
    // MOV    $tmp,$src1.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)/* src2 */) );
    // SBB   $tmp,$src2.hi\t! Compute flags for long compare
    emit_opcode( cbuf, 0x1B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)/* src1 */) );
  
#line 27704 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovLL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27723 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2040 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27731 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27740 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)/* src */));
  
#line 27748 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovLL_mem_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27767 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 27781 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27790 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)/* dst */);  // Hi register of pair, computed from lo
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(4)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 27804 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovII_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27823 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27831 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovII_mem_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27850 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 27864 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmovPP_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// flags
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 1773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 27883 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */, opnd_array(4)->reg(ra_,this,idx4)/* src */);
  
#line 27891 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1867 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->in_24_bit_fp_mode()) {
      MacroAssembler _masm(&cbuf);
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_resets_size(), "correct size prediction");
  
#line 27919 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1892 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    if (!_method) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     runtime_call_Relocation::spec(), RELOC_IMM32 );
    } else if (_optimized_virtual) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     opt_virtual_call_Relocation::spec(), RELOC_IMM32 );
    } else {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     static_call_Relocation::spec(), RELOC_IMM32 );
    }
    if (_method) {  // Emit stub for static call
      emit_java_to_interp(cbuf);
    }
  
#line 27943 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 817 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 27961 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1884 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if (Compile::current()->in_24_bit_fp_mode()) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 27973 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CallStaticJavaHandleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// ebp_mh_SP_save
  {

#line 1867 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->in_24_bit_fp_mode()) {
      MacroAssembler _masm(&cbuf);
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_resets_size(), "correct size prediction");
  
#line 28001 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 802 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    debug_only(int off0 = cbuf.insts_size());
    MacroAssembler _masm(&cbuf);
    // RBP is preserved across all calls, even compiled calls.
    // Use it to preserve RSP in places where the callee might change the SP.
    __ movptr(rbp_mh_SP_save, rsp);
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == preserve_SP_size(), "correct size prediction");
  
#line 28015 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1892 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    if (!_method) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     runtime_call_Relocation::spec(), RELOC_IMM32 );
    } else if (_optimized_virtual) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     opt_virtual_call_Relocation::spec(), RELOC_IMM32 );
    } else {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     static_call_Relocation::spec(), RELOC_IMM32 );
    }
    if (_method) {  // Emit stub for static call
      emit_java_to_interp(cbuf);
    }
  
#line 28039 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 812 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    MacroAssembler _masm(&cbuf);
    __ movptr(rsp, rbp_mh_SP_save);
  
#line 28048 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 817 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 28066 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1884 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if (Compile::current()->in_24_bit_fp_mode()) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 28078 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1867 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->in_24_bit_fp_mode()) {
      MacroAssembler _masm(&cbuf);
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_resets_size(), "correct size prediction");
  
#line 28106 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1912 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // !!!!!
    // Generate  "Mov EAX,0x00", placeholder instruction to load oop-info
    // emit_call_dynamic_prologue( cbuf );
    cbuf.set_insts_mark();
    emit_opcode(cbuf, 0xB8 + EAX_enc);        // mov    EAX,-1
    emit_d32_reloc(cbuf, (int)Universe::non_oop_word(), oop_Relocation::spec_for_immediate(), RELOC_IMM32);
    address  virtual_call_oop_addr = cbuf.insts_mark();
    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                virtual_call_Relocation::spec(virtual_call_oop_addr), RELOC_IMM32 );
  
#line 28126 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 817 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 28144 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1884 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if (Compile::current()->in_24_bit_fp_mode()) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 28156 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1867 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->in_24_bit_fp_mode()) {
      MacroAssembler _masm(&cbuf);
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_resets_size(), "correct size prediction");
  
#line 28184 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1808 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler masm(&cbuf);
    int start = masm.offset();
    if (UseSSE >= 2) {
      if (VerifyFPU) {
        masm.verify_FPU(0, "must be empty in SSE2+ mode");
      }
    } else {
      // External c_calling_convention expects the FPU stack to be 'clean'.
      // Compiled code leaves it dirty.  Do cleanup now.
      masm.empty_FPU_stack();
    }
    if (sizeof_FFree_Float_Stack_All == -1) {
      sizeof_FFree_Float_Stack_All = masm.offset() - start;
    } else {
      assert(masm.offset() - start == sizeof_FFree_Float_Stack_All, "wrong size");
    }
  
#line 28207 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1834 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is the instruction starting address for relocation info.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    // CALL directly to the runtime
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                runtime_call_Relocation::spec(), RELOC_IMM32 );

    if (UseSSE >= 2) {
      MacroAssembler _masm(&cbuf);
      BasicType rt = tf()->return_type();

      if ((rt == T_FLOAT || rt == T_DOUBLE) && !return_value_is_used()) {
        // A C runtime call where the return value is unused.  In SSE2+
        // mode the result needs to be removed from the FPU stack.  It's
        // likely that this function call could be removed by the
        // optimizer if the C function is a pure function.
        __ ffree(0);
      } else if (rt == T_FLOAT) {
        __ lea(rsp, Address(rsp, -4));
        __ fstp_s(Address(rsp, 0));
        __ movflt(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  4));
      } else if (rt == T_DOUBLE) {
        __ lea(rsp, Address(rsp, -8));
        __ fstp_d(Address(rsp, 0));
        __ movdbl(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  8));
      }
    }
  
#line 28243 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1884 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if (Compile::current()->in_24_bit_fp_mode()) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 28255 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1867 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->in_24_bit_fp_mode()) {
      MacroAssembler _masm(&cbuf);
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_resets_size(), "correct size prediction");
  
#line 28283 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1808 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler masm(&cbuf);
    int start = masm.offset();
    if (UseSSE >= 2) {
      if (VerifyFPU) {
        masm.verify_FPU(0, "must be empty in SSE2+ mode");
      }
    } else {
      // External c_calling_convention expects the FPU stack to be 'clean'.
      // Compiled code leaves it dirty.  Do cleanup now.
      masm.empty_FPU_stack();
    }
    if (sizeof_FFree_Float_Stack_All == -1) {
      sizeof_FFree_Float_Stack_All = masm.offset() - start;
    } else {
      assert(masm.offset() - start == sizeof_FFree_Float_Stack_All, "wrong size");
    }
  
#line 28306 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1834 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is the instruction starting address for relocation info.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    // CALL directly to the runtime
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                runtime_call_Relocation::spec(), RELOC_IMM32 );

    if (UseSSE >= 2) {
      MacroAssembler _masm(&cbuf);
      BasicType rt = tf()->return_type();

      if ((rt == T_FLOAT || rt == T_DOUBLE) && !return_value_is_used()) {
        // A C runtime call where the return value is unused.  In SSE2+
        // mode the result needs to be removed from the FPU stack.  It's
        // likely that this function call could be removed by the
        // optimizer if the C function is a pure function.
        __ ffree(0);
      } else if (rt == T_FLOAT) {
        __ lea(rsp, Address(rsp, -4));
        __ fstp_s(Address(rsp, 0));
        __ movflt(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  4));
      } else if (rt == T_DOUBLE) {
        __ lea(rsp, Address(rsp, -8));
        __ fstp_d(Address(rsp, 0));
        __ movdbl(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  8));
      }
    }
  
#line 28342 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1827 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if( VerifyFPU ) {
      MacroAssembler masm(&cbuf);
      masm.verify_FPU( -3, "Returning from Runtime Leaf call");
    }
  
#line 28353 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1884 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if (Compile::current()->in_24_bit_fp_mode()) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 28365 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1834 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is the instruction starting address for relocation info.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    // CALL directly to the runtime
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                runtime_call_Relocation::spec(), RELOC_IMM32 );

    if (UseSSE >= 2) {
      MacroAssembler _masm(&cbuf);
      BasicType rt = tf()->return_type();

      if ((rt == T_FLOAT || rt == T_DOUBLE) && !return_value_is_used()) {
        // A C runtime call where the return value is unused.  In SSE2+
        // mode the result needs to be removed from the FPU stack.  It's
        // likely that this function call could be removed by the
        // optimizer if the C function is a pure function.
        __ ffree(0);
      } else if (rt == T_FLOAT) {
        __ lea(rsp, Address(rsp, -4));
        __ fstp_s(Address(rsp, 0));
        __ movflt(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  4));
      } else if (rt == T_DOUBLE) {
        __ lea(rsp, Address(rsp, -8));
        __ fstp_d(Address(rsp, 0));
        __ movdbl(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  8));
      }
    }
  
#line 28408 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC3 /*primary()*/));
  
#line 28423 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 28439 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* jump_target */ );
  
#line 28447 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void tailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3479 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0x5A);
  
#line 28463 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 28471 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1769 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* jump_target */ );
  
#line 28479 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}
void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3483 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();
    emit_opcode(cbuf, 0xE9);        // jmp    entry
    emit_d32_reloc(cbuf, (int)OptoRuntime::rethrow_stub() - ((int)cbuf.insts_end())-4,
                   runtime_call_Relocation::spec(), RELOC_IMM32 );
  
#line 28509 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// scr
  {

#line 3018 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"


    Register objReg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register boxReg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register tmpReg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register scrReg = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* scr */);

    // Ensure the register assignents are disjoint
    guarantee (objReg != boxReg, "") ;
    guarantee (objReg != tmpReg, "") ;
    guarantee (objReg != scrReg, "") ;
    guarantee (boxReg != tmpReg, "") ;
    guarantee (boxReg != scrReg, "") ;
    guarantee (tmpReg == as_Register(EAX_enc), "") ;

    MacroAssembler masm(&cbuf);

    if (_counters != NULL) {
      masm.atomic_incl(ExternalAddress((address) _counters->total_entry_count_addr()));
    }
    if (EmitSync & 1) {
        // set box->dhw = unused_mark (3)
        // Force all sync thru slow-path: slow_enter() and slow_exit() 
        masm.movptr (Address(boxReg, 0), int32_t(markOopDesc::unused_mark())) ;             
        masm.cmpptr (rsp, (int32_t)0) ;                        
    } else 
    if (EmitSync & 2) { 
        Label DONE_LABEL ;           
        if (UseBiasedLocking) {
           // Note: tmpReg maps to the swap_reg argument and scrReg to the tmp_reg argument.
           masm.biased_locking_enter(boxReg, objReg, tmpReg, scrReg, false, DONE_LABEL, NULL, _counters);
        }

        masm.movptr(tmpReg, Address(objReg, 0)) ;          // fetch markword 
        masm.orptr (tmpReg, 0x1);
        masm.movptr(Address(boxReg, 0), tmpReg);           // Anticipate successful CAS 
        if (os::is_MP()) { masm.lock();  }
        masm.cmpxchgptr(boxReg, Address(objReg, 0));          // Updates tmpReg
        masm.jcc(Assembler::equal, DONE_LABEL);
        // Recursive locking
        masm.subptr(tmpReg, rsp);
        masm.andptr(tmpReg, (int32_t) 0xFFFFF003 );
        masm.movptr(Address(boxReg, 0), tmpReg);
        masm.bind(DONE_LABEL) ; 
    } else {  
      // Possible cases that we'll encounter in fast_lock 
      // ------------------------------------------------
      // * Inflated
      //    -- unlocked
      //    -- Locked
      //       = by self
      //       = by other
      // * biased
      //    -- by Self
      //    -- by other
      // * neutral
      // * stack-locked
      //    -- by self
      //       = sp-proximity test hits
      //       = sp-proximity test generates false-negative
      //    -- by other
      //

      Label IsInflated, DONE_LABEL, PopDone ;

      // TODO: optimize away redundant LDs of obj->mark and improve the markword triage
      // order to reduce the number of conditional branches in the most common cases.
      // Beware -- there's a subtle invariant that fetch of the markword
      // at [FETCH], below, will never observe a biased encoding (*101b).
      // If this invariant is not held we risk exclusion (safety) failure.
      if (UseBiasedLocking && !UseOptoBiasInlining) {
        masm.biased_locking_enter(boxReg, objReg, tmpReg, scrReg, false, DONE_LABEL, NULL, _counters);
      }

      masm.movptr(tmpReg, Address(objReg, 0)) ;         // [FETCH]
      masm.testptr(tmpReg, 0x02) ;                      // Inflated v (Stack-locked or neutral)
      masm.jccb  (Assembler::notZero, IsInflated) ;

      // Attempt stack-locking ...
      masm.orptr (tmpReg, 0x1);
      masm.movptr(Address(boxReg, 0), tmpReg);          // Anticipate successful CAS
      if (os::is_MP()) { masm.lock();  }
      masm.cmpxchgptr(boxReg, Address(objReg, 0));           // Updates tmpReg
      if (_counters != NULL) {
        masm.cond_inc32(Assembler::equal,
                        ExternalAddress((address)_counters->fast_path_entry_count_addr()));
      }
      masm.jccb (Assembler::equal, DONE_LABEL);

      // Recursive locking
      masm.subptr(tmpReg, rsp);
      masm.andptr(tmpReg, 0xFFFFF003 );
      masm.movptr(Address(boxReg, 0), tmpReg);
      if (_counters != NULL) {
        masm.cond_inc32(Assembler::equal,
                        ExternalAddress((address)_counters->fast_path_entry_count_addr()));
      }
      masm.jmp  (DONE_LABEL) ;

      masm.bind (IsInflated) ;

      // The object is inflated.
      //
      // TODO-FIXME: eliminate the ugly use of manifest constants:
      //   Use markOopDesc::monitor_value instead of "2".
      //   use markOop::unused_mark() instead of "3".
      // The tmpReg value is an objectMonitor reference ORed with
      // markOopDesc::monitor_value (2).   We can either convert tmpReg to an
      // objectmonitor pointer by masking off the "2" bit or we can just
      // use tmpReg as an objectmonitor pointer but bias the objectmonitor
      // field offsets with "-2" to compensate for and annul the low-order tag bit.
      //
      // I use the latter as it avoids AGI stalls.
      // As such, we write "mov r, [tmpReg+OFFSETOF(Owner)-2]"
      // instead of "mov r, [tmpReg+OFFSETOF(Owner)]".
      //
      #define OFFSET_SKEWED(f) ((ObjectMonitor::f ## _offset_in_bytes())-2)

      // boxReg refers to the on-stack BasicLock in the current frame.
      // We'd like to write:
      //   set box->_displaced_header = markOop::unused_mark().  Any non-0 value suffices.
      // This is convenient but results a ST-before-CAS penalty.  The following CAS suffers
      // additional latency as we have another ST in the store buffer that must drain.

      if (EmitSync & 8192) { 
         masm.movptr(Address(boxReg, 0), 3) ;            // results in ST-before-CAS penalty
         masm.get_thread (scrReg) ; 
         masm.movptr(boxReg, tmpReg);                    // consider: LEA box, [tmp-2] 
         masm.movptr(tmpReg, NULL_WORD);                 // consider: xor vs mov
         if (os::is_MP()) { masm.lock(); } 
         masm.cmpxchgptr(scrReg, Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2)) ; 
      } else 
      if ((EmitSync & 128) == 0) {                      // avoid ST-before-CAS
         masm.movptr(scrReg, boxReg) ; 
         masm.movptr(boxReg, tmpReg);                   // consider: LEA box, [tmp-2] 

         // Using a prefetchw helps avoid later RTS->RTO upgrades and cache probes
         if ((EmitSync & 2048) && VM_Version::supports_3dnow_prefetch() && os::is_MP()) {
            // prefetchw [eax + Offset(_owner)-2]
            masm.prefetchw(Address(rax, ObjectMonitor::owner_offset_in_bytes()-2));
         }

         if ((EmitSync & 64) == 0) {
           // Optimistic form: consider XORL tmpReg,tmpReg
           masm.movptr(tmpReg, NULL_WORD) ; 
         } else { 
           // Can suffer RTS->RTO upgrades on shared or cold $ lines
           // Test-And-CAS instead of CAS
           masm.movptr(tmpReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;   // rax, = m->_owner
           masm.testptr(tmpReg, tmpReg) ;                   // Locked ? 
           masm.jccb  (Assembler::notZero, DONE_LABEL) ;                   
         }

         // Appears unlocked - try to swing _owner from null to non-null.
         // Ideally, I'd manifest "Self" with get_thread and then attempt
         // to CAS the register containing Self into m->Owner.
         // But we don't have enough registers, so instead we can either try to CAS
         // rsp or the address of the box (in scr) into &m->owner.  If the CAS succeeds
         // we later store "Self" into m->Owner.  Transiently storing a stack address
         // (rsp or the address of the box) into  m->owner is harmless.
         // Invariant: tmpReg == 0.  tmpReg is EAX which is the implicit cmpxchg comparand.
         if (os::is_MP()) { masm.lock();  }
         masm.cmpxchgptr(scrReg, Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2)) ; 
         masm.movptr(Address(scrReg, 0), 3) ;          // box->_displaced_header = 3
         masm.jccb  (Assembler::notZero, DONE_LABEL) ; 
         masm.get_thread (scrReg) ;                    // beware: clobbers ICCs
         masm.movptr(Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2), scrReg) ; 
         masm.xorptr(boxReg, boxReg) ;                 // set icc.ZFlag = 1 to indicate success
                       
         // If the CAS fails we can either retry or pass control to the slow-path.  
         // We use the latter tactic.  
         // Pass the CAS result in the icc.ZFlag into DONE_LABEL
         // If the CAS was successful ...
         //   Self has acquired the lock
         //   Invariant: m->_recursions should already be 0, so we don't need to explicitly set it.
         // Intentional fall-through into DONE_LABEL ...
      } else {
         masm.movptr(Address(boxReg, 0), 3) ;       // results in ST-before-CAS penalty
         masm.movptr(boxReg, tmpReg) ; 

         // Using a prefetchw helps avoid later RTS->RTO upgrades and cache probes
         if ((EmitSync & 2048) && VM_Version::supports_3dnow_prefetch() && os::is_MP()) {
            // prefetchw [eax + Offset(_owner)-2]
            masm.prefetchw(Address(rax, ObjectMonitor::owner_offset_in_bytes()-2));
         }

         if ((EmitSync & 64) == 0) {
           // Optimistic form
           masm.xorptr  (tmpReg, tmpReg) ; 
         } else { 
           // Can suffer RTS->RTO upgrades on shared or cold $ lines
           masm.movptr(tmpReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;   // rax, = m->_owner
           masm.testptr(tmpReg, tmpReg) ;                   // Locked ? 
           masm.jccb  (Assembler::notZero, DONE_LABEL) ;                   
         }

         // Appears unlocked - try to swing _owner from null to non-null.
         // Use either "Self" (in scr) or rsp as thread identity in _owner.
         // Invariant: tmpReg == 0.  tmpReg is EAX which is the implicit cmpxchg comparand.
         masm.get_thread (scrReg) ;
         if (os::is_MP()) { masm.lock(); }
         masm.cmpxchgptr(scrReg, Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;

         // If the CAS fails we can either retry or pass control to the slow-path.
         // We use the latter tactic.
         // Pass the CAS result in the icc.ZFlag into DONE_LABEL
         // If the CAS was successful ...
         //   Self has acquired the lock
         //   Invariant: m->_recursions should already be 0, so we don't need to explicitly set it.
         // Intentional fall-through into DONE_LABEL ...
      }

      // DONE_LABEL is a hot target - we'd really like to place it at the
      // start of cache line by padding with NOPs.
      // See the AMD and Intel software optimization manuals for the
      // most efficient "long" NOP encodings.
      // Unfortunately none of our alignment mechanisms suffice.
      masm.bind(DONE_LABEL);

      // Avoid branch-to-branch on AMD processors
      // This appears to be superstition.
      if (EmitSync & 32) masm.nop() ;


      // At DONE_LABEL the icc ZFlag is set as follows ...
      // Fast_Unlock uses the same protocol.
      // ZFlag == 1 -> Success
      // ZFlag == 0 -> Failure - force control through the slow-path
    }
  
#line 28754 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {

#line 3276 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"


    Register objReg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register boxReg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register tmpReg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);

    guarantee (objReg != boxReg, "") ;
    guarantee (objReg != tmpReg, "") ;
    guarantee (boxReg != tmpReg, "") ;
    guarantee (boxReg == as_Register(EAX_enc), "") ;
    MacroAssembler masm(&cbuf);

    if (EmitSync & 4) {
      // Disable - inhibit all inlining.  Force control through the slow-path
      masm.cmpptr (rsp, 0) ; 
    } else 
    if (EmitSync & 8) {
      Label DONE_LABEL ;
      if (UseBiasedLocking) {
         masm.biased_locking_exit(objReg, tmpReg, DONE_LABEL);
      }
      // classic stack-locking code ...
      masm.movptr(tmpReg, Address(boxReg, 0)) ;
      masm.testptr(tmpReg, tmpReg) ;
      masm.jcc   (Assembler::zero, DONE_LABEL) ;
      if (os::is_MP()) { masm.lock(); }
      masm.cmpxchgptr(tmpReg, Address(objReg, 0));          // Uses EAX which is box
      masm.bind(DONE_LABEL);
    } else {
      Label DONE_LABEL, Stacked, CheckSucc, Inflated ;

      // Critically, the biased locking test must have precedence over
      // and appear before the (box->dhw == 0) recursive stack-lock test.
      if (UseBiasedLocking && !UseOptoBiasInlining) {
         masm.biased_locking_exit(objReg, tmpReg, DONE_LABEL);
      }
      
      masm.cmpptr(Address(boxReg, 0), 0) ;            // Examine the displaced header
      masm.movptr(tmpReg, Address(objReg, 0)) ;       // Examine the object's markword
      masm.jccb  (Assembler::zero, DONE_LABEL) ;      // 0 indicates recursive stack-lock

      masm.testptr(tmpReg, 0x02) ;                     // Inflated? 
      masm.jccb  (Assembler::zero, Stacked) ;

      masm.bind  (Inflated) ;
      // It's inflated.
      // Despite our balanced locking property we still check that m->_owner == Self
      // as java routines or native JNI code called by this thread might
      // have released the lock.
      // Refer to the comments in synchronizer.cpp for how we might encode extra
      // state in _succ so we can avoid fetching EntryList|cxq.
      //
      // I'd like to add more cases in fast_lock() and fast_unlock() --
      // such as recursive enter and exit -- but we have to be wary of
      // I$ bloat, T$ effects and BP$ effects.
      //
      // If there's no contention try a 1-0 exit.  That is, exit without
      // a costly MEMBAR or CAS.  See synchronizer.cpp for details on how
      // we detect and recover from the race that the 1-0 exit admits.
      //
      // Conceptually Fast_Unlock() must execute a STST|LDST "release" barrier
      // before it STs null into _owner, releasing the lock.  Updates
      // to data protected by the critical section must be visible before
      // we drop the lock (and thus before any other thread could acquire
      // the lock and observe the fields protected by the lock).
      // IA32's memory-model is SPO, so STs are ordered with respect to
      // each other and there's no need for an explicit barrier (fence).
      // See also http://gee.cs.oswego.edu/dl/jmm/cookbook.html.

      masm.get_thread (boxReg) ;
      if ((EmitSync & 4096) && VM_Version::supports_3dnow_prefetch() && os::is_MP()) {
        // prefetchw [ebx + Offset(_owner)-2]
        masm.prefetchw(Address(rbx, ObjectMonitor::owner_offset_in_bytes()-2));
      }

      // Note that we could employ various encoding schemes to reduce
      // the number of loads below (currently 4) to just 2 or 3.
      // Refer to the comments in synchronizer.cpp.
      // In practice the chain of fetches doesn't seem to impact performance, however.
      if ((EmitSync & 65536) == 0 && (EmitSync & 256)) {
         // Attempt to reduce branch density - AMD's branch predictor.
         masm.xorptr(boxReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;  
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::recursions_offset_in_bytes()-2)) ;
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::EntryList_offset_in_bytes()-2)) ; 
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::cxq_offset_in_bytes()-2)) ; 
         masm.jccb  (Assembler::notZero, DONE_LABEL) ; 
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), NULL_WORD) ; 
         masm.jmpb  (DONE_LABEL) ; 
      } else { 
         masm.xorptr(boxReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;  
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::recursions_offset_in_bytes()-2)) ;
         masm.jccb  (Assembler::notZero, DONE_LABEL) ; 
         masm.movptr(boxReg, Address (tmpReg, ObjectMonitor::EntryList_offset_in_bytes()-2)) ; 
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::cxq_offset_in_bytes()-2)) ; 
         masm.jccb  (Assembler::notZero, CheckSucc) ; 
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), NULL_WORD) ; 
         masm.jmpb  (DONE_LABEL) ; 
      }

      // The Following code fragment (EmitSync & 65536) improves the performance of
      // contended applications and contended synchronization microbenchmarks.
      // Unfortunately the emission of the code - even though not executed - causes regressions
      // in scimark and jetstream, evidently because of $ effects.  Replacing the code
      // with an equal number of never-executed NOPs results in the same regression.
      // We leave it off by default.

      if ((EmitSync & 65536) != 0) {
         Label LSuccess, LGoSlowPath ;

         masm.bind  (CheckSucc) ;

         // Optional pre-test ... it's safe to elide this
         if ((EmitSync & 16) == 0) { 
            masm.cmpptr(Address (tmpReg, ObjectMonitor::succ_offset_in_bytes()-2), 0) ; 
            masm.jccb  (Assembler::zero, LGoSlowPath) ; 
         }

         // We have a classic Dekker-style idiom:
         //    ST m->_owner = 0 ; MEMBAR; LD m->_succ
         // There are a number of ways to implement the barrier:
         // (1) lock:andl &m->_owner, 0
         //     is fast, but mask doesn't currently support the "ANDL M,IMM32" form.
         //     LOCK: ANDL [ebx+Offset(_Owner)-2], 0
         //     Encodes as 81 31 OFF32 IMM32 or 83 63 OFF8 IMM8
         // (2) If supported, an explicit MFENCE is appealing.
         //     In older IA32 processors MFENCE is slower than lock:add or xchg
         //     particularly if the write-buffer is full as might be the case if
         //     if stores closely precede the fence or fence-equivalent instruction.
         //     In more modern implementations MFENCE appears faster, however.
         // (3) In lieu of an explicit fence, use lock:addl to the top-of-stack
         //     The $lines underlying the top-of-stack should be in M-state.
         //     The locked add instruction is serializing, of course.
         // (4) Use xchg, which is serializing
         //     mov boxReg, 0; xchgl boxReg, [tmpReg + Offset(_owner)-2] also works
         // (5) ST m->_owner = 0 and then execute lock:orl &m->_succ, 0.
         //     The integer condition codes will tell us if succ was 0.
         //     Since _succ and _owner should reside in the same $line and
         //     we just stored into _owner, it's likely that the $line
         //     remains in M-state for the lock:orl.
         //
         // We currently use (3), although it's likely that switching to (2)
         // is correct for the future.
            
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), NULL_WORD) ; 
         if (os::is_MP()) { 
            if (VM_Version::supports_sse2() && 1 == FenceInstruction) { 
              masm.mfence();
            } else { 
              masm.lock () ; masm.addptr(Address(rsp, 0), 0) ; 
            }
         }
         // Ratify _succ remains non-null
         masm.cmpptr(Address (tmpReg, ObjectMonitor::succ_offset_in_bytes()-2), 0) ; 
         masm.jccb  (Assembler::notZero, LSuccess) ; 

         masm.xorptr(boxReg, boxReg) ;                  // box is really EAX
         if (os::is_MP()) { masm.lock(); }
         masm.cmpxchgptr(rsp, Address(tmpReg, ObjectMonitor::owner_offset_in_bytes()-2));
         masm.jccb  (Assembler::notEqual, LSuccess) ;
         // Since we're low on registers we installed rsp as a placeholding in _owner.
         // Now install Self over rsp.  This is safe as we're transitioning from
         // non-null to non=null
         masm.get_thread (boxReg) ;
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), boxReg) ;
         // Intentional fall-through into LGoSlowPath ...

         masm.bind  (LGoSlowPath) ; 
         masm.orptr(boxReg, 1) ;                      // set ICC.ZF=0 to indicate failure
         masm.jmpb  (DONE_LABEL) ; 

         masm.bind  (LSuccess) ; 
         masm.xorptr(boxReg, boxReg) ;                 // set ICC.ZF=1 to indicate success
         masm.jmpb  (DONE_LABEL) ; 
      }

      masm.bind (Stacked) ;
      // It's not inflated and it's not recursively stack-locked and it's not biased.
      // It must be stack-locked.
      // Try to reset the header to displaced header.
      // The "box" value on the stack is stable, so we can reload
      // and be assured we observe the same value as above.
      masm.movptr(tmpReg, Address(boxReg, 0)) ;
      if (os::is_MP()) {   masm.lock();    }
      masm.cmpxchgptr(tmpReg, Address(objReg, 0)); // Uses EAX which is box
      // Intention fall-thru into DONE_LABEL


      // DONE_LABEL is a hot target - we'd really like to place it at the
      // start of cache line by padding with NOPs.
      // See the AMD and Intel software optimization manuals for the
      // most efficient "long" NOP encodings.
      // Unfortunately none of our alignment mechanisms suffice.
      if ((EmitSync & 65536) == 0) {
         masm.bind (CheckSucc) ;
      }
      masm.bind(DONE_LABEL);

      // Avoid branch to branch on AMD processors
      if (EmitSync & 32768) { masm.nop() ; }
    }
  
#line 28969 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void safePoint_pollNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3671 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.relocate(cbuf.insts_mark(), relocInfo::poll_type, 0);
    emit_opcode(cbuf,0x85);
    emit_rm (cbuf, 0x0, 0x7, 0x5);
    emit_d32(cbuf, (intptr_t)os::get_polling_page());
  
#line 28987 "../generated/adfiles/ad_x86_32.cpp"
  }
}

uint safePoint_pollNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}
void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register dstReg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ get_thread(dstReg);
  
#line 29008 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 880 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ int3();
  
#line 29024 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 894 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29041 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 906 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29058 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 906 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29075 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 917 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29092 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_immNode::eval_constant(Compile* C) {
  {

#line 918 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29101 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 929 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29117 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 941 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29134 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 941 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29151 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 953 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29168 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addF_reg_immNode::eval_constant(Compile* C) {
  {

#line 954 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29177 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 965 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29193 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 977 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29210 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 977 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29227 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 988 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29244 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_immNode::eval_constant(Compile* C) {
  {

#line 989 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29253 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1000 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29269 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1012 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29286 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1012 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29303 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1024 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29320 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void addD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1025 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29329 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1036 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29345 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1048 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29362 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29379 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subF_immNode::eval_constant(Compile* C) {
  {

#line 1060 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29388 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1071 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29404 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1083 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29421 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1095 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29438 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1096 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29447 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1107 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29463 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1119 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29480 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1130 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29497 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subD_immNode::eval_constant(Compile* C) {
  {

#line 1131 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29506 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1142 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29522 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1154 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29539 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1166 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29556 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void subD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1167 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29565 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1178 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29581 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1190 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29598 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1190 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29615 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1201 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29632 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_immNode::eval_constant(Compile* C) {
  {

#line 1202 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29641 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1213 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29657 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1225 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29674 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1225 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29691 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1237 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29708 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1238 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29717 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1249 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29733 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1261 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29750 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1261 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29767 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1272 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29784 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_immNode::eval_constant(Compile* C) {
  {

#line 1273 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29793 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1284 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29809 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1296 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29826 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1296 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 29843 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1308 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29860 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void mulD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1309 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29869 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1320 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 29885 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1332 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29902 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1343 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29919 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divF_immNode::eval_constant(Compile* C) {
  {

#line 1344 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29928 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1355 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 29944 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1367 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 29961 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1379 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29978 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1380 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29987 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1391 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 30003 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 30020 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1414 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30037 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divD_immNode::eval_constant(Compile* C) {
  {

#line 1415 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 30046 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1426 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 30062 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1438 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 30079 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1450 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30096 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void divD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1451 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 30105 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1461 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ andps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(float_signmask()));
  
#line 30120 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void absF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1472 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vandps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(float_signmask()), vector256);
  
#line 30138 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1486 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ andpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(double_signmask()));
  
#line 30154 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void absD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1498 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vandpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(double_signmask()), vector256);
  
#line 30172 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1511 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(float_signflip()));
  
#line 30188 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1522 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vxorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(float_signflip()), vector256);
  
#line 30206 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1536 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(double_signflip()));
  
#line 30222 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1548 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vxorpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(double_signflip()), vector256);
  
#line 30240 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1562 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 30256 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1574 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 30272 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1585 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30288 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtF_immNode::eval_constant(Compile* C) {
  {

#line 1586 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 30297 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1597 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 30312 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1609 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 30328 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1620 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30344 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void sqrtD_immNode::eval_constant(Compile* C) {
  {

#line 1621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 30353 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1635 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 30368 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1647 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 30384 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1659 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdqu(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 30400 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void loadV32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1671 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmovdqu(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 30416 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1683 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 30433 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1694 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 30450 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1705 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdqu(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 30467 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void storeV32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1716 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmovdqu(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 30484 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 30502 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1743 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 30520 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1758 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30539 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl32BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1775 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30559 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1790 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30575 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4B_immNode::eval_constant(Compile* C) {
  {

#line 1791 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate4_imm(opnd_array(1)->constant(), 1));
#line 30584 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1800 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30599 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8B_immNode::eval_constant(Compile* C) {
  {

#line 1801 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 1));
#line 30608 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1811 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30624 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl16B_immNode::eval_constant(Compile* C) {
  {

#line 1812 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 1));
#line 30633 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl32B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1824 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30650 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl32B_immNode::eval_constant(Compile* C) {
  {

#line 1825 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 1));
#line 30659 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1837 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30674 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1847 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30690 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl16B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1857 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30706 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl32B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1867 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 30724 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1881 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 30741 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1893 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 30758 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1906 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30776 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl16SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1921 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30795 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1935 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30811 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2S_immNode::eval_constant(Compile* C) {
  {

#line 1936 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate4_imm(opnd_array(1)->constant(), 2));
#line 30820 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1945 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 30835 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4S_immNode::eval_constant(Compile* C) {
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 2));
#line 30844 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1956 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30860 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8S_immNode::eval_constant(Compile* C) {
  {

#line 1957 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 2));
#line 30869 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl16S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1969 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30886 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl16S_immNode::eval_constant(Compile* C) {
  {

#line 1970 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 2));
#line 30895 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1982 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30910 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1992 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30926 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2002 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 30942 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl16S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2012 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 30960 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 30977 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2038 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 30994 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2051 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31012 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2064 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 31028 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2I_immNode::eval_constant(Compile* C) {
  {

#line 2065 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 4));
#line 31037 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2075 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31053 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4I_immNode::eval_constant(Compile* C) {
  {

#line 2076 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 4));
#line 31062 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl8I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2088 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31079 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8I_immNode::eval_constant(Compile* C) {
  {

#line 2089 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 4));
#line 31088 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2102 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 31104 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2114 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 31121 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2127 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31139 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2I_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2140 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31155 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4I_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2150 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31171 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8I_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2160 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 31189 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 2204 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ movdl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* src */));
    __ punpckldq(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */);
    __ punpcklqdq(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */);
  
#line 31210 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 2222 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ movdl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */, HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)/* src */));
    __ punpckldq(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp */);
    __ punpcklqdq(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */);
    __ vinserti128h(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */);
  
#line 31232 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2239 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31249 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2L_immNode::eval_constant(Compile* C) {
  {

#line 2240 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 31258 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2252 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31275 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4L_immNode::eval_constant(Compile* C) {
  {

#line 2253 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 31284 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2266 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31300 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2279 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31318 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2292 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31334 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2302 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 31352 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2315 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x00);
  
#line 31368 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2325 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x00);
  
#line 31384 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2336 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x00);
    __ vinsertf128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31401 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2F_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2348 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31417 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4F_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31433 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl8F_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2368 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vxorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 31450 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2380 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x44);
  
#line 31466 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2391 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x44);
    __ vinsertf128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31483 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl2D_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 31499 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void Repl4D_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vxorpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 31516 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2429 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31533 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2439 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31551 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2450 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31568 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2460 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31586 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2471 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31603 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2481 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31621 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2492 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 31639 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2503 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31657 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2514 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 31675 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2526 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31692 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2536 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31710 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31727 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2557 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31745 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2568 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31762 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2578 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31780 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2589 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 31798 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2600 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31816 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd16S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2611 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 31834 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2623 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31851 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2633 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31869 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31886 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2654 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31904 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2665 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 31922 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2676 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31940 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2687 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 31958 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 31975 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2709 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 31993 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2720 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32011 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2731 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32029 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2742 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32047 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2754 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32064 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2764 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32082 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2775 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32099 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2785 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32117 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2796 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32135 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2807 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32153 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2818 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32171 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2830 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32188 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2840 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32206 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2851 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32224 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2862 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32242 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vadd4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2873 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32260 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2887 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32277 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2897 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32295 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2908 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32312 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2918 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32330 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2929 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32347 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2939 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32365 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32383 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2961 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32401 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2972 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32419 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2984 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32436 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2994 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32454 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3005 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32471 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3015 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32489 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3026 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32506 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3036 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32524 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3047 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32542 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3058 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32560 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub16S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3069 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32578 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3081 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32595 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3091 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32613 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3102 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32630 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3112 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32648 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3123 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32666 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3134 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32684 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3145 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32702 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3157 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32719 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3167 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32737 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3178 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32755 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3189 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32773 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3200 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32791 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3212 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32808 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3222 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32826 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32843 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3243 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32861 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3254 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32879 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3265 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32897 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3276 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32915 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3288 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 32932 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3298 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32950 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3309 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 32968 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3320 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 32986 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsub4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3331 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33004 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3345 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmullw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33021 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3355 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33039 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3366 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmullw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33056 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3376 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33074 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3387 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmullw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33091 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3397 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33109 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3408 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33127 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3419 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33145 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul16S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3430 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33163 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3442 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmulld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33180 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3452 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33198 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3463 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmulld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33215 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3473 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33233 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3484 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33251 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3495 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33269 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3506 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33287 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3518 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33304 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3528 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33322 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3539 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33339 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3549 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33357 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3560 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33375 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3571 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33393 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3582 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33411 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3594 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33428 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3604 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33446 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3615 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33464 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33482 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vmul4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3637 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33500 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3651 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33517 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3661 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33535 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3672 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33552 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3682 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33570 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3693 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33588 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3704 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33606 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3715 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33624 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3727 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33641 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3737 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33659 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3748 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33677 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3759 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 33695 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vdiv4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3770 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 33713 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vshiftcntNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 3785 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
  
#line 33729 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vshiftcnt_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 3785 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
  
#line 33745 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3798 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 33762 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3808 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 33779 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3818 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 33797 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3829 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 33815 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3840 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 33832 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3850 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 33849 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3860 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 33867 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3871 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 33885 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3882 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 33902 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3892 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 33919 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3902 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 33937 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll8S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3913 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 33955 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3924 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 33973 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll16S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3935 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 33991 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3947 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34008 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3957 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34025 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3967 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34043 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3978 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34061 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3989 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34078 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3999 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34095 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4009 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34113 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4020 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34131 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4031 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34149 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll8I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4042 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34167 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4054 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34184 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4064 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34201 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4074 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34219 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll2L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4085 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34237 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4096 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34255 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsll4L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4107 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34273 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4125 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34290 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4135 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34307 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4145 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34325 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4156 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34343 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4167 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34360 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4177 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34377 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4187 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34395 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4198 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34413 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4209 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34430 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4219 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34447 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4229 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34465 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl8S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4240 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34483 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4251 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34501 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl16S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4262 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34519 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4274 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34536 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4284 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34553 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4294 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34571 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4305 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34589 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4316 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34606 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4326 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34623 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4336 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34641 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4347 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34659 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34677 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl8I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4369 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34695 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4381 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34712 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4391 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34729 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4401 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34747 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl2L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4412 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34765 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4423 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34783 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsrl4L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4434 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34801 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4448 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34818 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34835 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4468 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34853 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4479 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34871 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4490 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34888 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4500 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34905 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4510 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34923 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4521 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 34941 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4532 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 34958 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 34975 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 34993 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra8S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4563 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 35011 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4574 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 35029 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra16S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4585 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 35047 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4597 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 35064 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4607 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 35081 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4617 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 35099 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra2I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4628 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 35117 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4639 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 35134 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4649 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 35151 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4659 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 35169 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra4I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4670 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 35187 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4681 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 35205 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vsra8I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4692 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 35223 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4708 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pand(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35240 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35258 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pand(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35275 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4739 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35293 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4750 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pand(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35310 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35328 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4771 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 35346 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4782 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35364 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vand32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4793 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 35382 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4806 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ por(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35399 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4816 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35417 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4827 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ por(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35434 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4837 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35452 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4848 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ por(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35469 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4858 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35487 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4869 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 35505 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4880 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35523 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vor32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4891 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 35541 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4904 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35558 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4914 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35576 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4925 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35593 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4935 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35611 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35628 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4956 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35646 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4967 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 35664 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4978 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35682 "../generated/adfiles/ad_x86_32.cpp"
  }
}

void vxor32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4989 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()), vector256);
  
#line 35700 "../generated/adfiles/ad_x86_32.cpp"
  }
}

const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_immI8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2UBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2SNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2USNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_65535Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLX_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLX_reg_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchr0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrT0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrT2Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchw0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAlloc0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocT0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocT2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL2INode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLX_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLX_reg_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmI16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmPNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmCMNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDPR_roundedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPR_roundedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPR_DroundedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPR_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_immNode::memory_operand() const { return _opnds[1]; }
const TypePtr *membar_acquireNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquireNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_acquire_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquire_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_releaseNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_releaseNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_release_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_release_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_storestoreNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_storestoreNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* cmovI_memNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovI_memUNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovI_memUCFNode::memory_operand() const { return _opnds[4]; }
const MachOper* addI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* incI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* decI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddINode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgINode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgPNode::memory_operand() const { return _opnds[1]; }
const MachOper* subI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* mulI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* mulINode::memory_operand() const { return _opnds[2]; }
const MachOper* mulI_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* andI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* orI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* orI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* xorI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* addL_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addL_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* subL_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andL_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andL_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orl_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* orl_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorl_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* xorl_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* cmpD_ccmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_ccmemCFNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_regmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* subDPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addDPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addDPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addDPR_mem_regNode::memory_operand() const { return _opnds[1]; }
const MachOper* addDPR_mem_reg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulDPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulDPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulDPR_reg_mem_ciscNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulDPR_reg_mem_cisc_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* cmpF_ccmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpF_ccmemCFNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpF_regmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR24_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR24_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addFPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addFPR24_mem_regNode::memory_operand() const { return _opnds[1]; }
const TypePtr *addFPR24_mem_ciscNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* addFPR24_mem_ciscNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *addFPR24_mem_cisc_0Node::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* addFPR24_mem_cisc_0Node::memory_operand() const { return (MachOper*)-1; }
const TypePtr *addFPR24_mem_memNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* addFPR24_mem_memNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* mulFPR24_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulFPR24_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulFPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulFPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const TypePtr *mulFPR24_mem_memNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* mulFPR24_mem_memNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* mulFPR_reg_load1Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulFPR_reg_load1_0Node::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_mulFPR_reg_load1Node::memory_operand() const { return _opnds[1]; }
const MachOper* addFPR_mulFPR_reg_load1_1Node::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_mulFPR_reg_load1_0Node::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_mulFPR_reg_load1_2Node::memory_operand() const { return _opnds[3]; }
const MachOper* convI2D_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2DPR_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2FPR_SSF_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2FPR_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* compI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* testI_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compU_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compP_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compP_mem_eRegNode::memory_operand() const { return _opnds[2]; }
const MachOper* testP_Reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* cmovLL_mem_LTGENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovII_mem_LTGENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovLL_mem_EQNENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovII_mem_EQNENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovLL_mem_LEGTNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovII_mem_LEGTNode::memory_operand() const { return _opnds[4]; }
const MachOper* addF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addF_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addD_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* subF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulD_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* divF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* sqrtF_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* sqrtD_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV32Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV32Node::memory_operand() const { return _opnds[1]; }
const MachOper* Repl2I_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl4I_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl8I_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl2L_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl4L_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* vadd16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd8S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd16S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd8I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd2L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub8S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub16S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub8I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub2L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul8S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul16S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul4I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul8I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vand16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vand32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vor16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vor32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vxor16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vxor32B_memNode::memory_operand() const { return _opnds[2]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // RegFlags
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    false,  // AbsI
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    true ,  // AryEq
    true ,  // AtanD
    true ,  // Binary
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastII
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    false,  // CMoveN
    false,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    false,  // CompareAndSwapN
    true ,  // GetAndAddI
    false,  // GetAndAddL
    true ,  // GetAndSetI
    false,  // GetAndSetL
    true ,  // GetAndSetP
    false,  // GetAndSetN
    false,  // Con
    false,  // ConN
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    true ,  // CosD
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    false,  // DecodeN
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    true ,  // DivModI
    false,  // DivModL
    false,  // EncodeP
    true ,  // ExpD
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // Goto
    true ,  // Halt
    true ,  // If
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    true ,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    false,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    false,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    true ,  // LogD
    true ,  // Log10D
    false,  // Loop
    true ,  // LoopLimit
    false,  // Mach
    false,  // MachProj
    true ,  // MaxI
    true ,  // MemBarAcquire
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    true ,  // ModD
    true ,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    false,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // Opaque1
    false,  // Opaque2
    true ,  // OrI
    true ,  // OrL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PowD
    true ,  // PrefetchAllocation
    true ,  // PrefetchRead
    true ,  // PrefetchWrite
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    true ,  // RoundDouble
    true ,  // RoundFloat
    true ,  // SafePoint
    false,  // SafePointScalarObject
    false,  // SCMemProj
    true ,  // SinD
    true ,  // SqrtD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    false,  // StoreN
    true ,  // StrComp
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    true ,  // TanD
    true ,  // ThreadLocal
    false,  // Unlock
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddVL
    true ,  // AddVF
    true ,  // AddVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulVF
    true ,  // MulVD
    true ,  // DivVF
    true ,  // DivVD
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    false,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    false,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    false,  // RShiftVL
    false,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // OrV
    true ,  // XorV
    true ,  // LoadVector
    true ,  // StoreVector
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    false,  // ExtractS
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false   // ExtractD
};


bool Matcher::stack_direction() const { return false; }

int Compile::sync_stack_slots() const { return 1; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 1 +
              round_to((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::in_preserve_stack_slots() { return 2+VerifyStackAtCalls; }

uint Compile::out_preserve_stack_slots() { return SharedRuntime::out_preserve_stack_slots(); }

uint Compile::varargs_C_out_slots_killed() const { return 0; }

void Matcher::calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length, bool is_outgoing) {

#line 3787 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // No difference between ingoing/outgoing just pass false
    SharedRuntime::java_calling_convention(sig_bt, regs, length, false);
  
#line 36305 "../generated/adfiles/ad_x86_32.cpp"

}

void Matcher::c_calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length) {

#line 3799 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is obviously always outgoing
    (void) SharedRuntime::c_calling_convention(sig_bt, regs, length);
  
#line 36316 "../generated/adfiles/ad_x86_32.cpp"

}

OptoRegPair Matcher::return_value(int ideal_reg, bool is_outgoing) {

#line 3821 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    assert( ideal_reg >= Op_RegI && ideal_reg <= Op_RegL, "only return normal values" );
    static int lo[Op_RegL+1] = { 0, 0, OptoReg::Bad, EAX_num,      EAX_num,      FPR1L_num,    FPR1L_num, EAX_num };
    static int hi[Op_RegL+1] = { 0, 0, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, FPR1H_num, EDX_num };
    if( ideal_reg == Op_RegD && UseSSE>=2 )
      return OptoRegPair(XMM0b_num,XMM0_num);
    if( ideal_reg == Op_RegF && UseSSE>=1 )
      return OptoRegPair(OptoReg::Bad,XMM0_num);
    return OptoRegPair(hi[ideal_reg],lo[ideal_reg]);
  
#line 36333 "../generated/adfiles/ad_x86_32.cpp"

}

OptoRegPair Matcher::c_return_value(int ideal_reg, bool is_outgoing) {

#line 3805 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    assert( ideal_reg >= Op_RegI && ideal_reg <= Op_RegL, "only return normal values" );
    static int lo[Op_RegL+1] = { 0, 0, OptoReg::Bad, EAX_num,      EAX_num,      FPR1L_num,    FPR1L_num, EAX_num };
    static int hi[Op_RegL+1] = { 0, 0, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, FPR1H_num, EDX_num };

    // in SSE2+ mode we want to keep the FPU stack clean so pretend
    // that C functions return float and double results in XMM0.
    if( ideal_reg == Op_RegD && UseSSE>=2 )
      return OptoRegPair(XMM0b_num,XMM0_num);
    if( ideal_reg == Op_RegF && UseSSE>=2 )
      return OptoRegPair(OptoReg::Bad,XMM0_num);

    return OptoRegPair(hi[ideal_reg],lo[ideal_reg]);
  
#line 36354 "../generated/adfiles/ad_x86_32.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(EAX_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_method_oop_reg() { return OptoReg::Name(EBX_num); }

int Matcher::interpreter_method_oop_reg_encode() { return _regEncode[interpreter_method_oop_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(EBP_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(ESP_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DIA32=1
#ifndef IA32
#  error "IA32 must be defined"
#endif // IA32
// Check adlc -U_LP64
#ifdef _LP64
#  error "_LP64 must not be defined"
#endif // _LP64
